

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'LATIN1';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

SET default_tablespace = '';

SET default_table_access_method = heap;


CREATE TABLE public.aliases (
    format text NOT NULL,
    alias text NOT NULL,
    name text NOT NULL
);



CREATE TABLE public.constants (
    index integer NOT NULL,
    name text NOT NULL,
    phase double precision NOT NULL,
    amp double precision NOT NULL,
    CONSTRAINT constants_amp_check CHECK ((amp >= (0.00005)::double precision)),
    CONSTRAINT constants_phase_check CHECK (((phase >= (0)::double precision) AND (phase < (360)::double precision)))
);



CREATE TABLE public.constituents (
    name text NOT NULL,
    definition text NOT NULL,
    speed double precision NOT NULL,
    CONSTRAINT constituents_speed_check CHECK ((speed > (0)::double precision))
);



CREATE TABLE public.data_sets (
    index integer NOT NULL,
    name text NOT NULL,
    station_id_context text,
    station_id text,
    lat double precision,
    lng double precision,
    timezone text NOT NULL,
    country text,
    units text NOT NULL,
    min_dir double precision,
    max_dir double precision,
    legalese text,
    notes text,
    comments text,
    source text,
    restriction text NOT NULL,
    date_imported date DEFAULT ('now'::text)::date,
    xfields text,
    meridian interval hour to minute,
    datumkind text,
    datum double precision,
    months_on_station smallint,
    last_date_on_station date,
    ref_index integer,
    min_time_add interval hour to minute,
    min_level_add double precision,
    min_level_multiply double precision,
    max_time_add interval hour to minute,
    max_level_add double precision,
    max_level_multiply double precision,
    flood_begins interval hour to minute,
    ebb_begins interval hour to minute,
    original_name text,
    state text,
    CONSTRAINT data_sets_check CHECK ((((lat IS NULL) AND (lng IS NULL)) OR ((lat IS NOT NULL) AND (lng IS NOT NULL)))),
    CONSTRAINT data_sets_check2 CHECK ((((datum IS NULL) AND (meridian IS NULL)) OR ((datum IS NOT NULL) AND (meridian IS NOT NULL)))),
    CONSTRAINT data_sets_check3 CHECK (((datum IS NOT NULL) OR (ref_index IS NOT NULL))),
    CONSTRAINT data_sets_lat_check CHECK (((lat >= ('-90'::integer)::double precision) AND (lat <= (90)::double precision))),
    CONSTRAINT data_sets_lng_check CHECK (((lng >= ('-180'::integer)::double precision) AND (lng <= (180)::double precision))),
    CONSTRAINT data_sets_max_dir_check CHECK (((max_dir >= (0)::double precision) AND (max_dir < (360)::double precision))),
    CONSTRAINT data_sets_max_level_multiply_check CHECK ((max_level_multiply > (0)::double precision)),
    CONSTRAINT data_sets_min_dir_check CHECK (((min_dir >= (0)::double precision) AND (min_dir < (360)::double precision))),
    CONSTRAINT data_sets_min_level_multiply_check CHECK ((min_level_multiply > (0)::double precision)),
    CONSTRAINT data_sets_units_check CHECK (((units = 'feet'::text) OR (units = 'meters'::text) OR (units = 'knots'::text) OR (units = 'knots^2'::text)))
);



CREATE SEQUENCE public.data_sets_index_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



ALTER SEQUENCE public.data_sets_index_seq OWNED BY public.data_sets.index;



CREATE TABLE public.data_sets_old (
    index integer,
    name text,
    station_id_context text,
    station_id text,
    lat double precision,
    lng double precision,
    timezone text,
    country text,
    units text,
    min_dir double precision,
    max_dir double precision,
    legalese text,
    notes text,
    comments text,
    source text,
    restriction text,
    date_imported date,
    xfields text,
    meridian interval hour to minute,
    datumkind text,
    datum double precision,
    months_on_station smallint,
    last_date_on_station date,
    ref_index integer,
    min_time_add interval hour to minute,
    min_level_add double precision,
    min_level_multiply double precision,
    max_time_add interval hour to minute,
    max_level_add double precision,
    max_level_multiply double precision,
    flood_begins interval hour to minute,
    ebb_begins interval hour to minute,
    original_name text,
    state text
);



CREATE VIEW public.reference_stations AS
 SELECT data_sets.index,
    data_sets.name,
    data_sets.original_name,
    data_sets.station_id_context,
    data_sets.station_id,
    data_sets.lat,
    data_sets.lng,
    data_sets.timezone,
    data_sets.country,
    data_sets.state,
    data_sets.units,
    data_sets.min_dir,
    data_sets.max_dir,
    data_sets.legalese,
    data_sets.notes,
    data_sets.comments,
    data_sets.source,
    data_sets.restriction,
    data_sets.date_imported,
    data_sets.xfields,
    data_sets.meridian,
    data_sets.datumkind,
    data_sets.datum,
    data_sets.months_on_station,
    data_sets.last_date_on_station
   FROM public.data_sets
  WHERE (data_sets.datum IS NOT NULL);



CREATE VIEW public.subordinate_stations AS
 SELECT data_sets.index,
    data_sets.name,
    data_sets.original_name,
    data_sets.station_id_context,
    data_sets.station_id,
    data_sets.lat,
    data_sets.lng,
    data_sets.timezone,
    data_sets.country,
    data_sets.state,
    data_sets.units,
    data_sets.min_dir,
    data_sets.max_dir,
    data_sets.legalese,
    data_sets.notes,
    data_sets.comments,
    data_sets.source,
    data_sets.restriction,
    data_sets.date_imported,
    data_sets.xfields,
    data_sets.ref_index,
    data_sets.min_time_add,
    data_sets.min_level_add,
    data_sets.min_level_multiply,
    data_sets.max_time_add,
    data_sets.max_level_add,
    data_sets.max_level_multiply,
    data_sets.flood_begins,
    data_sets.ebb_begins
   FROM public.data_sets
  WHERE (data_sets.datum IS NULL);



ALTER TABLE ONLY public.data_sets ALTER COLUMN index SET DEFAULT nextval('public.data_sets_index_seq'::regclass);



COPY public.aliases (format, alias, name) FROM stdin;
N	SM	MSF
N	OQ2	OQ2-HORN
N	LABDA2	LDA2
N	3MSN10	3MNS10
N	4MSN12	4MNS12
G	OQ2	OQ2-HORN
G	LAM2	LDA2
G	4MSN12	4MNS12
G	MQ3	NO3
G	3M(SK2	3MKS2
G	3M2S2	3MS2
G	2MV6	2MNU6
G	MVS2	MNUS2
GI	SA	SA-IOS
GI	MF	MF-IOS
GI	S1	S1-IOS
GI	OO1	OO1-IOS
GI	R2	R2-IOS
NOS	LAM2	LDA2
NOS	RHO	RHO1
NOS	SIGMA1	SIG1
NOS	2MLNS6	2MNLS6
NOS	2MS8	2(MS)8
NOS	2MN8	2(MN)8
NOS	M2KS2	M2(KS)2
NOS	2SNMK2	2SN(MK)2
NOS	2KMSN2	2KM(SN)2
NOS	THETA1	THE1
NOS	OO2	OQ2-HORN
NOS	RP1	PSI1
NOS	KJ2	KJ2-IHO
\.



COPY public.constants (index, name, phase, amp) FROM stdin;
16143	M2	105.6	0.31
16143	S2	82.1	0.095
16143	N2	79.8	0.071
16143	K1	282.9	0.958
16143	M4	184.9	0.057
16143	O1	275.5	0.884
16143	M6	282.2	0.01
16143	S4	167.2	0.029
16143	NU2	83.3	0.014
16143	S6	191.3	0.011
16143	2N2	54	0.009
16143	OO1	290.4	0.038
16143	LDA2	94.7	0.002
16143	M1	279.2	0.063
16143	J1	286.7	0.07
16143	RHO1	272.3	0.034
16143	Q1	271.7	0.172
16143	T2	83.1	0.006
16143	R2	81.2	0.001
16143	2Q1	268.1	0.023
16143	P1	282.4	0.317
16143	L2	79.8	0.01
16143	K2	80.2	0.026
16143	M8	38.9	0.002
16144	M2	149.2	0.753
16144	S2	165.3	0.107
16144	N2	101.7	0.107
16144	K1	215	0.25
16144	O1	234.6	0.146
16144	NU2	108.1	0.02
16144	2N2	54.3	0.014
16144	J1	205.1	0.012
16144	Q1	244.5	0.028
16144	P1	215.4	0.082
16144	L2	196.7	0.021
16144	K2	164.9	0.029
16145	M2	144.8	1.533
16145	S2	178.1	0.291
16145	N2	134.4	0.276
16145	K1	6.5	0.099
16145	M4	263.6	0.159
16145	O1	5.1	0.044
16145	M6	2.2	0.129
16145	MK3	192.5	0.009
16145	S4	34.2	0.073
16145	MN4	267.3	0.063
16145	NU2	129.6	0.108
16145	S6	165.6	0.03
16145	MU2	234	0.069
16145	2N2	166	0.036
16145	OO1	160.9	0.015
16145	LDA2	122.5	0.059
16145	M1	186.8	0.008
16145	J1	21.6	0.011
16145	RHO1	36.7	0.004
16145	Q1	83.4	0.018
16145	2Q1	120.7	0.003
16145	P1	23.3	0.046
16145	2SM2	246.4	0.019
16145	M3	153.5	0.043
16145	L2	141.6	0.106
16145	2MK3	102.3	0.03
16145	K2	173.7	0.072
16145	M8	93.6	0.038
16145	MS4	259.8	0.087
16146	M2	137	0.685
16146	S2	125.1	0.184
16146	N2	105.8	0.169
16146	K1	286.1	0.995
16146	M4	241.6	0.069
16146	O1	280.4	0.917
16146	M6	271.3	0.008
16146	MK3	333	0.053
16146	MN4	217.8	0.028
16146	NU2	106.4	0.038
16146	MU2	28.7	0.042
16146	2N2	157.9	0.086
16146	OO1	292.7	0.174
16146	LDA2	165.3	0.034
16146	S1	19.8	0.007
16146	M1	13.3	0.016
16146	J1	65.4	0.041
16146	RHO1	295.4	0.051
16146	Q1	268.1	0.21
16146	T2	142.3	0.01
16146	R2	329.4	0.006
16146	2Q1	262.8	0.052
16146	P1	283.2	0.242
16146	2SM2	111.6	0.005
16146	M3	354.9	0.012
16146	L2	212.8	0.037
16146	2MK3	317.2	0.046
16146	K2	179.7	0.165
16146	M8	30.3	0.005
16146	MS4	232.3	0.04
16148	M2	152.4	1.843
16148	S2	175.2	0.325
16148	N2	143.2	0.396
16148	K1	44.5	0.144
16148	M4	162.9	0.19
16148	O1	53	0.103
16148	M6	348.7	0.056
16148	MK3	354	0.054
16148	MN4	126.5	0.071
16148	NU2	135.2	0.069
16148	MU2	176.8	0.063
16148	2N2	130.7	0.071
16148	OO1	36	0.004
16148	LDA2	131.7	0.031
16148	S1	351.5	0.031
16148	M1	138.1	0.01
16148	J1	49.8	0.013
16148	MM	193.7	0.023
16148	SA	325.7	0.02
16148	MSF	161.2	0.014
16148	RHO1	56.6	0.004
16148	Q1	55.6	0.026
16148	T2	158.3	0.031
16148	R2	77.5	0.017
16148	2Q1	61.4	0.003
16148	P1	50.4	0.049
16148	2SM2	195.3	0.014
16148	M3	179.4	0.053
16148	L2	137.7	0.064
16148	2MK3	7.7	0.051
16148	K2	177.4	0.088
16148	M8	133.4	0.038
16148	MS4	157.7	0.06
16150	M2	301.8	2.265
16150	S2	324.5	0.592
16150	N2	289	0.457
16150	K1	48.2	0.569
16150	M4	57.9	0.154
16150	O1	47.3	0.296
16150	M6	344.5	0.079
16150	NU2	290.7	0.089
16150	2N2	276.3	0.061
16150	OO1	49.1	0.013
16150	LDA2	312.3	0.016
16150	M1	47.8	0.021
16150	J1	48.6	0.023
16150	RHO1	46.9	0.011
16150	Q1	46.7	0.058
16150	T2	324.9	0.035
16150	P1	48.8	0.188
16150	L2	314.5	0.064
16150	K2	323.9	0.161
16150	M8	49.9	0.031
16151	M2	198.3	15.689
16151	S2	220.4	2.795
16151	N2	180.5	3.231
16151	K1	19.9	0.257
16151	M4	106.6	0.567
16151	O1	36.2	0.5
16151	M6	111	0.475
16151	NU2	202.7	0.422
16151	MU2	187	0.37
16151	2N2	159.7	0.419
16151	LDA2	192	0.176
16151	M1	28.1	0.035
16151	J1	11.8	0.039
16151	SSA	7.6	0.56
16151	SA	151.2	0.387
16151	Q1	50	0.127
16151	T2	220.6	0.165
16151	P1	52.9	0.18
16151	L2	220.1	1.302
16151	K2	229	0.732
16152	M2	80.3	10.092
16152	S2	87.1	1.896
16152	N2	46.7	2.946
16152	K1	95	2.958
16152	M4	31.7	0.372
16152	O1	96.3	1.374
16152	M6	151.3	0.282
16152	NU2	48.5	0.552
16152	2N2	35.2	0.252
16152	LDA2	83.5	0.072
16152	M1	93.2	0.216
16152	J1	94.3	0.108
16152	Q1	78.4	0.216
16152	T2	87.4	0.114
16152	P1	85.8	0.972
16152	M3	167	0.24
16152	L2	278.6	0.222
16152	K2	71.3	0.486
16154	M2	8	2.461
16154	S2	148	0.041
16154	N2	294	0.477
16154	K1	191	0.508
16154	M4	352	0.353
16154	O1	186	0.214
16154	M6	261	0.185
16154	NU2	304	0.123
16154	2N2	218	0.085
16154	LDA2	73	0.017
16154	M1	189	0.016
16154	J1	193	0.017
16154	Q1	183	0.041
16154	P1	192	0.168
16154	L2	84	0.069
16154	K2	148	0.011
16154	M8	219	0.081
16157	M2	177.4	1.818
16157	S2	206.3	0.27
16157	N2	140.3	0.292
16157	K1	310.6	0.102
16157	M4	106.4	0.08
16157	O1	254.9	0.074
16157	M6	6.9	0.046
16157	NU2	145.2	0.057
16157	MU2	343.1	0.07
16157	2N2	103.1	0.039
16157	LDA2	190.8	0.013
16157	Q1	227	0.014
16157	T2	206.5	0.016
16157	P1	311	0.034
16157	L2	226.5	0.198
16157	K2	205	0.094
16159	M2	198	1.28
16159	S2	183.6	0.555
16159	N2	182.7	0.29
16159	K1	11.4	0.407
16159	M4	179.1	0.054
16159	O1	359.5	0.252
16159	NU2	184.8	0.056
16159	2N2	167.5	0.039
16159	OO1	23.3	0.011
16159	M1	5.5	0.018
16159	J1	17.4	0.02
16159	Q1	353.4	0.049
16159	T2	183.9	0.033
16159	P1	12.1	0.135
16159	L2	213.2	0.036
16159	K2	182.9	0.151
16162	M2	174	1.983
16162	S2	195.6	0.27
16162	N2	157.9	0.405
16162	K1	44.4	0.142
16162	M4	253.7	0.136
16162	O1	68.7	0.133
16162	M6	15.1	0.106
16162	MK3	77.6	0.023
16162	S4	66.3	0.016
16162	MN4	189.7	0.036
16162	NU2	110.7	0.113
16162	2N2	112.7	0.015
16162	OO1	312.3	0.019
16162	LDA2	34.5	0.039
16162	M1	101	0.017
16162	J1	94.6	0.01
16162	RHO1	79.1	0.005
16162	Q1	58.6	0.045
16162	T2	194.7	0.016
16162	R2	196.5	0.002
16162	2Q1	92.7	0.003
16162	P1	28.8	0.047
16162	2SM2	301.2	0.023
16162	M3	242.3	0.066
16162	L2	156.1	0.103
16162	K2	174.3	0.097
16162	M8	312	0.021
16162	MS4	269.9	0.036
16163	M2	212	2.008
16163	S2	229.5	0.236
16163	N2	188.2	0.401
16163	K1	80.6	0.21
16163	M4	81.4	0.131
16163	O1	103.2	0.173
16163	M6	148.9	0.114
16163	MK3	261	0.019
16163	S4	31.7	0.025
16163	MN4	81.6	0.035
16163	NU2	190.5	0.074
16163	MU2	273.3	0.026
16163	2N2	164.4	0.053
16163	OO1	32.7	0.023
16163	LDA2	253.3	0.069
16163	M1	91.9	0.012
16163	J1	56	0.012
16163	RHO1	180.9	0.021
16163	Q1	90.7	0.033
16163	T2	228.8	0.014
16163	R2	230.2	0.002
16163	2Q1	290.3	0.013
16163	P1	89.4	0.076
16163	2SM2	204.8	0.026
16163	M3	332.5	0.028
16163	L2	228.2	0.14
16163	2MK3	291.9	0.032
16163	K2	251.7	0.1
16163	M8	72.5	0.027
16163	MS4	164.5	0.039
16165	M2	337.6	1.045
16165	S2	343.9	0.368
16165	N2	333.9	0.187
16165	K1	250.7	0.611
16165	M4	14.4	0.043
16165	O1	247.1	0.515
16165	MK3	261.2	0.042
16165	S4	281	0.02
16165	MN4	21.4	0.015
16165	NU2	351.4	0.036
16165	MU2	205.2	0.04
16165	2N2	330.2	0.025
16165	OO1	254.2	0.022
16165	LDA2	42.3	0.03
16165	S1	329	0.078
16165	M1	248.9	0.037
16165	J1	248.9	0.03
16165	RHO1	245.6	0.02
16165	Q1	246.4	0.102
16165	T2	344.1	0.022
16165	R2	343.7	0.003
16165	2Q1	243.6	0.013
16165	P1	251.4	0.19
16165	2SM2	256	0.03
16165	M3	120.1	0.013
16165	L2	3.2	0.051
16165	2MK3	277.2	0.039
16165	K2	345.9	0.146
16165	MS4	0.4	0.027
16171	M2	326	0.607
16171	S2	9.6	0.064
16171	N2	302.6	0.117
16171	K1	100.8	0.199
16171	O1	123.9	0.108
16171	NU2	305.7	0.023
16171	2N2	279.2	0.016
16171	Q1	135.5	0.021
16171	P1	101.1	0.066
16171	L2	349.4	0.017
16171	K2	9.3	0.018
25446	M2	301.8	2.508
25446	S2	330.3	0.853
25446	N2	282.2	0.456
25446	K1	38.4	0.285
25446	M4	266.4	0.36
25446	O1	10.7	0.145
25446	M6	281.9	0.077
25446	S4	48.1	0.022
25446	NU2	284.8	0.088
25446	S6	128.9	0.007
25446	2N2	262.5	0.061
25446	OO1	66	0.006
25446	LDA2	315.1	0.018
25446	M1	24.5	0.01
25446	J1	52.1	0.011
25446	RHO1	358.9	0.005
25446	Q1	357	0.028
25446	T2	329.2	0.05
25446	R2	331.5	0.007
25446	2Q1	343.3	0.004
25446	P1	36.3	0.094
25446	L2	272.4	0.065
25446	K2	332.6	0.232
25446	M8	350.5	0.087
65504	M2	44.1	0.52
65504	S2	38.3	0.22
65504	N2	38.3	0.1
65504	K1	226.5	0.54
65504	O1	221.5	0.28
65504	NU2	25.2	0.02
65504	MU2	356	0.01
65504	2N2	45	0.01
65504	OO1	263.1	0.02
65504	M1	247.2	0.02
65504	J1	237.6	0.04
65504	SA	192.1	0.16
65504	RHO1	219.4	0.01
65504	Q1	215.7	0.05
65504	T2	38.2	0.02
65504	2Q1	216.4	0.01
65504	P1	223.3	0.17
65504	L2	35.1	0.01
65504	K2	34	0.06
65505	M2	48.1	0.49
65505	S2	45.3	0.19
65505	N2	35	0.1
65505	K1	230.3	0.48
65505	M4	187.3	0.01
65505	O1	221.3	0.28
65505	NU2	33.6	0.02
65505	MU2	357.4	0.01
65505	2N2	20.9	0.01
65505	OO1	255	0.02
65505	LDA2	54.8	0.01
65505	M1	241.5	0.02
65505	J1	246.3	0.03
65505	MM	19.4	0.03
65505	SA	181.1	0.17
65505	MF	49.6	0.02
65505	RHO1	217.3	0.01
65505	Q1	212.4	0.05
65505	T2	45.3	0.01
65505	P1	228	0.15
65505	L2	30.2	0.01
65505	K2	34.8	0.05
65505	MS4	206.8	0.01
65506	M2	59.4	0.56
65506	S2	54.7	0.18
65506	N2	48.8	0.11
65506	K1	226.8	0.49
65506	O1	215.9	0.27
65506	NU2	56	0.02
65506	MU2	7.8	0.01
65506	2N2	39.9	0.01
65506	OO1	251.7	0.02
65506	S1	210	0.01
65506	M1	232.5	0.02
65506	J1	238.3	0.03
65506	MM	43.4	0.02
65506	SA	177.7	0.16
65506	MF	44.3	0.02
65506	RHO1	195.4	0.01
65506	Q1	209.6	0.05
65506	T2	43.6	0.01
65506	P1	224.9	0.15
65506	L2	49.3	0.01
65506	K2	45.7	0.05
65507	M2	64.1	0.52
65507	S2	57.5	0.18
65507	N2	50.1	0.1
65507	K1	223.6	0.51
65507	M4	268.1	0.01
65507	O1	215.9	0.27
65507	NU2	52	0.02
65507	MU2	114.7	0.01
65507	2N2	35.6	0.01
65507	OO1	231.3	0.01
65507	M1	219.8	0.02
65507	J1	227.4	0.02
65507	SA	191.5	0.13
65507	MF	48.2	0.02
65507	RHO1	212.6	0.01
65507	Q1	212.1	0.05
65507	T2	57.8	0.01
65507	2Q1	208.3	0.01
65507	P1	223	0.17
65507	L2	77.8	0.01
65507	K2	57	0.05
65508	M2	64.9	0.53
65508	S2	58.4	0.18
65508	N2	50.1	0.1
65508	K1	223.7	0.51
65508	M4	286.6	0.01
65508	O1	215.5	0.27
65508	NU2	52.1	0.02
65508	MU2	115.5	0.01
65508	2N2	34.8	0.01
65508	OO1	232	0.01
65508	M1	219.7	0.02
65508	J1	227.9	0.02
65508	SA	191.5	0.13
65508	RHO1	212	0.01
65508	Q1	211.4	0.05
65508	T2	58.7	0.01
65508	2Q1	207.2	0.01
65508	P1	223.1	0.17
65508	L2	79.6	0.02
65508	K2	57.9	0.05
65509	M2	13.2	0.52
65509	S2	14	0.26
65509	N2	7.8	0.11
65509	K1	236.2	0.58
65509	M4	178.8	0.01
65509	O1	227.3	0.32
65509	NU2	10.6	0.02
65509	MU2	337.1	0.02
65509	2N2	0.2	0.02
65509	OO1	260.7	0.03
65509	LDA2	324.2	0.01
65509	M1	249.5	0.02
65509	J1	248.7	0.04
65509	MM	43.1	0.02
65509	SA	184.6	0.16
65509	MF	43.6	0.02
65509	RHO1	224	0.01
65509	Q1	220	0.06
65509	T2	7.4	0.02
65509	R2	315.5	0.01
65509	P1	234.7	0.18
65509	2SM2	238.4	0.01
65509	M3	153.1	0.01
65509	L2	3.5	0.01
65509	K2	11.1	0.08
65510	M2	55.9	0.6
65510	S2	59.6	0.22
65510	N2	44	0.11
65510	K1	227.7	0.52
65510	M4	227.3	0.01
65510	O1	216.5	0.29
65510	NU2	43.8	0.02
65510	MU2	15.1	0.02
65510	2N2	49.1	0.02
65510	OO1	243.1	0.02
65510	LDA2	61.4	0.01
65510	S1	149.9	0.01
65510	M1	227.5	0.02
65510	J1	236.8	0.03
65510	SA	181.5	0.13
65510	MF	48.2	0.02
65510	RHO1	171.7	0.01
65510	Q1	218.7	0.04
65510	T2	38.8	0.02
65510	R2	59	0.03
65510	2Q1	245.7	0.01
65510	P1	222.8	0.17
65510	L2	88.4	0.01
65510	K2	56.3	0.06
65511	M2	8	0.6
65511	S2	15.3	0.31
65511	N2	1.4	0.11
65511	K1	233.3	0.55
65511	O1	219.7	0.31
65511	NU2	4.6	0.02
65511	MU2	343.2	0.03
65511	2N2	354	0.02
65511	OO1	258.1	0.02
65511	LDA2	351.5	0.01
65511	S1	188.5	0.01
65511	M1	244.9	0.02
65511	J1	246.1	0.04
65511	MM	37.2	0.02
65511	SA	179.2	0.16
65511	MF	28.7	0.02
65511	RHO1	210	0.01
65511	Q1	210.9	0.05
65511	T2	14.6	0.02
65511	R2	63.8	0.01
65511	P1	230.1	0.17
65511	M3	134.5	0.01
65511	L2	359.5	0.02
65511	K2	9.4	0.09
65512	M2	57.6	0.65
65512	S2	64.6	0.22
65512	N2	45.8	0.13
65512	K1	226.2	0.52
65512	O1	213.4	0.29
65512	NU2	53.7	0.03
65512	MU2	16.6	0.02
65512	2N2	36.7	0.02
65512	OO1	255	0.02
65512	S1	218.7	0.01
65512	M1	230.3	0.02
65512	J1	242.4	0.03
65512	SA	174.4	0.16
65512	MF	38.8	0.02
65512	RHO1	199.4	0.01
65512	Q1	204.9	0.05
65512	T2	83.2	0.01
65512	P1	223.2	0.16
65512	L2	42.2	0.01
65512	K2	53.3	0.06
65513	M2	29	0.72
65513	S2	34.6	0.3
65513	N2	19.3	0.14
65513	K1	233.4	0.53
65513	O1	222.6	0.3
65513	NU2	27.3	0.03
65513	MU2	0.9	0.03
65513	2N2	13.3	0.02
65513	OO1	264	0.02
65513	S1	238.4	0.01
65513	M1	242.4	0.02
65513	J1	246.4	0.04
65513	MM	19.8	0.03
65513	SA	188.2	0.15
65513	MF	41.3	0.02
65513	RHO1	208.8	0.01
65513	Q1	215.2	0.05
65513	T2	33	0.01
65513	P1	231.2	0.16
65513	2SM2	221.3	0.01
65513	M3	114.7	0.01
65513	L2	12.8	0.02
65513	K2	26.6	0.09
65514	M2	100.4	0.89
65514	S2	122.1	0.34
65514	N2	99.8	0.16
65514	K1	214.8	0.27
65514	O1	223.9	0.11
65514	NU2	96.5	0.03
65514	MU2	106	0.02
65514	2N2	95.1	0.02
65514	OO1	239.1	0.01
65514	LDA2	110.4	0.01
65514	S1	250.9	0.01
65514	M1	219.3	0.01
65514	J1	223.8	0.02
65514	SA	204.3	0.18
65514	MF	30.4	0.03
65514	Q1	229.1	0.02
65514	T2	129.3	0.03
65514	P1	212.2	0.08
65514	L2	93.9	0.02
65514	K2	117.9	0.09
65514	MS4	13.8	0.01
65515	M2	91.8	0.39
65515	S2	165.5	0.07
65515	N2	54.9	0.08
65515	K1	274.7	0.25
65515	O1	279.2	0.18
65515	NU2	58.9	0.02
65515	MU2	279.7	0.01
65515	2N2	17.8	0.01
65515	OO1	282.5	0.01
65515	LDA2	134.6	0.01
65515	S1	184	0.01
65515	M1	307	0.01
65515	J1	263.5	0.01
65515	SA	232.6	0.17
65515	RHO1	265.6	0.01
65515	Q1	278.7	0.04
65515	T2	143.9	0.01
65515	R2	344.5	0.01
65515	2Q1	317.4	0.01
65515	P1	274	0.08
65515	M3	240.7	0.01
65515	L2	126.3	0.01
65515	K2	173.3	0.02
65516	M2	291.4	0.72
65516	S2	306.7	0.18
65516	N2	276.5	0.16
65516	K1	64.7	0.53
65516	M4	155	0.01
65516	O1	43.6	0.38
65516	NU2	278.3	0.03
65516	MU2	266.4	0.01
65516	2N2	245.2	0.02
65516	OO1	101.6	0.02
65516	LDA2	328.7	0.01
65516	S1	236.1	0.02
65516	M1	83.6	0.03
65516	J1	85.9	0.03
65516	MM	355.5	0.03
65516	SA	103.6	0.23
65516	MF	18	0.03
65516	RHO1	36.1	0.02
65516	Q1	36.8	0.08
65516	T2	308.4	0.02
65516	R2	68.5	0.01
65516	2Q1	27.1	0.01
65516	P1	66.4	0.18
65516	L2	319.5	0.02
65516	K2	304.4	0.05
65516	MS4	212.4	0.01
65517	M2	276.2	0.47
65517	S2	282.9	0.09
65517	N2	253.4	0.12
65517	K1	61.3	0.46
65517	M4	119.3	0.01
65517	O1	42.6	0.33
65517	MK3	325.1	0.01
65517	MN4	101.6	0.01
65517	NU2	300.4	0.02
65517	2N2	209.9	0.01
65517	OO1	95.8	0.02
65517	LDA2	295.3	0.01
65517	S1	267	0.03
65517	M1	90.5	0.02
65517	J1	90.5	0.03
65517	MF	355.2	0.04
65517	RHO1	37.3	0.01
65517	Q1	33.9	0.06
65517	T2	27.5	0.01
65517	R2	190.9	0.01
65517	P1	62.8	0.15
65517	M3	38.8	0.01
65517	K2	265.5	0.03
65517	MS4	168.3	0.01
65518	M2	296.2	0.62
65518	S2	305.3	0.14
65518	N2	278.9	0.15
65518	K1	64.9	0.55
65518	O1	45.6	0.37
65518	S4	189.7	0.01
65518	NU2	287.4	0.03
65518	MU2	283.2	0.01
65518	2N2	228.6	0.02
65518	OO1	110.6	0.02
65518	LDA2	334	0.01
65518	S1	80.4	0.02
65518	M1	59.5	0.02
65518	J1	70.9	0.04
65518	RHO1	21.4	0.02
65518	Q1	33.3	0.08
65518	T2	280.1	0.02
65518	R2	108.7	0.02
65518	2Q1	38	0.01
65518	P1	66.7	0.2
65518	M3	350.3	0.01
65518	L2	316.4	0.02
65518	K2	300.7	0.05
65518	MS4	261.6	0.01
65519	M2	180.2	1.22
65519	S2	163.8	0.2
65519	N2	161.3	0.34
65519	K1	83.5	0.13
65519	O1	66.4	0.09
65519	NU2	165.1	0.07
65519	MU2	138.3	0.06
65519	2N2	140.7	0.05
65519	LDA2	172.6	0.01
65519	M1	75	0.01
65519	J1	92	0.01
65519	MM	10.2	0.02
65519	MF	23.5	0.03
65519	Q1	47.6	0.02
65519	T2	164.6	0.01
65519	P1	71.1	0.04
65519	M3	15.8	0.01
65519	L2	186.5	0.01
65519	K2	158.2	0.06
65520	M2	128	1.53
65520	S2	148.6	0.86
65520	N2	126.9	0.29
65520	K1	65.9	0.33
65520	O1	39.6	0.21
65520	NU2	126.1	0.05
65520	MU2	129.5	0.05
65520	2N2	119	0.04
65520	OO1	126.6	0.01
65520	LDA2	122.3	0.01
65520	S1	249.8	0.02
65520	M1	84.2	0.01
65520	J1	87.5	0.02
65520	MM	15.7	0.03
65520	SA	48.8	0.15
65520	MF	16.5	0.04
65520	RHO1	29.2	0.01
65520	Q1	26	0.04
65520	T2	138.3	0.06
65520	R2	114.6	0.01
65520	2Q1	352.7	0.01
65520	P1	67	0.1
65520	M3	320.4	0.01
65520	L2	125	0.05
65520	K2	144.9	0.24
65521	M2	129.2	0.24
65521	S2	147.5	0.34
65521	N2	185	0.05
65521	K1	64.8	0.62
65521	O1	44	0.39
65521	NU2	177.4	0.01
65521	MU2	133.4	0.02
65521	2N2	240.7	0.01
65521	OO1	85.6	0.02
65521	S1	253	0.01
65521	M1	54.4	0.03
65521	J1	81.2	0.04
65521	SSA	25.7	0.1
65521	SA	62.6	0.11
65521	MF	16.7	0.04
65521	RHO1	35.1	0.01
65521	Q1	34.2	0.08
65521	T2	147.5	0.02
65521	2Q1	23.2	0.01
65521	P1	64.2	0.2
65521	M3	30.6	0.01
65521	L2	73.6	0.01
65521	K2	143.2	0.1
65522	M2	115.5	0.91
65522	S2	149.5	0.46
65522	N2	105.8	0.15
65522	K1	44.5	0.2
65522	O1	14.8	0.16
65522	NU2	106.2	0.03
65522	MU2	128.6	0.02
65522	2N2	100.4	0.02
65522	OO1	134	0.01
65522	LDA2	103.5	0.01
65522	S1	279.5	0.01
65522	M1	63.3	0.01
65522	J1	80.5	0.01
65522	SA	167.2	0.11
65522	MF	38	0.02
65522	RHO1	5.6	0.01
65522	Q1	5.8	0.04
65522	T2	144.8	0.03
65522	2Q1	340.1	0.01
65522	P1	40.7	0.07
65522	M3	308.5	0.01
65522	L2	127.6	0.03
65522	K2	146.6	0.12
65523	M2	98.7	8.82
65523	S2	139.3	1.38
65523	N2	69.4	1.78
65523	K1	196.4	0.51
65523	M4	86.5	0.2
65523	O1	176.9	0.39
65523	M6	277.2	0.17
65523	MN4	55.8	0.08
65523	NU2	73.5	0.41
65523	MU2	163.9	0.07
65523	2N2	46.5	0.21
65523	OO1	230.6	0.02
65523	LDA2	122.8	0.17
65523	S1	110.2	0.03
65523	M1	206.8	0.02
65523	J1	208.6	0.03
65523	SSA	127.6	0.05
65523	RHO1	154	0.01
65523	Q1	163	0.07
65523	T2	115.8	0.12
65523	R2	356.5	0.03
65523	2Q1	157.5	0.01
65523	P1	195.5	0.17
65523	2SM2	83.9	0.02
65523	L2	134.5	0.44
65523	2MK3	331.6	0.02
65523	K2	138.3	0.38
65523	M8	253.7	0.02
65523	MS4	131.9	0.06
65524	M2	117.3	7.93
65524	S2	161.4	1.18
65524	N2	94.6	1.57
65524	K1	216.1	0.48
65524	M4	136.2	0.26
65524	O1	192.3	0.37
65524	M6	339.7	0.33
65524	S4	314.6	0.01
65524	NU2	97.6	0.31
65524	S6	251.2	0.01
65524	MU2	299	0.19
65524	2N2	71.8	0.21
65524	OO1	240.1	0.02
65524	LDA2	137.8	0.06
65524	M1	204.3	0.03
65524	J1	228	0.03
65524	SSA	127.6	0.05
65524	RHO1	182	0.01
65524	Q1	180.4	0.07
65524	T2	159.7	0.07
65524	R2	163.2	0.01
65524	2Q1	168.5	0.01
65524	P1	214.3	0.16
65524	L2	140	0.22
65524	K2	165	0.32
65524	M8	329.7	0.04
65525	M2	106.7	8.97
65525	S2	147	1.46
65525	N2	83.8	1.85
65525	K1	202	0.53
65525	M4	97.3	0.25
65525	O1	180.3	0.4
65525	M6	311.4	0.27
65525	S4	271.8	0.01
65525	NU2	86.9	0.36
65525	S6	205.5	0.01
65525	MU2	292	0.22
65525	2N2	61	0.25
65525	OO1	223.6	0.02
65525	LDA2	125.4	0.06
65525	M1	191.2	0.03
65525	J1	212.7	0.03
65525	SSA	127.6	0.05
65525	RHO1	170.9	0.02
65525	Q1	169.5	0.08
65525	T2	145.4	0.09
65525	R2	148.6	0.01
65525	2Q1	158.7	0.01
65525	P1	200.3	0.17
65525	L2	129.5	0.25
65525	K2	150.3	0.4
65525	M8	306.8	0.04
65526	M2	105.1	9.13
65526	S2	147.6	1.4
65526	N2	75.9	1.95
65526	K1	199.7	0.51
65526	M4	111.4	0.27
65526	O1	178.9	0.39
65526	M6	282	0.33
65526	MN4	81	0.11
65526	NU2	85.8	0.44
65526	MU2	172.8	0.12
65526	2N2	78.3	0.21
65526	OO1	238.9	0.03
65526	LDA2	125.8	0.17
65526	S1	160	0.03
65526	M1	191.6	0.03
65526	J1	221.1	0.03
65526	SSA	127.6	0.05
65526	Q1	170.4	0.06
65526	T2	126.5	0.13
65526	2Q1	165	0.01
65526	P1	199.4	0.15
65526	2SM2	48.5	0.02
65526	L2	145.2	0.74
65526	K2	148.5	0.41
65526	M8	294	0.06
65526	MS4	162	0.08
65527	M2	135.5	7.88
65527	S2	185.6	1.13
65527	N2	110.5	1.57
65527	K1	226.1	0.45
65527	M4	182.1	0.44
65527	O1	204.8	0.35
65527	M6	24.4	0.46
65527	MK3	244.7	0.04
65527	S4	284.2	0.01
65527	MN4	156.2	0.19
65527	NU2	111.6	0.39
65527	MU2	216.9	0.28
65527	2N2	133.9	0.19
65527	OO1	267.3	0.02
65527	LDA2	143.1	0.17
65527	S1	150	0.03
65527	M1	223.3	0.03
65527	J1	262.5	0.03
65527	SSA	127.6	0.05
65527	RHO1	154.8	0.01
65527	Q1	199.3	0.05
65527	T2	162	0.11
65527	R2	0.8	0.03
65527	2Q1	204.4	0.02
65527	P1	227.4	0.14
65527	2SM2	65.9	0.02
65527	M3	156.2	0.01
65527	L2	160.5	0.86
65527	2MK3	222.3	0.04
65527	K2	185.4	0.32
65527	M8	62.7	0.1
65527	MS4	232	0.12
65528	M2	93.7	6.62
65528	S2	131.7	1.02
65528	N2	62.6	1.35
65528	K1	192.3	0.48
65528	M4	157.3	0.06
65528	O1	173.6	0.37
65528	M6	230.8	0.04
65528	MK3	326.7	0.01
65528	MN4	142.9	0.02
65528	NU2	69.2	0.32
65528	MU2	129.1	0.01
65528	2N2	39.5	0.14
65528	OO1	216.1	0.03
65528	LDA2	125.5	0.12
65528	S1	169.1	0.02
65528	M1	214.5	0.02
65528	J1	199.1	0.02
65528	SSA	127.6	0.05
65528	RHO1	192.3	0.02
65528	Q1	158.3	0.06
65528	T2	110	0.09
65528	R2	348.6	0.03
65528	P1	193.2	0.15
65528	2SM2	57.2	0.02
65528	L2	142.5	0.35
65528	2MK3	294.6	0.02
65528	K2	131.1	0.28
65528	MS4	215.8	0.02
65529	M2	92.9	6.11
65529	S2	129.8	0.94
65529	N2	62.8	1.29
65529	K1	193.7	0.46
65529	M4	108.5	0.04
65529	O1	173.5	0.36
65529	M6	255.3	0.03
65529	MN4	81.5	0.01
65529	NU2	69.4	0.28
65529	2N2	40.9	0.16
65529	OO1	228.5	0.02
65529	LDA2	124.2	0.11
65529	S1	158.8	0.02
65529	M1	205.9	0.02
65529	J1	204.8	0.03
65529	RHO1	142.2	0.01
65529	Q1	159.2	0.06
65529	T2	103.7	0.09
65529	R2	329.9	0.03
65529	2Q1	153.4	0.01
65529	P1	193.1	0.16
65529	2SM2	77.7	0.02
65529	L2	136	0.28
65529	2MK3	295.9	0.02
65529	K2	128.7	0.26
65529	MS4	186.4	0.01
65530	M2	98.2	5.35
65530	S2	138.4	0.73
65530	N2	64.8	1.08
65530	K1	192.8	0.48
65530	M4	106.5	0.28
65530	O1	180.1	0.4
65530	M6	356.5	0.05
65530	NU2	69.3	0.21
65530	S6	59.7	0.01
65530	MU2	282.2	0.13
65530	2N2	31.5	0.14
65530	OO1	205.5	0.02
65530	LDA2	116.9	0.04
65530	M1	186.5	0.03
65530	J1	199.1	0.03
65530	RHO1	174.7	0.02
65530	Q1	173.8	0.08
65530	T2	136.8	0.04
65530	R2	140	0.01
65530	2Q1	167.5	0.01
65530	P1	191.9	0.16
65530	L2	131.6	0.15
65530	K2	141.7	0.2
65530	M8	162.2	0.03
65531	M2	91.9	5.16
65531	S2	128.1	0.78
65531	N2	61.4	1.14
65531	K1	193.8	0.46
65531	M4	92.8	0.03
65531	O1	174.4	0.36
65531	M6	48.3	0.04
65531	MN4	42.9	0.01
65531	NU2	67.6	0.25
65531	MU2	42.8	0.03
65531	2N2	37.1	0.14
65531	OO1	231.5	0.02
65531	LDA2	125.3	0.09
65531	S1	160.4	0.03
65531	M1	210	0.02
65531	J1	196.8	0.03
65531	SSA	133.7	0.04
65531	SA	135.8	0.1
65531	MSF	86.4	0.04
65531	RHO1	143	0.01
65531	Q1	155.2	0.07
65531	T2	107.7	0.07
65531	R2	335.2	0.02
65531	2Q1	174.5	0.01
65531	P1	190.6	0.16
65531	2SM2	68.4	0.01
65531	L2	135.4	0.26
65531	2MK3	259.9	0.01
65531	K2	128.7	0.21
65531	MS4	167	0.01
65532	M2	99.1	5.25
65532	S2	140.2	0.75
65532	N2	67.2	1.15
65532	K1	197.8	0.52
65532	M4	80.9	0.11
65532	O1	178.3	0.39
65532	M6	100.6	0.11
65532	NU2	71.4	0.22
65532	S6	98.6	0.01
65532	MU2	281.2	0.12
65532	2N2	35.2	0.15
65532	OO1	216.8	0.02
65532	LDA2	118.1	0.04
65532	M1	188	0.03
65532	J1	207	0.03
65532	RHO1	170	0.02
65532	Q1	168.7	0.08
65532	T2	138.5	0.04
65532	R2	141.8	0.01
65532	2Q1	159.1	0.01
65532	P1	196.3	0.17
65532	L2	131	0.15
65532	K2	143.5	0.2
65532	M8	105.1	0.05
65533	M2	95.6	5.05
65533	S2	132.1	0.73
65533	N2	71.2	1.13
65533	K1	199.2	0.52
65533	M4	74.3	0.04
65533	O1	174.9	0.35
65533	M6	81	0.08
65533	NU2	74.4	0.22
65533	MU2	142.4	0.12
65533	2N2	46.7	0.15
65533	OO1	223.5	0.02
65533	LDA2	112.6	0.04
65533	M1	187.1	0.03
65533	J1	211.3	0.03
65533	RHO1	164.5	0.01
65533	Q1	162.8	0.07
65533	T2	130.7	0.04
65533	R2	133.6	0.01
65533	2Q1	150.8	0.01
65533	P1	197.4	0.17
65533	L2	120	0.14
65533	K2	135.1	0.2
65533	M8	70.1	0.02
65534	M2	94.6	4.98
65534	S2	145.8	0.76
65534	N2	62.5	1.12
65534	K1	191.9	0.43
65534	M4	53.6	0.02
65534	O1	176.6	0.37
65534	M6	82.4	0.08
65534	MK3	237.1	0.01
65534	MN4	339.8	0.01
65534	NU2	69.9	0.23
65534	MU2	7.8	0.01
65534	2N2	57.1	0.11
65534	OO1	223.2	0.02
65534	LDA2	113.8	0.08
65534	S1	227.1	0.06
65534	M1	188.6	0.02
65534	J1	203.8	0.03
65534	Q1	166.5	0.06
65534	T2	192.7	0.07
65534	R2	25.7	0.22
65534	2Q1	165.1	0.01
65534	P1	181.2	0.13
65534	2SM2	69.3	0.02
65534	M3	155.3	0.01
65534	L2	151	0.34
65534	2MK3	232.6	0.01
65534	K2	109.6	0.24
65534	M8	122.3	0.01
65534	MS4	180.5	0.01
65535	M2	112.6	6
65535	S2	150.7	0.86
65535	N2	74.9	1.24
65535	K1	206.6	0.48
65535	M4	114.9	0.44
65535	O1	190.4	0.37
65535	M6	246.3	0.65
65535	S4	100.7	0.03
65535	NU2	79.9	0.24
65535	S6	250.8	0.04
65535	MU2	296.9	0.14
65535	2N2	37.2	0.16
65535	OO1	222.9	0.02
65535	LDA2	130.3	0.04
65535	M1	198.6	0.03
65535	J1	214.7	0.03
65535	RHO1	183.4	0.01
65535	Q1	182.3	0.07
65535	T2	149.2	0.05
65535	R2	152.3	0.01
65535	2Q1	174.3	0.01
65535	P1	205.4	0.16
65535	L2	150.2	0.17
65535	K2	153.8	0.24
65535	M8	303.5	0.09
65536	M2	98.2	5.21
65536	S2	134.5	0.74
65536	N2	63.5	1.16
65536	K1	195.9	0.49
65536	M4	58.2	0.04
65536	O1	177.9	0.37
65536	M6	118.1	0.17
65536	NU2	68.1	0.23
65536	S6	76.1	0.02
65536	MU2	284.1	0.12
65536	2N2	28.8	0.15
65536	OO1	214	0.02
65536	LDA2	115.1	0.04
65536	M1	187	0.03
65536	J1	204.9	0.03
65536	SSA	105.8	0.07
65536	SA	128.3	0.1
65536	RHO1	170.2	0.01
65536	Q1	168.9	0.07
65536	T2	133	0.04
65536	R2	135.9	0.01
65536	2Q1	160	0.01
65536	P1	194.6	0.16
65536	L2	132.8	0.15
65536	K2	137.4	0.2
65536	M8	163.6	0.02
65537	M2	98.2	4.9
65537	S2	134.1	0.72
65537	N2	65.9	1.12
65537	K1	197.7	0.46
65537	M4	50.7	0.03
65537	O1	178.6	0.36
65537	M6	99.8	0.12
65537	S4	237.9	0.01
65537	NU2	70.3	0.22
65537	MU2	62.3	0.12
65537	2N2	33.7	0.15
65537	OO1	216.7	0.02
65537	LDA2	114.8	0.03
65537	M1	188.2	0.03
65537	J1	207.1	0.03
65537	RHO1	170.4	0.01
65537	Q1	169.2	0.07
65537	T2	132.6	0.04
65537	R2	135.5	0.01
65537	2Q1	159.7	0.01
65537	P1	196.2	0.15
65537	L2	130.4	0.14
65537	K2	137	0.19
65537	M8	164.8	0.01
65538	M2	97.9	4.92
65538	S2	133.2	0.64
65538	N2	65.3	1.08
65538	K1	201.2	0.5
65538	O1	170.3	0.39
65538	M6	98.2	0.11
65538	NU2	69.6	0.21
65538	2N2	32.7	0.14
65538	OO1	231.9	0.02
65538	LDA2	114.1	0.03
65538	M1	185.6	0.03
65538	J1	216.6	0.03
65538	RHO1	157	0.02
65538	Q1	154.8	0.08
65538	T2	133.1	0.04
65538	2Q1	139.4	0.01
65538	P1	201.1	0.17
65538	L2	130.4	0.14
65538	K2	133.2	0.17
65538	M8	186.9	0.03
65539	M2	101.3	4.55
65539	S2	139.2	0.64
65539	N2	72.3	1.02
65539	K1	186.3	0.46
65539	M4	347	0.02
65539	O1	184.6	0.36
65539	M6	119.2	0.11
65539	S4	0.9	0.01
65539	NU2	76.2	0.2
65539	S6	9.5	0.01
65539	MU2	285	0.11
65539	2N2	43.4	0.13
65539	OO1	184.5	0.01
65539	LDA2	118.9	0.03
65539	M1	184.7	0.03
65539	J1	184.8	0.03
65539	RHO1	184.5	0.01
65539	Q1	184.5	0.07
65539	T2	137.7	0.04
65539	R2	140.8	0.01
65539	2Q1	184.5	0.01
65539	P1	186.1	0.15
65539	L2	130.3	0.13
65539	K2	142.3	0.17
65539	M8	99.5	0.02
65540	M2	106.4	4.45
65540	S2	143.6	0.68
65540	N2	78.2	0.96
65540	K1	205.7	0.47
65540	M4	97.9	0.06
65540	O1	184.7	0.36
65540	M6	270.8	0.06
65540	MK3	215.2	0.02
65540	MN4	71.2	0.03
65540	NU2	87	0.21
65540	S6	196.1	0.01
65540	MU2	112.9	0.01
65540	2N2	71.7	0.13
65540	OO1	233	0.01
65540	LDA2	133.6	0.07
65540	S1	116.5	0.02
65540	J1	199.7	0.03
65540	MM	19.7	0.06
65540	SSA	239	0.01
65540	SA	125.7	0.05
65540	RHO1	186.7	0.02
65540	Q1	157.6	0.07
65540	T2	114.9	0.06
65540	2Q1	263.1	0.01
65540	P1	204.5	0.16
65540	2SM2	106.5	0.01
65540	L2	146.3	0.15
65540	2MK3	196.1	0.02
65540	K2	142.3	0.19
65540	M8	262.1	0.01
65540	MS4	136.1	0.02
65541	M2	105.8	4.7
65541	S2	146	0.69
65541	N2	71.6	1.01
65541	K1	201.4	0.48
65541	M4	309.9	0.07
65541	O1	186.2	0.36
65541	M6	218.6	0.01
65541	NU2	76.1	0.19
65541	MU2	65.5	0.11
65541	2N2	37.3	0.13
65541	OO1	216.4	0.01
65541	LDA2	124.5	0.03
65541	M1	193.9	0.02
65541	J1	208.8	0.03
65541	SSA	105.8	0.07
65541	SA	128.3	0.1
65541	RHO1	179.8	0.01
65541	Q1	178.8	0.07
65541	T2	144.3	0.04
65541	R2	147.7	0.01
65541	2Q1	171.4	0.01
65541	P1	200.2	0.16
65541	L2	140.1	0.13
65541	K2	149.3	0.18
65541	M8	118	0.02
65542	M2	118.1	4.35
65542	S2	165.1	0.61
65542	N2	82.5	0.88
65542	K1	211.5	0.48
65542	M4	103	0.06
65542	O1	196.3	0.31
65542	M6	322.2	0.12
65542	S4	203.1	0.01
65542	NU2	87.3	0.17
65542	S6	350.3	0.01
65542	MU2	71.1	0.1
65542	2N2	46.9	0.12
65542	OO1	226.6	0.01
65542	LDA2	139.9	0.03
65542	M1	204	0.02
65542	J1	219	0.03
65542	SSA	105.8	0.07
65542	SA	128.3	0.1
65542	RHO1	189.9	0.01
65542	Q1	188.8	0.06
65542	T2	163.2	0.04
65542	2Q1	181.3	0.01
65542	P1	210.3	0.16
65542	L2	153.7	0.12
65542	K2	168.9	0.17
65542	M8	259.6	0.03
65543	M2	209.8	2.61
65543	S2	259.8	0.29
65543	N2	179.7	0.53
65543	K1	283.9	0.34
65543	M4	317.9	0.22
65543	O1	262.5	0.26
65543	M6	290.2	0.16
65543	S4	14	0.02
65543	NU2	183.8	0.1
65543	S6	64.4	0.01
65543	MU2	20.2	0.06
65543	2N2	149.7	0.07
65543	OO1	305.2	0.01
65543	LDA2	233	0.02
65543	M1	273.3	0.02
65543	J1	294.5	0.02
65543	RHO1	253.3	0.01
65543	Q1	251.9	0.05
65543	T2	257.8	0.02
65543	2Q1	241.3	0.01
65543	P1	282.3	0.11
65543	L2	239.8	0.07
65543	K2	263.9	0.08
65543	M8	52.8	0.04
65544	M2	221	0.915
65544	S2	306.2	0.125
65544	N2	181.2	0.187
65544	K1	268.4	0.141
65544	M4	55.7	0.272
65544	O1	277.5	0.213
65544	M6	243.6	0.062
65544	S4	108.7	0.01
65544	NU2	186.6	0.036
65544	S6	27.4	0.003
65544	MU2	133.3	0.02
65544	2N2	141.9	0.023
65544	OO1	253.5	0.01
65544	LDA2	262.7	0.007
65544	M1	271.6	0.016
65544	J1	259.4	0.016
65544	RHO1	281.4	0.007
65544	Q1	283.4	0.039
65544	T2	301.9	0.007
65544	2Q1	290.4	0.003
65544	P1	269.4	0.046
65544	L2	260.2	0.026
65544	K2	314	0.033
65544	M8	120	0.013
65545	M2	104.8	4.18
65545	S2	137.6	0.62
65545	N2	73.4	0.98
65545	K1	206.4	0.47
65545	M4	292.2	0.04
65545	O1	188.4	0.36
65545	M6	357	0.02
65545	NU2	77.6	0.19
65545	MU2	292.4	0.1
65545	2N2	42	0.13
65545	OO1	224.5	0.02
65545	LDA2	120	0.03
65545	M1	197.5	0.03
65545	J1	215.4	0.03
65545	RHO1	180.7	0.01
65545	Q1	179.5	0.07
65545	T2	136.3	0.04
65545	R2	139	0.01
65545	2Q1	170.5	0.01
65545	P1	205.1	0.15
65545	L2	136.2	0.12
65545	K2	140.3	0.17
65545	M8	134.9	0.01
65546	M2	190.2	2.45
65546	S2	232.7	0.29
65546	N2	158.4	0.49
65546	K1	271.6	0.32
65546	M4	231.1	0.09
65546	O1	250.9	0.26
65546	M6	204.4	0.12
65546	S4	317.5	0.02
65546	NU2	162.7	0.1
65546	MU2	8.1	0.06
65546	2N2	126.7	0.07
65546	OO1	292.4	0.01
65546	LDA2	209.9	0.02
65546	M1	261.3	0.02
65546	J1	281.9	0.02
65546	RHO1	242	0.01
65546	Q1	240.6	0.05
65546	T2	231	0.02
65546	2Q1	230.3	0.01
65546	P1	270.1	0.11
65546	L2	222	0.07
65546	K2	236.1	0.08
65546	M8	273.3	0.02
65547	M2	130.1	3.52
65547	S2	166.3	0.5
65547	N2	96	0.72
65547	K1	219.5	0.41
65547	M4	120	0.1
65547	O1	204.6	0.31
65547	M6	324.4	0.02
65547	S4	227.2	0.01
65547	NU2	100.6	0.14
65547	MU2	314.2	0.09
65547	2N2	61.9	0.1
65547	OO1	234.3	0.01
65547	LDA2	146.9	0.02
65547	M1	212	0.02
65547	J1	226.8	0.02
65547	RHO1	198.2	0.01
65547	Q1	197.2	0.06
65547	T2	164.9	0.03
65547	2Q1	189.8	0.01
65547	P1	218.3	0.13
65547	L2	164.1	0.1
65547	K2	169.2	0.13
65547	M8	121.6	0.02
65548	M2	102.2	4.51
65548	S2	139.1	0.68
65548	N2	70.5	0.98
65548	K1	201.4	0.47
65548	M4	5.8	0.04
65548	O1	182	0.37
65548	M6	123.2	0.05
65548	MK3	232.3	0.01
65548	MN4	350.1	0.02
65548	NU2	77.1	0.22
65548	S6	160.9	0.01
65548	MU2	37.9	0.04
65548	2N2	47.4	0.13
65548	OO1	223.4	0.02
65548	LDA2	137.4	0.07
65548	S1	206.4	0.03
65548	M1	224.4	0.01
65548	J1	214	0.03
65548	SSA	108	0.05
65548	SA	136.2	0.1
65548	RHO1	175.3	0.01
65548	Q1	164	0.06
65548	T2	111.5	0.07
65548	R2	348.3	0.01
65548	P1	200.1	0.16
65548	2SM2	88.9	0.01
65548	L2	155.3	0.2
65548	2MK3	217.7	0.02
65548	K2	137.6	0.19
65548	M8	129.4	0.01
65548	MS4	52.6	0.01
65549	M2	109.1	4.21
65549	S2	147.5	0.57
65549	N2	81.5	0.93
65549	K1	208.8	0.46
65549	M4	128.7	0.07
65549	O1	188.8	0.35
65549	M6	306.4	0.03
65549	S4	215.1	0.01
65549	NU2	85.2	0.18
65549	MU2	290	0.1
65549	2N2	53.9	0.12
65549	OO1	228.6	0.02
65549	LDA2	126.9	0.03
65549	M1	198.8	0.03
65549	J1	218.6	0.03
65549	RHO1	180.2	0.01
65549	Q1	178.9	0.07
65549	T2	146	0.03
65549	2Q1	169.1	0.01
65549	P1	207.3	0.15
65549	L2	136.7	0.12
65549	K2	150.6	0.16
65549	M8	255.2	0.02
65550	M2	105.3	4.28
65550	S2	143.1	0.63
65550	N2	73.5	0.98
65550	K1	204.1	0.48
65550	M4	116.1	0.05
65550	O1	183.6	0.37
65550	M6	96.2	0.02
65550	S4	200.3	0.01
65550	NU2	77.8	0.19
65550	MU2	286.8	0.1
65550	2N2	41.7	0.13
65550	OO1	224.4	0.02
65550	LDA2	122.8	0.03
65550	M1	193.9	0.03
65550	J1	214.1	0.03
65550	RHO1	174.9	0.01
65550	Q1	173.5	0.07
65550	T2	141.6	0.04
65550	R2	144.6	0.01
65550	2Q1	163.4	0.01
65550	P1	202.5	0.16
65550	L2	137.1	0.12
65550	K2	146.2	0.17
65550	M8	249.4	0.01
65551	M2	112.1	4.31
65551	S2	161	1.26
65551	N2	79.6	1.01
65551	K1	209.1	0.46
65551	M4	99.9	0.1
65551	O1	188.7	0.37
65551	M6	135.8	0.03
65551	MK3	247.1	0.03
65551	S4	200.5	0.01
65551	MN4	54.2	0.06
65551	NU2	87.8	0.21
65551	MU2	357.6	0.02
65551	2N2	62.4	0.19
65551	OO1	256.7	0.01
65551	LDA2	157.7	0.08
65551	S1	100.1	0.03
65551	M1	186.2	0.03
65551	J1	215.5	0.04
65551	SSA	105.8	0.07
65551	SA	128.3	1.05
65551	RHO1	179.5	0.03
65551	Q1	173.8	0.07
65551	T2	116.4	0.3
65551	R2	46.1	0.67
65551	2Q1	226.5	0.01
65551	P1	195.4	0.15
65551	2SM2	57.9	0.01
65551	M3	136.5	0.02
65551	L2	168.4	0.21
65551	2MK3	218.1	0.04
65551	K2	144.7	0.44
65551	M8	295.7	0.02
65551	MS4	153	0.05
65552	M2	106.5	4.24
65552	S2	130.1	0.79
65552	N2	72.9	0.98
65552	K1	206.8	0.5
65552	M4	352.6	0.05
65552	O1	184.1	0.36
65552	M6	225.4	0.02
65552	MK3	248.1	0.02
65552	MN4	329.5	0.03
65552	NU2	78.9	0.19
65552	MU2	30.3	0.03
65552	2N2	57.1	0.18
65552	OO1	245.4	0.02
65552	LDA2	155.4	0.06
65552	S1	354.1	0.08
65552	M1	178.5	0.03
65552	J1	210.1	0.04
65552	SSA	105.8	0.07
65552	SA	128.3	0.1
65552	RHO1	177.8	0.01
65552	Q1	172	0.07
65552	T2	71.4	0.1
65552	R2	318.1	0.2
65552	2Q1	204.2	0.02
65552	P1	181.1	0.15
65552	2SM2	142.2	0.01
65552	M3	124.1	0.02
65552	L2	162.3	0.2
65552	2MK3	208.9	0.02
65552	K2	122.1	0.19
65552	M8	108.9	0.01
65552	MS4	43.9	0.02
65553	M2	105.3	4.36
65553	S2	141.7	0.67
65553	N2	71.4	0.96
65553	K1	203.7	0.45
65553	M4	328.9	0.08
65553	O1	186.5	0.36
65553	M6	193.7	0.03
65553	MN4	301.7	0.03
65553	NU2	82.6	0.22
65553	MU2	37.2	0.03
65553	2N2	35.9	0.17
65553	OO1	256.1	0.02
65553	LDA2	145	0.07
65553	S1	122.3	0.02
65553	M1	193.9	0.01
65553	J1	207.5	0.02
65553	SSA	105.8	0.07
65553	SA	128.3	0.1
65553	RHO1	183.6	0.02
65553	Q1	182.7	0.07
65553	T2	114	0.06
65553	R2	16	0.02
65553	2Q1	117.3	0.02
65553	P1	203.1	0.16
65553	2SM2	129.9	0.01
65553	M3	100	0.01
65553	L2	150.1	0.19
65553	2MK3	209.8	0.01
65553	K2	139.3	0.18
65553	M8	43.3	0.01
65553	MS4	9.6	0.03
65554	M2	111.6	3.93
65554	S2	143.2	0.63
65554	N2	80.4	0.79
65554	K1	208.4	0.41
65554	M4	355	0.05
65554	O1	184.8	0.34
65554	M6	179.7	0.02
65554	S4	56	0.01
65554	NU2	84.6	0.15
65554	S6	208.3	0.01
65554	MU2	298.5	0.1
65554	2N2	49.2	0.1
65554	OO1	232	0.01
65554	LDA2	126.3	0.03
65554	M1	196.7	0.02
65554	J1	220.1	0.03
65554	SSA	101	0.05
65554	SA	125	0.11
65554	RHO1	174.7	0.01
65554	Q1	173.1	0.07
65554	T2	142	0.04
65554	R2	144.5	0.01
65554	2Q1	161.4	0.01
65554	P1	206.6	0.13
65554	L2	142.8	0.11
65554	K2	145.8	0.17
65555	M2	150.1	3.3
65555	S2	189.1	0.43
65555	N2	117.4	0.63
65555	K1	230.8	0.38
65555	M4	108.7	0.09
65555	O1	220.2	0.31
65555	M6	102.8	0.07
65555	NU2	121.7	0.12
65555	MU2	329.4	0.08
65555	2N2	84.6	0.08
65555	OO1	241.4	0.01
65555	LDA2	168.1	0.02
65555	M1	225.5	0.02
65555	J1	236	0.02
65555	RHO1	215.6	0.01
65555	Q1	214.9	0.06
65555	T2	187.6	0.03
65555	2Q1	209.6	0.01
65555	P1	230	0.13
65555	L2	182.8	0.09
65555	K2	192.3	0.11
65555	M8	32.3	0.03
65556	M2	141.2	3.15
65556	S2	177.4	0.4
65556	N2	108	0.65
65556	K1	230.9	0.38
65556	M4	49.1	0.09
65556	O1	209.4	0.32
65556	M6	112.3	0.04
65556	NU2	112.5	0.12
65556	MU2	105.1	0.08
65556	2N2	74.8	0.09
65556	OO1	252.7	0.01
65556	LDA2	158	0.02
65556	M1	220.3	0.02
65556	J1	241.8	0.03
65556	SSA	89.8	0.06
65556	SA	126.3	0.1
65556	RHO1	200.3	0.01
65556	Q1	198.7	0.06
65556	T2	175.9	0.02
65556	2Q1	188.3	0.01
65556	P1	229.3	0.12
65556	L2	174.4	0.09
65556	K2	180.3	0.11
65556	M8	343.5	0.01
65557	M2	105.9	4.31
65557	S2	136.2	0.59
65557	N2	76.1	0.96
65557	K1	203.3	0.44
65557	M4	324.5	0.06
65557	O1	187.1	0.37
65557	M6	134.7	0.03
65557	MK3	244.9	0.01
65557	MN4	317.9	0.02
65557	NU2	85.2	0.21
65557	MU2	24	0.03
65557	2N2	49.3	0.16
65557	OO1	247.6	0.01
65557	LDA2	144.8	0.06
65557	S1	168.7	0.03
65557	M1	250.2	0.02
65557	J1	214.2	0.03
65557	SSA	105.8	0.07
65557	SA	128.3	0.1
65557	RHO1	159.4	0.01
65557	Q1	156.6	0.07
65557	T2	94.5	0.08
65557	R2	130.7	0.09
65557	2Q1	38	0.01
65557	P1	204.1	0.13
65557	2SM2	156.6	0.02
65557	L2	140.3	0.15
65557	2MK3	225.4	0.02
65557	K2	131.8	0.21
65557	M8	293.2	0.01
65557	MS4	23.9	0.02
65558	M2	132.3	3.6
65558	S2	157.9	0.48
65558	N2	105.8	0.72
65558	K1	225.5	0.41
65558	M4	178.2	0.15
65558	O1	210.3	0.33
65558	M6	62.9	0.1
65558	MK3	255.7	0.05
65558	S4	245.9	0.01
65558	MN4	161.3	0.07
65558	NU2	121.5	0.16
65558	MU2	233	0.07
65558	2N2	41.5	0.05
65558	OO1	278.4	0.02
65558	LDA2	135.8	0.06
65558	S1	308.2	0.06
65558	M1	246.8	0.03
65558	J1	277.4	0.01
65558	SSA	89.8	0.06
65558	SA	126.3	0.1
65558	Q1	201.9	0.05
65558	T2	70.9	0.05
65558	2Q1	274.7	0.03
65558	P1	207.1	0.08
65558	2SM2	37.1	0.01
65558	M3	309.6	0.01
65558	L2	143.3	0.27
65558	2MK3	224.9	0.06
65558	K2	159.6	0.1
65558	M8	68.2	0.03
65558	MS4	217.1	0.06
65559	M2	149.6	3.19
65559	S2	192.2	0.39
65559	N2	130.3	0.6
65559	K1	246.4	0.39
65559	M4	209.9	0.21
65559	O1	219.6	0.32
65559	M6	114	0.13
65559	NU2	132.9	0.12
65559	S6	270.7	0.01
65559	MU2	324.9	0.08
65559	2N2	111	0.08
65559	OO1	273.2	0.01
65559	LDA2	169.4	0.02
65559	M1	233.1	0.02
65559	J1	259.7	0.03
65559	SSA	89.8	0.06
65559	SA	126.3	0.1
65559	RHO1	208.2	0.01
65559	Q1	206.4	0.06
65559	T2	190.5	0.02
65559	2Q1	193.1	0.01
65559	P1	244.4	0.13
65559	L2	168.8	0.09
65559	K2	195.7	0.11
65559	M8	145.4	0.05
65560	M2	115.7	3.84
65560	S2	153	0.54
65560	N2	85.6	0.78
65560	K1	211.2	0.43
65560	M4	133	0.03
65560	O1	194.2	0.34
65560	M6	335.3	0.08
65560	NU2	89.6	0.15
65560	MU2	297	0.09
65560	2N2	55.5	0.1
65560	OO1	227.9	0.01
65560	LDA2	133	0.03
65560	M1	202.7	0.02
65560	J1	219.4	0.03
65560	SSA	89.8	0.06
65560	SA	126.3	0.1
65560	RHO1	187	0.01
65560	Q1	185.8	0.07
65560	T2	151.6	0.03
65560	2Q1	177.5	0.01
65560	P1	209.9	0.14
65560	L2	145.9	0.11
65560	K2	156.1	0.15
65560	M8	177.9	0.01
65561	M2	122	3.86
65561	S2	166.2	0.51
65561	N2	91.7	0.76
65561	K1	216.8	0.42
65561	M4	164.2	0.17
65561	O1	203.3	0.36
65561	M6	16.9	0.08
65561	S4	246.4	0.01
65561	NU2	95.8	0.15
65561	MU2	296	0.09
65561	2N2	61.4	0.1
65561	OO1	230.3	0.02
65561	LDA2	142.6	0.03
65561	M1	210.1	0.03
65561	J1	223.5	0.03
65561	SSA	89.8	0.06
65561	SA	126.3	0.1
65561	RHO1	197.5	0.01
65561	Q1	196.6	0.07
65561	T2	164.5	0.03
65561	2Q1	189.9	0.01
65561	P1	215.8	0.14
65561	L2	152.4	0.11
65561	K2	169.8	0.14
65561	M8	356.6	0.02
65562	M2	176	2.49
65562	S2	227.5	0.3
65562	N2	151.6	0.44
65562	K1	267.4	0.32
65562	M4	284.6	0.46
65562	O1	240.8	0.29
65562	M6	109.9	0.04
65562	S4	41.6	0.01
65562	NU2	154.9	0.09
65562	MU2	342.4	0.06
65562	2N2	127.1	0.06
65562	OO1	294	0.01
65562	LDA2	199.9	0.02
65562	M1	254.2	0.02
65562	J1	280.6	0.02
65562	SSA	89.8	0.06
65562	SA	126.3	0.1
65562	RHO1	229.4	0.01
65562	Q1	227.6	0.06
65562	T2	225.5	0.02
65562	2Q1	214.3	0.01
65562	P1	265.4	0.1
65562	L2	200.4	0.07
65562	K2	231.7	0.08
65562	M8	270.9	0.05
65563	M2	116.9	4.19
65563	S2	159.1	0.52
65563	N2	88.2	0.88
65563	K1	212.8	0.43
65563	M4	176.6	0.06
65563	O1	199.9	0.37
65563	M6	345.1	0.09
65563	NU2	92.1	0.17
65563	MU2	293	0.1
65563	2N2	59.5	0.11
65563	OO1	225.6	0.02
65563	LDA2	136.5	0.03
65563	M1	206.4	0.03
65563	J1	219.1	0.03
65563	SSA	89.8	0.06
65563	SA	126.3	0.1
65563	RHO1	194.4	0.01
65563	Q1	193.6	0.07
65563	T2	157.4	0.03
65563	2Q1	187.2	0.01
65563	P1	211.8	0.14
65563	L2	145.6	0.12
65563	K2	162.5	0.14
65563	M8	329.5	0.02
65564	M2	106.6	4.23
65564	S2	144.2	0.61
65564	N2	75.5	1
65564	K1	204.9	0.47
65564	M4	357.6	0.04
65564	O1	186	0.38
65564	M6	228.6	0.02
65564	NU2	79.6	0.19
65564	MU2	287.7	0.1
65564	2N2	44.4	0.13
65564	OO1	223.5	0.02
65564	LDA2	124.1	0.03
65564	M1	195.5	0.03
65564	J1	214	0.03
65564	SSA	89.8	0.06
65564	SA	126.3	0.1
65564	RHO1	178	0.01
65564	Q1	176.7	0.08
65564	T2	142.7	0.04
65564	2Q1	167.4	0.01
65564	P1	203.4	0.16
65564	L2	137.8	0.12
65564	K2	147.2	0.17
65564	M8	234.1	0.01
65565	M2	118.4	4.28
65565	S2	169.8	0.69
65565	N2	92.9	0.94
65565	K1	219.3	0.47
65565	M4	140.6	0.2
65565	O1	196.6	0.38
65565	M6	318	0.09
65565	MK3	232.6	0.05
65565	S4	247.2	0.01
65565	MN4	109.8	0.08
65565	NU2	93.3	0.19
65565	MU2	165	0.05
65565	2N2	61.5	0.13
65565	OO1	315.5	0.01
65565	LDA2	115.3	0.08
65565	S1	88.8	0.07
65565	M1	224.2	0.04
65565	J1	248.8	0.02
65565	SSA	89.8	0.06
65565	SA	126.3	0.1
65565	RHO1	273.9	0.01
65565	Q1	187.9	0.06
65565	T2	181.5	0.09
65565	2Q1	142.4	0.02
65565	P1	214.3	0.18
65565	L2	118.5	0.19
65565	2MK3	195.2	0.04
65565	K2	145.9	0.19
65565	M8	260.2	0.08
65565	MS4	186.3	0.05
65566	M2	108.3	4.27
65566	S2	145.6	0.62
65566	N2	77.6	1.06
65566	K1	206.2	0.49
65566	M4	359.7	0.06
65566	O1	187.5	0.38
65566	M6	275	0.05
65566	NU2	81.7	0.21
65566	MU2	289.1	0.1
65566	2N2	46.9	0.14
65566	OO1	224.5	0.02
65566	LDA2	125.6	0.03
65566	M1	196.8	0.03
65566	J1	215.2	0.03
65566	RHO1	179.5	0.01
65566	Q1	178.3	0.08
65566	T2	144.1	0.04
65566	R2	147.1	0.01
65566	2Q1	169.1	0.01
65566	P1	204.8	0.16
65566	L2	139	0.12
65566	K2	148.6	0.17
65566	M8	178.8	0.01
65567	M2	109.7	4.39
65567	S2	151.5	0.78
65567	N2	78.1	1.08
65567	K1	208	0.44
65567	M4	28.9	0.06
65567	O1	185.3	0.39
65567	M6	285.9	0.08
65567	MK3	244.1	0.02
65567	MN4	8.3	0.04
65567	NU2	83.2	0.17
65567	MU2	72.4	0.06
65567	2N2	61.6	0.12
65567	OO1	201.6	0.02
65567	LDA2	152.1	0.07
65567	S1	139.9	0.06
65567	M1	199.6	0.03
65567	J1	204.3	0.04
65567	SSA	89.8	0.06
65567	SA	126.3	0.1
65567	RHO1	91.9	0.02
65567	Q1	186.4	0.08
65567	T2	146.3	0.1
65567	R2	10.3	0.15
65567	2Q1	162	0.01
65567	P1	217	0.15
65567	2SM2	113.5	0.02
65567	M3	137.4	0.02
65567	L2	168.3	0.24
65567	2MK3	202.8	0.03
65567	K2	127	0.2
65567	M8	220.5	0.01
65567	MS4	70.8	0.02
65568	M2	110.7	4.53
65568	S2	148.9	0.69
65568	N2	82.6	1.03
65568	K1	203.2	0.49
65568	M4	34.8	0.09
65568	O1	189.2	0.39
65568	M6	292.7	0.11
65568	S4	185.4	0.01
65568	NU2	86.3	0.2
65568	MU2	290.4	0.11
65568	2N2	54.4	0.14
65568	OO1	217	0.02
65568	LDA2	128.4	0.03
65568	M1	196.2	0.03
65568	J1	210	0.03
65568	SSA	89.8	0.06
65568	SA	126.3	0.1
65568	RHO1	183.2	0.01
65568	Q1	182.2	0.08
65568	T2	147.4	0.04
65568	R2	150.5	0.01
65568	2Q1	175.3	0.01
65568	P1	202.2	0.16
65568	L2	138.8	0.13
65568	K2	152	0.19
65568	M8	249.4	0.02
65569	M2	111.1	4.5
65569	S2	146.2	0.67
65569	N2	81.1	1.05
65569	K1	203.8	0.47
65569	M4	19.4	0.07
65569	O1	187.2	0.37
65569	M6	290.2	0.11
65569	S4	96.1	0.01
65569	NU2	85.1	0.2
65569	S6	72.4	0.01
65569	MU2	293.8	0.11
65569	2N2	51.1	0.14
65569	OO1	220.3	0.02
65569	LDA2	127.4	0.03
65569	M1	195.6	0.03
65569	J1	212	0.03
65569	SSA	89.8	0.06
65569	SA	126.3	0.1
65569	RHO1	180.1	0.01
65569	Q1	179	0.07
65569	T2	144.8	0.04
65569	R2	147.6	0.01
65569	2Q1	170.8	0.01
65569	P1	202.5	0.15
65569	L2	141	0.12
65569	K2	149.1	0.18
65569	M8	236.5	0.02
65570	M2	109.4	4.59
65570	S2	146.2	0.7
65570	N2	78.9	1.01
65570	K1	205.2	0.47
65570	M4	25.9	0.08
65570	O1	186.7	0.39
65570	M6	282.1	0.11
65570	MK3	232.5	0.02
65570	MN4	14.6	0.04
65570	NU2	85.5	0.22
65570	MU2	69	0.03
65570	2N2	55	0.13
65570	OO1	227	0.02
65570	LDA2	143.2	0.07
65570	S1	122.8	0.01
65570	M1	214.4	0.02
65570	J1	213.5	0.03
65570	SSA	89.8	0.06
65570	SA	126.3	0.1
65570	RHO1	152.8	0.01
65570	Q1	171.1	0.07
65570	T2	123.9	0.06
65570	R2	8.2	0.02
65570	2Q1	168.3	0.01
65570	P1	202.1	0.15
65570	L2	156.2	0.18
65570	2MK3	207.9	0.02
65570	K2	144.5	0.19
65570	M8	237.1	0.02
65570	MS4	68.7	0.03
65571	M2	108.6	4.34
65571	S2	144.4	0.67
65571	N2	77	1
65571	K1	204.6	0.46
65571	M4	4.4	0.04
65571	O1	187.1	0.37
65571	M6	270	0.07
65571	MK3	247.5	0.02
65571	MN4	2	0.02
65571	NU2	85.4	0.22
65571	S6	236.9	0.01
65571	MU2	42.2	0.04
65571	2N2	59.3	0.13
65571	OO1	243.9	0.02
65571	LDA2	151.1	0.07
65571	S1	109.3	0.03
65571	M1	202.9	0.02
65571	J1	217.7	0.03
65571	SSA	89.8	0.06
65571	SA	126.3	0.1
65571	RHO1	132.7	0.01
65571	Q1	171.2	0.06
65571	T2	120.8	0.05
65571	R2	12.5	0.02
65571	2Q1	201.3	0.01
65571	P1	199.1	0.16
65571	2SM2	119.8	0.01
65571	M3	142.1	0.01
65571	L2	156.2	0.22
65571	2MK3	212	0.02
65571	K2	145.7	0.19
65571	MS4	50.8	0.01
65572	M2	110.6	4.46
65572	S2	147.1	0.68
65572	N2	77.2	1.03
65572	K1	205.8	0.46
65572	M4	35.6	0.05
65572	O1	187.6	0.38
65572	M6	285.9	0.11
65572	MK3	234.3	0.02
65572	MN4	26	0.03
65572	NU2	89.9	0.22
65572	S6	263.5	0.01
65572	MU2	65.3	0.03
65572	2N2	66.8	0.15
65572	OO1	251	0.02
65572	LDA2	137.2	0.07
65572	S1	173.4	0.01
65572	M1	188.6	0.02
65572	J1	210.5	0.03
65572	SSA	89.8	0.06
65572	SA	126.3	0.1
65572	RHO1	140.7	0.01
65572	Q1	174.8	0.06
65572	T2	128.1	0.06
65572	R2	12.7	0.02
65572	2Q1	210.6	0.03
65572	P1	203.7	0.15
65572	2SM2	126.9	0.01
65572	M3	155.1	0.01
65572	L2	161.7	0.21
65572	2MK3	207.2	0.03
65572	K2	148.6	0.2
65572	M8	239.5	0.02
65572	MS4	85.5	0.02
65573	M2	113.2	4.54
65573	S2	153.9	0.66
65573	N2	87	1.03
65573	K1	207.6	0.48
65573	M4	49	0.08
65573	O1	188	0.39
65573	M6	296.3	0.14
65573	NU2	90.5	0.2
65573	MU2	290.4	0.11
65573	2N2	60.9	0.14
65573	OO1	227	0.02
65573	LDA2	132.1	0.03
65573	M1	197.9	0.03
65573	J1	217.2	0.03
65573	SSA	89.8	0.06
65573	SA	126.3	0.1
65573	RHO1	179.7	0.02
65573	Q1	178.4	0.08
65573	T2	152.3	0.04
65573	R2	155.6	0.01
65573	2Q1	168.7	0.01
65573	P1	206.1	0.16
65573	L2	139.3	0.13
65573	K2	157.2	0.18
65573	M8	238.3	0.03
65574	M2	110.3	4.25
65574	S2	147.8	0.62
65574	N2	76.2	0.96
65574	K1	205.7	0.46
65574	M4	359.9	0.06
65574	O1	188.4	0.38
65574	M6	288.7	0.07
65574	NU2	80.8	0.19
65574	MU2	291.3	0.1
65574	2N2	42.1	0.13
65574	OO1	223	0.02
65574	LDA2	127.8	0.03
65574	M1	197.1	0.03
65574	J1	214.2	0.03
65574	RHO1	180.9	0.01
65574	Q1	179.8	0.08
65574	T2	146.3	0.04
65574	R2	149.3	0.01
65574	2Q1	171.2	0.01
65574	P1	204.4	0.15
65574	L2	144.6	0.12
65574	K2	150.8	0.17
65574	M8	275.1	0.01
65575	M2	112.8	4.27
65575	S2	150.1	0.63
65575	N2	77.1	1.01
65575	K1	207.6	0.45
65575	M4	8.1	0.06
65575	O1	189.4	0.39
65575	M6	299.9	0.1
65575	NU2	81.9	0.2
65575	MU2	293.7	0.1
65575	2N2	41.5	0.13
65575	OO1	225.9	0.02
65575	LDA2	130.3	0.03
65575	M1	198.6	0.03
65575	J1	216.7	0.03
65575	SSA	89.8	0.06
65575	SA	126.3	0.1
65575	RHO1	181.5	0.02
65575	Q1	180.3	0.08
65575	T2	148.6	0.04
65575	R2	151.6	0.01
65575	2Q1	171.3	0.01
65575	P1	206.3	0.15
65575	L2	148.4	0.12
65575	K2	153.1	0.17
65576	M2	112	4.48
65576	S2	151.3	0.57
65576	N2	78.8	1.06
65576	K1	206.1	0.45
65576	M4	9.7	0.07
65576	O1	187.9	0.39
65576	M6	294.6	0.13
65576	MK3	245.8	0.02
65576	MN4	351.1	0.03
65576	NU2	91.9	0.24
65576	MU2	56.5	0.01
65576	2N2	74.7	0.1
65576	OO1	235.5	0.02
65576	LDA2	141.9	0.07
65576	S1	221.2	0.02
65576	M1	201.7	0.02
65576	J1	211.9	0.03
65576	SSA	89.8	0.06
65576	SA	126.3	0.1
65576	RHO1	194.4	0.01
65576	Q1	172	0.06
65576	T2	96.9	0.04
65576	2Q1	198.3	0.01
65576	P1	201.7	0.14
65576	2SM2	102.2	0.01
65576	M3	152.2	0.01
65576	L2	170.3	0.27
65576	2MK3	216.6	0.02
65576	K2	138.8	0.23
65576	MS4	55.6	0.02
65577	M2	120.4	4.47
65577	S2	161.4	0.63
65577	N2	89.5	1
65577	K1	213.2	0.47
65577	M4	127.9	0.24
65577	O1	193.6	0.4
65577	M6	340	0.19
65577	NU2	93.6	0.19
65577	S6	109.7	0.01
65577	MU2	298.2	0.11
65577	2N2	58.4	0.13
65577	OO1	232.8	0.02
65577	LDA2	139.4	0.03
65577	M1	203.5	0.03
65577	J1	222.9	0.03
65577	SSA	89.8	0.06
65577	SA	126.3	0.1
65577	RHO1	185.2	0.02
65577	Q1	183.9	0.08
65577	T2	159.7	0.04
65577	R2	163	0.01
65577	2Q1	174.2	0.01
65577	P1	211.7	0.15
65577	L2	151.6	0.12
65577	K2	164.7	0.17
65577	M8	340.4	0.06
65578	M2	117.4	4.45
65578	S2	156.3	0.68
65578	N2	83.5	1
65578	K1	210.9	0.46
65578	M4	112.7	0.15
65578	O1	193.4	0.38
65578	M6	325.2	0.19
65578	NU2	88.1	0.19
65578	S6	90.8	0.01
65578	MU2	297.2	0.11
65578	2N2	49.7	0.13
65578	OO1	228.4	0.02
65578	LDA2	135.4	0.03
65578	M1	202.2	0.03
65578	J1	219.5	0.03
65578	SSA	89.8	0.06
65578	SA	126.3	0.1
65578	RHO1	185.9	0.01
65578	Q1	184.8	0.08
65578	T2	154.7	0.04
65578	R2	157.8	0.01
65578	2Q1	176.1	0.01
65578	P1	209.6	0.15
65578	L2	151.3	0.12
65578	K2	159.4	0.18
65578	M8	300.5	0.04
65579	M2	107.3	3.658
65579	S2	142	0.541
65579	N2	75.4	0.876
65579	K1	202.2	0.43
65579	M4	64.1	0.144
65579	O1	188	0.344
65579	M6	297.3	0.128
65579	S4	35.9	0.007
65579	NU2	79.7	0.171
65579	S6	130.7	0.003
65579	MU2	291.6	0.089
65579	2N2	43.5	0.118
65579	OO1	216.3	0.016
65579	LDA2	123.5	0.026
65579	M1	195.2	0.023
65579	J1	209.2	0.026
65579	RHO1	182	0.013
65579	Q1	181	0.066
65579	T2	140.6	0.033
65579	R2	143.4	0.003
65579	2Q1	174	0.01
65579	P1	201.1	0.141
65579	L2	139.3	0.102
65579	K2	144.8	0.148
65579	M8	223.7	0.016
65580	M2	109.2	4.1
65580	S2	146.6	0.6
65580	N2	77.6	0.96
65580	K1	203.3	0.45
65580	M4	35.2	0.1
65580	O1	187.9	0.36
65580	M6	294.6	0.13
65580	NU2	81.9	0.19
65580	MU2	71.8	0.1
65580	2N2	46	0.13
65580	OO1	218.7	0.02
65580	LDA2	126.6	0.03
65580	M1	195.7	0.03
65580	J1	211	0.03
65580	RHO1	181.3	0.01
65580	Q1	180.3	0.07
65580	T2	145.2	0.04
65580	2Q1	172.6	0.01
65580	P1	202.1	0.15
65580	L2	140.9	0.11
65580	K2	149.7	0.16
65581	M2	99.1	2.82
65581	S2	130.5	0.41
65581	N2	66.6	0.71
65581	K1	198.5	0.34
65581	M4	58.3	0.14
65581	O1	194.8	0.3
65581	M6	295.4	0.11
65581	S4	52.4	0.01
65581	NU2	70.9	0.14
65581	S6	93.2	0.01
65581	MU2	286.5	0.07
65581	2N2	34	0.1
65581	OO1	202.8	0.01
65581	LDA2	113.8	0.02
65581	M1	196.7	0.02
65581	J1	200.7	0.02
65581	RHO1	192.3	0.01
65581	Q1	192.8	0.06
65581	T2	129.4	0.02
65581	2Q1	190.6	0.01
65581	P1	198.2	0.11
65581	L2	131.8	0.08
65581	K2	133.1	0.11
65581	M8	221.3	0.02
65582	M2	111.8	4.69
65582	S2	148.5	0.7
65582	N2	79	1.08
65582	K1	205	0.46
65582	M4	21.7	0.1
65582	O1	189	0.37
65582	M6	298.8	0.22
65582	NU2	83.4	0.21
65582	MU2	294.8	0.11
65582	2N2	46.2	0.14
65582	OO1	220.8	0.02
65582	LDA2	128.9	0.03
65582	M1	197	0.03
65582	J1	212.7	0.03
65582	SSA	89.8	0.06
65582	SA	126.3	0.1
65582	RHO1	182.2	0.01
65582	Q1	181.1	0.07
65582	T2	147.1	0.04
65582	R2	150	0.01
65582	2Q1	173.2	0.01
65582	P1	203.8	0.15
65582	L2	144.6	0.13
65582	K2	151.6	0.19
65582	M8	21.3	0.01
65583	M2	79.1	1.95
65583	S2	104.8	0.3
65583	N2	49.1	0.55
65583	K1	187.9	0.3
65583	M4	64.8	0.22
65583	O1	196.7	0.28
65583	M6	300	0.11
65583	S4	50.8	0.02
65583	NU2	53.1	0.11
65583	S6	88.8	0.01
65583	MU2	272.3	0.05
65583	2N2	19	0.07
65583	OO1	179.1	0.01
65583	LDA2	91.1	0.01
65583	M1	192.2	0.02
65583	J1	183.5	0.02
65583	RHO1	200.4	0.01
65583	Q1	201	0.05
65583	T2	103.8	0.02
65583	2Q1	205.4	0.01
65583	P1	188.5	0.1
65583	L2	109.2	0.06
65583	K2	106.9	0.08
65583	M8	231.1	0.02
65584	M2	50	1.7
65584	S2	65.2	0.31
65584	N2	28.2	0.48
65584	K1	184.9	0.27
65584	M4	65.4	0.3
65584	O1	194.9	0.23
65584	M6	292.4	0.07
65584	MK3	12.7	0.03
65584	S4	20.5	0.03
65584	MN4	14.8	0.12
65584	NU2	35.6	0.09
65584	S6	320.1	0.02
65584	MU2	4	0.08
65584	2N2	15.7	0.08
65584	OO1	194.8	0.02
65584	LDA2	126	0.01
65584	S1	117.4	0.03
65584	M1	191.5	0.02
65584	J1	179.9	0.02
65584	RHO1	185.1	0.01
65584	Q1	185.1	0.05
65584	T2	61.8	0.04
65584	2Q1	204.7	0.01
65584	P1	185.4	0.1
65584	M3	43	0.02
65584	L2	90.3	0.01
65584	2MK3	354.8	0.04
65584	K2	63.8	0.08
65584	M8	229.1	0.02
65584	MS4	143.4	0.08
65585	M2	28.7	1.74
65585	S2	47.6	0.32
65585	N2	10.2	0.47
65585	K1	173.4	0.28
65585	M4	54.6	0.29
65585	O1	199.9	0.17
65585	M6	292.7	0.08
65585	S4	0.2	0.03
65585	NU2	12.6	0.09
65585	S6	273.4	0.02
65585	MU2	228.5	0.04
65585	2N2	351.6	0.06
65585	OO1	148.3	0.01
65585	LDA2	37.5	0.01
65585	M1	186.6	0.01
65585	J1	160.8	0.01
65585	RHO1	211.4	0.01
65585	Q1	213.1	0.03
65585	T2	46.9	0.02
65585	P1	175.4	0.09
65585	L2	47.2	0.05
65585	K2	49.1	0.09
65585	M8	193.5	0.01
65586	M2	10.7	1.83
65586	S2	33.8	0.41
65586	N2	350.3	0.51
65586	K1	165.5	0.23
65586	M4	45.1	0.33
65586	O1	198.4	0.19
65586	M6	315.8	0.04
65586	S4	67.2	0.04
65586	NU2	353	0.1
65586	S6	284.4	0.01
65586	MU2	206.1	0.04
65586	2N2	329.8	0.07
65586	OO1	132.7	0.01
65586	LDA2	21.4	0.01
65586	M1	181.8	0.01
65586	J1	149.2	0.02
65586	RHO1	212.5	0.01
65586	Q1	214.7	0.04
65586	T2	32.9	0.02
65586	2Q1	231	0.01
65586	P1	168	0.08
65586	L2	31.1	0.05
65586	K2	35.7	0.11
65586	M8	236.5	0.01
65587	M2	8.7	2.01
65587	S2	31.1	0.43
65587	N2	353.5	0.5
65587	K1	168.9	0.23
65587	M4	64.8	0.33
65587	O1	200.3	0.17
65587	M6	335.4	0.07
65587	MK3	29.8	0.04
65587	S4	29.3	0.04
65587	MN4	15	0.15
65587	NU2	348.5	0.08
65587	S6	338.6	0.01
65587	MU2	0.2	0.1
65587	2N2	341.1	0.07
65587	OO1	172.6	0.01
65587	LDA2	341.6	0.01
65587	S1	124.7	0.06
65587	M1	183.3	0.01
65587	J1	205.3	0.02
65587	SA	131.8	0.2
65587	RHO1	213.8	0.01
65587	Q1	182.2	0.04
65587	T2	17.1	0.04
65587	P1	185.1	0.09
65587	M3	35.9	0.03
65587	L2	344.4	0.07
65587	2MK3	9.9	0.06
65587	K2	30.2	0.12
65587	MS4	149.6	0.09
65588	M2	9.5	1.84
65588	S2	31.7	0.38
65588	N2	353.5	0.47
65588	K1	166.3	0.24
65588	M4	41.3	0.3
65588	O1	201	0.16
65588	M6	286.7	0.04
65588	S4	347.6	0.04
65588	NU2	355.7	0.09
65588	S6	262.3	0.02
65588	MU2	205.8	0.04
65588	2N2	337.6	0.06
65588	OO1	131.9	0.01
65588	LDA2	19.8	0.01
65588	M1	183.6	0.01
65588	J1	149.3	0.01
65588	SSA	61.8	0.07
65588	SA	140.5	0.2
65588	RHO1	215.9	0.01
65588	Q1	218.2	0.03
65588	T2	30.8	0.02
65588	P1	168.9	0.08
65588	L2	25.5	0.05
65588	K2	33.5	0.1
65588	M8	154.7	0.01
65589	M2	140	2.34
65589	S2	182.1	0.29
65589	N2	108.5	0.46
65589	K1	237.6	0.34
65589	M4	172.7	0.14
65589	O1	223.4	0.29
65589	M6	140.6	0.06
65589	MK3	254	0.06
65589	S4	306.7	0.01
65589	MN4	154.6	0.06
65589	NU2	120.4	0.12
65589	MU2	269.1	0.04
65589	2N2	65.8	0.05
65589	OO1	235.8	0.02
65589	LDA2	156.4	0.06
65589	S1	285.8	0.02
65589	M1	289.7	0.02
65589	J1	292.5	0.02
65589	SA	165.7	0.12
65589	Q1	217.7	0.05
65589	T2	160	0.03
65589	R2	12.9	0.01
65589	2Q1	269.3	0.01
65589	P1	232.5	0.11
65589	M3	316.2	0.02
65589	L2	170.3	0.18
65589	2MK3	235	0.05
65589	K2	185.1	0.09
65589	M8	120.2	0.02
65589	MS4	228.3	0.05
65590	M2	130.3	1.8
65590	S2	163.5	0.22
65590	N2	93.8	0.47
65590	K1	219	0.34
65590	M4	8	0.13
65590	O1	203.3	0.3
65590	M6	298.4	0.07
65590	S4	353.9	0.01
65590	NU2	98.7	0.09
65590	MU2	317.1	0.04
65590	2N2	57.2	0.06
65590	OO1	234.9	0.01
65590	LDA2	145.7	0.01
65590	M1	211.3	0.02
65590	J1	227	0.02
65590	SA	165.7	0.12
65590	RHO1	196.5	0.01
65590	Q1	195.4	0.06
65590	T2	162.2	0.01
65590	2Q1	187.5	0.01
65590	P1	217.8	0.11
65590	L2	166.9	0.05
65590	K2	166.2	0.06
65591	M2	132.6	1.83
65591	S2	175.6	0.21
65591	N2	101.4	0.47
65591	K1	220.8	0.32
65591	M4	13.7	0.11
65591	O1	211	0.31
65591	M6	312.8	0.07
65591	S4	40.6	0.01
65591	NU2	105.6	0.09
65591	MU2	309.8	0.04
65591	2N2	70.2	0.06
65591	OO1	230	0.01
65591	LDA2	152.5	0.01
65591	M1	215.8	0.02
65591	J1	225.2	0.02
65591	SA	165.7	0.12
65591	RHO1	206.9	0.01
65591	Q1	206.2	0.06
65591	T2	173.9	0.01
65591	2Q1	201.6	0.01
65591	P1	220	0.11
65591	L2	163.9	0.05
65591	K2	179.1	0.06
65591	M8	309.7	0.02
65592	M2	134.3	1.49
65592	S2	167	0.15
65592	N2	98.7	0.4
65592	K1	219.5	0.32
65592	M4	10.1	0.15
65592	O1	209.2	0.29
65592	M6	333.7	0.07
65592	S4	358.4	0.01
65592	NU2	103.5	0.08
65592	MU2	101.8	0.04
65592	2N2	63.2	0.05
65592	OO1	229.8	0.01
65592	LDA2	149.4	0.01
65592	M1	214.3	0.02
65592	J1	224.5	0.02
65592	SA	145.9	0.17
65592	RHO1	204.8	0.01
65592	Q1	204.1	0.06
65592	T2	165.6	0.01
65592	2Q1	199.1	0.01
65592	P1	218.7	0.11
65592	L2	169.9	0.04
65592	K2	169.7	0.04
65592	M8	149.9	0.01
65593	M2	7.2	1.8
65593	S2	28.8	0.37
65593	N2	351.6	0.46
65593	K1	167.4	0.23
65593	M4	37.5	0.28
65593	O1	201.4	0.16
65593	M6	299.1	0.02
65593	S4	344	0.03
65593	NU2	353.7	0.09
65593	S6	245.4	0.01
65593	MU2	345.8	0.04
65593	2N2	336	0.06
65593	OO1	133.3	0.01
65593	LDA2	17.3	0.01
65593	M1	184.3	0.01
65593	J1	150.5	0.01
65593	SA	145.9	0.17
65593	RHO1	216.1	0.01
65593	Q1	218.1	0.03
65593	T2	27.9	0.02
65593	P1	170	0.08
65593	L2	23	0.05
65593	K2	30.4	0.1
65594	M2	7.8	1.69
65594	S2	29.4	0.38
65594	N2	354.6	0.42
65594	K1	168.3	0.19
65594	M4	43.3	0.24
65594	O1	199.9	0.17
65594	M6	24.8	0.01
65594	S4	315.5	0.01
65594	NU2	356.4	0.08
65594	S6	83.6	0.01
65594	MU2	204.1	0.04
65594	2N2	341.3	0.06
65594	OO1	137.2	0.01
65594	LDA2	18	0.01
65594	M1	184.1	0.01
65594	J1	153	0.01
65594	SSA	61.8	0.07
65594	SA	140.5	0.2
65594	RHO1	213.3	0.01
65594	Q1	215.4	0.03
65594	T2	28.5	0.02
65594	P1	170.6	0.06
65594	L2	21.2	0.05
65594	K2	31.2	0.1
65594	M8	142.2	0.01
65595	M2	7.9	1.65
65595	S2	359.9	0.58
65595	N2	353.7	0.43
65595	K1	163.3	0.17
65595	M4	41.4	0.21
65595	O1	208.9	0.19
65595	M6	101.8	0.01
65595	MK3	23.2	0.05
65595	MN4	350.4	0.09
65595	NU2	355.4	0.1
65595	MU2	350.8	0.08
65595	2N2	338.4	0.07
65595	OO1	154.5	0.01
65595	LDA2	4.3	0.03
65595	S1	191.1	0.05
65595	M1	190.4	0.02
65595	J1	160.2	0.02
65595	SSA	61.8	0.07
65595	SA	140.5	0.2
65595	RHO1	100.6	0.04
65595	Q1	152.4	0.08
65595	T2	332.7	0.16
65595	R2	146.9	0.32
65595	2Q1	64.4	0.01
65595	P1	156	0.05
65595	2SM2	105.4	0.01
65595	M3	44.7	0.02
65595	L2	328	0.04
65595	2MK3	339.5	0.04
65595	K2	164.3	0.1
65595	MS4	117.6	0.04
65596	M2	34.6	0.8
65596	S2	35.6	0.2
65596	N2	19.4	0.26
65596	K1	189	0.23
65596	M4	355.1	0.18
65596	O1	203.7	0.22
65596	M6	45.5	0.07
65596	MK3	13.6	0.04
65596	S4	347.2	0.01
65596	MN4	315.4	0.08
65596	NU2	25.9	0.03
65596	MU2	352.2	0.08
65596	2N2	2.4	0.05
65596	OO1	174.2	0.01
65596	LDA2	35.1	0.01
65596	S1	117.2	0.02
65596	M1	182.9	0.01
65596	J1	212.4	0.02
65596	SA	145.9	0.17
65596	RHO1	184.9	0.01
65596	Q1	185.1	0.05
65596	T2	25	0.02
65596	2Q1	218.2	0.01
65596	P1	199.9	0.09
65596	M3	24.9	0.02
65596	L2	252	0.03
65596	2MK3	344.7	0.04
65596	K2	29.7	0.05
65596	M8	165.8	0.01
65596	MS4	56.4	0.04
65597	M2	86.9	0.68
65597	S2	59.1	0.1
65597	N2	56.6	0.24
65597	K1	202	0.24
65597	M4	339.9	0.17
65597	O1	206.1	0.22
65597	M6	12.9	0.07
65597	S4	341.7	0.01
65597	NU2	60.7	0.05
65597	S6	45.8	0.01
65597	MU2	114.8	0.02
65597	2N2	26.2	0.03
65597	OO1	198	0.01
65597	M1	204	0.01
65597	J1	199.9	0.02
65597	SA	145.9	0.17
65597	RHO1	208.3	0.01
65597	Q1	208.2	0.04
65597	T2	60.2	0.01
65597	2Q1	209.9	0.01
65597	P1	202.3	0.08
65597	L2	117.3	0.02
65597	K2	56.8	0.03
65597	M8	185.5	0.02
65598	M2	2.5	1.611
65598	S2	23	0.358
65598	N2	348	0.404
65598	K1	166	0.18
65598	M4	29.7	0.19
65598	O1	199.7	0.164
65598	M6	85.3	0.01
65598	MK3	8.4	0.039
65598	S4	350.3	0.013
65598	MN4	343.8	0.085
65598	NU2	346	0.069
65598	MU2	346.9	0.075
65598	2N2	333.9	0.056
65598	OO1	214.3	0.013
65598	LDA2	346.1	0.007
65598	S1	141	0.046
65598	M1	175	0.01
65598	J1	196	0.026
65598	SSA	61.8	0.066
65598	SA	140.5	0.2
65598	RHO1	235.4	0.007
65598	Q1	169.1	0.039
65598	T2	2.9	0.036
65598	R2	205.1	0.007
65598	2Q1	214.5	0.013
65598	P1	185.7	0.056
65598	2SM2	5.2	0.003
65598	M3	30.5	0.02
65598	L2	314.9	0.043
65598	2MK3	345.6	0.036
65598	K2	20.5	0.092
65598	MS4	102.2	0.049
65599	M2	111.8	0.869
65599	S2	108.7	0.075
65599	N2	75.4	0.289
65599	K1	210.6	0.262
65599	M4	22.9	0.22
65599	O1	212.6	0.236
65599	M6	23.3	0.098
65599	S4	98.3	0.02
65599	NU2	80.3	0.056
65599	S6	163.3	0.007
65599	MU2	333.9	0.02
65599	2N2	39	0.039
65599	OO1	208.6	0.01
65599	LDA2	110.4	0.007
65599	M1	211.6	0.016
65599	J1	209.6	0.02
65599	RHO1	213.4	0.01
65599	Q1	213.6	0.046
65599	T2	108.9	0.003
65599	2Q1	214.6	0.007
65599	P1	210.8	0.089
65599	L2	148.2	0.023
65599	K2	108.5	0.02
65599	M8	197.3	0.016
65600	M2	13.3	1.27
65600	S2	33.1	0.27
65600	N2	358.6	0.33
65600	K1	173.8	0.2
65600	M4	24.2	0.14
65600	O1	200.5	0.16
65600	M6	76.3	0.05
65600	MK3	342.7	0.03
65600	S4	345.8	0.01
65600	MN4	346.3	0.05
65600	NU2	351.1	0.05
65600	MU2	350.7	0.06
65600	2N2	339.9	0.05
65600	OO1	179.4	0.01
65600	LDA2	11.8	0.01
65600	S1	147.8	0.02
65600	M1	240.6	0.02
65600	J1	173.3	0.01
65600	SA	166.3	0.24
65600	RHO1	179.4	0.01
65600	Q1	191.9	0.03
65600	T2	18.3	0.02
65600	R2	276.7	0.01
65600	P1	187.3	0.06
65600	2SM2	22.1	0.01
65600	M3	4.5	0.01
65600	L2	14.6	0.03
65600	2MK3	335.4	0.03
65600	K2	33.3	0.07
65600	M8	130.8	0.01
65600	MS4	92.6	0.05
65601	M2	354.9	1.32
65601	S2	17.7	0.26
65601	N2	338.5	0.33
65601	K1	167.8	0.18
65601	M4	318.8	0.1
65601	O1	203.9	0.14
65601	M6	332.9	0.04
65601	S4	142.1	0.03
65601	NU2	340.7	0.07
65601	S6	100.9	0.01
65601	MU2	332.1	0.03
65601	2N2	322.1	0.04
65601	OO1	131.7	0.01
65601	LDA2	5.5	0.01
65601	M1	185.7	0.01
65601	J1	149.9	0.01
65601	SA	165.7	0.12
65601	RHO1	219.4	0.01
65601	Q1	221.8	0.03
65601	T2	16.8	0.02
65601	P1	170.5	0.06
65601	L2	11.3	0.04
65601	K2	19.6	0.07
65601	M8	69.1	0.01
65602	M2	134.7	1.44
65602	S2	166.7	0.15
65602	N2	102.5	0.37
65602	K1	221.6	0.3
65602	M4	25.5	0.09
65602	O1	215.9	0.28
65602	M6	7.3	0.03
65602	MN4	355.4	0.04
65602	NU2	114.7	0.08
65602	MU2	23.2	0.03
65602	2N2	77.9	0.05
65602	OO1	238.9	0.01
65602	LDA2	183.9	0.02
65602	M1	238.1	0.01
65602	J1	247.3	0.02
65602	SA	165.7	0.12
65602	RHO1	213.4	0.01
65602	Q1	204.4	0.05
65602	T2	147	0.02
65602	2Q1	210.1	0.01
65602	P1	225.8	0.1
65602	L2	183.4	0.06
65602	K2	166.3	0.04
65602	MS4	73.3	0.02
65603	M2	359.5	1.55
65603	S2	13.4	0.34
65603	N2	343	0.39
65603	K1	169.3	0.17
65603	M4	16.8	0.13
65603	O1	198.9	0.16
65603	M6	171.3	0.03
65603	MK3	17.6	0.02
65603	S4	305.5	0.01
65603	MN4	324.5	0.06
65603	NU2	344.1	0.06
65603	MU2	346.1	0.07
65603	2N2	332.4	0.06
65603	OO1	215.3	0.02
65603	LDA2	20.3	0.01
65603	S1	73.9	0.05
65603	M1	184.6	0.01
65603	J1	215.2	0.01
65603	MM	73.9	0.06
65603	SSA	75.1	0.05
65603	SA	145.3	0.2
65603	RHO1	190.7	0.01
65603	Q1	191.6	0.04
65603	T2	313.7	0.03
65603	R2	176.1	0.05
65603	2Q1	111.2	0.01
65603	P1	163.6	0.09
65603	2SM2	26	0.01
65603	M3	345.5	0.01
65603	L2	345.3	0.05
65603	2MK3	338.6	0.03
65603	K2	5.3	0.09
65603	M8	298.2	0.01
65603	MS4	71.6	0.03
65604	M2	8.6	1.9
65604	S2	30	0.43
65604	N2	359.6	0.44
65604	K1	184.1	0.28
65604	M4	63.5	0.28
65604	O1	172.2	0.15
65604	M6	308.9	0.04
65604	S4	1.5	0.07
65604	NU2	0.8	0.09
65604	S6	294.8	0.01
65604	MU2	204.7	0.05
65604	2N2	350.6	0.06
65604	OO1	196	0.01
65604	LDA2	18.5	0.01
65604	M1	178.2	0.01
65604	J1	190	0.01
65604	SSA	61.8	0.07
65604	SA	140.5	0.2
65604	RHO1	167.2	0.01
65604	Q1	166.4	0.03
65604	T2	29.1	0.03
65604	P1	183.2	0.1
65604	L2	17.6	0.05
65604	K2	31.7	0.12
65605	M2	6.6	1.9
65605	S2	32.5	0.42
65605	N2	352.3	0.44
65605	K1	157.8	0.2
65605	M4	56.4	0.28
65605	O1	203.6	0.16
65605	M6	296.1	0.06
65605	MK3	33.8	0.05
65605	S4	42.2	0.02
65605	MN4	10.1	0.11
65605	NU2	351	0.08
65605	MU2	355	0.08
65605	2N2	330.6	0.06
65605	OO1	215.6	0.01
65605	LDA2	337.4	0.01
65605	S1	182.9	0.06
65605	M1	163.7	0.01
65605	J1	197.4	0.03
65605	SA	131.8	0.2
65605	RHO1	226.7	0.02
65605	Q1	172.4	0.07
65605	T2	38.5	0.05
65605	R2	246.9	0.03
65605	2Q1	268.3	0.03
65605	P1	158.8	0.06
65605	2SM2	52.2	0.01
65605	M3	73.3	0.04
65605	L2	318.8	0.03
65605	2MK3	16.3	0.04
65605	K2	19.5	0.1
65605	M8	100.2	0.01
65605	MS4	137.8	0.06
65606	M2	2.3	1.66
65606	S2	25	0.35
65606	N2	345.8	0.41
65606	K1	166.1	0.2
65606	M4	35.8	0.19
65606	O1	202	0.15
65606	M6	220.1	0.02
65606	MK3	19.5	0.03
65606	S4	5.1	0.02
65606	MN4	347.9	0.09
65606	NU2	341	0.07
65606	MU2	344.5	0.08
65606	2N2	333	0.06
65606	OO1	195.7	0.01
65606	LDA2	345.5	0.01
65606	S1	121.9	0.02
65606	M1	204	0.01
65606	J1	181.1	0.02
65606	MM	73.9	0.06
65606	SSA	75.1	0.05
65606	SA	145.3	0.2
65606	RHO1	230.9	0.01
65606	Q1	185.3	0.04
65606	T2	9	0.03
65606	2Q1	172.9	0.01
65606	P1	176.6	0.07
65606	2SM2	48.8	0.01
65606	M3	34.1	0.02
65606	L2	349.9	0.04
65606	2MK3	357.1	0.03
65606	K2	21.7	0.1
65606	MS4	106.4	0.05
65607	M2	7.2	1.95
65607	S2	30	0.43
65607	N2	351.9	0.48
65607	K1	165.7	0.22
65607	M4	58.3	0.3
65607	O1	198.6	0.17
65607	M6	304.4	0.06
65607	MK3	28.8	0.04
65607	S4	23.5	0.03
65607	MN4	9.9	0.13
65607	NU2	344.6	0.08
65607	MU2	354.4	0.09
65607	2N2	340.9	0.08
65607	OO1	169.1	0.02
65607	LDA2	18.1	0.01
65607	S1	120.5	0.05
65607	M1	178.1	0.01
65607	J1	201.6	0.02
65607	SA	131.8	0.2
65607	RHO1	212.7	0.01
65607	Q1	183.7	0.04
65607	T2	10.2	0.04
65607	P1	183.2	0.08
65607	2SM2	43	0.01
65607	M3	30.1	0.03
65607	L2	338.3	0.07
65607	2MK3	3.1	0.05
65607	K2	28.6	0.12
65607	MS4	142.4	0.08
65608	M2	2.8	1.69
65608	S2	24.8	0.35
65608	N2	349.3	0.41
65608	K1	172.9	0.29
65608	M4	45.5	0.18
65608	O1	200.6	0.17
65608	M6	232.7	0.02
65608	S4	12.2	0.03
65608	NU2	351.1	0.08
65608	S6	345.1	0.01
65608	MU2	198.1	0.04
65608	2N2	335.8	0.05
65608	OO1	145.1	0.01
65608	LDA2	13	0.01
65608	M1	186.6	0.01
65608	J1	159.1	0.01
65608	RHO1	212.5	0.01
65608	Q1	214.4	0.03
65608	T2	23.9	0.02
65608	P1	174.9	0.1
65608	L2	16.3	0.05
65608	K2	26.6	0.1
65608	M8	19.2	0.01
65609	M2	9.5	2.11
65609	S2	33.6	0.45
65609	N2	354.6	0.5
65609	K1	169.4	0.24
65609	M4	62.1	0.34
65609	O1	202.2	0.18
65609	M6	312.7	0.09
65609	MK3	39.3	0.05
65609	S4	23.8	0.05
65609	MN4	12.7	0.14
65609	NU2	353	0.09
65609	MU2	358.6	0.1
65609	2N2	343.2	0.07
65609	OO1	136.5	0.01
65609	LDA2	346.1	0.02
65609	S1	125	0.05
65609	M1	247.6	0.02
65609	J1	197.1	0.02
65609	SA	131.8	0.2
65609	RHO1	216.2	0.01
65609	Q1	179.9	0.05
65609	T2	14.1	0.04
65609	R2	216.5	0.01
65609	P1	182.3	0.08
65609	M3	68.3	0.04
65609	L2	321.4	0.04
65609	2MK3	11.5	0.04
65609	K2	29.7	0.12
65609	M8	130.7	0.02
65609	MS4	147.4	0.09
65610	M2	5	1.77
65610	S2	27.1	0.38
65610	N2	349.4	0.44
65610	K1	165.1	0.21
65610	M4	48.9	0.22
65610	O1	198.2	0.16
65610	M6	270.9	0.03
65610	MK3	21.4	0.03
65610	S4	10.3	0.03
65610	MN4	0.6	0.1
65610	NU2	344.7	0.08
65610	MU2	351.2	0.09
65610	2N2	339	0.07
65610	OO1	166.1	0.01
65610	LDA2	15.2	0.01
65610	S1	128.5	0.04
65610	M1	175.2	0.01
65610	J1	200.6	0.02
65610	SA	131.8	0.2
65610	RHO1	212.4	0.01
65610	Q1	183	0.04
65610	T2	6.8	0.03
65610	P1	185.7	0.08
65610	2SM2	29.2	0.01
65610	M3	25.4	0.02
65610	L2	336.7	0.06
65610	2MK3	356.5	0.04
65610	K2	25.8	0.1
65610	MS4	129.2	0.06
65611	M2	6.8	1.75
65611	S2	29.6	0.36
65611	N2	353.7	0.42
65611	K1	165.4	0.23
65611	M4	56	0.21
65611	O1	201.8	0.16
65611	M6	268.2	0.03
65611	S4	348.4	0.02
65611	NU2	355.5	0.08
65611	MU2	201.1	0.04
65611	2N2	340.6	0.06
65611	OO1	128.7	0.01
65611	LDA2	17.4	0.01
65611	M1	183.3	0.01
65611	J1	147.1	0.01
65611	SSA	61.8	0.07
65611	SA	140.5	0.2
65611	RHO1	217.4	0.01
65611	Q1	219.9	0.03
65611	T2	28.7	0.02
65611	P1	168.1	0.08
65611	L2	19.9	0.05
65611	K2	31.5	0.1
65612	M2	6.6	1.87
65612	S2	32.5	0.41
65612	N2	352.2	0.43
65612	K1	157	0.2
65612	M4	55.2	0.27
65612	O1	204	0.15
65612	M6	287.2	0.06
65612	MK3	35.7	0.04
65612	S4	40.3	0.02
65612	MN4	8	0.11
65612	NU2	349	0.08
65612	MU2	354	0.09
65612	2N2	331.1	0.06
65612	OO1	216.5	0.01
65612	LDA2	330.2	0.01
65612	S1	188.3	0.06
65612	M1	155.6	0.01
65612	J1	197	0.03
65612	SA	131.8	0.2
65612	RHO1	219.9	0.02
65612	Q1	171.5	0.07
65612	T2	36.6	0.04
65612	R2	246.5	0.03
65612	2Q1	266.9	0.03
65612	P1	155	0.06
65612	2SM2	52.6	0.01
65612	M3	74	0.04
65612	L2	317.9	0.03
65612	2MK3	15.3	0.03
65612	K2	18.1	0.1
65612	MS4	136.2	0.06
65613	M2	8.2	1.5
65613	S2	28.2	0.32
65613	N2	349.2	0.36
65613	K1	162.9	0.21
65613	M4	23.9	0.08
65613	O1	198.1	0.16
65613	M6	196.9	0.04
65613	MK3	36.9	0.02
65613	S4	27.6	0.01
65613	MN4	331.4	0.04
65613	NU2	320.5	0.08
65613	MU2	347.1	0.08
65613	2N2	331.6	0.07
65613	OO1	304.1	0.01
65613	LDA2	145.3	0.02
65613	S1	150.1	0.05
65613	M1	215.7	0.02
65613	J1	217.9	0.02
65613	SSA	61.8	0.07
65613	SA	140.5	0.2
65613	RHO1	82	0.02
65613	Q1	208.2	0.05
65613	T2	1.6	0.03
65613	R2	192.9	0.03
65613	2Q1	223.6	0.01
65613	P1	193.6	0.05
65613	2SM2	61.6	0.02
65613	M3	353.8	0.02
65613	L2	21.1	0.04
65613	2MK3	18.1	0.03
65613	K2	32.1	0.07
65613	M8	341.3	0.01
65613	MS4	115.4	0.02
65614	M2	13.6	1.92
65614	S2	41	0.38
65614	N2	359.3	0.45
65614	K1	167.4	0.25
65614	M4	70	0.29
65614	O1	200.7	0.17
65614	M6	342.3	0.1
65614	S4	66.8	0.02
65614	NU2	1.2	0.09
65614	MU2	346.2	0.05
65614	2N2	345	0.06
65614	OO1	133.4	0.01
65614	LDA2	26.3	0.01
65614	M1	184	0.01
65614	J1	150.8	0.01
65614	SA	131.8	0.2
65614	RHO1	214.3	0.01
65614	Q1	217.4	0.03
65614	T2	40	0.02
65614	P1	169.9	0.08
65614	L2	27.8	0.05
65614	K2	43.2	0.1
65614	M8	101	0.01
65615	M2	44.2	1.2
65615	S2	65	0.22
65615	N2	25	0.28
65615	K1	172.5	0.25
65615	M4	8.8	0.13
65615	O1	207.5	0.16
65615	M6	217.3	0.09
65615	NU2	27.7	0.06
65615	MU2	23.5	0.03
65615	2N2	5.9	0.04
65615	OO1	137.8	0.01
65615	LDA2	53.9	0.01
65615	M1	190	0.01
65615	J1	155.3	0.01
65615	SSA	69.4	0.06
65615	SA	135.3	0.18
65615	RHO1	222.2	0.01
65615	Q1	224.9	0.03
65615	T2	64.2	0.01
65615	P1	175.2	0.09
65615	L2	63.4	0.03
65615	K2	66.7	0.06
65615	M8	198.7	0.01
65616	M2	19.3	1.24
65616	S2	31.2	0.24
65616	N2	3.6	0.32
65616	K1	184.2	0.24
65616	M4	30.2	0.04
65616	O1	206.7	0.14
65616	M6	174.1	0.05
65616	NU2	5.7	0.06
65616	S6	17.1	0.01
65616	MU2	223.9	0.03
65616	2N2	347.9	0.04
65616	OO1	161.7	0.01
65616	LDA2	24.8	0.01
65616	M1	195.4	0.01
65616	J1	173	0.01
65616	RHO1	216.4	0.01
65616	Q1	217.9	0.03
65616	T2	30.7	0.01
65616	P1	185.9	0.08
65616	L2	34.9	0.04
65616	K2	32.1	0.07
65616	M8	299.8	0.01
65617	M2	359.8	1.42
65617	S2	22.1	0.32
65617	N2	343.1	0.33
65617	K1	168.5	0.2
65617	M4	11.5	0.08
65617	O1	198.7	0.15
65617	M6	178	0.04
65617	MK3	16.6	0.02
65617	S4	312.7	0.01
65617	MN4	329.8	0.04
65617	NU2	343.6	0.05
65617	MU2	340.9	0.07
65617	2N2	326.9	0.05
65617	OO1	189.2	0.01
65617	S1	143.1	0.01
65617	M1	197.8	0.01
65617	J1	170.6	0.02
65617	SSA	69.4	0.06
65617	SA	135.3	0.18
65617	RHO1	144.8	0.02
65617	Q1	189.9	0.04
65617	T2	1.2	0.03
65617	2Q1	117.9	0.01
65617	P1	175.4	0.06
65617	2SM2	17.5	0.01
65617	M3	49.2	0.02
65617	L2	243.2	0.02
65617	2MK3	352.4	0.02
65617	K2	19.1	0.09
65617	M8	288.7	0.01
65617	MS4	81	0.02
65618	M2	8.1	1.3
65618	S2	28.9	0.28
65618	N2	350.3	0.31
65618	K1	165.2	0.23
65618	M4	16.1	0.08
65618	O1	200.8	0.15
65618	M6	182.9	0.05
65618	MK3	22.6	0.02
65618	MN4	327	0.04
65618	NU2	350.4	0.06
65618	MU2	343.1	0.07
65618	2N2	329	0.05
65618	OO1	180.1	0.01
65618	LDA2	84.5	0.01
65618	S1	227.3	0.02
65618	M1	196.1	0.01
65618	J1	171.6	0.02
65618	SSA	61.8	0.07
65618	SA	140.5	0.2
65618	RHO1	125	0.01
65618	Q1	183.8	0.04
65618	T2	21.2	0.02
65618	P1	162.4	0.06
65618	2SM2	37.8	0.01
65618	M3	59.1	0.02
65618	L2	251.3	0.02
65618	2MK3	0.3	0.01
65618	K2	29	0.08
65618	M8	276.5	0.01
65618	MS4	90.7	0.02
65619	M2	5.8	1.31
65619	S2	25	0.28
65619	N2	346.9	0.31
65619	K1	169.4	0.21
65619	M4	12.7	0.06
65619	O1	203.8	0.15
65619	M6	175.9	0.05
65619	MK3	8.2	0.01
65619	MN4	322.1	0.03
65619	NU2	347.9	0.06
65619	MU2	344.6	0.06
65619	2N2	329.8	0.05
65619	OO1	134.9	0.01
65619	LDA2	14.6	0.01
65619	S1	103.6	0.02
65619	M1	181.2	0.01
65619	J1	174.6	0.01
65619	SA	131.8	0.2
65619	RHO1	254.4	0.02
65619	Q1	185.7	0.04
65619	T2	8.5	0.03
65619	2Q1	201.1	0.02
65619	P1	185.1	0.07
65619	M3	43.5	0.02
65619	L2	81.2	0.02
65619	2MK3	3.6	0.02
65619	K2	25.5	0.08
65619	MS4	85.2	0.02
65620	M2	47.6	1.14
65620	S2	56.9	0.23
65620	N2	26.4	0.27
65620	K1	168.6	0.21
65620	M4	347.6	0.08
65620	O1	211.6	0.15
65620	M6	192	0.07
65620	MK3	39.9	0.02
65620	S4	340.1	0.01
65620	MN4	319.7	0.04
65620	NU2	26.3	0.06
65620	MU2	348.8	0.04
65620	2N2	355.2	0.03
65620	OO1	218.4	0.01
65620	S1	197.7	0.06
65620	M1	182	0.01
65620	J1	211.8	0.03
65620	SSA	69.4	0.06
65620	SA	135.3	0.18
65620	RHO1	236.8	0.02
65620	Q1	186	0.06
65620	T2	34.2	0.03
65620	R2	190.4	0.03
65620	2Q1	269.3	0.02
65620	P1	172.5	0.05
65620	2SM2	35.1	0.01
65620	M3	71.3	0.02
65620	L2	115.5	0.02
65620	2MK3	30.9	0.02
65620	K2	74.1	0.04
65620	MS4	28.6	0.01
65621	M2	58.3	1.22
65621	S2	69.9	0.22
65621	N2	34.6	0.29
65621	K1	178.5	0.24
65621	M4	343.7	0.09
65621	O1	209	0.17
65621	M6	206.1	0.04
65621	MK3	28.9	0.02
65621	S4	344.1	0.01
65621	MN4	313.3	0.05
65621	NU2	44.8	0.06
65621	MU2	347.7	0.05
65621	2N2	13.4	0.04
65621	OO1	209.8	0.01
65621	LDA2	113.2	0.02
65621	S1	145.5	0.02
65621	M1	253.9	0.02
65621	J1	215.6	0.02
65621	SSA	69.4	0.06
65621	SA	135.3	0.18
65621	RHO1	222	0.01
65621	Q1	193.4	0.05
65621	T2	52.4	0.02
65621	2Q1	233.8	0.01
65621	P1	189.8	0.08
65621	M3	66.4	0.01
65621	L2	127.1	0.04
65621	2MK3	15.2	0.01
65621	K2	70.8	0.06
65621	MS4	5.7	0.01
65622	M2	104.6	2.23
65622	S2	128.1	0.33
65622	N2	85.8	0.49
65622	K1	183.2	0.29
65622	M4	187.4	0.05
65622	O1	215.1	0.2
65622	M6	352.1	0.06
65622	NU2	88.3	0.1
65622	MU2	296.1	0.05
65622	2N2	67.1	0.07
65622	OO1	151.1	0.01
65622	LDA2	115.5	0.02
65622	M1	199	0.01
65622	J1	167.3	0.02
65622	SSA	69.4	0.06
65622	SA	135.3	0.18
65622	RHO1	228.8	0.01
65622	Q1	230.9	0.04
65622	T2	127.1	0.02
65622	2Q1	246.8	0.01
65622	P1	185.5	0.1
65622	L2	123.5	0.06
65622	K2	130	0.09
65622	M8	157.2	0.02
65623	M2	106.4	2.93
65623	S2	130.7	0.47
65623	N2	81.7	0.62
65623	K1	190	0.31
65623	M4	101.8	0.01
65623	O1	218.4	0.21
65623	M6	350	0.09
65623	MK3	186.5	0.01
65623	MN4	67.4	0.01
65623	NU2	86.3	0.14
65623	MU2	321.5	0.01
65623	2N2	72	0.09
65623	OO1	229.6	0.02
65623	LDA2	133.6	0.06
65623	S1	113.2	0.05
65623	M1	228.7	0.01
65623	J1	248.9	0.03
65623	SSA	61.2	0.07
65623	SA	132	0.21
65623	RHO1	173.1	0.01
65623	Q1	210.7	0.05
65623	T2	99.6	0.04
65623	2Q1	246.5	0.01
65623	P1	203.7	0.1
65623	M3	162.4	0.01
65623	L2	143.8	0.17
65623	2MK3	186.1	0.01
65623	K2	131.1	0.13
65624	M2	109.6	3.25
65624	S2	135.9	0.52
65624	N2	87.6	0.66
65624	K1	191.6	0.32
65624	M4	127.4	0.04
65624	O1	219.5	0.21
65624	M6	353.9	0.04
65624	MK3	198.8	0.02
65624	MN4	97.2	0.02
65624	NU2	89.8	0.15
65624	2N2	65.6	0.08
65624	OO1	228.7	0.02
65624	LDA2	131.1	0.07
65624	S1	175.5	0.03
65624	M1	264.4	0.02
65624	J1	237	0.02
65624	SSA	61.2	0.07
65624	SA	132	0.21
65624	RHO1	258.1	0.02
65624	Q1	205.7	0.06
65624	T2	106.4	0.05
65624	2Q1	238.8	0.01
65624	P1	204.1	0.1
65624	M3	200.1	0.01
65624	L2	134.1	0.16
65624	2MK3	203.7	0.02
65624	K2	134.7	0.15
65625	M2	110.2	3.31
65625	S2	138.4	0.489
65625	N2	92.6	0.718
65625	K1	182.8	0.331
65625	M4	134.9	0.039
65625	O1	214.5	0.197
65625	M6	354.3	0.046
65625	S4	135	0.007
65625	NU2	94.9	0.141
65625	MU2	295.4	0.079
65625	2N2	75	0.095
65625	OO1	151.4	0.01
65625	LDA2	123.4	0.023
65625	M1	198.6	0.013
65625	J1	167.3	0.016
65625	SSA	61.2	0.072
65625	SA	132	0.207
65625	RHO1	228.1	0.007
65625	Q1	230.1	0.036
65625	T2	137.3	0.03
65625	R2	139.6	0.003
65625	2Q1	245.9	0.007
65625	P1	185.2	0.108
65625	L2	127.8	0.092
65625	K2	140.7	0.135
65625	M8	310.4	0.007
65626	M2	110.7	3.41
65626	S2	145.7	0.47
65626	N2	91.2	0.67
65626	K1	181.2	0.31
65626	M4	130.1	0.04
65626	O1	220	0.19
65626	M6	4.9	0.03
65626	NU2	93.8	0.13
65626	S6	213.2	0.01
65626	MU2	75.7	0.08
65626	2N2	71.7	0.09
65626	OO1	142.5	0.01
65626	LDA2	127	0.02
65626	M1	200.5	0.01
65626	J1	162	0.02
65626	SSA	61.2	0.07
65626	SA	132	0.21
65626	RHO1	236.6	0.01
65626	Q1	239.2	0.04
65626	T2	144.3	0.03
65626	2Q1	258.4	0.01
65626	P1	184.2	0.1
65626	L2	130.2	0.1
65626	K2	148.6	0.13
65626	M8	342.4	0.01
65627	M2	111.9	3.41
65627	S2	146	0.55
65627	N2	90.3	0.67
65627	K1	185.3	0.3
65627	M4	136.7	0.08
65627	O1	224.5	0.2
65627	M6	31.2	0.02
65627	MK3	203.6	0.03
65627	S4	155.5	0.01
65627	MN4	112.7	0.04
65627	NU2	89.1	0.15
65627	MU2	199.9	0.01
65627	2N2	72.7	0.05
65627	OO1	275.3	0.01
65627	LDA2	138.4	0.06
65627	S1	201.6	0.03
65627	M1	209.5	0.01
65627	J1	237.4	0.03
65627	SSA	61.2	0.07
65627	SA	132	0.21
65627	RHO1	242	0.02
65627	Q1	196.4	0.07
65627	T2	174.7	0.05
65627	R2	34.1	0.08
65627	2Q1	284.3	0.03
65627	P1	196.7	0.07
65627	2SM2	54.2	0.01
65627	M3	219	0.02
65627	L2	142.2	0.19
65627	2MK3	214.7	0.02
65627	K2	124.1	0.17
65627	M8	320.7	0.01
65627	MS4	149.4	0.02
65628	M2	113.9	3.51
65628	S2	137	0.55
65628	N2	92.7	0.79
65628	K1	185.2	0.33
65628	M4	131.9	0.07
65628	O1	219.4	0.22
65628	M6	143	0.02
65628	S4	123.7	0.01
65628	NU2	95.5	0.15
65628	MU2	303.9	0.09
65628	2N2	71.5	0.1
65628	OO1	150.9	0.01
65628	LDA2	124.6	0.02
65628	M1	202.1	0.02
65628	J1	168.2	0.02
65628	SSA	61.2	0.07
65628	SA	132	0.21
65628	RHO1	234.1	0.01
65628	Q1	236.4	0.04
65628	T2	136	0.03
65628	2Q1	253.4	0.01
65628	P1	187.7	0.11
65628	L2	134.9	0.1
65628	K2	138.8	0.15
65628	M8	311.2	0.01
65629	M2	111.7	3.48
65629	S2	141	0.53
65629	N2	88	0.74
65629	K1	185.8	0.36
65629	M4	137	0.08
65629	O1	229	0.16
65629	M6	154.3	0.06
65629	S4	169.1	0.02
65629	NU2	91.2	0.14
65629	MU2	82.4	0.08
65629	2N2	64.4	0.1
65629	OO1	142.6	0.01
65629	LDA2	125.3	0.02
65629	M1	207.2	0.01
65629	J1	164.4	0.01
65629	SSA	61.2	0.07
65629	SA	132	0.21
65629	RHO1	247.5	0.01
65629	Q1	250.4	0.03
65629	T2	139.8	0.03
65629	P1	189	0.12
65629	L2	135.4	0.1
65629	K2	143.4	0.14
65630	M2	113.5	3.68
65630	S2	139.3	0.59
65630	N2	91.8	0.72
65630	K1	192.4	0.31
65630	M4	133.1	0.1
65630	O1	217.9	0.21
65630	M6	158.4	0.12
65630	MK3	198.1	0.03
65630	S4	168.5	0.01
65630	MN4	110.9	0.06
65630	NU2	93.5	0.18
65630	MU2	174.2	0.01
65630	2N2	74.7	0.05
65630	OO1	245.4	0.01
65630	LDA2	119	0.07
65630	S1	163.2	0.04
65630	M1	179.1	0.01
65630	J1	256.9	0.02
65630	SSA	61.2	0.07
65630	SA	132	0.21
65630	RHO1	288.6	0.01
65630	Q1	204	0.06
65630	T2	121	0.06
65630	R2	339.8	0.02
65630	2Q1	283.4	0.01
65630	P1	206.7	0.09
65630	2SM2	40.5	0.01
65630	M3	220.2	0.02
65630	L2	141.1	0.2
65630	2MK3	218.1	0.03
65630	K2	132.4	0.17
65630	M8	216.7	0.01
65630	MS4	154.2	0.02
65631	M2	113.6	3.66
65631	S2	143.2	0.55
65631	N2	91.6	0.73
65631	K1	187	0.32
65631	M4	137.1	0.08
65631	O1	224.7	0.21
65631	M6	160.4	0.09
65631	S4	190.9	0.01
65631	NU2	94.6	0.14
65631	MU2	83.9	0.09
65631	2N2	69.6	0.1
65631	OO1	149.1	0.01
65631	LDA2	127.3	0.03
65631	M1	205.7	0.01
65631	J1	168.3	0.02
65631	SSA	61.2	0.07
65631	SA	132	0.21
65631	RHO1	240.6	0.01
65631	Q1	243.4	0.04
65631	T2	142	0.03
65631	2Q1	262.5	0.01
65631	P1	189.9	0.1
65631	L2	135.6	0.1
65631	K2	145.6	0.15
65631	M8	280.8	0.01
65632	M2	0.7	1.24
65632	S2	26.2	0.28
65632	N2	345	0.29
65632	K1	161.1	0.22
65632	M4	123.7	0.05
65632	O1	194.3	0.13
65632	M6	199.5	0.05
65632	MK3	347.9	0.01
65632	NU2	339.4	0.06
65632	MU2	341.7	0.07
65632	2N2	331	0.04
65632	OO1	127.7	0.01
65632	LDA2	12.5	0.01
65632	S1	194	0.02
65632	M1	177.7	0.01
65632	J1	144.4	0.01
65632	SSA	64.4	0.06
65632	SA	145.7	0.17
65632	RHO1	208.7	0.01
65632	Q1	170	0.04
65632	T2	26.1	0.02
65632	P1	158.4	0.05
65632	M3	55.7	0.02
65632	L2	269.2	0.04
65632	2MK3	328.9	0.02
65632	K2	18.8	0.08
65632	MS4	148.8	0.03
65633	M2	48.5	0.92
65633	S2	60.7	0.18
65633	N2	25.6	0.25
65633	K1	174.8	0.22
65633	M4	16.7	0.07
65633	O1	215.8	0.14
65633	M6	158.3	0.04
65633	NU2	28.7	0.05
65633	MU2	252.4	0.02
65633	2N2	2.7	0.03
65633	OO1	133.8	0.01
65633	LDA2	54.1	0.01
65633	M1	195.2	0.01
65633	J1	154.5	0.01
65633	RHO1	233.4	0.01
65633	Q1	236.2	0.03
65633	T2	60.2	0.01
65633	P1	177.9	0.07
65633	L2	71.4	0.03
65633	K2	61.6	0.05
65633	M8	250.1	0.01
65634	M2	46.8	0.99
65634	S2	56.6	0.21
65634	N2	22.2	0.26
65634	K1	178.7	0.24
65634	M4	342.7	0.08
65634	O1	209.8	0.18
65634	M6	160.3	0.04
65634	MK3	16.9	0.02
65634	S4	327.7	0.01
65634	MN4	307.4	0.04
65634	NU2	33.6	0.05
65634	MU2	354.5	0.07
65634	2N2	354.6	0.04
65634	OO1	184.6	0.01
65634	LDA2	147.1	0.01
65634	S1	143.6	0.02
65634	M1	223.4	0.01
65634	J1	202.7	0.02
65634	SSA	50.9	0.11
65634	SA	135.1	0.23
65634	RHO1	228.1	0.01
65634	Q1	192.6	0.05
65634	T2	41.7	0.02
65634	2Q1	199.4	0.01
65634	P1	193.7	0.08
65634	M3	52.1	0.01
65634	L2	168.3	0.03
65634	2MK3	6.2	0.02
65634	K2	61.6	0.06
65635	M2	60.1	1.06
65635	S2	73.8	0.2
65635	N2	37.6	0.26
65635	K1	178.9	0.24
65635	M4	344	0.07
65635	O1	208.1	0.15
65635	M6	194.2	0.05
65635	MK3	22.2	0.02
65635	S4	327.9	0.01
65635	MN4	309.3	0.04
65635	NU2	47	0.05
65635	S6	216.6	0.01
65635	MU2	344.3	0.04
65635	2N2	33.9	0.04
65635	OO1	186	0.01
65635	LDA2	130.9	0.02
65635	S1	91.6	0.04
65635	M1	205.5	0.02
65635	J1	242.9	0.03
65635	SSA	69.4	0.06
65635	SA	135.3	0.18
65635	RHO1	223.5	0.02
65635	Q1	192.7	0.04
65635	T2	65.6	0.02
65635	2Q1	130.2	0.01
65635	P1	199.6	0.08
65635	2SM2	35.4	0.01
65635	M3	45.8	0.01
65635	L2	86.4	0.02
65635	2MK3	355	0.02
65635	K2	68.9	0.05
65635	MS4	11.4	0.01
65636	M2	78	1.16
65636	S2	89.1	0.21
65636	N2	50	0.27
65636	K1	186.4	0.23
65636	M4	284.1	0.03
65636	O1	214.9	0.15
65636	M6	166.7	0.02
65636	MK3	0	0.02
65636	S4	330.4	0.01
65636	MN4	291.5	0.02
65636	NU2	59.1	0.05
65636	MU2	358.3	0.05
65636	2N2	9	0.05
65636	OO1	226.2	0.01
65636	LDA2	142	0.02
65636	S1	135.1	0.02
65636	M1	209.9	0.02
65636	SSA	50.9	0.11
65636	SA	135.1	0.23
65636	RHO1	193.8	0.02
65636	Q1	211.7	0.05
65636	T2	54.6	0.02
65636	R2	236.2	0.01
65636	2Q1	137	0.01
65636	P1	191.7	0.06
65636	2SM2	47.8	0.01
65636	M3	74.4	0.01
65636	L2	148.1	0.09
65636	2MK3	14.1	0.02
65636	K2	85.2	0.06
65636	M8	247	0.01
65636	MS4	232.9	0.01
65637	M2	73.6	1.22
65637	S2	84.7	0.22
65637	N2	44.6	0.29
65637	K1	180.5	0.25
65637	M4	12.1	0.04
65637	O1	212.7	0.17
65637	M6	237.1	0.02
65637	MN4	319.5	0.03
65637	NU2	55.6	0.05
65637	MU2	350.4	0.06
65637	2N2	16.1	0.04
65637	OO1	225.5	0.02
65637	LDA2	134.1	0.03
65637	S1	148.9	0.02
65637	M1	201.1	0.02
65637	J1	230.1	0.02
65637	SSA	50.9	0.11
65637	SA	135.1	0.23
65637	Q1	202.7	0.05
65637	T2	56.2	0.02
65637	2Q1	169.6	0.02
65637	P1	188.7	0.08
65637	M3	65.4	0.01
65637	L2	139.2	0.07
65637	2MK3	15.8	0.01
65637	K2	80.1	0.06
65638	M2	91.3	1.14
65638	S2	101.3	0.19
65638	N2	63.9	0.25
65638	K1	188.2	0.24
65638	M4	3.7	0.06
65638	O1	230.5	0.18
65638	M6	219.2	0.01
65638	NU2	67.5	0.05
65638	MU2	81.3	0.03
65638	2N2	36.5	0.03
65638	OO1	145.6	0.01
65638	LDA2	95.9	0.01
65638	M1	209.1	0.01
65638	J1	167.2	0.01
65638	SSA	50.9	0.11
65638	SA	135.1	0.23
65638	RHO1	248.8	0.01
65638	Q1	251.6	0.04
65638	T2	100.9	0.01
65638	P1	191.3	0.08
65638	L2	118.6	0.03
65638	K2	102.1	0.05
65638	M8	212.9	0.01
65639	M2	83.3	1.2
65639	S2	93.1	0.19
65639	N2	58.4	0.26
65639	K1	195.9	0.22
65639	M4	350.9	0.06
65639	O1	233	0.17
65639	M6	135.3	0.01
65639	S4	325.6	0.01
65639	NU2	61.7	0.05
65639	S6	201	0.01
65639	MU2	73.5	0.03
65639	2N2	33.5	0.03
65639	OO1	160	0.01
65639	LDA2	87.9	0.01
65639	M1	214.6	0.01
65639	J1	178.4	0.01
65639	SSA	69.4	0.06
65639	SA	135.3	0.18
65639	RHO1	248.7	0.01
65639	Q1	251.3	0.03
65639	T2	92.6	0.01
65639	P1	198.7	0.07
65639	L2	108	0.03
65639	K2	93.9	0.05
65639	M8	223.7	0.01
65640	M2	92.2	1.15
65640	S2	104.1	0.18
65640	N2	64.7	0.25
65640	K1	187.5	0.24
65640	M4	330	0.06
65640	O1	228	0.18
65640	M6	224.3	0.01
65640	NU2	68.4	0.05
65640	MU2	80.2	0.03
65640	2N2	37.2	0.03
65640	OO1	147	0.01
65640	LDA2	97.7	0.01
65640	M1	207.5	0.01
65640	J1	167.9	0.01
65640	SSA	50.9	0.11
65640	SA	135.1	0.23
65640	RHO1	245.3	0.01
65640	Q1	248	0.04
65640	T2	103.6	0.01
65640	P1	190.6	0.08
65640	L2	119.6	0.03
65640	K2	105.1	0.05
65640	M8	233.6	0.01
65641	M2	353.6	1.44
65641	S2	22.7	0.3
65641	N2	338.9	0.32
65641	K1	172	0.21
65641	M4	46	0.14
65641	O1	174.7	0.13
65641	M6	260	0.02
65641	S4	238.3	0.01
65641	NU2	340.9	0.06
65641	MU2	325	0.04
65641	2N2	324.2	0.04
65641	LDA2	7	0.01
65641	M1	173.5	0.01
65641	J1	171.3	0.01
65641	SSA	42.9	0.09
65641	SA	129.1	0.22
65641	Q1	175.6	0.02
65641	T2	21.6	0.02
65641	P1	172.2	0.07
65641	L2	8.3	0.04
65641	K2	25	0.08
65641	M8	353.1	0.01
65642	M2	7.8	1.35
65642	S2	38.4	0.27
65642	N2	355.9	0.3
65642	K1	181.7	0.22
65642	M4	329.1	0.04
65642	O1	185.9	0.16
65642	M6	333	0.02
65642	S4	311.7	0.01
65642	NU2	357.5	0.06
65642	MU2	337.3	0.03
65642	2N2	343.9	0.04
65642	OO1	179	0.01
65642	LDA2	22	0.01
65642	M1	184.2	0.01
65642	J1	180	0.01
65642	SSA	42.9	0.09
65642	SA	129.1	0.22
65642	RHO1	186	0.01
65642	Q1	187.3	0.03
65642	T2	37.1	0.02
65642	P1	182.1	0.07
65642	L2	19.7	0.04
65642	K2	40.9	0.07
65643	M2	114.2	2.46
65643	S2	141.7	0.38
65643	N2	94.1	0.53
65643	K1	185.6	0.31
65643	M4	218.7	0.02
65643	O1	223.2	0.2
65643	M6	356	0.08
65643	NU2	96.8	0.1
65643	MU2	301.5	0.06
65643	2N2	73.9	0.07
65643	OO1	148	0.01
65643	LDA2	127	0.02
65643	M1	204.2	0.01
65643	J1	166.9	0.02
65643	RHO1	239.3	0.01
65643	Q1	241.8	0.04
65643	T2	140.6	0.02
65643	2Q1	260.5	0.01
65643	P1	188.4	0.1
65643	L2	134.3	0.07
65643	K2	143.9	0.1
65643	M8	139.9	0.01
65644	M2	135.3	1.32
65644	S2	161.2	0.19
65644	N2	116.7	0.24
65644	K1	206.7	0.26
65644	M4	161.7	0.05
65644	O1	248.7	0.18
65644	M6	79.6	0.04
65644	S4	219.6	0.01
65644	NU2	119.2	0.05
65644	MU2	324.3	0.03
65644	2N2	98.1	0.03
65644	OO1	164.7	0.01
65644	LDA2	147.3	0.01
65644	M1	227.5	0.01
65644	J1	185.9	0.01
65644	RHO1	266.7	0.01
65644	Q1	269.5	0.04
65644	T2	160.2	0.01
65644	P1	209.9	0.09
65644	L2	153.9	0.04
65644	K2	163.3	0.05
65644	M8	72.3	0.01
65645	M2	48.9	1.11
65645	S2	66.3	0.2
65645	N2	37.6	0.23
65645	K1	202.8	0.23
65645	M4	38.1	0.13
65645	O1	211.4	0.12
65645	M6	110.7	0.03
65645	MK3	172.9	0.03
65645	S4	81.1	0.01
65645	MN4	27.4	0.06
65645	NU2	26	0.06
65645	MU2	112.9	0.06
65645	2N2	317.5	0.01
65645	OO1	243.7	0.01
65645	LDA2	44.4	0.03
65645	S1	184	0.02
65645	M1	236	0.01
65645	J1	288.1	0.01
65645	SSA	50.9	0.11
65645	SA	135.1	0.23
65645	RHO1	238.8	0.01
65645	Q1	222.6	0.04
65645	T2	80.1	0.04
65645	R2	83.5	0.06
65645	2Q1	230.6	0.01
65645	P1	211.7	0.06
65645	2SM2	257.2	0.01
65645	M3	189.8	0.01
65645	L2	10.1	0.07
65645	2MK3	94.5	0.02
65645	K2	65.6	0.06
65645	M8	111.6	0.01
65645	MS4	74.3	0.05
65646	M2	111.9	2.55
65646	S2	135.6	0.41
65646	N2	87.4	0.52
65646	K1	191.3	0.29
65646	M4	242.3	0.01
65646	O1	221.5	0.19
65646	M6	345.1	0.08
65646	MK3	224.1	0.01
65646	NU2	91.9	0.12
65646	MU2	305.9	0.01
65646	2N2	66.1	0.05
65646	OO1	203.8	0.01
65646	LDA2	143.2	0.06
65646	S1	125.4	0.02
65646	M1	222.5	0.01
65646	J1	223.7	0.02
65646	SSA	61.2	0.07
65646	SA	132	0.21
65646	RHO1	194.4	0.02
65646	Q1	213.4	0.04
65646	T2	108.3	0.04
65646	2Q1	274.5	0.01
65646	P1	205.5	0.09
65646	2SM2	107.2	0.01
65646	M3	203.7	0.01
65646	L2	156.7	0.14
65646	2MK3	211.4	0.01
65646	K2	136.4	0.11
65646	M8	97.5	0.01
65647	M2	36.4	0.85
65647	S2	69.7	0.14
65647	N2	27.3	0.18
65647	K1	210.8	0.16
65647	M4	24.7	0.04
65647	O1	212.7	0.13
65647	M6	146.4	0.02
65647	S4	9.5	0.01
65647	NU2	28.5	0.03
65647	MU2	3	0.02
65647	2N2	18.2	0.02
65647	OO1	205.8	0.01
65647	LDA2	51.9	0.01
65647	M1	212.2	0.01
65647	J1	209.9	0.01
65647	SSA	50.9	0.11
65647	SA	135.1	0.23
65647	Q1	213	0.03
65647	T2	68.1	0.01
65647	P1	211.1	0.06
65647	L2	45.4	0.02
65647	K2	72.4	0.04
65648	M2	351.1	1.36
65648	S2	18.4	0.27
65648	N2	332.6	0.3
65648	K1	168.8	0.2
65648	M4	87.3	0.12
65648	O1	168.4	0.12
65648	M6	190.8	0.02
65648	S4	264.2	0.01
65648	NU2	335.1	0.06
65648	MU2	323.8	0.03
65648	2N2	314.1	0.04
65648	LDA2	3.7	0.01
65648	M1	169.1	0.01
65648	J1	170.9	0.01
65648	SSA	50.9	0.11
65648	SA	135.1	0.23
65648	Q1	167.7	0.02
65648	T2	17.2	0.02
65648	P1	168.9	0.07
65648	L2	9.6	0.04
65648	K2	20.6	0.07
65648	M8	161.2	0.01
65649	M2	77.8	0.52
65649	S2	114.6	0.08
65649	N2	56.6	0.11
65649	K1	235.4	0.13
65649	M4	43.9	0.03
65649	O1	232	0.09
65649	M6	142.1	0.01
65649	MK3	183	0.02
65649	MN4	34.5	0.02
65649	NU2	71.3	0.03
65649	MU2	183.9	0.01
65649	2N2	11.9	0.02
65649	OO1	297.8	0.01
65649	LDA2	105.7	0.01
65649	S1	184.8	0.02
65649	M1	2.1	0.01
65649	J1	273.5	0.01
65649	SSA	50.9	0.11
65649	SA	135.1	0.23
65649	RHO1	174.8	0.01
65649	Q1	228.9	0.02
65649	R2	306.2	0.01
65649	P1	242.6	0.05
65649	2SM2	349.2	0.01
65649	L2	87.8	0.03
65649	2MK3	139.3	0.01
65649	K2	107.3	0.02
65649	M8	185.9	0.01
65649	MS4	84	0.01
65650	M2	104	0.49
65650	S2	135.7	0.07
65650	N2	82.2	0.09
65650	K1	251.2	0.12
65650	M4	143.2	0.03
65650	O1	248.4	0.08
65650	M6	323.3	0.02
65650	MK3	211.7	0.01
65650	MN4	109.5	0.01
65650	NU2	99.4	0.02
65650	MU2	212.2	0.01
65650	2N2	25.5	0.01
65650	LDA2	132	0.02
65650	S1	182.3	0.02
65650	M1	352.5	0.01
65650	J1	303.1	0.01
65650	RHO1	269	0.01
65650	Q1	264.8	0.02
65650	T2	84.5	0.01
65650	P1	255.3	0.03
65650	L2	100.5	0.03
65650	2MK3	147.1	0.01
65650	K2	139.3	0.02
65650	MS4	175.8	0.01
65651	M2	113	3.06
65651	S2	144.6	0.5
65651	N2	90.4	0.6
65651	K1	192.8	0.3
65651	M4	176.3	0.03
65651	O1	219.3	0.2
65651	M6	348.9	0.07
65651	MK3	220.8	0.02
65651	MN4	140	0.02
65651	NU2	93.6	0.11
65651	MU2	339.1	0.02
65651	2N2	60.3	0.03
65651	OO1	238.1	0.02
65651	LDA2	145.5	0.06
65651	S1	222.5	0.03
65651	M1	217	0.02
65651	J1	212.6	0.02
65651	SSA	61.2	0.07
65651	SA	132	0.21
65651	RHO1	164.3	0.03
65651	Q1	210.4	0.07
65651	T2	23.9	0.08
65651	2Q1	95.3	0.02
65651	P1	195.8	0.06
65651	2SM2	95.8	0.02
65651	M3	231.2	0.01
65651	L2	152.3	0.2
65651	2MK3	218.5	0.01
65651	K2	130.1	0.12
65651	M8	354.9	0.01
65652	M2	82.5	0.54
65652	S2	106.2	0.07
65652	N2	60.4	0.1
65652	K1	236.2	0.14
65652	M4	110.2	0.02
65652	O1	244.1	0.11
65652	M6	219	0.01
65652	NU2	63.3	0.02
65652	MU2	58.8	0.01
65652	2N2	38.2	0.01
65652	M1	240.1	0.01
65652	J1	232.3	0.01
65652	SSA	42.9	0.09
65652	SA	129.1	0.22
65652	Q1	248	0.02
65652	P1	236.8	0.05
65652	L2	104.7	0.02
65652	K2	108.1	0.02
65653	M2	9	0.91
65653	S2	30.9	0.15
65653	N2	351.7	0.18
65653	K1	199	0.16
65653	M4	249.6	0.02
65653	O1	195.6	0.12
65653	S4	303.7	0.01
65653	NU2	354	0.04
65653	S6	138.3	0.01
65653	MU2	347	0.02
65653	2N2	334.4	0.02
65653	OO1	200.3	0.01
65653	LDA2	19.2	0.01
65653	M1	197.3	0.01
65653	J1	200	0.01
65653	SSA	42.9	0.09
65653	SA	129.1	0.22
65653	Q1	194.1	0.02
65653	T2	30	0.01
65653	P1	198.9	0.05
65653	L2	25.8	0.03
65653	K2	32.7	0.04
65654	M2	116	3.64
65654	S2	144.9	0.59
65654	N2	89.5	0.74
65654	K1	188.1	0.33
65654	M4	144.8	0.07
65654	O1	221.5	0.21
65654	M6	182.6	0.06
65654	S4	165.9	0.01
65654	NU2	93.1	0.14
65654	MU2	300.5	0.09
65654	2N2	63	0.1
65654	OO1	154.7	0.01
65654	LDA2	129.4	0.03
65654	M1	204.7	0.02
65654	J1	171.6	0.02
65654	SSA	61.2	0.07
65654	SA	132	0.21
65654	RHO1	235.8	0.01
65654	Q1	238	0.04
65654	T2	143.7	0.04
65654	2Q1	254.2	0.01
65654	P1	190.6	0.11
65654	L2	142.7	0.1
65654	K2	147.2	0.16
65654	M8	302.4	0.01
65655	M2	114.1	3.58
65655	S2	137.5	0.55
65655	N2	94.9	0.77
65655	K1	184.9	0.32
65655	M4	151.6	0.07
65655	O1	222.2	0.2
65655	M6	178.3	0.05
65655	MK3	190.5	0.03
65655	S4	173.9	0.01
65655	MN4	119.9	0.05
65655	NU2	83.6	0.16
65655	MU2	119	0.02
65655	2N2	52.8	0.09
65655	OO1	204.9	0.02
65655	LDA2	140.3	0.1
65655	S1	188.8	0.04
65655	M1	219	0.03
65655	J1	231.2	0.02
65655	SSA	61.2	0.07
65655	SA	132	0.21
65655	RHO1	214.6	0.01
65655	Q1	201.4	0.07
65655	T2	95.5	0.06
65655	R2	200.7	0.04
65655	2Q1	236.1	0.01
65655	P1	197.9	0.09
65655	2SM2	90.2	0.01
65655	M3	166.1	0.02
65655	L2	107.5	0.22
65655	2MK3	190	0.02
65655	K2	145.9	0.18
65655	M8	302.2	0.01
65655	MS4	187.1	0.01
65656	M2	114.7	3.51
65656	S2	148.8	0.55
65656	N2	87.4	0.69
65656	K1	186.7	0.31
65656	M4	147.9	0.07
65656	O1	220.9	0.21
65656	M6	168.4	0.05
65656	S4	139.9	0.01
65656	NU2	91	0.13
65656	MU2	293.8	0.09
65656	2N2	60	0.09
65656	OO1	152.6	0.01
65656	LDA2	130.5	0.02
65656	M1	203.7	0.02
65656	J1	169.8	0.02
65656	SSA	61.2	0.07
65656	SA	132	0.21
65656	RHO1	235.4	0.01
65656	Q1	237.8	0.04
65656	T2	147.4	0.03
65656	2Q1	254.7	0.01
65656	P1	189.3	0.1
65656	L2	141.9	0.1
65656	K2	151.5	0.15
65656	M8	303	0.01
65657	M2	115.8	3.74
65657	S2	144.5	0.62
65657	N2	90.3	0.76
65657	K1	188	0.33
65657	M4	146.9	0.08
65657	O1	221.1	0.21
65657	M6	173.2	0.11
65657	S4	148.8	0.01
65657	NU2	93.7	0.15
65657	MU2	300.1	0.09
65657	2N2	64.7	0.1
65657	OO1	155	0.01
65657	LDA2	129.1	0.03
65657	M1	204.4	0.02
65657	J1	171.6	0.02
65657	SSA	60.1	0.08
65657	SA	135.5	0.21
65657	RHO1	235.3	0.01
65657	Q1	237.6	0.04
65657	T2	143.4	0.04
65657	2Q1	254	0.01
65657	P1	190.5	0.11
65657	L2	141.4	0.1
65657	K2	146.9	0.17
65657	M8	279.7	0.01
65658	M2	20.8	1.41
65658	S2	56.1	0.25
65658	N2	6.9	0.27
65658	K1	198.5	0.21
65658	M4	246.5	0.02
65658	O1	187.4	0.16
65658	M6	97.2	0.05
65658	S4	2.9	0.02
65658	NU2	8.8	0.05
65658	S6	240.6	0.01
65658	MU2	345.3	0.03
65658	2N2	353.2	0.04
65658	OO1	209.7	0.01
65658	LDA2	37.4	0.01
65658	M1	193.1	0.01
65658	J1	204.1	0.01
65658	SSA	42.9	0.09
65658	SA	129.1	0.22
65658	RHO1	182.8	0.01
65658	Q1	181.9	0.03
65658	T2	54.7	0.01
65658	P1	197.7	0.07
65658	L2	34.8	0.04
65658	K2	59	0.07
65659	M2	116.9	3.79
65659	S2	147.3	0.62
65659	N2	91	0.78
65659	K1	188.8	0.33
65659	M4	167.7	0.1
65659	O1	220.3	0.22
65659	M6	184	0.12
65659	S4	162.6	0.01
65659	NU2	94.5	0.15
65659	MU2	299.5	0.09
65659	2N2	65	0.1
65659	OO1	157.2	0.01
65659	LDA2	131	0.03
65659	M1	204.4	0.02
65659	J1	173.1	0.02
65659	SSA	60.1	0.08
65659	SA	135.5	0.21
65659	RHO1	233.9	0.01
65659	Q1	236	0.04
65659	T2	146.1	0.04
65659	R2	148.4	0.01
65659	2Q1	251.7	0.01
65659	P1	191.1	0.11
65659	L2	143	0.1
65659	K2	149.8	0.17
65659	M8	258.9	0.02
65660	M2	2.4	1.95
65660	S2	31.1	0.32
65660	N2	349.9	0.42
65660	K1	172.3	0.35
65660	M4	50.6	0.01
65660	O1	180.2	0.15
65660	M6	29.8	0.05
65660	S4	75.9	0.01
65660	NU2	351.5	0.08
65660	MU2	333.7	0.05
65660	2N2	337.3	0.06
65660	OO1	164	0.01
65660	LDA2	15.8	0.01
65660	M1	176.2	0.01
65660	J1	168.2	0.01
65660	SSA	42.9	0.09
65660	SA	129.1	0.22
65660	RHO1	184.1	0.01
65660	Q1	184.2	0.03
65660	T2	30	0.02
65660	P1	172.8	0.11
65660	L2	14.9	0.06
65660	K2	33.4	0.09
65661	M2	11.8	2.02
65661	S2	45.6	0.34
65661	N2	2.2	0.43
65661	K1	177.2	0.35
65661	M4	269.8	0.09
65661	O1	186.7	0.18
65661	M6	79.9	0.08
65661	S4	88.1	0.01
65661	NU2	3.5	0.08
65661	S6	32.1	0.01
65661	MU2	337.9	0.05
65661	2N2	352.7	0.06
65661	OO1	167.9	0.01
65661	LDA2	27.4	0.01
65661	M1	181.9	0.01
65661	J1	172.5	0.01
65661	SSA	42.9	0.09
65661	SA	129.1	0.22
65661	RHO1	191.5	0.01
65661	Q1	191.5	0.03
65661	T2	44.3	0.02
65661	P1	178	0.11
65661	L2	21.3	0.06
65661	K2	48.3	0.1
65661	M8	320.3	0.01
65662	M2	115.6	3.83
65662	S2	141.3	0.59
65662	N2	95.1	0.76
65662	K1	186.8	0.33
65662	M4	143.2	0.1
65662	O1	229.1	0.25
65662	M6	168.4	0.19
65662	S4	169.1	0.01
65662	NU2	97.9	0.15
65662	S6	246.8	0.01
65662	MU2	90	0.09
65662	2N2	74.6	0.1
65662	OO1	144.3	0.01
65662	LDA2	127.6	0.03
65662	M1	208	0.02
65662	J1	165.6	0.02
65662	SSA	60.1	0.08
65662	SA	135.5	0.21
65662	RHO1	247.3	0.01
65662	Q1	250.3	0.05
65662	T2	140.2	0.04
65662	2Q1	271.2	0.01
65662	P1	190	0.11
65662	L2	136.2	0.11
65662	K2	143.4	0.16
65662	M8	187.5	0.01
65663	M2	116.8	3.84
65663	S2	145.6	0.64
65663	N2	91.1	0.78
65663	K1	187.9	0.33
65663	M4	145.9	0.09
65663	O1	220.8	0.22
65663	M6	169	0.2
65663	S4	164.6	0.01
65663	NU2	94.5	0.15
65663	MU2	300.6	0.09
65663	2N2	65.4	0.1
65663	OO1	155.1	0.01
65663	LDA2	130.2	0.03
65663	M1	204.2	0.02
65663	J1	171.5	0.02
65663	SSA	60.1	0.08
65663	SA	135.5	0.21
65663	RHO1	235	0.01
65663	Q1	237.1	0.04
65663	T2	144.5	0.04
65663	R2	146.9	0.01
65663	2Q1	253.7	0.01
65663	P1	190.4	0.11
65663	L2	142.5	0.11
65663	K2	148	0.17
65663	M8	208.5	0.01
65664	M2	15.8	2.13
65664	S2	51.9	0.35
65664	N2	8.1	0.45
65664	K1	180.4	0.36
65664	M4	288.4	0.09
65664	O1	188.8	0.18
65664	M6	82.8	0.09
65664	S4	113.8	0.01
65664	NU2	9.2	0.09
65664	MU2	339.5	0.05
65664	2N2	0.5	0.06
65664	OO1	172.2	0.01
65664	LDA2	32.6	0.02
65664	M1	184.5	0.01
65664	J1	176.2	0.01
65664	SSA	42.9	0.09
65664	SA	129.1	0.22
65664	RHO1	193.2	0.01
65664	Q1	192.9	0.04
65664	T2	50.5	0.02
65664	P1	181.1	0.12
65664	L2	23.4	0.06
65664	K2	54.8	0.1
65664	M8	265.7	0.01
65665	M2	10.2	2
65665	S2	45.1	0.4
65665	N2	357.3	0.4
65665	K1	187.6	0.27
65665	M4	264.6	0.05
65665	O1	171.2	0.21
65665	M6	55.2	0.06
65665	S4	9	0.03
65665	NU2	359	0.08
65665	S6	233.8	0.02
65665	MU2	335.2	0.05
65665	2N2	344.5	0.05
65665	OO1	204.7	0.01
65665	LDA2	26.4	0.01
65665	M1	179.6	0.01
65665	J1	195.9	0.02
65665	SSA	42.9	0.09
65665	SA	129.1	0.22
65665	RHO1	164.1	0.01
65665	Q1	162.9	0.04
65665	T2	43.7	0.02
65665	P1	186.3	0.09
65665	L2	23.1	0.06
65665	K2	47.9	0.11
65665	M8	276	0.01
65666	M2	118.3	3.89
65666	S2	149	0.65
65666	N2	93.9	0.82
65666	K1	187.9	0.34
65666	M4	146.8	0.1
65666	O1	221.8	0.22
65666	M6	171.5	0.26
65666	NU2	97.1	0.16
65666	S6	213.1	0.01
65666	MU2	300.3	0.1
65666	2N2	69.5	0.11
65666	OO1	153.9	0.01
65666	LDA2	132.6	0.03
65666	M1	204.7	0.02
65666	J1	171.2	0.02
65666	SSA	60.1	0.08
65666	SA	135.5	0.21
65666	RHO1	236.4	0.01
65666	Q1	238.7	0.04
65666	T2	147.9	0.04
65666	R2	150.3	0.01
65666	2Q1	255.5	0.01
65666	P1	190.4	0.11
65666	L2	142.8	0.11
65666	K2	151.5	0.18
65666	M8	191.1	0.02
65667	M2	359.9	2.06
65667	S2	28.4	0.36
65667	N2	346.6	0.45
65667	K1	169.6	0.35
65667	M4	61	0.01
65667	O1	174.6	0.16
65667	M6	21.6	0.05
65667	S4	53.6	0.01
65667	NU2	348.4	0.09
65667	MU2	331.3	0.05
65667	2N2	333.3	0.06
65667	OO1	164.4	0.01
65667	LDA2	13.2	0.01
65667	M1	172	0.01
65667	J1	167.2	0.01
65667	SSA	42.9	0.09
65667	SA	129.1	0.22
65667	RHO1	177.2	0.01
65667	Q1	177	0.03
65667	T2	27.2	0.02
65667	P1	170	0.12
65667	L2	13.2	0.06
65667	K2	30.8	0.1
65668	M2	18.2	2.57
65668	S2	48.9	0.49
65668	N2	7.8	0.58
65668	K1	187.8	0.33
65668	M4	309.7	0.1
65668	O1	175.5	0.21
65668	M6	100.7	0.1
65668	S4	33.5	0.07
65668	NU2	9.2	0.11
65668	S6	342.4	0.01
65668	MU2	347.5	0.06
65668	2N2	357.4	0.08
65668	OO1	198.3	0.01
65668	LDA2	32.3	0.02
65668	M1	181.6	0.02
65668	J1	193.5	0.02
65668	SSA	42.9	0.09
65668	SA	129.1	0.09
65668	RHO1	171.6	0.01
65668	Q1	169.5	0.04
65668	T2	47.7	0.03
65668	P1	186.8	0.11
65668	L2	28.5	0.07
65668	K2	51.4	0.13
65668	M8	324.6	0.01
65669	M2	115.7	3.75
65669	S2	140.7	0.62
65669	N2	92.6	0.79
65669	K1	192	0.33
65669	M4	145.5	0.12
65669	O1	220.6	0.22
65669	M6	159.9	0.26
65669	MK3	202.8	0.03
65669	S4	152.3	0.01
65669	MN4	117.2	0.07
65669	NU2	92	0.17
65669	2N2	69.7	0.1
65669	OO1	224.5	0.02
65669	LDA2	141.7	0.08
65669	S1	121.9	0.03
65669	M1	228.4	0.02
65669	J1	252.1	0.03
65669	SSA	60.1	0.08
65669	SA	135.5	0.21
65669	RHO1	204.5	0.01
65669	Q1	212.2	0.06
65669	T2	112.3	0.05
65669	R2	141.8	0.01
65669	2Q1	249.1	0.01
65669	P1	211.1	0.1
65669	2SM2	75.1	0.01
65669	M3	181.4	0.02
65669	L2	140.4	0.23
65669	2MK3	202.4	0.03
65669	K2	141.8	0.17
65669	M8	155	0.02
65669	MS4	160.9	0.03
65670	M2	116.2	3.62
65670	S2	142.2	0.6
65670	N2	94.3	0.73
65670	K1	193.1	0.32
65670	M4	147.3	0.12
65670	O1	220.7	0.21
65670	M6	160	0.25
65670	MK3	207.6	0.04
65670	S4	146.3	0.01
65670	MN4	121.9	0.07
65670	NU2	95	0.16
65670	MU2	96.1	0.01
65670	2N2	72.9	0.09
65670	OO1	232.3	0.02
65670	LDA2	139.5	0.08
65670	S1	116.2	0.03
65670	M1	263.1	0.02
65670	J1	235.8	0.02
65670	SSA	60.1	0.08
65670	SA	135.5	0.21
65670	RHO1	254.8	0.01
65670	Q1	206.2	0.06
65670	T2	117	0.06
65670	R2	143.3	0.01
65670	2Q1	224.2	0.01
65670	P1	206.1	0.1
65670	M3	216.7	0.02
65670	L2	140.9	0.17
65670	2MK3	215.6	0.03
65670	K2	141.3	0.18
65670	M8	150.3	0.02
65670	MS4	160.7	0.03
65671	M2	13.2	2.54
65671	S2	44.2	0.5
65671	N2	1	0.54
65671	K1	180.2	0.33
65671	M4	311.1	0.09
65671	O1	170.5	0.16
65671	M6	84.1	0.08
65671	MK3	106.9	0.04
65671	S4	59.3	0.03
65671	MN4	320.2	0.04
65671	NU2	349.5	0.11
65671	MU2	51.2	0.1
65671	2N2	4.7	0.07
65671	OO1	187	0.02
65671	LDA2	348.5	0.04
65671	S1	152.2	0.06
65671	M1	248	0.02
65671	J1	192.8	0.01
65671	SSA	42.9	0.09
65671	SA	129.1	0.22
65671	RHO1	172.1	0.01
65671	Q1	187.6	0.05
65671	T2	32.8	0.07
65671	R2	178.3	0.01
65671	2Q1	255.7	0.02
65671	P1	182.8	0.09
65671	M3	99.7	0.04
65671	L2	343.2	0.11
65671	2MK3	23	0.02
65671	K2	45	0.14
65671	MS4	269.3	0.03
65672	M2	15.4	2.58
65672	S2	48.2	0.45
65672	N2	3.5	0.55
65672	K1	180.9	0.33
65672	M4	303.1	0.09
65672	O1	172.7	0.16
65672	M6	91.7	0.1
65672	MK3	104	0.04
65672	S4	64.7	0.03
65672	MN4	313.9	0.04
65672	NU2	354.4	0.1
65672	MU2	53.6	0.1
65672	2N2	3.4	0.07
65672	OO1	164.1	0.02
65672	LDA2	341.9	0.05
65672	S1	151.5	0.08
65672	M1	247.8	0.02
65672	J1	187.1	0.01
65672	SSA	42.9	0.09
65672	SA	129.1	0.22
65672	RHO1	190.4	0.01
65672	Q1	193	0.05
65672	T2	39.3	0.04
65672	R2	44.8	0.04
65672	2Q1	255.2	0.02
65672	P1	182.2	0.09
65672	2SM2	182.1	0.01
65672	M3	105.2	0.04
65672	L2	347	0.13
65672	2MK3	21.5	0.02
65672	K2	49.7	0.17
65672	M8	312.4	0.01
65672	MS4	277.5	0.04
65673	M2	118.5	3.59
65673	S2	144.7	0.56
65673	N2	97.4	0.73
65673	K1	188.8	0.33
65673	M4	166.4	0.14
65673	O1	227.7	0.24
65673	M6	162.1	0.34
65673	S4	178.2	0.01
65673	NU2	100.2	0.14
65673	S6	224.6	0.01
65673	MU2	92.2	0.09
65673	2N2	76.3	0.1
65673	OO1	149.7	0.01
65673	LDA2	130.7	0.03
65673	M1	208	0.02
65673	J1	169	0.02
65673	SSA	60.1	0.08
65673	SA	135.5	0.21
65673	RHO1	244.4	0.01
65673	Q1	247.1	0.05
65673	T2	143.7	0.03
65673	2Q1	266.3	0.01
65673	P1	191.7	0.11
65673	L2	139.5	0.1
65673	K2	146.9	0.15
65673	M8	142.4	0.04
65674	M2	117.5	3.576
65674	S2	145.6	0.597
65674	N2	91.6	0.692
65674	K1	189.5	0.325
65674	M4	165.3	0.141
65674	O1	239	0.207
65674	M6	156.1	0.348
65674	S4	169.3	0.003
65674	NU2	95.1	0.135
65674	S6	272.2	0.01
65674	MU2	89.4	0.085
65674	2N2	65.7	0.092
65674	OO1	140	0.01
65674	LDA2	130.5	0.026
65674	M1	214	0.013
65674	J1	164.9	0.016
65674	SSA	60.1	0.079
65674	SA	135.5	0.213
65674	RHO1	260.2	0.007
65674	Q1	263.5	0.039
65674	T2	144.5	0.036
65674	R2	146.7	0.003
65674	2Q1	288.1	0.007
65674	P1	193.2	0.108
65674	L2	143.4	0.102
65674	K2	147.9	0.161
65674	M8	149	0.039
65675	M2	6.3	2.33
65675	S2	35.5	0.43
65675	N2	351.5	0.5
65675	K1	174.4	0.33
65675	M4	317.4	0.04
65675	O1	167.6	0.16
65675	M6	62.5	0.05
65675	MK3	95.7	0.02
65675	S4	38.1	0.02
65675	MN4	324.9	0.02
65675	NU2	345.3	0.1
65675	MU2	30.1	0.07
65675	2N2	344	0.06
65675	OO1	163.9	0.02
65675	LDA2	345.7	0.03
65675	S1	158.6	0.07
65675	M1	232.4	0.02
65675	J1	182.4	0.01
65675	SSA	42.9	0.09
65675	SA	129.1	0.22
65675	RHO1	188.9	0.01
65675	Q1	186.7	0.05
65675	T2	34.5	0.05
65675	R2	21.7	0.02
65675	2Q1	228.6	0.02
65675	P1	170.4	0.09
65675	2SM2	171	0.01
65675	M3	82.5	0.03
65675	L2	349.5	0.09
65675	2MK3	40.8	0.01
65675	K2	36.2	0.14
65675	M8	146.2	0.01
65675	MS4	204.2	0.02
65676	M2	24	2.14
65676	S2	42	0.42
65676	N2	359.5	0.54
65676	K1	191	0.35
65676	M4	184.3	0.05
65676	O1	172.7	0.21
65676	M6	167.2	0.1
65676	S4	349	0.06
65676	NU2	2.7	0.1
65676	S6	269.3	0.01
65676	MU2	218	0.05
65676	2N2	334.9	0.07
65676	OO1	209.3	0.01
65676	LDA2	32.4	0.02
65676	M1	181.9	0.02
65676	J1	200.1	0.02
65676	SSA	47.4	0.1
65676	SA	129.9	0.23
65676	RHO1	164.9	0.01
65676	Q1	163.6	0.04
65676	T2	41.3	0.03
65676	2Q1	154.6	0.01
65676	P1	189.6	0.12
65676	L2	48.6	0.06
65676	K2	43.5	0.11
65676	M8	284.8	0.02
65677	M2	113.9	3.73
65677	S2	140.8	0.62
65677	N2	91.1	0.72
65677	K1	192.6	0.32
65677	M4	134.5	0.1
65677	O1	217.6	0.22
65677	M6	164.1	0.16
65677	MK3	205.6	0.04
65677	S4	137.9	0.01
65677	MN4	115.3	0.05
65677	NU2	92	0.16
65677	MU2	263.7	0.02
65677	2N2	83.1	0.05
65677	OO1	231.6	0.02
65677	LDA2	144.1	0.08
65677	S1	144.1	0.03
65677	M1	221.7	0.01
65677	J1	205.2	0.02
65677	MM	313	0.16
65677	SSA	64.6	0.12
65677	SA	112.3	0.23
65677	MSF	278.5	0.07
65677	MF	257.4	0.04
65677	RHO1	157.7	0.02
65677	Q1	220.5	0.06
65677	T2	101.2	0.06
65677	R2	334.4	0.01
65677	2Q1	113.8	0.01
65677	P1	205.4	0.08
65677	2SM2	95	0.02
65677	M3	237	0.02
65677	L2	162.1	0.23
65677	2MK3	215.7	0.03
65677	K2	141	0.17
65677	M8	216	0.01
65677	MS4	142.8	0.02
65678	M2	117.2	3.78
65678	S2	143.8	0.59
65678	N2	96.5	0.76
65678	K1	189	0.34
65678	M4	145.3	0.13
65678	O1	227.2	0.24
65678	M6	162.3	0.29
65678	S4	169.9	0.01
65678	NU2	99.3	0.15
65678	S6	208.5	0.01
65678	MU2	90.6	0.09
65678	2N2	75.8	0.1
65678	OO1	150.4	0.01
65678	LDA2	129.6	0.03
65678	M1	207.8	0.02
65678	J1	169.7	0.02
65678	SSA	60.1	0.08
65678	SA	135.5	0.21
65678	RHO1	243.6	0.01
65678	Q1	246.2	0.05
65678	T2	142.8	0.04
65678	2Q1	265.3	0.01
65678	P1	191.8	0.11
65678	L2	137.9	0.1
65678	K2	146	0.16
65678	M8	147.7	0.02
65679	M2	116.5	3.3
65679	S2	141.4	0.54
65679	N2	91.6	0.71
65679	K1	194.4	0.33
65679	M4	171.7	0.12
65679	O1	218.2	0.22
65679	M6	160	0.31
65679	MK3	204.9	0.02
65679	S4	133.3	0.01
65679	MN4	139.5	0.07
65679	NU2	93.9	0.15
65679	S6	203.3	0.01
65679	MU2	26.2	0.02
65679	2N2	79.9	0.1
65679	OO1	235.3	0.02
65679	LDA2	137.1	0.07
65679	S1	127.9	0.03
65679	M1	207.8	0.02
65679	J1	260.3	0.03
65679	SSA	47.4	0.1
65679	SA	129.9	0.23
65679	RHO1	109.5	0.02
65679	Q1	211.5	0.05
65679	T2	99	0.04
65679	R2	140.3	0.01
65679	2Q1	81.8	0.02
65679	P1	211.9	0.1
65679	2SM2	83.8	0.01
65679	M3	172.1	0.03
65679	L2	154.6	0.18
65679	2MK3	212.2	0.02
65679	K2	142.1	0.15
65679	M8	163.4	0.03
65679	MS4	198.6	0.04
65680	M2	92.2	2.14
65680	S2	118.1	0.33
65680	N2	71	0.45
65680	K1	185.7	0.34
65680	M4	249.5	0.09
65680	O1	214	0.19
65680	M6	175.4	0.25
65680	S4	136.1	0.01
65680	NU2	73.9	0.09
65680	MU2	66.4	0.05
65680	2N2	49.8	0.06
65680	OO1	156.9	0.01
65680	LDA2	104.2	0.02
65680	M1	199.7	0.01
65680	J1	171.6	0.02
65680	SSA	47.4	0.1
65680	SA	129.9	0.23
65680	RHO1	226.2	0.01
65680	Q1	228.1	0.04
65680	T2	117	0.02
65680	2Q1	242.9	0.01
65680	P1	187.8	0.11
65680	L2	113.5	0.06
65680	K2	120.2	0.09
65680	M8	215.2	0.01
65681	M2	93.8	2.22
65681	S2	116.1	0.38
65681	N2	73.6	0.49
65681	K1	186.9	0.33
65681	M4	237.1	0.07
65681	O1	201.7	0.17
65681	M6	170.3	0.25
65681	MK3	146.3	0.01
65681	S4	65.2	0.01
65681	MN4	208.7	0.02
65681	NU2	64.8	0.1
65681	S6	218.3	0.01
65681	MU2	46.4	0.04
65681	2N2	42.5	0.07
65681	OO1	204.8	0.02
65681	LDA2	138.2	0.05
65681	S1	116.8	0.03
65681	M1	227.5	0.02
65681	J1	240.3	0.02
65681	MM	49.3	0.09
65681	SSA	76.2	0.19
65681	SA	127.2	0.34
65681	MSF	13.7	0.12
65681	MF	81.5	0.05
65681	RHO1	236	0.01
65681	Q1	209.3	0.05
65681	T2	89.4	0.04
65681	R2	300.3	0.01
65681	P1	204	0.1
65681	2SM2	79.8	0.01
65681	M3	126.8	0.01
65681	L2	94.2	0.11
65681	2MK3	135.7	0.01
65681	K2	118.9	0.1
65681	M8	223.1	0.01
65681	MS4	261.2	0.03
65682	M2	61.4	1.88
65682	S2	80.5	0.33
65682	N2	36.9	0.42
65682	K1	186.1	0.34
65682	M4	240.5	0.08
65682	O1	192.6	0.16
65682	M6	175.3	0.19
65682	S4	23	0.04
65682	NU2	40.2	0.08
65682	S6	261.9	0.01
65682	MU2	254.4	0.05
65682	2N2	12.5	0.06
65682	OO1	180.6	0.01
65682	LDA2	70.3	0.01
65682	M1	189.7	0.01
65682	J1	184.3	0.01
65682	SSA	47.4	0.1
65682	SA	129.9	0.23
65682	RHO1	195.4	0.01
65682	Q1	195.5	0.03
65682	T2	79.8	0.02
65682	P1	186.5	0.11
65682	L2	85.9	0.05
65682	K2	82	0.09
65682	M8	264.5	0.02
65683	M2	36.8	1.9
65683	S2	59.6	0.32
65683	N2	16.8	0.42
65683	K1	179.4	0.35
65683	M4	249.2	0.08
65683	O1	184.8	0.15
65683	M6	167.5	0.13
65683	S4	3.2	0.02
65683	NU2	19.5	0.08
65683	MU2	226	0.05
65683	2N2	356.9	0.06
65683	OO1	173.9	0.01
65683	LDA2	47.4	0.01
65683	M1	181.7	0.01
65683	J1	176.9	0.01
65683	SSA	47.4	0.1
65683	SA	129.9	0.23
65683	RHO1	187	0.01
65683	Q1	187.5	0.03
65683	T2	58.7	0.02
65683	P1	179.8	0.12
65683	L2	56.7	0.05
65683	K2	61.4	0.09
65683	M8	295.5	0.02
65684	M2	19	2.19
65684	S2	43.3	0.42
65684	N2	0	0.51
65684	K1	179.6	0.33
65684	M4	258.2	0.08
65684	O1	176.3	0.17
65684	M6	151.2	0.09
65684	MK3	71.6	0.03
65684	S4	18.8	0.03
65684	MN4	262.7	0.04
65684	NU2	357.8	0.09
65684	MU2	10	0.07
65684	2N2	347.7	0.07
65684	OO1	220.1	0.02
65684	LDA2	25	0.03
65684	S1	128	0.04
65684	M1	229.8	0.01
65684	J1	211.3	0.02
65684	SSA	47.4	0.1
65684	SA	129.9	0.23
65684	RHO1	174.9	0.01
65684	Q1	190.7	0.04
65684	T2	30.5	0.04
65684	P1	183.9	0.1
65684	M3	68	0.03
65684	L2	27.8	0.08
65684	2MK3	49.3	0.03
65684	K2	43.9	0.11
65684	M8	326.7	0.01
65684	MS4	247.2	0.05
65685	M2	42.8	1.88
65685	S2	70.8	0.3
65685	N2	24.4	0.4
65685	K1	195.4	0.31
65685	M4	272.4	0.1
65685	O1	201.9	0.12
65685	M6	185.9	0.07
65685	S4	141.2	0.01
65685	NU2	26.8	0.08
65685	MU2	14.7	0.05
65685	2N2	5.9	0.05
65685	OO1	189.9	0.01
65685	LDA2	55.8	0.01
65685	M1	198.6	0.01
65685	J1	192.1	0.01
65685	SSA	47.4	0.1
65685	SA	129.9	0.23
65685	Q1	205.2	0.02
65685	T2	69.7	0.02
65685	P1	195.9	0.1
65685	L2	61.2	0.05
65685	K2	73.1	0.08
65685	M8	80.2	0.02
65686	M2	46	1.77
65686	S2	71.5	0.34
65686	N2	23.6	0.38
65686	K1	192.3	0.27
65686	M4	263.5	0.06
65686	O1	199.4	0.13
65686	M6	190	0.08
65686	S4	43.3	0.02
65686	NU2	26.6	0.07
65686	2N2	1.2	0.05
65686	OO1	185.1	0.01
65686	LDA2	57.8	0.01
65686	M1	195.8	0.01
65686	J1	188.7	0.01
65686	RHO1	202.5	0.01
65686	Q1	202.8	0.03
65686	T2	71.4	0.02
65686	P1	192.2	0.09
65686	L2	68.4	0.05
65686	K2	71.4	0.09
65686	M8	62.7	0.01
65687	M2	47.6	1.79
65687	S2	74	0.33
65687	N2	23.4	0.4
65687	K1	189.5	0.27
65687	M4	279.3	0.06
65687	O1	190.8	0.13
65687	M6	189.6	0.07
65687	S4	14.6	0.01
65687	NU2	26.7	0.08
65687	MU2	21.2	0.04
65687	2N2	359.2	0.05
65687	OO1	188.2	0.01
65687	LDA2	59.9	0.01
65687	M1	190.2	0.01
65687	J1	188.9	0.01
65687	SSA	47.4	0.1
65687	SA	129.9	0.23
65687	Q1	191.5	0.03
65687	T2	73	0.02
65687	P1	189.6	0.09
65687	L2	71.8	0.05
65687	K2	76.1	0.09
65687	M8	78.4	0.01
65688	M2	94.8	1.52
65688	S2	118.9	0.27
65688	N2	73.1	0.29
65688	K1	238.6	0.27
65688	M4	106.2	0.09
65688	O1	235.8	0.15
65688	M6	26.3	0.05
65688	MK3	206.7	0.04
65688	S4	183.9	0.02
65688	MN4	96.5	0.04
65688	NU2	66.1	0.08
65688	MU2	236.7	0.02
65688	2N2	64.1	0.05
65688	OO1	297.9	0.01
65688	LDA2	109.9	0.04
65688	S1	212.3	0.06
65688	M1	28.6	0.02
65688	J1	84.9	0.01
65688	MM	186.6	0.02
65688	SSA	68.5	0.13
65688	SA	109.4	0.18
65688	MSF	37.7	0.08
65688	MF	204.3	0.08
65688	Q1	258.6	0.03
65688	T2	109.6	0.02
65688	R2	6.5	0.02
65688	P1	233.3	0.08
65688	2SM2	23.2	0.01
65688	M3	167.4	0.02
65688	L2	129.7	0.1
65688	2MK3	178.8	0.05
65688	K2	118.9	0.07
65688	M8	323.2	0.01
65688	MS4	96.8	0.02
65689	M2	124.7	1.51
65689	S2	148.3	0.24
65689	N2	104.5	0.3
65689	K1	244.7	0.37
65689	M4	145.5	0.07
65689	O1	265.7	0.19
65689	M6	111.9	0.06
65689	S4	318.8	0.01
65689	NU2	107.2	0.06
65689	MU2	101	0.04
65689	2N2	84.3	0.04
65689	OO1	223.9	0.01
65689	LDA2	135.7	0.01
65689	M1	255	0.01
65689	J1	234.5	0.02
65689	RHO1	274.5	0.01
65689	Q1	275.8	0.04
65689	T2	147.2	0.01
65689	P1	246.3	0.12
65689	L2	145	0.04
65689	K2	150.2	0.07
65690	M2	158.5	1.65
65690	S2	182.9	0.25
65690	N2	135.9	0.32
65690	K1	256	0.41
65690	M4	227.9	0.1
65690	O1	277.6	0.21
65690	M6	184.3	0.07
65690	S4	25.6	0.01
65690	NU2	139	0.06
65690	MU2	133.9	0.04
65690	2N2	113.3	0.04
65690	OO1	234.5	0.01
65690	LDA2	170.1	0.01
65690	M1	266.9	0.02
65690	J1	245.2	0.02
65690	RHO1	286.8	0.01
65690	Q1	288.4	0.04
65690	T2	181.9	0.01
65690	2Q1	298.6	0.01
65690	P1	257.6	0.13
65690	L2	181.2	0.05
65690	K2	184.9	0.07
65690	M8	163	0.01
65691	M2	183	1.79
65691	S2	208.1	0.28
65691	N2	158.3	0.35
65691	K1	272.1	0.36
65691	M4	263.5	0.16
65691	O1	270.4	0.18
65691	M6	247	0.07
65691	MK3	323.1	0.06
65691	S4	321.7	0.01
65691	MN4	241.4	0.06
65691	NU2	166.2	0.07
65691	MU2	29.4	0.02
65691	2N2	145.9	0.07
65691	OO1	313	0.01
65691	LDA2	207.6	0.05
65691	S1	239.7	0.07
65691	J1	128.1	0.01
65691	SSA	47.4	0.1
65691	SA	129.9	0.23
65691	RHO1	300.1	0.02
65691	Q1	304.8	0.05
65691	T2	191.8	0.02
65691	R2	291.8	0.01
65691	2Q1	259.4	0.02
65691	P1	267.5	0.11
65691	2SM2	95.5	0.01
65691	M3	298.6	0.02
65691	L2	223.6	0.1
65691	2MK3	293.3	0.06
65691	K2	223.2	0.08
65691	M8	359.6	0.01
65691	MS4	283.2	0.05
65692	M2	269.1	2.25
65692	S2	301.5	0.32
65692	N2	249.3	0.42
65692	K1	313.6	0.37
65692	M4	85.1	0.3
65692	O1	307.7	0.21
65692	M6	178	0.15
65692	MK3	98.7	0.1
65692	S4	139.4	0.01
65692	MN4	67.7	0.11
65692	NU2	241.7	0.08
65692	MU2	45.8	0.08
65692	2N2	209.7	0.04
65692	OO1	13.3	0.01
65692	LDA2	270.3	0.12
65692	S1	274.8	0.09
65692	M1	57.1	0.03
65692	J1	157.9	0.02
65692	SSA	78.5	0.31
65692	SA	21.7	0.39
65692	RHO1	255.8	0.01
65692	Q1	324.6	0.04
65692	T2	127.8	0.01
65692	2Q1	215.3	0.01
65692	P1	312.3	0.1
65692	2SM2	224.3	0.02
65692	M3	54.2	0.04
65692	L2	277.9	0.22
65692	2MK3	65.1	0.1
65692	K2	303.2	0.11
65692	M8	9.6	0.04
65692	MS4	111.2	0.09
65693	M2	8.8	2.19
65693	S2	33.8	0.37
65693	N2	353.5	0.49
65693	K1	170.2	0.36
65693	M4	245.9	0.08
65693	O1	177.5	0.16
65693	M6	117.6	0.05
65693	S4	92.1	0.02
65693	NU2	355.5	0.1
65693	MU2	343.7	0.05
65693	2N2	338.1	0.07
65693	OO1	162.8	0.01
65693	LDA2	20.4	0.02
65693	M1	173.6	0.01
65693	J1	166.5	0.01
65693	SSA	42.9	0.09
65693	SA	129.1	0.22
65693	RHO1	181.1	0.01
65693	Q1	181.1	0.03
65693	T2	32.7	0.02
65693	P1	170.8	0.12
65693	L2	24.1	0.06
65693	K2	35.8	0.1
65694	M2	4.6	2.35
65694	S2	32.4	0.4
65694	N2	350.9	0.51
65694	K1	168.2	0.37
65694	M4	250.4	0.1
65694	O1	175	0.18
65694	M6	91.9	0.09
65694	S4	81.7	0.02
65694	NU2	352.8	0.1
65694	S6	45.6	0.01
65694	MU2	336.7	0.06
65694	2N2	337.2	0.07
65694	OO1	161.8	0.01
65694	LDA2	17.6	0.02
65694	M1	171.7	0.01
65694	J1	164.9	0.01
65694	SSA	42.9	0.09
65694	SA	129.1	0.22
65694	RHO1	178.3	0.01
65694	Q1	178.3	0.04
65694	T2	31.4	0.02
65694	P1	168.8	0.12
65694	L2	18.3	0.07
65694	K2	34.7	0.11
65694	M8	43	0.01
65695	M2	21.2	2.44
65695	S2	51.2	0.47
65695	N2	5.1	0.54
65695	K1	182.9	0.35
65695	M4	292.4	0.12
65695	O1	179.3	0.17
65695	M6	174.3	0.07
65695	MK3	72.8	0.03
65695	S4	44.5	0.05
65695	MN4	291.5	0.06
65695	NU2	1.6	0.11
65695	MU2	38.1	0.1
65695	2N2	345	0.07
65695	OO1	204.5	0.01
65695	LDA2	2.3	0.04
65695	S1	139.6	0.04
65695	M1	245.9	0.02
65695	J1	204	0.02
65695	SSA	58.4	0.1
65695	SA	129.2	0.24
65695	RHO1	181.5	0.01
65695	Q1	191.3	0.04
65695	T2	30.4	0.04
65695	R2	270.2	0.02
65695	P1	181.8	0.11
65695	M3	86.6	0.04
65695	L2	10.2	0.09
65695	2MK3	46.1	0.03
65695	K2	47.9	0.13
65695	MS4	284.9	0.06
65696	M2	10.9	2.5
65696	S2	41.9	0.47
65696	N2	355	0.56
65696	K1	179.1	0.39
65696	M4	275.1	0.1
65696	O1	169.3	0.17
65696	M6	117	0.1
65696	MK3	25.5	0.01
65696	S4	49.8	0.05
65696	MN4	278.7	0.05
65696	NU2	0.5	0.1
65696	MU2	37.9	0.1
65696	2N2	341.1	0.09
65696	OO1	221.3	0.01
65696	LDA2	352.9	0.05
65696	S1	106.7	0.13
65696	M1	162.2	0.01
65696	J1	215.8	0.03
65696	MM	339.1	0.06
65696	SSA	42.9	0.09
65696	SA	129.1	0.22
65696	MSF	233.5	0.06
65696	MF	219.2	0.09
65696	RHO1	154.6	0.01
65696	Q1	193.7	0.05
65696	T2	11	0.05
65696	R2	283.3	0.02
65696	2Q1	319	0.02
65696	P1	172.8	0.08
65696	2SM2	93.5	0.01
65696	M3	60.3	0.04
65696	L2	18.5	0.13
65696	2MK3	40.8	0.03
65696	K2	40.7	0.13
65696	M8	48.2	0.01
65696	MS4	255.8	0.06
65697	M2	11.7	2.41
65697	S2	45.2	0.49
65697	N2	359.8	0.55
65697	K1	172.1	0.36
65697	M4	261	0.09
65697	O1	180.9	0.19
65697	M6	128.7	0.09
65697	S4	63	0.02
65697	NU2	1.4	0.1
65697	MU2	338.2	0.06
65697	2N2	348	0.07
65697	OO1	161.6	0.01
65697	LDA2	27.2	0.02
65697	M1	176.2	0.01
65697	J1	166.8	0.02
65697	SSA	42.9	0.09
65697	SA	129.1	0.22
65697	RHO1	184.2	0.01
65697	Q1	185.5	0.04
65697	T2	43.9	0.03
65697	2Q1	191.4	0.01
65697	P1	172.8	0.12
65697	L2	23.5	0.07
65697	K2	47.9	0.13
65698	M2	10.9	2.37
65698	S2	39.3	0.44
65698	N2	354.6	0.5
65698	K1	181	0.43
65698	M4	297.1	0.12
65698	O1	175.7	0.18
65698	M6	113.3	0.1
65698	S4	3.5	0.06
65698	NU2	356.7	0.1
65698	MU2	193.9	0.06
65698	2N2	338.3	0.07
65698	OO1	183.7	0.01
65698	LDA2	24	0.02
65698	M1	177.8	0.01
65698	J1	181.7	0.01
65698	SSA	42.9	0.09
65698	SA	129.1	0.22
65698	RHO1	173.7	0.01
65698	Q1	173.6	0.04
65698	T2	38.2	0.03
65698	P1	180.8	0.14
65698	L2	26.8	0.07
65698	K2	41.6	0.12
65698	M8	43	0.02
65699	M2	11.3	2.47
65699	S2	39.1	0.51
65699	N2	358.4	0.57
65699	K1	176.9	0.35
65699	M4	283.8	0.11
65699	O1	174.4	0.2
65699	M6	126.4	0.11
65699	MK3	67.4	0.05
65699	S4	62.7	0.04
65699	MN4	288.9	0.06
65699	NU2	350.7	0.1
65699	MU2	31.3	0.09
65699	2N2	338.6	0.07
65699	OO1	265.9	0.01
65699	LDA2	347.7	0.05
65699	S1	166	0.04
65699	M1	176.4	0.03
65699	SSA	42.9	0.09
65699	SA	129.1	0.22
65699	RHO1	262.7	0.02
65699	Q1	190.8	0.03
65699	T2	27.2	0.06
65699	R2	147.3	0.02
65699	2Q1	235.6	0.02
65699	P1	168	0.1
65699	2SM2	103.8	0.02
65699	M3	60.4	0.04
65699	L2	342.8	0.15
65699	2MK3	9.3	0.04
65699	K2	49.7	0.15
65699	M8	57.1	0.01
65699	MS4	258.4	0.06
65700	M2	25.3	2.66
65700	S2	57.9	0.38
65700	N2	15.7	0.62
65700	K1	188.7	0.35
65700	M4	299.6	0.1
65700	O1	193.3	0.18
65700	M6	179.4	0.13
65700	MK3	53.5	0.05
65700	S4	92.9	0.03
65700	MN4	303.4	0.05
65700	NU2	4.6	0.08
65700	S6	132.5	0.01
65700	MU2	67.1	0.17
65700	2N2	14.5	0.05
65700	OO1	15.2	0.03
65700	LDA2	338.4	0.09
65700	S1	149.4	0.06
65700	M1	184.9	0.04
65700	J1	243.5	0.02
65700	SSA	42.9	0.09
65700	SA	129.1	0.22
65700	RHO1	275.4	0.02
65700	Q1	230.4	0.05
65700	T2	352.1	0.05
65700	R2	48	0.16
65700	2Q1	203.9	0.01
65700	P1	194.5	0.07
65700	2SM2	153.7	0.04
65700	M3	99.1	0.04
65700	L2	339.7	0.22
65700	2MK3	26.9	0.07
65700	K2	61	0.25
65700	M8	107.4	0.01
65700	MS4	280.6	0.1
65701	M2	14.9	2.55
65701	S2	47.6	0.51
65701	N2	3.5	0.58
65701	K1	180.2	0.36
65701	M4	292.5	0.14
65701	O1	184.4	0.18
65701	M6	137.9	0.12
65701	MK3	68.1	0.05
65701	S4	32.4	0.06
65701	MN4	290.9	0.06
65701	NU2	1.3	0.13
65701	S6	352.1	0.01
65701	MU2	45.8	0.11
65701	2N2	349.1	0.06
65701	OO1	254.9	0.02
65701	LDA2	354.2	0.07
65701	S1	156.1	0.05
65701	M1	188.9	0.03
65701	J1	322.9	0.01
65701	SSA	42.9	0.09
65701	SA	129.1	0.22
65701	RHO1	336.6	0.02
65701	Q1	170.5	0.04
65701	T2	44.2	0.07
65701	R2	262	0.03
65701	2Q1	156.1	0.02
65701	P1	176.1	0.09
65701	2SM2	156.6	0.02
65701	M3	70.9	0.04
65701	L2	345	0.14
65701	2MK3	14.7	0.05
65701	K2	43.2	0.15
65701	M8	81.3	0.01
65701	MS4	268.2	0.08
65702	M2	23.8	2.65
65702	S2	58.4	0.56
65702	N2	13.7	0.61
65702	K1	185	0.35
65702	M4	305.6	0.15
65702	O1	184.7	0.2
65702	M6	175.5	0.13
65702	MK3	82.7	0.06
65702	S4	93.8	0.05
65702	MN4	310.8	0.08
65702	NU2	4.9	0.09
65702	S6	96.9	0.01
65702	MU2	64.5	0.15
65702	2N2	2.5	0.07
65702	OO1	333.1	0.02
65702	LDA2	349.3	0.06
65702	S1	193.5	0.04
65702	M1	186.1	0.04
65702	J1	256.2	0.01
65702	SSA	69	0.09
65702	SA	129.1	0.22
65702	RHO1	279.7	0.02
65702	Q1	208.4	0.04
65702	T2	67.4	0.06
65702	R2	169	0.08
65702	2Q1	272.2	0.01
65702	P1	174.8	0.1
65702	2SM2	145.3	0.03
65702	M3	83.2	0.04
65702	L2	344.3	0.21
65702	2MK3	24.7	0.07
65702	K2	77.2	0.15
65702	M8	109.6	0.01
65702	MS4	289.5	0.1
65703	M2	6	2.26
65703	S2	32.6	0.44
65703	N2	348.6	0.52
65703	K1	175.7	0.34
65703	M4	269.7	0.05
65703	O1	172.5	0.18
65703	M6	83.8	0.06
65703	MK3	52.4	0.02
65703	S4	11.4	0.03
65703	MN4	275.8	0.03
65703	NU2	345.7	0.1
65703	MU2	14.5	0.08
65703	2N2	336.8	0.07
65703	OO1	218.7	0.02
65703	LDA2	359.7	0.03
65703	S1	124.9	0.03
65703	M1	220.8	0.01
65703	J1	209.2	0.02
65703	SSA	42.9	0.09
65703	SA	129.1	0.22
65703	RHO1	171.1	0.01
65703	Q1	183.1	0.04
65703	T2	17.4	0.03
65703	2Q1	169.2	0.01
65703	P1	180.2	0.1
65703	M3	56.4	0.04
65703	L2	359.8	0.09
65703	2MK3	33.8	0.03
65703	K2	31.5	0.12
65703	MS4	224.3	0.04
65704	M2	39.1	1.63
65704	S2	69.9	0.26
65704	N2	22.5	0.32
65704	K1	199.9	0.27
65704	M4	163.4	0.01
65704	O1	198.6	0.15
65704	M6	143.9	0.06
65704	MK3	128.1	0.01
65704	S4	51.6	0.01
65704	NU2	15.9	0.08
65704	MU2	101.1	0.04
65704	2N2	8	0.03
65704	OO1	194.6	0.01
65704	LDA2	30.3	0.04
65704	S1	209.8	0.03
65704	M1	294.3	0.01
65704	SSA	42.9	0.09
65704	SA	129.1	0.22
65704	RHO1	124.9	0.01
65704	Q1	206.8	0.04
65704	T2	63.4	0.03
65704	2Q1	251.6	0.01
65704	P1	200.3	0.07
65704	M3	127.8	0.02
65704	L2	42.4	0.1
65704	2MK3	68.7	0.02
65704	K2	70.1	0.08
65704	M8	312.5	0.01
65704	MS4	237.7	0.02
65705	M2	122.6	0.33
65705	S2	139.7	0.05
65705	N2	92.7	0.06
65705	K1	294	0.11
65705	M4	127.6	0.01
65705	O1	266.4	0.08
65705	M6	336.6	0.02
65705	NU2	96.2	0.01
65705	MU2	106.2	0.01
65705	2N2	63.3	0.01
65705	M1	280.2	0.01
65705	J1	306.5	0.01
65705	SSA	40	0.1
65705	SA	145.5	0.23
65705	Q1	252.7	0.02
65705	P1	291.8	0.04
65705	L2	152.3	0.01
65705	K2	140.4	0.01
65705	M8	13	0.01
65706	M2	91.2	0.3
65706	S2	108.2	0.04
65706	N2	73.5	0.06
65706	K1	262.7	0.11
65706	M4	54.6	0.01
65706	O1	250.9	0.08
65706	M6	249.5	0.02
65706	MN4	21.6	0.01
65706	NU2	71.8	0.01
65706	MU2	233.7	0.01
65706	OO1	233.5	0.01
65706	LDA2	105.2	0.01
65706	S1	244.5	0.02
65706	M1	8.9	0.01
65706	SSA	40	0.1
65706	SA	145.5	0.23
65706	Q1	274.8	0.01
65706	2Q1	297.6	0.01
65706	P1	258.5	0.04
65706	L2	106.9	0.03
65706	2MK3	100.4	0.01
65706	K2	134.5	0.01
65707	M2	2.9	1.12
65707	S2	27.2	0.21
65707	N2	347	0.25
65707	K1	183.3	0.22
65707	M4	297.2	0.03
65707	O1	178.1	0.13
65707	M6	74.3	0.03
65707	MK3	102.4	0.02
65707	S4	321.2	0.01
65707	MN4	288.9	0.02
65707	NU2	344.9	0.05
65707	MU2	2.7	0.03
65707	2N2	327	0.02
65707	OO1	215.6	0.01
65707	LDA2	0.1	0.02
65707	S1	123.5	0.01
65707	M1	212.1	0.01
65707	SSA	40	0.1
65707	SA	145.5	0.23
65707	RHO1	319.5	0.01
65707	Q1	178.5	0.03
65707	T2	357.2	0.02
65707	R2	249	0.01
65707	P1	187.6	0.07
65707	2SM2	96.9	0.01
65707	M3	42.7	0.02
65707	L2	8.4	0.07
65707	2MK3	84.9	0.01
65707	K2	29.2	0.05
65707	MS4	326.3	0.01
65708	M2	20.6	1.31
65708	S2	47.4	0.22
65708	N2	3.5	0.27
65708	K1	198.3	0.27
65708	M4	81.4	0.02
65708	O1	187.3	0.18
65708	M6	109.6	0.05
65708	MK3	127.3	0.01
65708	NU2	356.3	0.06
65708	MU2	64	0.01
65708	2N2	342.4	0.04
65708	OO1	213.1	0.02
65708	LDA2	14.2	0.03
65708	S1	134.5	0.02
65708	M1	311.7	0.01
65708	J1	164.6	0.01
65708	SSA	40	0.1
65708	SA	145.5	0.23
65708	RHO1	241.7	0.01
65708	Q1	197.6	0.04
65708	T2	10.5	0.02
65708	2Q1	108.6	0.01
65708	P1	190.2	0.08
65708	2SM2	45	0.01
65708	M3	70.4	0.01
65708	L2	27.7	0.06
65708	2MK3	54.3	0.01
65708	K2	43.6	0.06
65708	MS4	130	0.01
65709	M2	72.9	1.759
65709	S2	120	0.262
65709	N2	65.8	0.344
65709	K1	237.8	0.344
65709	M4	4.1	0.164
65709	O1	227.1	0.276
65709	M6	267.4	0.079
65709	MK3	124	0.095
65709	S4	34.8	0.01
65709	MN4	352.1	0.069
65709	NU2	58.9	0.085
65709	S6	23.9	0.003
65709	MU2	153.3	0.128
65709	2N2	180.6	0.013
65709	OO1	261.4	0.026
65709	LDA2	78.6	0.095
65709	S1	192.9	0.023
65709	M1	280.2	0.023
65709	J1	302.2	0.01
65709	RHO1	228.7	0.013
65709	Q1	246.9	0.059
65709	T2	47.8	0.026
65709	R2	111.4	0.016
65709	2Q1	144.7	0.007
65709	P1	231.1	0.082
65709	2SM2	337.8	0.02
65709	M3	184.1	0.046
65709	L2	54	0.187
65709	2MK3	91.3	0.095
65709	K2	125.5	0.092
65709	M8	184.5	0.013
65709	MS4	44.1	0.049
65710	M2	355.4	1.95
65710	S2	17.8	0.38
65710	N2	335.9	0.46
65710	K1	183.2	0.36
65710	M4	181.7	0.03
65710	O1	166.1	0.25
65710	M6	84.8	0.02
65710	MN4	156.9	0.02
65710	NU2	336.6	0.09
65710	MU2	341.1	0.07
65710	2N2	319.5	0.07
65710	OO1	203.7	0.01
65710	LDA2	13.6	0.02
65710	S1	114.7	0.02
65710	M1	214.4	0.01
65710	J1	174.2	0.02
65710	SSA	40	0.1
65710	SA	145.5	0.23
65710	RHO1	158.8	0.01
65710	Q1	168.7	0.04
65710	T2	0.2	0.03
65710	2Q1	149	0.01
65710	P1	178.5	0.11
65710	M3	37.5	0.02
65710	L2	6.3	0.06
65710	2MK3	33.2	0.01
65710	K2	18.7	0.1
65711	M2	355.1	1.93
65711	S2	19.9	0.38
65711	N2	335.9	0.44
65711	K1	182.3	0.36
65711	M4	186	0.03
65711	O1	167.1	0.25
65711	M6	70.1	0.01
65711	MK3	90.6	0.01
65711	S4	232.6	0.01
65711	MN4	160.2	0.02
65711	NU2	336.9	0.09
65711	MU2	339.5	0.07
65711	2N2	317.9	0.06
65711	OO1	193.3	0.01
65711	LDA2	10.8	0.02
65711	S1	110.1	0.03
65711	M1	173.6	0.01
65711	J1	170.8	0.02
65711	SSA	39.8	0.09
65711	SA	132.9	0.25
65711	RHO1	181.3	0.01
65711	Q1	168.5	0.04
65711	T2	358.6	0.03
65711	R2	257.5	0.01
65711	2Q1	159.5	0.01
65711	P1	180.4	0.11
65711	2SM2	8.8	0.01
65711	M3	44.9	0.02
65711	L2	8.7	0.04
65711	2MK3	77.4	0.01
65711	K2	17.3	0.1
65711	MS4	163.3	0.01
65712	M2	8.2	1.79
65712	S2	37.3	0.33
65712	N2	356.1	0.39
65712	K1	193.6	0.33
65712	M4	311.1	0.03
65712	O1	181.1	0.23
65712	M6	76.4	0.02
65712	S4	283.1	0.01
65712	NU2	357.7	0.08
65712	MU2	190.1	0.04
65712	2N2	343.8	0.05
65712	OO1	205.5	0.01
65712	LDA2	21.6	0.01
65712	M1	187.3	0.02
65712	J1	199.4	0.02
65712	SSA	40	0.1
65712	SA	145.5	0.23
65712	RHO1	175.7	0.01
65712	Q1	174.9	0.04
65712	T2	36.1	0.02
65712	2Q1	168.7	0.01
65712	P1	192.8	0.11
65712	L2	20.4	0.05
65712	K2	39.6	0.09
65712	M8	84.7	0.01
65713	M2	59.4	1.64
65713	S2	106	0.2
65713	N2	50.8	0.25
65713	K1	235.1	0.38
65713	M4	338.3	0.2
65713	O1	222.7	0.29
65713	M6	239.1	0.07
65713	NU2	51.9	0.05
65713	MU2	13.4	0.04
65713	2N2	42.3	0.03
65713	OO1	247.5	0.01
65713	LDA2	80.9	0.01
65713	M1	228.9	0.02
65713	J1	241.3	0.02
65713	RHO1	217.4	0.01
65713	Q1	216.5	0.06
65713	T2	105.9	0.01
65713	2Q1	210.3	0.01
65713	P1	235.1	0.13
65713	L2	67.9	0.05
65713	K2	106	0.06
65714	M2	51.9	2.59
65714	S2	85.8	0.41
65714	N2	34.8	0.52
65714	K1	214.6	0.35
65714	M4	354	0.11
65714	O1	197	0.28
65714	M6	183.1	0.06
65714	MK3	144.8	0.04
65714	S4	49.9	0.01
65714	MN4	336.3	0.05
65714	NU2	23.9	0.12
65714	MU2	110.4	0.06
65714	2N2	1.6	0.08
65714	OO1	286.5	0.04
65714	LDA2	65.5	0.05
65714	S1	164	0.06
65714	M1	348.9	0.01
65714	J1	220.2	0.02
65714	SSA	41.3	0.1
65714	SA	140.5	0.17
65714	RHO1	190.6	0.02
65714	Q1	203	0.07
65714	T2	80.1	0.04
65714	R2	347.7	0.01
65714	2Q1	52	0.03
65714	P1	205.1	0.12
65714	2SM2	300.2	0.01
65714	M3	150	0.02
65714	L2	60.8	0.14
65714	2MK3	118.6	0.03
65714	K2	89.2	0.11
65714	M8	54.6	0.02
65714	MS4	48.9	0.03
65715	M2	8.5	1.87
65715	S2	37.1	0.33
65715	N2	354.1	0.4
65715	K1	194.2	0.34
65715	M4	162.2	0.04
65715	O1	178.8	0.27
65715	M6	45	0.01
65715	MK3	354.7	0.02
65715	S4	230.7	0.01
65715	MN4	154.7	0.03
65715	NU2	345.9	0.09
65715	MU2	26.3	0.06
65715	2N2	343.4	0.06
65715	LDA2	18.8	0.03
65715	S1	115.7	0.03
65715	J1	198.7	0.02
65715	SSA	40	0.1
65715	SA	145.5	0.23
65715	RHO1	213.3	0.02
65715	Q1	184.4	0.04
65715	T2	18.7	0.03
65715	P1	183.7	0.11
65715	2SM2	196.1	0.01
65715	M3	84.9	0.02
65715	L2	5.9	0.07
65715	2MK3	329.4	0.02
65715	K2	29.8	0.11
65715	MS4	177	0.02
65716	M2	8.9	1.9
65716	S2	38.1	0.38
65716	N2	351.8	0.4
65716	K1	197.4	0.33
65716	M4	154.6	0.03
65716	O1	180.6	0.26
65716	M6	39.6	0.02
65716	MK3	345.6	0.02
65716	S4	272	0.01
65716	MN4	149.9	0.02
65716	NU2	343.4	0.09
65716	MU2	27.7	0.05
65716	2N2	329.9	0.05
65716	OO1	154	0.02
65716	LDA2	10.5	0.03
65716	S1	143.4	0.06
65716	M1	227.7	0.02
65716	J1	175.4	0.02
65716	SSA	40	0.1
65716	SA	145.5	0.23
65716	Q1	199.3	0.04
65716	T2	43.5	0.07
65716	R2	199.5	0.04
65716	2Q1	148.8	0.02
65716	P1	196.3	0.1
65716	M3	74.4	0.02
65716	L2	8.6	0.08
65716	2MK3	344.7	0.02
65716	K2	33.7	0.08
65716	MS4	162.8	0.02
65717	M2	24	1.91
65717	S2	58.7	0.33
65717	N2	10.6	0.41
65717	K1	207	0.35
65717	M4	245.4	0.05
65717	O1	189.3	0.27
65717	M6	67	0.04
65717	MK3	27.9	0.03
65717	S4	311.1	0.01
65717	MN4	220.2	0.03
65717	NU2	4.7	0.08
65717	MU2	65	0.08
65717	2N2	350.8	0.05
65717	OO1	261.9	0.02
65717	LDA2	11.2	0.05
65717	S1	169.4	0.02
65717	M1	282.5	0.01
65717	J1	212.3	0.02
65717	SSA	40	0.1
65717	SA	145.5	0.23
65717	MF	188.6	0.12
65717	RHO1	209.4	0.02
65717	Q1	191.1	0.07
65717	T2	27.5	0.04
65717	R2	245.6	0.01
65717	2Q1	45.9	0.02
65717	P1	199.4	0.11
65717	M3	78	0.03
65717	L2	15.3	0.1
65717	2MK3	9.5	0.03
65717	K2	52.4	0.09
65717	M8	270.7	0.01
65717	MS4	261.8	0.02
65718	M2	1	2.05
65718	S2	22.8	0.42
65718	N2	343.6	0.49
65718	K1	185.6	0.37
65718	M4	166	0.03
65718	O1	172	0.28
65718	M6	255.7	0.02
65718	S4	237.5	0.01
65718	NU2	345.9	0.1
65718	MU2	338.5	0.05
65718	2N2	326.5	0.07
65718	OO1	199.9	0.01
65718	LDA2	11	0.01
65718	M1	178.9	0.02
65718	J1	192.7	0.02
65718	SSA	40	0.1
65718	SA	145.5	0.23
65718	RHO1	166	0.01
65718	Q1	165.1	0.05
65718	T2	21.9	0.03
65718	2Q1	158.1	0.01
65718	P1	184.6	0.12
65718	L2	17.9	0.06
65718	K2	24.6	0.11
65719	M2	28.6	2.34
65719	S2	55.3	0.41
65719	N2	9.7	0.52
65719	K1	200.4	0.34
65719	M4	101	0.03
65719	O1	185.6	0.28
65719	M6	20.8	0.03
65719	MN4	115.3	0.01
65719	NU2	7.4	0.1
65719	MU2	40.5	0.04
65719	2N2	352.3	0.07
65719	OO1	215	0.01
65719	LDA2	41.6	0.03
65719	S1	134.7	0.03
65719	M1	243.4	0.01
65719	J1	197.1	0.02
65719	SSA	40.3	0.1
65719	SA	147.7	0.19
65719	RHO1	179.3	0.01
65719	Q1	184.1	0.04
65719	T2	33.7	0.04
65719	2Q1	171	0.01
65719	P1	199.2	0.12
65719	M3	94.1	0.02
65719	L2	43.9	0.12
65719	2MK3	110.5	0.01
65719	K2	54.5	0.11
65719	MS4	128.1	0.02
65720	M2	43.3	2.64
65720	S2	73.8	0.45
65720	N2	27.1	0.59
65720	K1	212	0.36
65720	M4	320	0.09
65720	O1	193.9	0.29
65720	M6	147.8	0.05
65720	S4	14.1	0.02
65720	NU2	29.2	0.11
65720	MU2	223.1	0.06
65720	2N2	10.8	0.08
65720	OO1	226.9	0.01
65720	LDA2	57.5	0.02
65720	M1	202.1	0.02
65720	J1	218.4	0.02
65720	SSA	40.3	0.1
65720	SA	147.7	0.19
65720	RHO1	186.9	0.01
65720	Q1	185.7	0.05
65720	T2	72.6	0.03
65720	2Q1	177.5	0.01
65720	P1	210.5	0.12
65720	L2	59.5	0.07
65720	K2	76.3	0.12
65720	M8	55.1	0.02
65721	M2	56.4	2.72
65721	S2	89.9	0.41
65721	N2	41.1	0.59
65721	K1	216.5	0.38
65721	M4	15.2	0.12
65721	O1	200.2	0.28
65721	M6	212.6	0.06
65721	NU2	43.1	0.11
65721	MU2	22.8	0.07
65721	2N2	25.8	0.08
65721	OO1	232.5	0.01
65721	LDA2	72	0.02
65721	M1	208.4	0.02
65721	J1	224.4	0.02
65721	SSA	40.3	0.1
65721	SA	147.7	0.19
65721	RHO1	193.4	0.01
65721	Q1	192.4	0.05
65721	T2	88.6	0.02
65721	2Q1	184.5	0.01
65721	P1	215.3	0.12
65721	L2	71.7	0.08
65721	K2	92.7	0.11
65721	M8	131.9	0.01
65722	M2	72.2	2.73
65722	S2	100.5	0.41
65722	N2	61.3	0.54
65722	K1	221.1	0.33
65722	M4	40	0.12
65722	O1	206.9	0.26
65722	M6	274.5	0.07
65722	MK3	162.2	0.04
65722	S4	55.7	0.01
65722	MN4	29.1	0.06
65722	NU2	35.1	0.17
65722	MU2	164.6	0.06
65722	2N2	55.4	0.04
65722	OO1	25.5	0.01
65722	LDA2	95.5	0.05
65722	S1	183.4	0.05
65722	M1	258.2	0.03
65722	J1	217.1	0.02
65722	MM	49	0.08
65722	SSA	55.4	0.25
65722	SA	120.3	0.39
65722	MSF	20.9	0.16
65722	MF	111.6	0.03
65722	RHO1	23.7	0.01
65722	Q1	222	0.05
65722	T2	72.9	0.04
65722	R2	251.9	0.01
65722	2Q1	25.3	0.02
65722	P1	220.4	0.11
65722	2SM2	21.3	0.01
65722	M3	119.9	0.02
65722	L2	47	0.25
65722	2MK3	135.1	0.05
65722	K2	100.4	0.11
65722	M8	200.3	0.01
65722	MS4	96.6	0.03
65723	M2	173.3	2.41
65723	S2	209	0.3
65723	N2	164.4	0.33
65723	K1	280.1	0.33
65723	M4	233.3	0.29
65723	O1	248.8	0.23
65723	M6	216.9	0.16
65723	S4	282.8	0.02
65723	NU2	165.6	0.07
65723	S6	335.3	0.01
65723	MU2	137.3	0.06
65723	2N2	155.8	0.04
65723	OO1	309.9	0.01
65723	LDA2	189.9	0.02
65723	M1	264.5	0.02
65723	J1	295	0.02
65723	SSA	63	0.3
65723	SA	119.2	0.49
65723	RHO1	235.6	0.01
65723	Q1	233.9	0.04
65723	T2	207.5	0.02
65723	2Q1	223.4	0.01
65723	P1	277.7	0.11
65723	L2	182.1	0.07
65723	K2	211.8	0.08
65723	M8	285	0.06
65724	M2	200.5	2.91
65724	S2	241.6	0.335
65724	N2	187.5	0.495
65724	K1	291.2	0.322
65724	M4	302.8	0.256
65724	O1	269.8	0.262
65724	M6	272	0.161
65724	MK3	357.7	0.082
65724	S4	249.1	0.01
65724	MN4	286.9	0.102
65724	NU2	173.6	0.157
65724	S6	323.6	0.003
65724	MU2	317.6	0.174
65724	2N2	119.5	0.033
65724	OO1	54.3	0.007
65724	LDA2	205.1	0.095
65724	S1	240.8	0.079
65724	M1	325.5	0.043
65724	J1	337.9	0.003
65724	MM	49.1	0.167
65724	SSA	57.7	0.305
65724	SA	121.4	0.427
65724	MSF	31.1	0.115
65724	MF	89.8	0.049
65724	RHO1	154	0.016
65724	Q1	265.5	0.039
65724	T2	206.7	0.023
65724	R2	101.6	0.003
65724	2Q1	70.8	0.013
65724	P1	293.5	0.095
65724	2SM2	161.3	0.016
65724	M3	284.4	0.03
65724	L2	190	0.358
65724	2MK3	321.9	0.085
65724	K2	237.5	0.102
65724	M8	17.2	0.082
65724	MS4	344.9	0.062
65725	M2	214.3	3.28
65725	S2	255.4	0.38
65725	N2	203.3	0.55
65725	K1	296.6	0.33
65725	M4	343	0.44
65725	O1	277.1	0.27
65725	M6	352.7	0.09
65725	MK3	19.7	0.11
65725	S4	315.3	0.01
65725	MN4	327.6	0.18
65725	NU2	185.9	0.18
65725	MU2	326	0.2
65725	2N2	126.1	0.04
65725	OO1	131	0.01
65725	LDA2	222.8	0.11
65725	S1	245.4	0.07
65725	M1	335.8	0.04
65725	J1	301.4	0.02
65725	MM	46.2	0.23
65725	SSA	78.9	0.36
65725	SA	137.8	0.41
65725	MSF	47.5	0.16
65725	MF	128.9	0.05
65725	RHO1	74.4	0.02
65725	Q1	292.6	0.06
65725	T2	193.8	0.04
65725	R2	299.9	0.01
65725	2Q1	95.3	0.02
65725	P1	294.4	0.1
65725	2SM2	181.1	0.02
65725	M3	301.5	0.04
65725	L2	203.9	0.39
65725	2MK3	345.9	0.11
65725	K2	254.4	0.13
65725	M8	76.1	0.05
65725	MS4	31	0.1
65726	M2	220.2	3.27
65726	S2	254.2	0.43
65726	N2	190	0.59
65726	K1	280.3	0.23
65726	M4	358.5	0.52
65726	O1	257.6	0.22
65726	M6	47.4	0.15
65726	S4	84.5	0.11
65726	NU2	194	0.11
65726	S6	123.1	0.03
65726	MU2	37.7	0.08
65726	2N2	159.8	0.08
65726	OO1	301.8	0.01
65726	LDA2	235.5	0.02
65726	M1	268.8	0.02
65726	J1	290.6	0.02
65726	SSA	91.1	0.24
65726	SA	139.4	0.35
65726	RHO1	248.2	0.01
65726	Q1	246.7	0.04
65726	T2	252.8	0.03
65726	2Q1	236.1	0.01
65726	P1	278.6	0.08
65726	L2	251	0.09
65726	K2	256.9	0.11
65726	M8	173.8	0.08
65727	M2	220.3	3.67
65727	S2	266.4	0.46
65727	N2	203.2	0.58
65727	K1	297.9	0.36
65727	M4	357.3	0.57
65727	O1	279.4	0.28
65727	M6	39.1	0.3
65727	MK3	28.9	0.12
65727	S4	78.3	0.01
65727	MN4	340.1	0.2
65727	NU2	198	0.2
65727	MU2	330.4	0.23
65727	2N2	194.2	0.07
65727	OO1	3.6	0.01
65727	LDA2	229.5	0.13
65727	S1	230.6	0.08
65727	M1	115.2	0.01
65727	J1	303.3	0.01
65727	SSA	66.3	0.19
65727	SA	88	0.33
65727	RHO1	277.5	0.01
65727	Q1	297.5	0.04
65727	T2	262.3	0.03
65727	2Q1	268.2	0.01
65727	P1	296.6	0.1
65727	2SM2	121.1	0.02
65727	M3	91.1	0.04
65727	L2	236	0.36
65727	2MK3	355.4	0.14
65727	K2	268.3	0.13
65727	M8	173	0.14
65727	MS4	47.2	0.15
65728	M2	146	2.55
65728	S2	181.5	0.32
65728	N2	130.2	0.44
65728	K1	261.8	0.33
65728	M4	195	0.3
65728	O1	246	0.28
65728	M6	156.2	0.12
65728	MK3	277.3	0.07
65728	S4	229.4	0.01
65728	MN4	178.9	0.11
65728	NU2	121.9	0.14
65728	MU2	263.3	0.11
65728	2N2	125	0.05
65728	OO1	254.2	0.01
65728	LDA2	154.7	0.08
65728	S1	208	0.07
65728	M1	337.3	0.01
65728	J1	242.1	0.01
65728	MM	58	0.12
65728	SSA	56.5	0.18
65728	SA	127.7	0.38
65728	MSF	33.5	0.11
65728	RHO1	196.5	0.02
65728	Q1	267.8	0.03
65728	T2	166.7	0.02
65728	P1	252.8	0.1
65728	2SM2	6.4	0.01
65728	M3	237.7	0.01
65728	L2	158.4	0.25
65728	2MK3	242.3	0.07
65728	K2	182	0.09
65728	M8	186.3	0.04
65728	MS4	240.1	0.09
65729	M2	185.8	2.75
65729	S2	225.5	0.31
65729	N2	168.7	0.48
65729	K1	283.7	0.33
65729	M4	256.4	0.28
65729	O1	263.8	0.27
65729	M6	248.4	0.17
65729	MK3	332.4	0.07
65729	MN4	240	0.11
65729	NU2	163.2	0.15
65729	MU2	309.1	0.15
65729	2N2	148.6	0.05
65729	OO1	303.5	0.01
65729	LDA2	196.2	0.09
65729	S1	240.3	0.08
65729	M1	352.1	0.02
65729	J1	311.7	0.02
65729	MM	27	0.1
65729	SSA	63	0.3
65729	SA	119.2	0.49
65729	MSF	17.7	0.09
65729	RHO1	264.2	0.01
65729	Q1	271.9	0.04
65729	T2	221.5	0.03
65729	2Q1	244.1	0.01
65729	P1	279.1	0.1
65729	2SM2	119.8	0.01
65729	M3	262.8	0.01
65729	L2	197.3	0.31
65729	2MK3	295.6	0.08
65729	K2	221.7	0.1
65729	M8	335.6	0.05
65729	MS4	305.2	0.07
65730	M2	195.1	2.71
65730	S2	235.1	0.31
65730	N2	175.8	0.43
65730	K1	289.7	0.34
65730	M4	286	0.36
65730	O1	273.2	0.25
65730	M6	289.8	0.16
65730	MK3	351.6	0.04
65730	MN4	271	0.14
65730	NU2	171.3	0.16
65730	MU2	312.2	0.12
65730	2N2	147.6	0.09
65730	OO1	306.2	0.01
65730	LDA2	198	0.08
65730	S1	233.8	0.06
65730	M1	281.4	0.02
65730	J1	298	0.02
65730	MM	66.2	0.14
65730	SSA	62.3	0.16
65730	SA	110.2	0.28
65730	MSF	15.1	0.2
65730	MF	2.4	0.12
65730	Q1	299.9	0.04
65730	T2	235	0.02
65730	R2	170	0.05
65730	P1	277.3	0.1
65730	L2	209.5	0.21
65730	2MK3	312.8	0.08
65730	K2	238	0.08
65730	M8	22.8	0.06
65730	MS4	339	0.11
65731	M2	194.7	2.77
65731	S2	235.1	0.31
65731	N2	177.9	0.44
65731	K1	286.1	0.34
65731	M4	274.8	0.23
65731	O1	270.1	0.24
65731	M6	262	0.16
65731	MK3	348	0.07
65731	S4	357.9	0.01
65731	MN4	258.1	0.08
65731	NU2	174.2	0.16
65731	MU2	318	0.15
65731	2N2	114.6	0.05
65731	OO1	37.7	0.03
65731	LDA2	197.6	0.1
65731	S1	240.9	0.07
65731	M1	43.5	0.02
65731	J1	8.9	0.03
65731	MM	27	0.1
65731	SSA	63	0.3
65731	SA	119.2	0.49
65731	MSF	17.7	0.09
65731	RHO1	227.3	0.02
65731	Q1	237.9	0.03
65731	T2	221.3	0.03
65731	R2	199	0.01
65731	2Q1	139.6	0.02
65731	P1	276.3	0.1
65731	2SM2	43.6	0.02
65731	M3	57.6	0.03
65731	L2	201.2	0.3
65731	2MK3	309.5	0.07
65731	K2	238	0.12
65731	M8	353.4	0.06
65731	MS4	320.6	0.06
65732	M2	219.6	3.51
65732	S2	265	0.42
65732	N2	205.2	0.63
65732	K1	299.3	0.35
65732	M4	353.3	0.46
65732	O1	276.2	0.24
65732	M6	31.7	0.22
65732	MK3	28.7	0.11
65732	MN4	334.5	0.18
65732	NU2	193.3	0.2
65732	MU2	334.4	0.22
65732	2N2	260.2	0.05
65732	OO1	288.3	0.02
65732	LDA2	234.9	0.11
65732	S1	236.7	0.09
65732	M1	322.9	0.02
65732	J1	30.8	0.03
65732	SSA	91.1	0.24
65732	SA	139.4	0.35
65732	RHO1	271.9	0.03
65732	Q1	269.6	0.03
65732	T2	261.2	0.04
65732	R2	86.3	0.01
65732	2Q1	262.8	0.01
65732	P1	291.2	0.13
65732	2SM2	93.9	0.01
65732	M3	306.3	0.04
65732	L2	230.6	0.59
65732	2MK3	348.5	0.12
65732	K2	261.2	0.13
65732	M8	162.3	0.08
65732	MS4	41.7	0.12
65733	M2	114.1	2.44
65733	S2	148	0.33
65733	N2	99.2	0.47
65733	K1	247.4	0.31
65733	M4	147.4	0.2
65733	O1	226.2	0.22
65733	M6	60	0.11
65733	MK3	237.8	0.05
65733	S4	133.1	0.01
65733	MN4	127.1	0.09
65733	NU2	91.2	0.12
65733	MU2	228.3	0.1
65733	2N2	122.4	0.05
65733	OO1	215.5	0.01
65733	LDA2	118.9	0.06
65733	S1	191.4	0.09
65733	M1	282.3	0.02
65733	J1	332	0.02
65733	SSA	31.3	0.13
65733	SA	144.5	0.44
65733	RHO1	239.7	0.02
65733	Q1	236.5	0.03
65733	T2	155.1	0.03
65733	R2	258.3	0.01
65733	2Q1	199.2	0.02
65733	P1	246.1	0.11
65733	2SM2	322.8	0.01
65733	M3	174.2	0.02
65733	L2	127.7	0.34
65733	2MK3	197.5	0.06
65733	K2	149	0.1
65733	M8	68.6	0.02
65733	MS4	189.7	0.06
65734	M2	109	2.54
65734	S2	143.2	0.33
65734	N2	93.4	0.46
65734	K1	244.4	0.29
65734	M4	132.5	0.18
65734	O1	224.3	0.22
65734	M6	51.8	0.11
65734	MK3	218.2	0.06
65734	MN4	115.3	0.08
65734	NU2	87.7	0.13
65734	MU2	221.8	0.1
65734	2N2	76.1	0.05
65734	OO1	264.4	0.01
65734	LDA2	114.7	0.07
65734	S1	200.8	0.07
65734	M1	302.6	0.02
65734	J1	265.1	0.01
65734	SSA	43.6	0.12
65734	SA	120.1	0.31
65734	RHO1	215.6	0.01
65734	Q1	233.4	0.04
65734	T2	135.7	0.03
65734	2Q1	204.3	0.01
65734	P1	240.6	0.1
65734	M3	184.8	0.01
65734	L2	120	0.25
65734	2MK3	185.9	0.06
65734	K2	142	0.1
65734	M8	38.8	0.02
65734	MS4	179.8	0.05
65735	M2	62.6	2.55
65735	S2	92.7	0.47
65735	N2	47.5	0.52
65735	K1	219	0.35
65735	M4	29.3	0.11
65735	O1	200.8	0.29
65735	M6	214	0.05
65735	MK3	178.6	0.04
65735	S4	12.7	0.01
65735	MN4	10.4	0.05
65735	NU2	41.5	0.11
65735	MU2	118.4	0.05
65735	2N2	30.3	0.07
65735	OO1	231.1	0.01
65735	LDA2	70.1	0.05
65735	S1	194.2	0.05
65735	M1	269.7	0.01
65735	J1	197.8	0.02
65735	SSA	41.3	0.1
65735	SA	140.5	0.17
65735	RHO1	253	0.01
65735	Q1	212.9	0.04
65735	T2	42.9	0.04
65735	2Q1	155.8	0.02
65735	P1	214	0.06
65735	2SM2	345.6	0.01
65735	M3	146.6	0.02
65735	L2	71	0.16
65735	2MK3	132.2	0.04
65735	K2	86.8	0.15
65735	M8	127	0.01
65735	MS4	75.6	0.03
65736	M2	36.9	2.37
65736	S2	61.9	0.4
65736	N2	20.4	0.53
65736	K1	203.1	0.34
65736	M4	144	0.03
65736	O1	189.6	0.28
65736	M6	51.4	0.01
65736	MK3	153.7	0.01
65736	S4	287.4	0.01
65736	MN4	162.7	0.01
65736	NU2	14.2	0.11
65736	MU2	54	0.04
65736	2N2	356.1	0.06
65736	LDA2	47	0.04
65736	S1	158.8	0.02
65736	M1	238.4	0.03
65736	J1	193.6	0.03
65736	MM	101.5	0.03
65736	SSA	61.2	0.22
65736	SA	128	0.31
65736	MSF	10.1	0.13
65736	MF	106.4	0.03
65736	RHO1	67.1	0.01
65736	Q1	198.9	0.05
65736	T2	40.4	0.04
65736	R2	299	0.01
65736	2Q1	13	0.01
65736	P1	197.7	0.11
65736	M3	106.2	0.02
65736	L2	26.3	0.12
65736	2MK3	101.8	0.01
65736	K2	61.6	0.11
65736	M8	228.4	0.01
65736	MS4	155.4	0.02
65737	M2	31.1	2.02
65737	S2	56.8	0.35
65737	N2	10.6	0.44
65737	K1	201.7	0.34
65737	M4	186.3	0.04
65737	O1	188.6	0.27
65737	M6	349.5	0.02
65737	MN4	177.8	0.02
65737	NU2	11.4	0.09
65737	MU2	16.9	0.04
65737	2N2	356.6	0.05
65737	OO1	239.3	0.01
65737	LDA2	55	0.03
65737	S1	133.1	0.03
65737	M1	221.4	0.01
65737	J1	194.7	0.02
65737	SSA	41.3	0.1
65737	SA	140.5	0.17
65737	RHO1	177.4	0.01
65737	Q1	182.9	0.04
65737	T2	30.5	0.04
65737	R2	280.3	0.01
65737	2Q1	175.5	0.01
65737	P1	199.1	0.11
65737	M3	110	0.01
65737	L2	48	0.07
65737	K2	51.9	0.1
65737	MS4	205.9	0.01
65738	M2	24.1	1.23
65738	S2	47.5	0.22
65738	N2	1.9	0.28
65738	K1	210.6	0.23
65738	M4	179.7	0.07
65738	O1	198.9	0.2
65738	M6	248.7	0.01
65738	MK3	17.1	0.02
65738	MN4	165.5	0.04
65738	NU2	4.6	0.05
65738	MU2	354.2	0.02
65738	2N2	349.3	0.03
65738	OO1	222.2	0.01
65738	LDA2	35	0.01
65738	S1	122.9	0.02
65738	M1	204.6	0.01
65738	J1	216.4	0.02
65738	MM	243.6	0.06
65738	SSA	43.6	0.1
65738	SA	153.5	0.2
65738	MF	182.2	0.05
65738	RHO1	193.8	0.01
65738	Q1	193.4	0.03
65738	T2	47.4	0.01
65738	2Q1	187.1	0.01
65738	P1	203.9	0.08
65738	L2	43.9	0.05
65738	2MK3	13.1	0.02
65738	K2	42.6	0.06
65738	MS4	203.3	0.02
65739	M2	0.9	1.64
65739	S2	24.6	0.32
65739	N2	342.1	0.38
65739	K1	194.4	0.29
65739	M4	221.5	0.02
65739	O1	185.3	0.28
65739	M6	311.3	0.05
65739	S4	211.3	0.01
65739	MN4	185.2	0.02
65739	NU2	341.6	0.08
65739	MU2	339.9	0.07
65739	2N2	328.6	0.05
65739	OO1	203.4	0.01
65739	LDA2	11.8	0.01
65739	S1	112.7	0.03
65739	M1	189.8	0.02
65739	J1	198.9	0.02
65739	MM	278.9	0.09
65739	SSA	51.1	0.11
65739	SA	155.7	0.2
65739	RHO1	181.3	0.01
65739	Q1	172	0.05
65739	T2	24.6	0.02
65739	2Q1	176.1	0.01
65739	P1	192.7	0.1
65739	L2	19.5	0.05
65739	K2	23.4	0.08
65740	M2	8.6	1
65740	S2	31.5	0.18
65740	N2	348.5	0.23
65740	K1	210.5	0.18
65740	M4	171.6	0.07
65740	O1	200	0.17
65740	M6	268.2	0.01
65740	MK3	359.5	0.02
65740	S4	210.9	0.01
65740	MN4	152.5	0.03
65740	NU2	346	0.05
65740	MU2	342	0.03
65740	2N2	333.4	0.03
65740	OO1	203.7	0.01
65740	LDA2	20.4	0.01
65740	S1	153.8	0.01
65740	J1	197.8	0.01
65740	MM	69.5	0.09
65740	SSA	69.2	0.15
65740	SA	147.2	0.29
65740	RHO1	181.6	0.01
65740	Q1	191.3	0.03
65740	T2	6.9	0.02
65740	R2	249.8	0.01
65740	P1	198.9	0.06
65740	M3	13	0.01
65740	L2	28.2	0.04
65740	2MK3	0.9	0.02
65740	K2	30.5	0.05
65740	M8	346.3	0.01
65740	MS4	187.9	0.01
65741	M2	141.9	0.2
65741	S2	164.2	0.03
65741	N2	127.1	0.05
65741	K1	295.6	0.08
65741	M4	250.1	0.01
65741	O1	291.5	0.06
65741	M6	194.1	0.01
65741	NU2	128.7	0.01
65741	2N2	112.5	0.01
65741	SSA	40.3	0.12
65741	SA	155.3	0.2
65741	Q1	288.1	0.01
65741	P1	295.5	0.03
65741	L2	159.7	0.01
65741	K2	166.8	0.01
65742	M2	142.3	0.22
65742	S2	171.7	0.04
65742	N2	131.1	0.05
65742	K1	298.5	0.08
65742	M4	201	0.02
65742	O1	292	0.06
65742	M6	52.7	0.01
65742	NU2	132.6	0.01
65742	MU2	322	0.01
65742	2N2	119.8	0.01
65742	J1	301.2	0.01
65742	SSA	40.3	0.12
65742	SA	155.3	0.2
65742	Q1	289	0.01
65742	P1	298.1	0.02
65742	L2	153.9	0.01
65742	K2	174.1	0.01
65743	M2	131.1	0.25
65743	S2	163.5	0.04
65743	N2	115	0.05
65743	K1	284.3	0.06
65743	M4	178.8	0.02
65743	O1	295.1	0.07
65743	M6	44	0.01
65743	MN4	157.9	0.01
65743	NU2	126.9	0.01
65743	MU2	265.1	0.01
65743	2N2	118.1	0.01
65743	LDA2	148.5	0.01
65743	S1	246.5	0.03
65743	J1	269.3	0.01
65743	RHO1	183.7	0.01
65743	Q1	302.2	0.01
65743	T2	151.1	0.01
65743	R2	45.8	0.01
65743	2Q1	280.5	0.01
65743	P1	276.3	0.03
65743	L2	139.4	0.02
65743	K2	149.9	0.02
65743	MS4	225.7	0.01
65744	M2	150.3	0.9
65744	S2	181.2	0.16
65744	N2	144.1	0.15
65744	K1	275.4	0.17
65744	M4	213.3	0.03
65744	O1	259.2	0.16
65744	M6	201.7	0.02
65744	NU2	145	0.03
65744	MU2	327.7	0.02
65744	2N2	137.9	0.02
65744	OO1	291.6	0.01
65744	LDA2	164.6	0.01
65744	M1	267.3	0.01
65744	J1	283.5	0.01
65744	RHO1	252.2	0.01
65744	Q1	251.1	0.03
65744	T2	180	0.01
65744	P1	274.2	0.06
65744	L2	156.5	0.03
65744	K2	183.7	0.04
65745	M2	162.4	0.738
65745	S2	191.6	0.11
65745	N2	141.1	0.15
65745	K1	279.9	0.1
65745	M4	217.4	0.04
65745	O1	293.4	0.09
65745	M6	243	0.02
65745	NU2	143.9	0.03
65745	MU2	341	0.02
65745	2N2	119.9	0.02
65745	LDA2	175.9	0.01
65745	M1	286.9	0.01
65745	J1	274.2	0.01
65745	SSA	35.7	0.12
65745	SA	133.1	0.27
65745	Q1	299.7	0.02
65745	T2	190.5	0.01
65745	P1	280.9	0.03
65745	L2	183.7	0.02
65745	K2	194	0.03
65746	M2	263.1	0.61
65746	S2	92.6	0.03
65746	N2	232.9	0.04
65746	K1	3.4	0.09
65746	M4	359.8	0.07
65746	O1	339.4	0.07
65746	M6	118.1	0.04
65746	S4	12.8	0.01
65746	NU2	236.9	0.01
65746	MU2	282.8	0.02
65746	2N2	202.7	0.01
65746	M1	351.5	0.01
65746	J1	15.3	0.01
65746	Q1	327.4	0.01
65746	P1	1.6	0.03
65746	L2	293.3	0.02
65746	K2	78.8	0.01
65747	M2	182.9	0.85
65747	S2	210	0.13
65747	N2	159.2	0.18
65747	K1	275.5	0.12
65747	M4	281.6	0.06
65747	O1	295.8	0.1
65747	M6	337.4	0.01
65747	MK3	313.2	0.02
65747	MN4	253.9	0.02
65747	NU2	154.5	0.04
65747	MU2	199.4	0.01
65747	2N2	137.3	0.02
65747	OO1	298.2	0.01
65747	LDA2	203.6	0.02
65747	S1	288.4	0.03
65747	J1	287.2	0.01
65747	MM	53.7	0.07
65747	SSA	57	0.16
65747	SA	130.8	0.37
65747	MF	325	0.03
65747	Q1	267.8	0.02
65747	T2	201.4	0.01
65747	P1	274.8	0.05
65747	M3	271.4	0.01
65747	L2	210.3	0.05
65747	2MK3	313.6	0.02
65747	K2	205.4	0.04
65747	MS4	330.1	0.02
65748	M2	191.5	1.02
65748	S2	221.2	0.16
65748	N2	175.4	0.22
65748	K1	282.2	0.14
65748	M4	303.9	0.06
65748	O1	298.8	0.11
65748	M6	32.4	0.01
65748	MK3	315.4	0.02
65748	MN4	282.1	0.02
65748	NU2	173.2	0.06
65748	MU2	235.1	0.02
65748	2N2	148.7	0.03
65748	OO1	326.8	0.01
65748	LDA2	230	0.02
65748	S1	276.7	0.03
65748	M1	263	0.01
65748	J1	298.1	0.01
65748	RHO1	251.9	0.02
65748	Q1	266.8	0.03
65748	T2	222.8	0.01
65748	2Q1	6.8	0.02
65748	P1	295	0.05
65748	M3	42.5	0.01
65748	L2	198.9	0.04
65748	2MK3	315.1	0.02
65748	K2	213.9	0.05
65748	MS4	354.3	0.02
65749	M2	194.1	0.58
65749	S2	209	0.1
65749	N2	168.1	0.13
65749	K1	305.1	0.1
65749	M4	243.6	0.02
65749	O1	325.1	0.08
65749	M6	277.5	0.01
65749	MK3	312.7	0.01
65749	MN4	218.7	0.01
65749	NU2	172.8	0.03
65749	2N2	148.9	0.02
65749	OO1	320.4	0.01
65749	LDA2	232.8	0.01
65749	S1	288.6	0.05
65749	M1	46.1	0.01
65749	SSA	36.1	0.11
65749	SA	131.4	0.29
65749	RHO1	43.4	0.01
65749	Q1	301.6	0.02
65749	T2	199.5	0.02
65749	R2	337	0.02
65749	P1	291	0.05
65749	M3	266.6	0.01
65749	L2	229.9	0.06
65749	2MK3	308.7	0.01
65749	K2	238.3	0.03
65750	M2	221.4	1.52
65750	S2	261.2	0.26
65750	N2	204.7	0.28
65750	K1	290.9	0.17
65750	M4	293.5	0.06
65750	O1	320.3	0.12
65750	M6	42.7	0.02
65750	S4	55.6	0.01
65750	NU2	207	0.06
65750	MU2	181.7	0.04
65750	2N2	188	0.04
65750	OO1	262.6	0.01
65750	LDA2	239.8	0.01
65750	M1	306.1	0.01
65750	J1	277.4	0.01
65750	SSA	57	0.16
65750	SA	130.8	0.4
65750	Q1	334.9	0.02
65750	T2	259.7	0.02
65750	P1	293.1	0.06
65750	L2	238.2	0.04
65750	K2	264.5	0.07
65750	M8	19.1	0.01
65751	M2	255.7	0.59
65751	S2	289.3	0.08
65751	N2	237.1	0.11
65751	K1	343.6	0.12
65751	M4	349.1	0.03
65751	O1	358.4	0.1
65751	M6	73	0.01
65751	MK3	8.6	0.02
65751	MN4	329.2	0.01
65751	NU2	226.6	0.03
65751	MU2	341.4	0.02
65751	2N2	266	0.01
65751	LDA2	248.3	0.02
65751	S1	313.7	0.04
65751	J1	131.4	0.01
65751	SSA	54.2	0.16
65751	SA	145.2	0.34
65751	RHO1	271.3	0.02
65751	Q1	308.9	0.02
65751	T2	203.1	0.01
65751	R2	240.8	0.01
65751	2Q1	36.1	0.01
65751	P1	342.1	0.05
65751	2SM2	200.3	0.01
65751	M3	82.6	0.01
65751	L2	274.7	0.05
65751	2MK3	4.1	0.02
65751	K2	280.8	0.03
65751	MS4	31.5	0.01
65752	M2	258.1	0.94
65752	S2	284.5	0.06
65752	N2	243.2	0.16
65752	K1	332	0.14
65752	M4	354.3	0.09
65752	O1	330.1	0.09
65752	M6	99.5	0.05
65752	S4	336.8	0.01
65752	NU2	245.2	0.03
65752	MU2	80	0.02
65752	2N2	228.4	0.02
65752	LDA2	270.3	0.01
65752	M1	331.1	0.01
65752	J1	333	0.01
65752	Q1	329.2	0.02
65752	P1	331.9	0.05
65752	L2	272.9	0.03
65752	K2	286.7	0.02
65752	M8	179.2	0.01
65753	M2	263.2	0.78
65753	S2	285.6	0.12
65753	N2	240.6	0.15
65753	K1	340.4	0.16
65753	M4	90.5	0.04
65753	O1	355.9	0.13
65753	MK3	82	0.02
65753	MN4	58.1	0.01
65753	NU2	245.1	0.04
65753	2N2	222.8	0.02
65753	OO1	324.8	0.01
65753	LDA2	287	0.02
65753	S1	305.8	0.06
65753	M1	348	0.01
65753	J1	337.2	0.01
65753	SSA	40.2	0.11
65753	SA	133.4	0.28
65753	RHO1	2.4	0.01
65753	Q1	329.6	0.02
65753	T2	269.3	0.01
65753	P1	336.3	0.07
65753	L2	289.7	0.06
65753	2MK3	79.6	0.02
65753	K2	283.8	0.04
65753	MS4	129.7	0.01
65754	M2	262.1	0.51
65754	S2	293	0.08
65754	N2	237.1	0.1
65754	K1	344.5	0.17
65754	M4	65.2	0.01
65754	O1	355	0.13
65754	M6	88.3	0.01
65754	MK3	88.1	0.01
65754	MN4	31	0.01
65754	NU2	244.8	0.02
65754	2N2	190.9	0.01
65754	OO1	338.6	0.01
65754	LDA2	285	0.01
65754	S1	301.6	0.06
65754	M1	29	0.01
65754	J1	319	0.01
65754	MM	52	0.03
65754	SSA	62.2	0.12
65754	SA	134.2	0.37
65754	MSF	241.1	0.02
65754	MF	335.8	0.03
65754	RHO1	348.3	0.01
65754	Q1	334.3	0.03
65754	T2	271	0.01
65754	R2	105.4	0.01
65754	2Q1	325.1	0.01
65754	P1	330	0.06
65754	L2	289.6	0.03
65754	2MK3	75.8	0.01
65754	K2	288.1	0.02
65755	M2	272	0.7
65755	S2	302.1	0.11
65755	N2	248.5	0.15
65755	K1	343.7	0.24
65755	M4	108.4	0.05
65755	O1	6.3	0.14
65755	M6	226.5	0.01
65755	NU2	251.7	0.03
65755	MU2	241.8	0.02
65755	2N2	225.1	0.02
65755	OO1	321.2	0.01
65755	M1	354.9	0.01
65755	J1	332.5	0.01
65755	SSA	44.5	0.12
65755	SA	128.4	0.34
65755	RHO1	16	0.01
65755	Q1	17.5	0.03
65755	T2	300.9	0.01
65755	P1	345.4	0.08
65755	L2	295.4	0.02
65755	K2	304.5	0.03
65756	M2	267.6	0.51
65756	S2	297.4	0.07
65756	N2	245.8	0.1
65756	K1	346	0.16
65756	M4	51.5	0.01
65756	O1	358.4	0.14
65756	MK3	89.4	0.01
65756	MN4	28.2	0.01
65756	NU2	252.1	0.03
65756	2N2	226.8	0.01
65756	LDA2	308.4	0.01
65756	S1	292.8	0.05
65756	J1	289.2	0.01
65756	MM	334.9	0.04
65756	SSA	0.3	0.08
65756	SA	129.3	0.22
65756	MSF	257.3	0.06
65756	MF	179.9	0.02
65756	Q1	340.2	0.02
65756	T2	253.2	0.01
65756	P1	334	0.06
65756	L2	297.8	0.03
65756	2MK3	95.5	0.01
65756	K2	292.1	0.03
65757	M2	13.9	1.03
65757	S2	110	0.09
65757	N2	358.1	0.12
65757	K1	40.8	0.2
65757	M4	231.7	0.1
65757	O1	44.3	0.16
65757	M6	85.9	0.05
65757	NU2	0.2	0.02
65757	MU2	125.9	0.03
65757	2N2	342.3	0.02
65757	OO1	37.3	0.01
65757	LDA2	58.5	0.01
65757	M1	42.6	0.01
65757	J1	39	0.01
65757	RHO1	45.9	0.01
65757	Q1	46.1	0.03
65757	T2	106.1	0.01
65757	P1	41.1	0.07
65757	L2	29.7	0.03
65757	K2	117.7	0.03
65758	M2	292.5	0.46
65758	S2	323.7	0.07
65758	N2	269.4	0.1
65758	K1	352.3	0.19
65758	M4	33.6	0.01
65758	O1	356.2	0.15
65758	M6	127.5	0.01
65758	MK3	121.3	0.01
65758	NU2	269.7	0.02
65758	2N2	249.3	0.01
65758	LDA2	311.2	0.01
65758	S1	288.9	0.06
65758	SSA	54	0.11
65758	SA	130.6	0.35
65758	P1	344.7	0.06
65758	L2	322.8	0.03
65758	2MK3	112.2	0.01
65758	K2	318.4	0.02
65759	M2	322.7	0.54
65759	S2	355.3	0.08
65759	N2	298.1	0.11
65759	K1	1.6	0.21
65759	O1	11.1	0.17
65759	MK3	167.8	0.01
65759	NU2	303.5	0.03
65759	2N2	274.3	0.01
65759	LDA2	2	0.01
65759	S1	301	0.06
65759	J1	318.5	0.01
65759	SSA	44.5	0.12
65759	SA	128.4	0.34
65759	RHO1	351.8	0.01
65759	Q1	331.6	0.02
65759	T2	355.8	0.01
65759	2Q1	161.3	0.01
65759	P1	346.6	0.06
65759	L2	342.4	0.03
65759	2MK3	150.4	0.01
65759	K2	353.8	0.02
65760	M2	8.3	1.04
65760	S2	51.9	0.14
65760	N2	349.8	0.2
65760	K1	19.4	0.25
65760	M4	159.4	0.01
65760	O1	33.9	0.19
65760	M6	67.8	0.02
65760	MK3	238.4	0.03
65760	NU2	321.2	0.05
65760	MU2	87	0.03
65760	2N2	15.9	0.04
65760	OO1	62.7	0.01
65760	LDA2	4.3	0.03
65760	S1	318.5	0.07
65760	M1	116.1	0.01
65760	J1	106.2	0.02
65760	SSA	62.3	0.11
65760	SA	143.5	0.36
65760	RHO1	306.8	0.01
65760	Q1	342.8	0.02
65760	R2	60.9	0.01
65760	2Q1	29.5	0.02
65760	P1	9.1	0.09
65760	M3	308	0.01
65760	L2	25.7	0.09
65760	2MK3	222.7	0.04
65760	K2	45.5	0.05
65761	M2	346.6	0.57
65761	S2	8	0.08
65761	N2	324.1	0.12
65761	K1	3.3	0.23
65761	M4	215.1	0.01
65761	O1	14	0.19
65761	MK3	173.5	0.01
65761	NU2	323.7	0.02
65761	2N2	296.7	0.01
65761	OO1	352.5	0.01
65761	LDA2	21.4	0.02
65761	S1	283.1	0.08
65761	M1	8.6	0.01
65761	J1	332.6	0.02
65761	SSA	47.9	0.17
65761	SA	138.3	0.41
65761	RHO1	18.6	0.01
65761	Q1	346.5	0.04
65761	2Q1	298.7	0.02
65761	P1	352.4	0.08
65761	L2	31.2	0.03
65761	K2	5.5	0.03
65762	M2	47.5	0.73
65762	S2	92.6	0.1
65762	N2	16.9	0.13
65762	K1	19.2	0.26
65762	M4	263.4	0.01
65762	O1	20.9	0.17
65762	MK3	320.7	0.02
65762	NU2	27.4	0.03
65762	MU2	149.1	0.01
65762	2N2	343	0.01
65762	OO1	344.1	0.01
65762	LDA2	86.8	0.02
65762	S1	277.3	0.06
65762	M1	225.7	0.01
65762	J1	251.3	0.01
65762	RHO1	324.7	0.02
65762	Q1	17.2	0.02
65762	T2	104.7	0.03
65762	R2	170.8	0.01
65762	2Q1	85.8	0.02
65762	P1	1.4	0.07
65762	L2	87.2	0.06
65762	2MK3	301.7	0.02
65762	K2	108.8	0.03
65763	M2	70.6	0.98
65763	S2	112.9	0.14
65763	N2	43.1	0.18
65763	K1	21.1	0.2
65763	M4	120.5	0.04
65763	O1	37.8	0.15
65763	M6	196.8	0.01
65763	MK3	299.3	0.02
65763	S4	224.9	0.01
65763	MN4	98.6	0.01
65763	NU2	40.1	0.05
65763	MU2	210.3	0.02
65763	2N2	34.8	0.02
65763	OO1	35.1	0.02
65763	LDA2	114.3	0.02
65763	S1	317.9	0.05
65763	M1	112.7	0.01
65763	J1	261.2	0.01
65763	SSA	53.2	0.1
65763	SA	127.9	0.35
65763	RHO1	10.2	0.03
65763	Q1	22.5	0.02
65763	T2	99.1	0.03
65763	R2	320	0.01
65763	2Q1	185	0.01
65763	P1	12.4	0.08
65763	2SM2	11.8	0.01
65763	M3	205.4	0.01
65763	L2	84.1	0.12
65763	2MK3	296.3	0.03
65763	K2	99.5	0.05
65763	MS4	154.1	0.01
65764	M2	92.4	1.35
65764	S2	129.8	0.18
65764	N2	72.2	0.22
65764	K1	348.4	0.11
65764	M4	140	0.07
65764	O1	7.3	0.05
65764	M6	103.9	0.03
65764	MK3	280.4	0.03
65764	S4	204.9	0.01
65764	MN4	127.1	0.02
65764	NU2	73.3	0.07
65764	MU2	214.7	0.06
65764	2N2	62.8	0.03
65764	OO1	320	0.01
65764	LDA2	99.5	0.04
65764	S1	248.6	0.03
65764	M1	111.9	0.01
65764	J1	358.6	0.01
65764	SSA	56.2	0.13
65764	SA	131.2	0.4
65764	Q1	336	0.02
65764	T2	123	0.02
65764	2Q1	309.2	0.01
65764	P1	337.4	0.02
65764	2SM2	9.3	0.01
65764	M3	283.1	0.01
65764	L2	112.5	0.13
65764	2MK3	259.9	0.02
65764	K2	139.5	0.06
65764	M8	94.5	0.01
65764	MS4	179.9	0.02
65765	M2	71.9	0.93
65765	S2	112.8	0.16
65765	N2	44.5	0.17
65765	K1	27.7	0.28
65765	M4	43.3	0.06
65765	O1	32.2	0.19
65765	MK3	348.5	0.04
65765	MN4	16.7	0.02
65765	NU2	45.8	0.04
65765	MU2	212.3	0.03
65765	2N2	17.2	0.02
65765	OO1	23.1	0.01
65765	LDA2	91.8	0.04
65765	S1	141.7	0.03
65765	M1	29.8	0.01
65765	J1	25.5	0.02
65765	SSA	53.9	0.11
65765	SA	104.8	0.25
65765	RHO1	34	0.01
65765	Q1	7.8	0.04
65765	T2	81.8	0.03
65765	2Q1	36.6	0.01
65765	P1	19.5	0.06
65765	2SM2	79.2	0.01
65765	L2	106.9	0.07
65765	2MK3	341.6	0.04
65765	K2	107.7	0.03
65765	MS4	72.5	0.02
65766	M2	27.8	0.58
65766	S2	59.7	0.07
65766	N2	354.8	0.11
65766	K1	9.1	0.35
65766	M4	254.8	0.04
65766	O1	30.5	0.14
65766	M6	112	0.02
65766	NU2	359.2	0.02
65766	MU2	203.6	0.01
65766	2N2	321.5	0.01
65766	OO1	346.1	0.01
65766	M1	19.3	0.01
65766	J1	357.2	0.01
65766	RHO1	40	0.01
65766	Q1	41.5	0.03
65766	P1	10.7	0.12
65766	L2	60.5	0.02
65766	K2	62.2	0.02
65767	M2	337	0.52
65767	S2	8.1	0.08
65767	N2	314.2	0.11
65767	K1	8	0.23
65767	M4	246	0.03
65767	O1	15	0.18
65767	MK3	176.7	0.02
65767	MN4	215.5	0.01
65767	NU2	316.7	0.02
65767	2N2	288	0.01
65767	OO1	94.9	0.02
65767	LDA2	7.4	0.01
65767	S1	292.9	0.07
65767	M1	11.4	0.01
65767	J1	319.2	0.01
65767	SSA	53.2	0.1
65767	SA	127.9	0.35
65767	RHO1	17.9	0.01
65767	Q1	342.2	0.04
65767	2Q1	21.8	0.01
65767	P1	1.3	0.07
65767	L2	355.7	0.02
65767	2MK3	170.1	0.02
65767	K2	6.3	0.03
65768	M2	336.5	0.51
65768	S2	7.5	0.08
65768	N2	315.3	0.11
65768	K1	6.9	0.22
65768	M4	247.2	0.03
65768	O1	16.4	0.18
65768	M6	7.2	0.01
65768	MK3	179.3	0.02
65768	MN4	215.5	0.01
65768	NU2	327.2	0.02
65768	MU2	325.8	0.01
65768	2N2	268.8	0.02
65768	OO1	28.1	0.02
65768	LDA2	23.6	0.01
65768	S1	283.6	0.06
65768	M1	294.6	0.01
65768	J1	343.7	0.01
65768	SSA	53.2	0.1
65768	SA	127.9	0.35
65768	RHO1	338.5	0.02
65768	Q1	345.2	0.05
65768	R2	60.4	0.01
65768	2Q1	68	0.02
65768	P1	0.3	0.06
65768	M3	29.2	0.01
65768	L2	330.2	0.01
65768	2MK3	159.4	0.01
65768	K2	353.5	0.02
65768	MS4	275.6	0.01
65769	M2	291.6	0.46
65769	S2	319.5	0.07
65769	N2	270.5	0.1
65769	K1	356.7	0.19
65769	M4	58.3	0.01
65769	O1	6	0.16
65769	M6	159.6	0.01
65769	NU2	268.5	0.02
65769	2N2	246.7	0.01
65769	OO1	347.3	0.01
65769	LDA2	318	0.01
65769	S1	290.5	0.07
65769	M1	1.2	0.01
65769	J1	340.9	0.01
65769	SSA	44.5	0.12
65769	SA	128.4	0.34
65769	RHO1	29	0.01
65769	Q1	331.6	0.03
65769	P1	348.8	0.07
65769	L2	308.1	0.03
65769	K2	317.9	0.02
65770	M2	223.6	0.47
65770	S2	250.3	0.07
65770	N2	194.9	0.09
65770	K1	339.3	0.11
65770	M4	286.4	0.01
65770	O1	351.4	0.1
65770	M6	336.6	0.01
65770	MK3	0.4	0.01
65770	NU2	202.9	0.02
65770	2N2	169.6	0.01
65770	LDA2	258.4	0.01
65770	S1	303.5	0.04
65770	M1	265	0.01
65770	J1	310.8	0.01
65770	SSA	36.1	0.11
65770	SA	131.4	0.29
65770	RHO1	305.3	0.01
65770	Q1	305.3	0.02
65770	T2	251.5	0.01
65770	P1	325.4	0.04
65770	L2	255.7	0.04
65770	2MK3	345.5	0.01
65770	K2	257.6	0.02
65771	M2	207.6	0.46
65771	S2	231.3	0.08
65771	N2	177.3	0.1
65771	K1	350.7	0.07
65771	M4	257.2	0.01
65771	O1	338.9	0.06
65771	M6	316.5	0.01
65771	NU2	181.4	0.02
65771	MU2	31.1	0.01
65771	2N2	147	0.01
65771	SSA	36.1	0.11
65771	SA	131.4	0.29
65771	Q1	333	0.01
65771	P1	349.8	0.02
65771	L2	237.8	0.01
65771	K2	233.2	0.02
65772	M2	198.8	0.56
65772	S2	225.9	0.09
65772	N2	172.3	0.12
65772	K1	315.6	0.09
65772	M4	276.5	0.02
65772	O1	332.4	0.08
65772	M6	301.2	0.01
65772	MK3	331.8	0.01
65772	NU2	177.8	0.03
65772	2N2	149.6	0.01
65772	LDA2	229.3	0.01
65772	S1	290.5	0.05
65772	M1	324	0.01
65772	J1	307.3	0.01
65772	SSA	36.1	0.11
65772	SA	131.4	0.29
65772	Q1	306.7	0.02
65772	T2	224.7	0.01
65772	P1	318.9	0.04
65772	L2	233.8	0.04
65772	2MK3	324.8	0.01
65772	K2	223.5	0.03
65773	M2	252	0.86
65773	S2	289	0.1
65773	N2	228.9	0.1
65773	K1	321.2	0.11
65773	M4	12.7	0.05
65773	O1	3.3	0.07
65773	M6	120.9	0.03
65773	NU2	232	0.02
65773	MU2	61.5	0.02
65773	2N2	205.9	0.01
65773	LDA2	269.2	0.01
65773	M1	342.1	0.01
65773	J1	300.4	0.01
65773	Q1	24.1	0.01
65773	T2	287.6	0.01
65773	P1	324.4	0.04
65773	L2	275	0.02
65773	K2	292	0.03
65774	M2	30.7	1.34
65774	S2	81.5	0.16
65774	N2	9.9	0.25
65774	K1	10.1	0.13
65774	M4	343.7	0.18
65774	O1	22.1	0.12
65774	M6	258	0.04
65774	S4	47.4	0.01
65774	NU2	12.8	0.05
65774	MU2	185.7	0.03
65774	2N2	348	0.03
65774	LDA2	54.4	0.01
65774	M1	15.3	0.01
65774	J1	1.9	0.01
65774	SSA	40	0.12
65774	SA	110.6	0.25
65774	Q1	28.5	0.02
65774	T2	79.4	0.01
65774	P1	10.7	0.04
65774	L2	52.1	0.04
65774	K2	85.6	0.04
65774	M8	164.4	0.01
65775	M2	20.4	1.34
65775	S2	64.3	0.17
65775	N2	356.5	0.25
65775	K1	357	0.15
65775	M4	320.9	0.14
65775	O1	22.6	0.11
65775	M6	191.3	0.04
65775	MK3	255.4	0.04
65775	MN4	297.6	0.05
65775	NU2	1.3	0.06
65775	MU2	117.7	0.03
65775	2N2	323.6	0.02
65775	OO1	57	0.01
65775	LDA2	45.4	0.04
65775	S1	326.3	0.04
65775	M1	9.7	0.01
65775	J1	344.3	0.01
65775	SSA	40	0.12
65775	SA	110.6	0.25
65775	Q1	345.8	0.02
65775	T2	104.1	0.02
65775	R2	85.4	0.01
65775	P1	4.4	0.04
65775	L2	33.5	0.09
65775	2MK3	266.7	0.04
65775	K2	62.2	0.06
65775	M8	106.3	0.01
65775	MS4	9.2	0.04
65776	M2	70.8	0.33
65776	S2	89.8	0.05
65776	N2	56.5	0.06
65776	K1	261.7	0.05
65776	M4	80.6	0.05
65776	O1	260.5	0.08
65776	M6	268	0.02
65776	S4	328	0.01
65776	NU2	58.7	0.01
65776	MU2	52	0.01
65776	2N2	42.8	0.01
65776	M1	261.4	0.01
65776	J1	262.9	0.01
65776	MM	278.9	0.09
65776	SSA	51.1	0.11
65776	SA	155.7	0.2
65776	Q1	259.9	0.02
65776	P1	261.3	0.02
65776	L2	85.4	0.01
65776	K2	91.1	0.01
65776	M8	278.6	0.01
65777	M2	21.1	0.768
65777	S2	53.6	0.138
65777	N2	7.9	0.161
65777	K1	203.8	0.112
65777	M4	338.9	0.026
65777	O1	218	0.131
65777	M6	134.9	0.023
65777	MK3	42.5	0.007
65777	S4	267.2	0.003
65777	MN4	311.5	0.013
65777	NU2	352.5	0.03
65777	MU2	66	0.007
65777	2N2	357.3	0.023
65777	OO1	218	0.003
65777	LDA2	24.2	0.013
65777	S1	178.8	0.007
65777	M1	255.6	0.003
65777	J1	206.6	0.007
65777	MM	69.5	0.089
65777	SSA	69.2	0.148
65777	SA	147.2	0.289
65777	RHO1	244.9	0.013
65777	Q1	221.4	0.02
65777	T2	39.8	0.003
65777	R2	262.9	0.016
65777	2Q1	197.1	0.01
65777	P1	208.5	0.036
65777	M3	34.2	0.007
65777	L2	21.8	0.036
65777	2MK3	30.3	0.007
65777	K2	40.7	0.03
65777	M8	59.8	0.003
65777	MS4	40.6	0.013
65778	M2	12.8	1.07
65778	S2	42.2	0.177
65778	N2	358.6	0.226
65778	K1	193.8	0.157
65778	M4	328.4	0.03
65778	O1	208.1	0.177
65778	M6	103.1	0.043
65778	NU2	0.5	0.043
65778	2N2	344.5	0.03
65778	OO1	179.4	0.007
65778	LDA2	26.3	0.007
65778	M1	200.9	0.013
65778	J1	186.6	0.013
65778	RHO1	214.1	0.007
65778	Q1	215.1	0.033
65778	T2	42.1	0.01
65778	2Q1	222.3	0.003
65778	P1	193.7	0.052
65778	L2	26.9	0.03
65778	K2	42.2	0.049
65779	M2	23	1.78
65779	S2	58	0.31
65779	N2	11.8	0.39
65779	K1	201.4	0.26
65779	M4	206.2	0.06
65779	O1	212.6	0.27
65779	M6	93.9	0.07
65779	MK3	357.6	0.03
65779	S4	303.5	0.02
65779	MN4	210.1	0.03
65779	NU2	2.3	0.08
65779	S6	261.9	0.01
65779	MU2	60.1	0.08
65779	2N2	0.7	0.05
65779	OO1	203.9	0.01
65779	LDA2	358.6	0.04
65779	S1	167.5	0.04
65779	M1	236.6	0.01
65779	J1	232.2	0.02
65779	SSA	33.5	0.16
65779	SA	153.8	0.24
65779	RHO1	190.3	0.01
65779	Q1	202.9	0.05
65779	T2	28.7	0.04
65779	R2	256.7	0.01
65779	2Q1	158.7	0.01
65779	P1	204.6	0.09
65779	M3	83.4	0.01
65779	L2	1.2	0.1
65779	2MK3	4.2	0.03
65779	K2	53.2	0.09
65779	M8	295.7	0.01
65779	MS4	214	0.02
65780	M2	32.5	1.27
65780	S2	56.3	0.22
65780	N2	12.3	0.29
65780	K1	193.4	0.19
65780	M4	295.9	0.02
65780	O1	213.6	0.15
65780	M6	291.9	0.02
65780	MK3	79.4	0.01
65780	MN4	271.5	0.01
65780	NU2	12	0.06
65780	MU2	21.8	0.03
65780	2N2	356.8	0.04
65780	OO1	215.1	0.01
65780	LDA2	54.1	0.02
65780	S1	100.8	0.02
65780	M1	211.1	0.01
65780	J1	200.2	0.01
65780	SSA	37.6	0.13
65780	SA	150.6	0.19
65780	RHO1	203	0.01
65780	Q1	194.9	0.03
65780	T2	44.2	0.02
65780	P1	201.7	0.06
65780	M3	72	0.01
65780	L2	47.4	0.06
65780	2MK3	94.7	0.01
65780	K2	57	0.06
65781	M2	44.3	1.12
65781	S2	69.6	0.2
65781	N2	24.2	0.25
65781	K1	198.4	0.17
65781	M4	325.4	0.04
65781	O1	216.6	0.12
65781	M6	333.2	0.01
65781	S4	307.7	0.01
65781	NU2	26.9	0.05
65781	MU2	19	0.03
65781	2N2	4.3	0.03
65781	OO1	180.4	0.01
65781	LDA2	56.1	0.01
65781	M1	207.3	0.01
65781	J1	189.5	0.01
65781	SSA	37.6	0.13
65781	SA	150.6	0.19
65781	Q1	225.9	0.02
65781	T2	68.6	0.01
65781	P1	199.8	0.06
65781	L2	64.5	0.03
65781	K2	71.7	0.05
65782	M2	86.8	0.78
65782	S2	113	0.11
65782	N2	66.9	0.14
65782	K1	222.4	0.13
65782	M4	32	0.05
65782	O1	248.5	0.1
65782	M6	63.3	0.02
65782	NU2	69.6	0.03
65782	MU2	268.6	0.02
65782	2N2	47	0.02
65782	LDA2	99	0.01
65782	M1	235.4	0.01
65782	J1	209.5	0.01
65782	Q1	261.5	0.02
65782	T2	112	0.01
65782	P1	224.4	0.04
65782	L2	106.7	0.02
65782	K2	115.2	0.03
65783	M2	95.4	0.85
65783	S2	130.5	0.11
65783	N2	68.4	0.17
65783	K1	234.6	0.14
65783	M4	92.3	0.05
65783	O1	248.9	0.11
65783	M6	146.5	0.01
65783	S4	85.1	0.01
65783	NU2	72	0.03
65783	MU2	268.5	0.02
65783	2N2	41.5	0.02
65783	OO1	220.3	0.01
65783	LDA2	111.7	0.01
65783	M1	241.7	0.01
65783	J1	227.5	0.01
65783	Q1	256.1	0.02
65783	T2	129.1	0.01
65783	P1	235.7	0.05
65783	L2	122.4	0.02
65783	K2	133.3	0.03
65784	M2	133.9	0.75
65784	S2	158.9	0.1
65784	N2	118.4	0.16
65784	K1	258.2	0.13
65784	M4	169.9	0.02
65784	O1	255.1	0.1
65784	M6	168.9	0.01
65784	NU2	120.5	0.03
65784	MU2	316.8	0.02
65784	2N2	103	0.02
65784	LDA2	145.5	0.01
65784	M1	256.7	0.01
65784	J1	259.8	0.01
65784	Q1	253.6	0.02
65784	T2	157.9	0.01
65784	P1	258	0.04
65784	L2	149.3	0.02
65784	K2	160.9	0.03
65785	M2	142.3	1.07
65785	S2	152.1	0.22
65785	N2	119.6	0.23
65785	K1	248.7	0.15
65785	M4	203.6	0.09
65785	O1	266.2	0.11
65785	M6	260.6	0.02
65785	MK3	255.9	0.02
65785	S4	179.7	0.01
65785	MN4	162	0.04
65785	NU2	100.9	0.04
65785	MU2	120.9	0.02
65785	2N2	157.6	0.03
65785	OO1	337.5	0.01
65785	LDA2	175.6	0.01
65785	S1	293.6	0.06
65785	M1	269.1	0.01
65785	J1	292.4	0.01
65785	SSA	35.7	0.12
65785	SA	133.1	0.27
65785	RHO1	205.8	0.01
65785	Q1	263	0.02
65785	T2	12.1	0.03
65785	R2	349.5	0.08
65785	P1	309	0.03
65785	M3	264.7	0.01
65785	L2	185	0.07
65785	2MK3	275.3	0.02
65785	K2	155.6	0.07
65785	MS4	261.6	0.02
65786	M2	220.4	0.75
65786	S2	255.9	0.12
65786	N2	200.7	0.15
65786	K1	297.2	0.09
65786	M4	5.2	0.02
65786	O1	325.1	0.08
65786	M6	88.9	0.01
65786	MK3	53.3	0.01
65786	MN4	336.2	0.01
65786	NU2	189.4	0.04
65786	MU2	233.4	0.02
65786	2N2	167.9	0.02
65786	OO1	34.5	0.01
65786	LDA2	191.2	0.02
65786	S1	282.6	0.02
65786	J1	252	0.01
65786	SSA	35.7	0.12
65786	SA	133.1	0.27
65786	RHO1	335.6	0.02
65786	Q1	351.1	0.02
65786	T2	266	0.02
65786	2Q1	13.5	0.01
65786	P1	300.9	0.03
65786	M3	35.5	0.01
65786	L2	237	0.03
65786	2MK3	36.1	0.02
65786	K2	245.7	0.04
65786	MS4	51.1	0.01
65787	M2	214.6	0.79
65787	S2	249.4	0.12
65787	N2	192.8	0.17
65787	K1	293.7	0.09
65787	M4	332.9	0.02
65787	O1	321.7	0.08
65787	M6	62.2	0.01
65787	MK3	22.8	0.01
65787	MN4	306.3	0.01
65787	NU2	187.7	0.04
65787	MU2	232	0.01
65787	2N2	170.3	0.02
65787	OO1	299.4	0.01
65787	LDA2	229.5	0.02
65787	S1	289.4	0.03
65787	J1	276.5	0.01
65787	SSA	26.2	0.15
65787	SA	123.7	0.38
65787	Q1	300	0.02
65787	T2	263.8	0.01
65787	2Q1	154.5	0.01
65787	P1	301.9	0.03
65787	M3	354.6	0.01
65787	L2	229.9	0.05
65787	2MK3	30.5	0.01
65787	K2	246.1	0.04
65788	M2	317.1	0.94
65788	S2	354.9	0.12
65788	N2	299.7	0.15
65788	K1	319.9	0.12
65788	M4	134.4	0.06
65788	O1	347.6	0.09
65788	M6	277.1	0.05
65788	MK3	125.9	0.03
65788	MN4	110.9	0.03
65788	NU2	296.5	0.06
65788	MU2	75.9	0.04
65788	2N2	256.5	0.04
65788	LDA2	341.8	0.03
65788	S1	297.8	0.04
65788	M1	90.4	0.01
65788	J1	162.3	0.01
65788	SSA	35.7	0.12
65788	SA	133.1	0.27
65788	RHO1	267.3	0.01
65788	Q1	340	0.02
65788	T2	26.8	0.01
65788	R2	58.6	0.01
65788	2Q1	260.8	0.02
65788	P1	328.1	0.02
65788	2SM2	240.1	0.01
65788	M3	62.2	0.01
65788	L2	344.1	0.08
65788	2MK3	140.4	0.04
65788	K2	356.7	0.04
65788	M8	106.5	0.01
65788	MS4	177.1	0.02
65789	M2	176.4	0.6
65789	S2	200	0.09
65789	N2	152.3	0.13
65789	K1	276.2	0.08
65789	M4	204.4	0.01
65789	O1	298.7	0.06
65789	M6	265.1	0.01
65789	NU2	151.3	0.03
65789	2N2	130.3	0.02
65789	LDA2	203.8	0.01
65789	S1	311	0.03
65789	J1	264.9	0.01
65789	SSA	35.7	0.12
65789	SA	133.1	0.27
65789	Q1	287.1	0.01
65789	T2	199.1	0.01
65789	P1	293	0.03
65789	L2	203.3	0.04
65789	K2	201.3	0.03
65790	M2	168	0.85
65790	S2	193.8	0.13
65790	N2	144.6	0.17
65790	K1	245.4	0.11
65790	M4	218.5	0.06
65790	O1	274.4	0.08
65790	M6	242.4	0.01
65790	MK3	282.8	0.02
65790	S4	247.7	0.01
65790	MN4	191.9	0.03
65790	NU2	144.5	0.04
65790	MU2	184.2	0.01
65790	2N2	108.5	0.02
65790	LDA2	191.6	0.02
65790	S1	219.5	0.01
65790	SSA	48	0.1
65790	SA	156	0.3
65790	Q1	269.2	0.02
65790	T2	173.6	0.01
65790	P1	249.4	0.03
65790	M3	286.5	0.01
65790	L2	186.1	0.04
65790	2MK3	304.5	0.02
65790	K2	193.4	0.04
65790	MS4	255.3	0.01
65791	M2	103.2	0.57
65791	S2	124.3	0.1
65791	N2	84	0.12
65791	K1	226.7	0.1
65791	M4	87.6	0.03
65791	O1	245.9	0.08
65791	M6	97.6	0.01
65791	MN4	59.1	0.01
65791	NU2	82.8	0.03
65791	MU2	82.4	0.01
65791	2N2	64.3	0.02
65791	S1	334.1	0.01
65791	M1	236.2	0.01
65791	J1	217.1	0.01
65791	SSA	48	0.1
65791	SA	156.3	0.3
65791	Q1	239.8	0.02
65791	T2	113.7	0.01
65791	P1	230.4	0.03
65791	L2	116	0.02
65791	K2	124.2	0.03
65792	M2	186.6	1.31
65792	S2	228.7	0.21
65792	N2	179.6	0.28
65792	K1	250	0.18
65792	M4	220.4	0.11
65792	O1	286.9	0.07
65792	M6	235.8	0.05
65792	S4	349.2	0.03
65792	NU2	180.6	0.05
65792	MU2	350.6	0.03
65792	2N2	172.6	0.04
65792	LDA2	206.1	0.01
65792	M1	268.3	0.01
65792	J1	231.7	0.01
65792	Q1	305.3	0.01
65792	T2	227	0.01
65792	P1	252.8	0.06
65792	L2	193.6	0.04
65792	K2	232.1	0.06
65792	M8	252.9	0.01
65793	M2	264.3	1.34
65793	S2	302.8	0.16
65793	N2	230.9	0.25
65793	K1	296.4	0.22
65793	M4	60.4	0.19
65793	O1	325.8	0.2
65793	M6	163.4	0.08
65793	S4	77.8	0.01
65793	NU2	235.5	0.05
65793	S6	264.9	0.01
65793	MU2	226.3	0.03
65793	2N2	197.5	0.03
65793	OO1	266.4	0.01
65793	LDA2	282.2	0.01
65793	M1	310.7	0.01
65793	J1	281.6	0.02
65793	RHO1	336.4	0.01
65793	Q1	340.3	0.04
65793	T2	301.1	0.01
65793	2Q1	356.8	0.01
65793	P1	298.6	0.07
65793	L2	297.4	0.04
65793	K2	305.9	0.04
65793	M8	327.8	0.04
65794	M2	47.7	0.8
65794	S2	72.6	0.15
65794	N2	29	0.18
65794	K1	197.4	0.13
65794	M4	21.4	0.05
65794	O1	218.9	0.09
65794	M6	357.7	0.01
65794	MK3	129.5	0.02
65794	S4	352.8	0.01
65794	MN4	356.9	0.02
65794	NU2	28.9	0.04
65794	MU2	50.9	0.02
65794	2N2	358.3	0.02
65794	OO1	169.9	0.01
65794	LDA2	53.2	0.01
65794	S1	99.3	0.01
65794	J1	219.3	0.01
65794	SSA	43.6	0.13
65794	SA	147	0.21
65794	RHO1	188.4	0.01
65794	Q1	218.3	0.03
65794	T2	58.7	0.01
65794	R2	235.5	0.01
65794	2Q1	129.5	0.01
65794	P1	197.7	0.03
65794	M3	101	0.01
65794	L2	71.8	0.03
65794	2MK3	142.3	0.01
65794	K2	69.5	0.04
65794	MS4	80.7	0.01
65795	M2	41	1.02
65795	S2	68.4	0.17
65795	N2	20.3	0.2
65795	K1	190.6	0.14
65795	M4	15.7	0.04
65795	O1	223.5	0.14
65795	M6	344	0.02
65795	NU2	23.1	0.04
65795	MU2	221.1	0.02
65795	2N2	359.6	0.03
65795	OO1	157.9	0.01
65795	LDA2	53.7	0.01
65795	M1	206.9	0.01
65795	J1	174.4	0.01
65795	SSA	37.6	0.13
65795	SA	150.6	0.19
65795	RHO1	237.5	0.01
65795	Q1	239.7	0.03
65795	T2	67.4	0.01
65795	P1	193.1	0.05
65795	L2	61.7	0.03
65795	K2	70.7	0.05
65796	M2	53.6	1.18
65796	S2	80	0.21
65796	N2	36.2	0.26
65796	K1	198.2	0.17
65796	M4	68.9	0.02
65796	O1	221	0.12
65796	M6	72.8	0.01
65796	MK3	117.3	0.01
65796	S4	26.4	0.02
65796	NU2	33.1	0.05
65796	MU2	50.1	0.04
65796	2N2	19.5	0.03
65796	OO1	175.3	0.01
65796	LDA2	66.4	0.02
65796	S1	108.6	0.03
65796	M1	209.5	0.01
65796	J1	186.9	0.01
65796	SSA	43.6	0.13
65796	SA	147	0.21
65796	RHO1	230.7	0.01
65796	Q1	202.5	0.03
65796	T2	68.7	0.02
65796	P1	192.7	0.05
65796	M3	141.5	0.01
65796	L2	50	0.05
65796	K2	72.3	0.06
65796	MS4	196.9	0.01
65797	M2	52.9	1.08
65797	S2	78.3	0.19
65797	N2	33.7	0.24
65797	K1	196.7	0.16
65797	M4	46.4	0.02
65797	O1	221.8	0.12
65797	M6	74.5	0.01
65797	MK3	114.2	0.01
65797	S4	22.8	0.01
65797	MN4	4.4	0.01
65797	NU2	33.6	0.05
65797	MU2	54	0.03
65797	2N2	20.8	0.03
65797	LDA2	60.4	0.02
65797	S1	127	0.03
65797	M1	223.2	0.01
65797	J1	225	0.01
65797	MM	63	0.09
65797	SSA	62.1	0.18
65797	SA	146.1	0.31
65797	Q1	200.2	0.02
65797	T2	86.5	0.02
65797	R2	315.5	0.01
65797	2Q1	142.9	0.01
65797	P1	194.3	0.04
65797	M3	122.4	0.01
65797	L2	62.5	0.05
65797	2MK3	129.7	0.01
65797	K2	74.4	0.05
65797	MS4	182.5	0.01
65798	M2	129.2	0.88
65798	S2	156.8	0.12
65798	N2	111	0.19
65798	K1	257.2	0.21
65798	M4	163.7	0.04
65798	O1	278.5	0.14
65798	M6	146.8	0.03
65798	NU2	113.5	0.04
65798	MU2	101.6	0.02
65798	2N2	93	0.03
65798	OO1	233.2	0.01
65798	LDA2	142	0.01
65798	M1	266.9	0.01
65798	J1	242.8	0.01
65798	SSA	33.9	0.12
65798	SA	149.2	0.16
65798	RHO1	292.9	0.01
65798	Q1	290.9	0.03
65798	T2	155.7	0.01
65798	P1	258.8	0.07
65798	L2	147.2	0.03
65798	K2	159.1	0.03
65799	M2	90.5	1.06
65799	S2	121.8	0.15
65799	N2	73	0.23
65799	K1	233.2	0.2
65799	M4	47.8	0.03
65799	O1	255.6	0.13
65799	M6	28.9	0.04
65799	NU2	75.3	0.05
65799	MU2	59.1	0.03
65799	2N2	55.4	0.03
65799	LDA2	105	0.01
65799	M1	243.1	0.01
65799	J1	221.2	0.01
65799	SSA	33.9	0.12
65799	SA	149.2	0.16
65799	RHO1	269	0.01
65799	Q1	267	0.02
65799	T2	120.6	0.01
65799	P1	234.8	0.07
65799	L2	108.1	0.03
65799	K2	124.3	0.04
65800	M2	54.5	1.31
65800	S2	86.6	0.24
65800	N2	38.4	0.3
65800	K1	196.7	0.17
65800	M4	345.3	0.03
65800	O1	225.9	0.12
65800	M6	108.5	0.03
65800	MK3	76.1	0.02
65800	S4	44.6	0.01
65800	MN4	332.8	0.02
65800	NU2	33.1	0.05
65800	MU2	72.3	0.04
65800	2N2	21.7	0.03
65800	OO1	188.9	0.02
65800	LDA2	57.3	0.02
65800	S1	144.7	0.02
65800	M1	259.6	0.02
65800	J1	214.2	0.01
65800	SSA	33.9	0.12
65800	SA	149.2	0.16
65800	RHO1	47.1	0.01
65800	Q1	220	0.03
65800	T2	81.7	0.03
65800	R2	293.8	0.01
65800	2Q1	136.2	0.01
65800	P1	166.1	0.04
65800	2SM2	118.4	0.01
65800	M3	167.8	0.01
65800	L2	30	0.08
65800	2MK3	81	0.02
65800	K2	70	0.06
65800	MS4	258.8	0.01
65801	M2	84.3	1.16
65801	S2	113.4	0.2
65801	N2	62	0.24
65801	K1	222.4	0.17
65801	M4	72.2	0.05
65801	O1	243.2	0.14
65801	M6	13.5	0.02
65801	MK3	147.7	0.02
65801	S4	83.3	0.01
65801	MN4	52.3	0.02
65801	NU2	60.7	0.06
65801	MU2	122.4	0.03
65801	2N2	29.8	0.02
65801	OO1	218.7	0.01
65801	LDA2	90.5	0.03
65801	S1	161	0.04
65801	M1	277.9	0.01
65801	SSA	33.9	0.12
65801	SA	149.2	0.16
65801	RHO1	36.5	0.01
65801	Q1	203	0.01
65801	T2	81.4	0.01
65801	R2	155.8	0.01
65801	2Q1	259.6	0.01
65801	P1	212.9	0.04
65801	2SM2	197.5	0.01
65801	M3	181.6	0.01
65801	L2	80.2	0.05
65801	2MK3	169.8	0.02
65801	K2	102.3	0.06
65801	MS4	111.6	0.01
65802	M2	103	1.09
65802	S2	138.6	0.19
65802	N2	91	0.23
65802	K1	227	0.18
65802	M4	117.4	0.05
65802	O1	250.1	0.14
65802	M6	38.4	0.03
65802	S4	127.5	0.01
65802	NU2	92.6	0.05
65802	MU2	274	0.03
65802	2N2	79.1	0.03
65802	OO1	203.9	0.01
65802	LDA2	119.5	0.01
65802	M1	238.5	0.01
65802	J1	215.6	0.01
65802	SSA	33.9	0.12
65802	SA	149.2	0.16
65802	RHO1	260	0.01
65802	Q1	261.6	0.03
65802	T2	137.1	0.01
65802	P1	228.8	0.06
65802	L2	114.9	0.03
65802	K2	141.4	0.05
65803	M2	124.2	0.94
65803	S2	159.9	0.15
65803	N2	112.3	0.19
65803	K1	242.9	0.2
65803	M4	156.2	0.05
65803	O1	277.5	0.13
65803	M6	124.9	0.03
65803	S4	277.7	0.01
65803	NU2	113.9	0.04
65803	MU2	295	0.02
65803	2N2	100.5	0.03
65803	OO1	208.4	0.01
65803	LDA2	140.8	0.01
65803	M1	260.1	0.01
65803	J1	225.8	0.01
65803	SSA	33.9	0.12
65803	SA	149.2	0.16
65803	RHO1	292.3	0.01
65803	Q1	294.6	0.03
65803	T2	158.5	0.01
65803	P1	245.5	0.07
65803	L2	136.1	0.03
65803	K2	162.8	0.04
65803	M8	122.1	0.01
65804	M2	181.4	1.22
65804	S2	223.6	0.19
65804	N2	170.2	0.23
65804	K1	279.2	0.19
65804	M4	180.8	0.06
65804	O1	301.2	0.15
65804	M6	323.5	0.05
65804	MK3	256.7	0.07
65804	S4	311.8	0.01
65804	MN4	198.7	0.03
65804	NU2	156.8	0.07
65804	MU2	261.4	0.06
65804	2N2	128.3	0.04
65804	LDA2	182.4	0.04
65804	S1	217.9	0.05
65804	M1	347.7	0.01
65804	J1	30.7	0.01
65804	SSA	33.9	0.12
65804	SA	149.2	0.16
65804	RHO1	292.4	0.01
65804	Q1	308.4	0.03
65804	T2	209.6	0.01
65804	R2	230.5	0.01
65804	2Q1	223.8	0.01
65804	P1	258.5	0.04
65804	2SM2	63.7	0.01
65804	M3	243.6	0.01
65804	L2	183.1	0.1
65804	2MK3	274.7	0.07
65804	K2	221.6	0.05
65804	M8	19	0.01
65804	MS4	223.3	0.02
65805	M2	155.5	0.85
65805	S2	187	0.12
65805	N2	135.9	0.17
65805	K1	264.8	0.17
65805	M4	198.7	0.06
65805	O1	287.7	0.13
65805	M6	197.3	0.05
65805	MK3	240.6	0.02
65805	MN4	180.7	0.03
65805	NU2	139.1	0.05
65805	MU2	249.4	0.02
65805	2N2	124	0.03
65805	LDA2	159.7	0.03
65805	S1	207.9	0.04
65805	M1	310.9	0.01
65805	J1	9.7	0.01
65805	SSA	33.9	0.12
65805	SA	149.2	0.16
65805	RHO1	283.2	0.01
65805	Q1	285.2	0.02
65805	T2	186.4	0.01
65805	2Q1	198.9	0.01
65805	P1	251.6	0.04
65805	2SM2	88.3	0.01
65805	M3	195.3	0.01
65805	L2	179.9	0.07
65805	2MK3	251.2	0.03
65805	K2	183.2	0.04
65805	M8	244.8	0.01
65805	MS4	246.4	0.02
65806	M2	202.5	0.97
65806	S2	230.2	0.11
65806	N2	181.5	0.2
65806	K1	287.9	0.26
65806	M4	242.5	0.07
65806	O1	296.8	0.15
65806	M6	276.5	0.03
65806	NU2	184.3	0.04
65806	MU2	174.9	0.02
65806	2N2	160.6	0.03
65806	LDA2	215.4	0.01
65806	M1	290.7	0.01
65806	J1	277	0.01
65806	RHO1	299.9	0.01
65806	Q1	301.9	0.03
65806	T2	229	0.01
65806	P1	288.5	0.09
65806	L2	223.6	0.03
65806	K2	232.5	0.03
65806	M8	342.5	0.01
65807	M2	230.7	1.135
65807	S2	268.7	0.125
65807	N2	214.9	0.21
65807	K1	294.2	0.184
65807	M4	312.9	0.062
65807	O1	315	0.161
65807	M6	18	0.039
65807	MK3	351.8	0.036
65807	S4	21.9	0.003
65807	MN4	293.8	0.023
65807	NU2	198.5	0.056
65807	S6	87.2	0.003
65807	MU2	348.6	0.046
65807	2N2	235.6	0.003
65807	OO1	337.9	0.003
65807	LDA2	239.1	0.039
65807	S1	246.3	0.056
65807	M1	5.3	0.02
65807	J1	76.5	0.01
65807	SSA	33.9	0.121
65807	SA	149.2	0.157
65807	RHO1	262.2	0.013
65807	Q1	323.6	0.026
65807	T2	251.3	0.01
65807	R2	329.3	0.003
65807	2Q1	159.1	0.003
65807	P1	274.6	0.046
65807	2SM2	121	0.007
65807	M3	304.2	0.007
65807	L2	236.6	0.135
65807	2MK3	11.3	0.033
65807	K2	262.6	0.039
65807	M8	101.5	0.01
65807	MS4	355.9	0.013
65808	M2	248.5	1.384
65808	S2	290.3	0.194
65808	N2	240.8	0.239
65808	K1	295.9	0.249
65808	M4	349	0.128
65808	O1	326.9	0.194
65808	M6	96.4	0.085
65808	S4	217.4	0.016
65808	NU2	241.8	0.046
65808	S6	339.3	0.007
65808	MU2	51.9	0.033
65808	2N2	233.1	0.033
65808	OO1	264.9	0.01
65808	LDA2	267.9	0.01
65808	M1	311.2	0.013
65808	J1	280.5	0.016
65808	SSA	33.9	0.121
65808	SA	149.2	0.157
65808	RHO1	340.2	0.007
65808	Q1	342.2	0.036
65808	T2	288.6	0.013
65808	R2	292	0.003
65808	2Q1	357.6	0.007
65808	P1	298.2	0.082
65808	L2	256.1	0.039
65808	K2	293.7	0.052
65808	M8	200.5	0.026
65809	M2	264.1	1.39
65809	S2	315.4	0.17
65809	N2	247.2	0.23
65809	K1	308.4	0.2
65809	M4	60.3	0.17
65809	O1	329.2	0.16
65809	M6	145.6	0.09
65809	MK3	56.9	0.06
65809	MN4	43.6	0.06
65809	NU2	244	0.07
65809	MU2	28.9	0.07
65809	2N2	240.2	0.05
65809	LDA2	251.7	0.06
65809	S1	257.7	0.06
65809	M1	335.3	0.01
65809	J1	110.3	0.01
65809	MM	40.2	0.25
65809	SSA	78.7	0.33
65809	SA	295.8	0.18
65809	MSF	321.3	0.25
65809	MF	48.4	0.1
65809	Q1	325.9	0.02
65809	T2	12.8	0.03
65809	R2	262.2	0.02
65809	2Q1	216.9	0.01
65809	P1	292.4	0.03
65809	L2	290.1	0.14
65809	2MK3	64	0.06
65809	K2	290.2	0.04
65809	M8	321	0.04
65809	MS4	115.5	0.05
65810	M2	46.7	1.2
65810	S2	74.6	0.21
65810	N2	28.3	0.27
65810	K1	200.9	0.16
65810	M4	295.6	0.01
65810	O1	224.6	0.14
65810	MK3	70	0.01
65810	NU2	26.6	0.05
65810	MU2	50.4	0.03
65810	2N2	15.9	0.04
65810	OO1	177.1	0.01
65810	LDA2	55.9	0.02
65810	S1	110.5	0.02
65810	M1	212.6	0.01
65810	J1	189.1	0.01
65810	SSA	33.9	0.12
65810	SA	149.2	0.16
65810	RHO1	234.8	0.01
65810	Q1	210.3	0.03
65810	T2	59.9	0.02
65810	P1	199.1	0.05
65810	M3	125.1	0.01
65810	L2	45.5	0.04
65810	K2	67.7	0.06
65811	M2	51.6	1.32
65811	S2	81.6	0.24
65811	N2	38.3	0.29
65811	K1	201.1	0.18
65811	M4	23.4	0.02
65811	O1	222.2	0.14
65811	M6	98.1	0.02
65811	MK3	90.7	0.02
65811	S4	358.3	0.02
65811	MN4	339	0.01
65811	NU2	27.6	0.06
65811	MU2	72.1	0.03
65811	2N2	12	0.03
65811	OO1	193	0.01
65811	LDA2	57	0.02
65811	S1	94	0.03
65811	M1	233.7	0.01
65811	J1	207	0.01
65811	SSA	33.9	0.12
65811	SA	149.2	0.16
65811	RHO1	251.8	0.02
65811	Q1	202.1	0.04
65811	T2	68.8	0.02
65811	R2	355.4	0.01
65811	2Q1	146.2	0.01
65811	P1	192.7	0.05
65811	M3	131.3	0.01
65811	L2	30.7	0.05
65811	2MK3	86.8	0.02
65811	K2	78.6	0.07
65811	MS4	211.2	0.01
65812	M2	52.4	1.27
65812	S2	78.7	0.22
65812	N2	36.2	0.3
65812	K1	194.2	0.17
65812	M4	344.7	0.03
65812	O1	227.9	0.13
65812	M6	78.4	0.02
65812	MK3	82	0.02
65812	S4	47.8	0.01
65812	MN4	335.4	0.02
65812	NU2	30.8	0.05
65812	MU2	64.7	0.04
65812	2N2	17.2	0.03
65812	OO1	212.1	0.02
65812	LDA2	85.2	0.02
65812	S1	70.5	0.02
65812	M1	246.6	0.01
65812	SSA	33.9	0.12
65812	SA	149.2	0.16
65812	Q1	224.1	0.03
65812	T2	68.5	0.04
65812	R2	117.4	0.02
65812	P1	187.8	0.05
65812	L2	37.3	0.09
65812	2MK3	77.7	0.02
65812	K2	83.8	0.07
65812	MS4	226.9	0.01
65813	M2	21	1.25
65813	S2	45.8	0.23
65813	N2	1.4	0.3
65813	K1	184.9	0.19
65813	M4	199.7	0.02
65813	O1	208.9	0.15
65813	M6	293.4	0.02
65813	MN4	199.2	0.01
65813	NU2	359.2	0.06
65813	MU2	13.7	0.04
65813	2N2	347.4	0.04
65813	OO1	215.2	0.01
65813	LDA2	35.7	0.01
65813	S1	83.3	0.04
65813	M1	204	0.01
65813	J1	201.5	0.01
65813	SSA	34	0.14
65813	SA	152	0.18
65813	RHO1	201.1	0.01
65813	Q1	191.1	0.03
65813	T2	35.7	0.02
65813	P1	188.1	0.06
65813	L2	28.8	0.05
65813	K2	46.4	0.06
65813	MS4	147.5	0.01
65814	M2	22.1	1.27
65814	S2	46.7	0.24
65814	N2	1.8	0.3
65814	K1	186.8	0.19
65814	M4	236.8	0.02
65814	O1	208.6	0.16
65814	M6	287.5	0.01
65814	MK3	50.3	0.01
65814	S4	280.5	0.01
65814	MN4	222.6	0.02
65814	NU2	1.8	0.06
65814	S6	198.2	0.01
65814	MU2	6.9	0.04
65814	2N2	346.9	0.05
65814	OO1	230.4	0.01
65814	LDA2	26.8	0.02
65814	S1	115.4	0.02
65814	M1	200.3	0.03
65814	J1	199.4	0.01
65814	SSA	34	0.14
65814	SA	152	0.18
65814	RHO1	167.7	0.01
65814	Q1	201.8	0.04
65814	T2	49.2	0.02
65814	R2	314.8	0.01
65814	P1	185	0.06
65814	M3	58.1	0.01
65814	L2	49.4	0.05
65814	2MK3	69	0.01
65814	K2	49.6	0.07
65814	MS4	170.6	0.01
65815	M2	5.6	1.59
65815	S2	29.9	0.29
65815	N2	345.6	0.35
65815	K1	175.5	0.25
65815	M4	201.8	0.02
65815	O1	201	0.18
65815	M6	278.9	0.03
65815	S4	250.4	0.01
65815	MN4	190.5	0.01
65815	NU2	343.8	0.06
65815	MU2	1.2	0.07
65815	2N2	332.6	0.04
65815	OO1	203.7	0.01
65815	LDA2	24	0.01
65815	S1	126.8	0.04
65815	M1	250.1	0.01
65815	J1	202.7	0.01
65815	SSA	37.2	0.12
65815	SA	169.5	0.19
65815	RHO1	95.6	0.01
65815	Q1	178.1	0.05
65815	T2	8.1	0.03
65815	R2	255.8	0.01
65815	2Q1	169.8	0.01
65815	P1	179.8	0.08
65815	2SM2	14.2	0.01
65815	M3	45.9	0.02
65815	L2	45.4	0.01
65815	K2	26.7	0.08
65815	MS4	94.4	0.01
65816	M2	54.1	1.38
65816	S2	81.7	0.24
65816	N2	35.1	0.31
65816	K1	201.2	0.17
65816	M4	4.2	0.01
65816	O1	226.5	0.14
65816	M6	112.9	0.02
65816	MK3	73	0.01
65816	S4	16	0.01
65816	MN4	327.1	0.01
65816	NU2	32.2	0.06
65816	MU2	71.7	0.04
65816	2N2	23.5	0.04
65816	OO1	243.4	0.01
65816	LDA2	62.5	0.03
65816	S1	101	0.04
65816	M1	213.8	0.01
65816	J1	188.7	0.01
65816	SSA	9.2	0.17
65816	SA	134	0.23
65816	RHO1	237.3	0.01
65816	Q1	218.5	0.03
65816	T2	69.1	0.02
65816	P1	198.3	0.05
65816	M3	120.1	0.01
65816	L2	64.3	0.07
65816	2MK3	103.3	0.01
65816	K2	82.3	0.07
65816	MS4	225.1	0.01
65817	M2	358	1.61
65817	S2	22.1	0.29
65817	N2	337.8	0.37
65817	K1	172.9	0.29
65817	M4	224.3	0.01
65817	O1	192.6	0.19
65817	M6	228.1	0.03
65817	MN4	188.6	0.01
65817	NU2	336.9	0.08
65817	MU2	343.9	0.06
65817	2N2	321.6	0.05
65817	OO1	193.9	0.01
65817	LDA2	14.9	0.01
65817	S1	96.8	0.04
65817	M1	194.1	0.01
65817	J1	175	0.02
65817	SSA	37.2	0.12
65817	SA	169.5	0.19
65817	RHO1	201.1	0.01
65817	Q1	178.4	0.05
65817	T2	351.8	0.03
65817	2Q1	212.1	0.01
65817	P1	173.7	0.09
65817	M3	36.7	0.01
65817	L2	22.3	0.03
65817	K2	18.2	0.08
65818	M2	87.8	0.08
65818	S2	142	0.02
65818	N2	78.4	0.01
65818	K1	341.3	0.04
65818	M4	79.6	0.01
65818	O1	256.9	0.02
65818	M6	320.4	0.01
65818	MM	18.4	0.07
65818	SSA	10.5	0.09
65818	SA	158.9	0.15
65818	P1	341	0.01
65818	K2	146.3	0.01
65819	M2	82.5	0.118
65819	S2	162.2	0.02
65819	N2	66.9	0.02
65819	K1	308.5	0.023
65819	M4	72.2	0.01
65819	O1	233.9	0.036
65819	M6	268.3	0.007
65819	S4	293.4	0.003
65819	NU2	69.8	0.003
65819	MU2	215.7	0.003
65819	J1	305.1	0.003
65819	SSA	10.5	0.085
65819	SA	158.9	0.151
65819	RHO1	262.7	0.003
65819	Q1	265.9	0.007
65819	P1	308.1	0.007
65819	L2	85.2	0.003
65819	K2	168.1	0.003
65820	M2	81.1	0.12
65820	S2	158.7	0.02
65820	N2	65.9	0.02
65820	K1	336.2	0.03
65820	M4	69.3	0.01
65820	O1	239.1	0.03
65820	M6	270.1	0.01
65820	SSA	10.5	0.09
65820	SA	158.9	0.15
65820	Q1	269.4	0.01
65820	P1	339.3	0.01
65820	K2	164.3	0.01
65821	M2	16.6	0.39
65821	S2	32.5	0.06
65821	N2	358.9	0.09
65821	K1	190.9	0.09
65821	M4	346.3	0.03
65821	O1	194.1	0.07
65821	M6	209.5	0.01
65821	MK3	166.1	0.01
65821	MN4	327.9	0.01
65821	NU2	351.5	0.02
65821	MU2	27.4	0.01
65821	2N2	351.7	0.01
65821	LDA2	41	0.01
65821	S1	248.9	0.04
65821	M1	210.3	0.01
65821	J1	211.2	0.01
65821	MM	56.5	0.06
65821	SSA	56.9	0.1
65821	SA	154.6	0.24
65821	RHO1	218.4	0.01
65821	Q1	219.8	0.01
65821	T2	14.4	0.01
65821	R2	238.2	0.01
65821	P1	218.6	0.04
65821	L2	34.2	0.01
65821	2MK3	185.5	0.01
65821	K2	23.4	0.01
65821	MS4	28.2	0.01
65822	M2	0	1.04
65822	S2	24.9	0.19
65822	N2	341.8	0.22
65822	K1	179.8	0.25
65822	M4	176.9	0.01
65822	O1	183.8	0.13
65822	M6	205	0.02
65822	NU2	344.2	0.04
65822	MU2	335.7	0.03
65822	2N2	323.5	0.03
65822	OO1	176.5	0.01
65822	LDA2	11.4	0.01
65822	M1	181.9	0.01
65822	J1	177.5	0.01
65822	MM	18.4	0.07
65822	SSA	10.5	0.09
65822	SA	158.9	0.15
65822	RHO1	185.5	0.01
65822	Q1	185.8	0.03
65822	T2	24.2	0.01
65822	P1	180.2	0.08
65822	L2	18.2	0.03
65822	K2	26.9	0.05
65823	M2	89.2	0.14
65823	S2	106.1	0.02
65823	N2	37.5	0.04
65823	K1	292.6	0.08
65823	M4	140.1	0.01
65823	O1	226	0.02
65823	NU2	43.7	0.01
65823	P1	289.4	0.03
65823	K2	109.1	0.01
65824	M2	353.2	1.49
65824	S2	16.2	0.27
65824	N2	331.3	0.35
65824	K1	184.6	0.31
65824	O1	186.4	0.25
65824	M6	170.1	0.01
65824	NU2	335.1	0.07
65824	MU2	333	0.05
65824	2N2	312.3	0.05
65824	OO1	205.9	0.01
65824	LDA2	2.4	0.01
65824	S1	192.3	0.03
65824	M1	196.6	0.01
65824	J1	192.2	0.02
65824	SSA	56.9	0.13
65824	SA	171.7	0.21
65824	RHO1	192.3	0.01
65824	Q1	180.8	0.05
65824	T2	358.9	0.02
65824	2Q1	188.2	0.01
65824	P1	186.3	0.1
65824	L2	31.2	0.03
65824	K2	16.7	0.07
65825	M2	37.2	0.14
65825	S2	73.8	0.03
65825	N2	16.5	0.03
65825	K1	248.6	0.03
65825	M4	322.6	0.01
65825	O1	214.7	0.03
65825	M6	148.8	0.01
65825	MK3	169.3	0.01
65825	MN4	314	0.01
65825	NU2	12.1	0.01
65825	S1	346.3	0.03
65825	MM	63.3	0.1
65825	SSA	7.1	0.14
65825	Q1	166.5	0.01
65825	T2	256.7	0.01
65825	R2	47.3	0.01
65825	P1	258.6	0.02
65825	L2	56.2	0.01
65825	K2	26	0.01
65826	M2	5.5	0.44
65826	S2	34.6	0.08
65826	N2	347.5	0.12
65826	K1	191.7	0.1
65826	M4	338.4	0.04
65826	O1	198.6	0.09
65826	M6	210.4	0.02
65826	NU2	349.9	0.02
65826	MU2	336.3	0.01
65826	2N2	329.6	0.02
65826	M1	195	0.01
65826	J1	188.2	0.01
65826	Q1	201.9	0.02
65826	T2	33.4	0.01
65826	P1	192.1	0.03
65826	L2	23.3	0.02
65826	K2	37	0.02
65827	M2	119.8	0.27
65827	S2	152.7	0.04
65827	N2	63.9	0.05
65827	K1	269.3	0.1
65827	M4	172.7	0.03
65827	O1	265.4	0.1
65827	M6	87.8	0.01
65827	NU2	71.4	0.01
65827	MU2	294.2	0.01
65827	2N2	8	0.01
65827	M1	267.4	0.01
65827	J1	271.2	0.01
65827	Q1	263.5	0.02
65827	P1	269	0.03
65827	L2	175.7	0.01
65827	K2	155.4	0.01
65828	M2	27.7	1.03
65828	S2	66.3	0.15
65828	N2	16.5	0.23
65828	K1	197.9	0.21
65828	M4	19.1	0.07
65828	O1	217	0.19
65828	M6	159.5	0.03
65828	NU2	18	0.04
65828	MU2	349	0.02
65828	2N2	5	0.03
65828	OO1	177.5	0.01
65828	LDA2	45.6	0.01
65828	M1	207.1	0.01
65828	J1	187.7	0.02
65828	SSA	43.7	0.17
65828	SA	166.4	0.3
65828	RHO1	225.3	0.01
65828	Q1	226.9	0.04
65828	T2	64.8	0.01
65828	P1	199.4	0.07
65828	L2	39	0.03
65828	K2	69.4	0.04
65828	M8	130.1	0.01
65829	M2	87.4	0.51
65829	S2	126.7	0.07
65829	N2	68.7	0.09
65829	K1	244.8	0.13
65829	M4	101.8	0.04
65829	O1	253.8	0.12
65829	M6	313.3	0.01
65829	S4	65	0.01
65829	NU2	71.2	0.02
65829	MU2	45.9	0.01
65829	2N2	50.1	0.01
65829	OO1	234.4	0.01
65829	M1	249.1	0.01
65829	J1	239.7	0.01
65829	SSA	57.1	0.12
65829	SA	166	0.22
65829	Q1	258.5	0.02
65829	P1	245.5	0.04
65829	L2	106	0.01
65829	K2	129.8	0.02
65830	M2	53.3	0.76
65830	S2	68	0.1
65830	N2	36.9	0.15
65830	K1	229.8	0.21
65830	M4	346.1	0.05
65830	O1	230.8	0.17
65830	M6	199.9	0.02
65830	S4	300.8	0.01
65830	NU2	39.1	0.03
65830	MU2	38.5	0.02
65830	2N2	20.5	0.02
65830	OO1	228.9	0.01
65830	LDA2	60.1	0.01
65830	M1	230.3	0.01
65830	J1	229.4	0.01
65830	SSA	57.1	0.12
65830	SA	166	0.22
65830	RHO1	231.2	0.01
65830	Q1	231.2	0.03
65830	T2	67.4	0.01
65830	P1	229.9	0.07
65830	L2	69.6	0.02
65830	K2	69.2	0.03
65830	M8	169.8	0.01
65831	M2	6.4	1.5
65831	S2	30	0.24
65831	N2	349.4	0.33
65831	K1	197.8	0.27
65831	M4	294.8	0.01
65831	O1	205	0.21
65831	M6	54.4	0.02
65831	MK3	15.5	0.01
65831	S4	302.3	0.02
65831	MN4	228.6	0.01
65831	NU2	345.6	0.07
65831	MU2	14.7	0.04
65831	2N2	338.4	0.05
65831	OO1	218.4	0.01
65831	LDA2	6.7	0.02
65831	S1	178.1	0.03
65831	M1	222.2	0.01
65831	J1	198.7	0.02
65831	SSA	43.7	0.17
65831	SA	166.4	0.3
65831	RHO1	209.6	0.01
65831	Q1	199.6	0.04
65831	T2	15.3	0.02
65831	R2	243.1	0.01
65831	2Q1	187.6	0.01
65831	P1	198.8	0.09
65831	2SM2	28.7	0.01
65831	M3	33.7	0.02
65831	L2	8	0.07
65831	2MK3	17	0.01
65831	K2	27.3	0.07
65831	M8	118.2	0.01
65831	MS4	132.2	0.02
65832	M2	350.8	1.8
65832	S2	10.9	0.31
65832	N2	329.5	0.43
65832	K1	185.4	0.31
65832	M4	236.2	0.02
65832	O1	190.8	0.24
65832	M6	254.3	0.02
65832	S4	265.9	0.03
65832	NU2	330.8	0.08
65832	MU2	336.6	0.07
65832	2N2	310.2	0.05
65832	OO1	201	0.02
65832	LDA2	15.1	0.02
65832	S1	162	0.04
65832	J1	192.1	0.02
65832	SSA	57.1	0.12
65832	SA	166	0.22
65832	RHO1	170.1	0.01
65832	Q1	184.2	0.05
65832	T2	359.5	0.03
65832	R2	237.3	0.01
65832	P1	187.9	0.1
65832	2SM2	6.7	0.01
65832	M3	14	0.03
65832	L2	20.1	0.05
65832	2MK3	50	0.01
65832	K2	16.1	0.08
65832	MS4	113.2	0.04
65833	M2	348.4	1.77
65833	S2	11.3	0.34
65833	N2	328.7	0.41
65833	K1	171.7	0.3
65833	M4	267.3	0.02
65833	O1	194.9	0.25
65833	M6	252	0.02
65833	S4	326.8	0.03
65833	NU2	331.3	0.08
65833	S6	54.9	0.01
65833	MU2	325.4	0.04
65833	2N2	308.8	0.06
65833	OO1	148.5	0.01
65833	LDA2	359.1	0.01
65833	M1	183.2	0.02
65833	J1	160.2	0.02
65833	SSA	57.1	0.12
65833	SA	166	0.22
65833	RHO1	204.9	0.01
65833	Q1	206.5	0.05
65833	T2	10.4	0.02
65833	2Q1	218	0.01
65833	P1	173.4	0.1
65833	L2	8.4	0.05
65833	K2	13.2	0.09
65834	M2	63.1	2.04
65834	S2	97.7	0.26
65834	N2	51	0.41
65834	K1	229.8	0.26
65834	M4	6.9	0.18
65834	O1	233.5	0.2
65834	M6	284.2	0.11
65834	MK3	109.8	0.04
65834	S4	126.8	0.01
65834	MN4	355.8	0.08
65834	NU2	41.5	0.09
65834	MU2	150.3	0.08
65834	2N2	44.5	0.05
65834	OO1	245.4	0.01
65834	LDA2	56.6	0.06
65834	S1	199.3	0.07
65834	M1	221.8	0.01
65834	J1	263.6	0.02
65834	MM	16.3	0.08
65834	SSA	24.9	0.17
65834	MSF	36.6	0.07
65834	RHO1	235.1	0.01
65834	Q1	237.5	0.04
65834	T2	82.5	0.03
65834	2Q1	237.2	0.01
65834	P1	236.6	0.09
65834	M3	147.6	0.03
65834	L2	58.9	0.19
65834	2MK3	100.4	0.05
65834	K2	95	0.08
65834	M8	253.6	0.02
65834	MS4	30	0.06
65835	M2	353.1	1.95
65835	S2	14.1	0.34
65835	N2	333.7	0.47
65835	K1	186.4	0.31
65835	M4	267.7	0.04
65835	O1	192.6	0.23
65835	M6	25.4	0.02
65835	S4	307.4	0.04
65835	MN4	242.1	0.03
65835	NU2	331.2	0.09
65835	MU2	338.6	0.07
65835	LDA2	4.5	0.02
65835	S1	136.5	0.03
65835	J1	177.7	0.02
65835	SSA	50.3	0.19
65835	SA	165	0.35
65835	RHO1	175.3	0.02
65835	Q1	186.1	0.05
65835	T2	355.7	0.03
65835	P1	187.5	0.11
65835	M3	25.1	0.04
65835	L2	358.3	0.06
65835	K2	13.2	0.09
65835	MS4	154.3	0.03
65836	M2	38	1.89
65836	S2	64	0.26
65836	N2	25	0.41
65836	K1	202.9	0.33
65836	M4	340.3	0.08
65836	O1	225.2	0.19
65836	M6	169	0.07
65836	NU2	26.8	0.08
65836	MU2	12.2	0.05
65836	2N2	11.9	0.06
65836	OO1	184.9	0.01
65836	LDA2	50	0.01
65836	M1	214.5	0.01
65836	J1	193.3	0.02
65836	MM	16.3	0.08
65836	SSA	24.9	0.17
65836	MSF	36.6	0.07
65836	RHO1	234.6	0.01
65836	Q1	235.6	0.04
65836	T2	63.1	0.02
65836	2Q1	246	0.01
65836	P1	204.6	0.11
65836	L2	51	0.05
65836	K2	66.2	0.07
65836	M8	111.1	0.01
65837	M2	26.4	1.88
65837	S2	51.6	0.28
65837	N2	12.6	0.41
65837	K1	196.5	0.31
65837	M4	330.4	0.04
65837	O1	214.8	0.2
65837	M6	130.6	0.07
65837	S4	16.3	0.01
65837	NU2	14.4	0.08
65837	MU2	1.2	0.05
65837	2N2	358.8	0.06
65837	OO1	176.5	0.01
65837	LDA2	38	0.01
65837	M1	205.8	0.01
65837	J1	186.3	0.02
65837	MM	16.3	0.08
65837	SSA	24.9	0.17
65837	MF	36.6	0.07
65837	RHO1	223.7	0.01
65837	Q1	224.5	0.04
65837	T2	50.5	0.02
65837	2Q1	233.5	0.01
65837	P1	197.9	0.1
65837	L2	40.2	0.05
65837	K2	53.7	0.08
65838	M2	8.6	2.06
65838	S2	31.7	0.3
65838	N2	348.4	0.44
65838	K1	195.6	0.34
65838	M4	287.2	0.02
65838	O1	199.7	0.22
65838	M6	94.6	0.05
65838	S4	41.3	0.01
65838	NU2	351.1	0.09
65838	S6	67.7	0.01
65838	MU2	189.5	0.05
65838	2N2	328.3	0.06
65838	OO1	191.5	0.01
65838	LDA2	19.3	0.01
65838	M1	197.6	0.02
65838	J1	193.6	0.02
65838	RHO1	201.4	0.01
65838	Q1	201.7	0.04
65838	T2	30.8	0.02
65838	2Q1	203.7	0.01
65838	P1	195.9	0.11
65838	L2	28.8	0.06
65838	K2	33.6	0.08
65838	M8	142.6	0.01
65839	M2	354.6	2.28
65839	S2	15.8	0.39
65839	N2	336.7	0.53
65839	K1	190.4	0.31
65839	M4	217.7	0.02
65839	O1	195.9	0.23
65839	M6	98.8	0.01
65839	MK3	121.7	0.01
65839	S4	355	0.02
65839	MN4	270.7	0.02
65839	NU2	340.7	0.1
65839	MU2	345.9	0.08
65839	2N2	322.3	0.08
65839	OO1	62.2	0.02
65839	LDA2	20.8	0.03
65839	S1	144.3	0.06
65839	M1	259.4	0.01
65839	J1	181.7	0.03
65839	SSA	50.1	0.17
65839	SA	170.9	0.27
65839	RHO1	218	0.05
65839	Q1	170	0.06
65839	T2	26.4	0.04
65839	R2	359.1	0.01
65839	2Q1	241.2	0.02
65839	P1	194.5	0.12
65839	M3	55.2	0.05
65839	L2	344.8	0.04
65839	2MK3	133.4	0.01
65839	K2	20.1	0.1
65839	MS4	203.9	0.03
65840	M2	355.9	2.35
65840	S2	13.1	0.38
65840	N2	339	0.56
65840	K1	188.9	0.32
65840	M4	271	0.02
65840	O1	196.1	0.23
65840	M6	101.5	0.01
65840	MK3	119.4	0.01
65840	S4	15.2	0.03
65840	MN4	267.2	0.02
65840	NU2	334	0.12
65840	MU2	355.8	0.09
65840	2N2	327.8	0.09
65840	OO1	192.7	0.01
65840	LDA2	18.1	0.02
65840	S1	120.7	0.05
65840	M1	220	0.03
65840	J1	182.6	0.03
65840	SSA	50.1	0.17
65840	SA	32.4	0.27
65840	RHO1	173.4	0.02
65840	Q1	180.7	0.05
65840	T2	33.9	0.03
65840	R2	200.9	0.06
65840	2Q1	321.1	0.02
65840	P1	188.3	0.12
65840	2SM2	38.1	0.02
65840	M3	53.5	0.06
65840	L2	323.8	0.06
65840	2MK3	132.7	0.01
65840	K2	6.4	0.12
65840	MS4	223.7	0.04
65841	M2	357.6	2.43
65841	S2	18.6	0.41
65841	N2	338.4	0.58
65841	K1	188.8	0.33
65841	M4	262.8	0.02
65841	O1	192.9	0.24
65841	M6	317.7	0.01
65841	S4	31.1	0.02
65841	MN4	282.8	0.02
65841	NU2	335.9	0.11
65841	MU2	350.9	0.08
65841	2N2	320.3	0.09
65841	OO1	198.8	0.02
65841	LDA2	12.2	0.02
65841	S1	145.4	0.06
65841	M1	185.7	0.01
65841	J1	186.2	0.02
65841	SSA	50.1	0.17
65841	SA	170.9	0.27
65841	RHO1	194.7	0.01
65841	Q1	185.1	0.05
65841	T2	2.3	0.04
65841	R2	250.1	0.01
65841	2Q1	114.6	0.01
65841	P1	188.2	0.11
65841	2SM2	27.9	0.01
65841	M3	59.1	0.07
65841	L2	3.9	0.09
65841	2MK3	64.3	0.02
65841	K2	21.9	0.1
65841	MS4	240	0.04
65842	M2	128.3	1
65842	S2	185	0.1
65842	N2	125.9	0.15
65842	K1	283.1	0.19
65842	M4	108.5	0.14
65842	O1	283.2	0.15
65842	M6	89.3	0.08
65842	MK3	200.1	0.05
65842	MN4	95.8	0.05
65842	NU2	130.5	0.06
65842	MU2	238.8	0.08
65842	2N2	186.6	0.01
65842	LDA2	148.3	0.03
65842	S1	230.4	0.04
65842	M1	40.8	0.02
65842	J1	30.6	0.01
65842	SSA	50.1	0.17
65842	SA	170.9	0.27
65842	RHO1	293.3	0.01
65842	Q1	299.9	0.03
65842	T2	241.7	0.02
65842	R2	356.9	0.01
65842	P1	270.2	0.05
65842	2SM2	314.8	0.01
65842	M3	282.2	0.02
65842	L2	131.6	0.14
65842	2MK3	189	0.06
65842	K2	152.8	0.02
65842	M8	89.2	0.02
65842	MS4	153.9	0.04
65843	M2	44	1.85
65843	S2	81.6	0.26
65843	N2	36.1	0.39
65843	K1	218.7	0.31
65843	M4	358.1	0.17
65843	O1	218.2	0.25
65843	M6	129.7	0.05
65843	MK3	133.3	0.03
65843	S4	128	0.02
65843	MN4	352.9	0.09
65843	NU2	16.1	0.08
65843	MU2	119	0.1
65843	2N2	63.1	0.05
65843	LDA2	37.3	0.06
65843	S1	173.1	0.06
65843	M1	222.8	0.03
65843	J1	175	0.02
65843	SSA	50.1	0.17
65843	SA	170.9	0.27
65843	RHO1	272.4	0.01
65843	Q1	237	0.06
65843	T2	87.4	0.02
65843	R2	286.6	0.01
65843	P1	218.3	0.1
65843	2SM2	179.8	0.01
65843	M3	114.7	0.03
65843	L2	32.6	0.25
65843	2MK3	95.9	0.03
65843	K2	78.8	0.07
65843	M8	117.4	0.03
65843	MS4	26.8	0.08
65844	M2	359	2.39
65844	S2	19.9	0.4
65844	N2	342	0.57
65844	K1	193.8	0.36
65844	M4	265	0.02
65844	O1	194.6	0.23
65844	M6	333.3	0.01
65844	S4	26.1	0.02
65844	NU2	344.3	0.11
65844	MU2	338.2	0.06
65844	2N2	325.1	0.08
65844	OO1	193.1	0.01
65844	LDA2	8.7	0.02
65844	M1	194.3	0.02
65844	J1	192.6	0.02
65844	SSA	50.1	0.17
65844	SA	170.9	0.27
65844	RHO1	196	0.01
65844	Q1	194.9	0.04
65844	T2	19	0.02
65844	2Q1	195	0.01
65844	P1	193.8	0.12
65844	L2	15.9	0.07
65844	K2	21.6	0.11
65844	M8	49.9	0.01
65845	M2	42.1	1.84
65845	S2	70.5	0.27
65845	N2	30	0.41
65845	K1	228.8	0.31
65845	M4	339.6	0.15
65845	O1	222.4	0.26
65845	M6	115.2	0.08
65845	S4	70.2	0.01
65845	NU2	31.6	0.08
65845	S6	177.4	0.01
65845	MU2	13.8	0.04
65845	2N2	17.9	0.05
65845	OO1	234.2	0.01
65845	LDA2	55.3	0.01
65845	M1	225.6	0.02
65845	J1	231.1	0.02
65845	RHO1	220.3	0.01
65845	Q1	219.5	0.05
65845	T2	69.4	0.02
65845	2Q1	216.9	0.01
65845	P1	228.3	0.1
65845	L2	54.2	0.05
65845	K2	72.9	0.07
65845	M8	75.7	0.03
65846	M2	84.7	1.42
65846	S2	112.8	0.15
65846	N2	80.7	0.21
65846	K1	252.9	0.23
65846	M4	47.1	0.18
65846	O1	254.6	0.19
65846	M6	352.1	0.08
65846	S4	224.3	0.01
65846	NU2	81.3	0.04
65846	MU2	61.2	0.03
65846	2N2	76.3	0.03
65846	OO1	248.6	0.01
65846	LDA2	94.9	0.01
65846	M1	253.5	0.01
65846	J1	250	0.01
65846	SSA	50.1	0.17
65846	SA	170.9	0.27
65846	RHO1	256.5	0.01
65846	Q1	255.9	0.04
65846	T2	111.9	0.01
65846	P1	253.1	0.08
65846	L2	89.2	0.04
65846	K2	115.3	0.04
65846	M8	336.6	0.03
65847	M2	28.4	1.67
65847	S2	62.4	0.23
65847	N2	24.9	0.32
65847	K1	214.1	0.35
65847	M4	319.8	0.17
65847	O1	222.5	0.3
65847	M6	177.9	0.06
65847	S4	78.2	0.02
65847	NU2	25.2	0.06
65847	S6	219.9	0.01
65847	MU2	354.6	0.04
65847	2N2	21	0.04
65847	OO1	206.8	0.01
65847	LDA2	44.1	0.01
65847	M1	218.8	0.02
65847	J1	211.3	0.02
65847	RHO1	224.6	0.01
65847	Q1	226	0.06
65847	T2	60.8	0.01
65847	2Q1	228.7	0.01
65847	P1	214.8	0.11
65847	L2	31.6	0.05
65847	K2	65.2	0.06
65847	M8	93.8	0.03
65848	M2	0.1	2.35
65848	S2	20.6	0.41
65848	N2	342.6	0.56
65848	K1	192.2	0.32
65848	M4	277.8	0.02
65848	O1	196.9	0.23
65848	M6	322.2	0.01
65848	MK3	110.2	0.01
65848	S4	45.2	0.02
65848	MN4	302.1	0.01
65848	NU2	344.6	0.11
65848	S6	162.3	0.01
65848	MU2	354.4	0.08
65848	2N2	328.1	0.07
65848	OO1	124.3	0.03
65848	LDA2	32.8	0.02
65848	S1	127.3	0.06
65848	M1	227.5	0.03
65848	J1	194.7	0.03
65848	MM	247.5	0.02
65848	SSA	100.8	0.13
65848	SA	140	0.45
65848	MSF	272	0.14
65848	MF	8.4	0.09
65848	RHO1	249.8	0.02
65848	Q1	167.7	0.05
65848	T2	10.8	0.04
65848	R2	216.3	0.02
65848	P1	188.1	0.12
65848	2SM2	13.5	0.01
65848	M3	57.3	0.07
65848	L2	342.8	0.08
65848	2MK3	344.2	0.01
65848	K2	15	0.09
65848	MS4	249	0.04
65849	M2	25.4	1.5
65849	S2	55.4	0.16
65849	N2	14.4	0.27
65849	K1	212.2	0.32
65849	M4	329.4	0.23
65849	O1	226.9	0.3
65849	M6	206.7	0.06
65849	S4	170.9	0.01
65849	NU2	15.9	0.05
65849	S6	169.1	0.01
65849	MU2	355.2	0.04
65849	2N2	3.5	0.04
65849	OO1	197.4	0.01
65849	LDA2	39.4	0.01
65849	M1	219.7	0.02
65849	J1	205.3	0.02
65849	SSA	50.1	0.17
65849	SA	170.9	0.27
65849	RHO1	232.4	0.01
65849	Q1	234.3	0.06
65849	T2	54.3	0.01
65849	2Q1	239.4	0.01
65849	P1	213.3	0.1
65849	L2	36.1	0.04
65849	K2	57.9	0.05
65849	M8	124.8	0.02
65850	M2	29.1	2.07
65850	S2	63.1	0.32
65850	N2	20.6	0.47
65850	K1	213.3	0.33
65850	M4	215.2	0.16
65850	O1	216.6	0.25
65850	M6	71.9	0.1
65850	MK3	22.9	0.07
65850	S4	110.6	0.01
65850	MN4	224.4	0.06
65850	NU2	356.6	0.07
65850	MU2	91.5	0.08
65850	2N2	38.8	0.07
65850	OO1	238.4	0.02
65850	LDA2	357	0.06
65850	S1	151.8	0.05
65850	M1	220	0.02
65850	J1	240.1	0.03
65850	SSA	50.5	0.17
65850	SA	176.3	0.26
65850	RHO1	193.5	0.01
65850	Q1	221.8	0.06
65850	T2	47.9	0.02
65850	R2	267.7	0.03
65850	2Q1	165.4	0.01
65850	P1	214	0.1
65850	2SM2	99.2	0.01
65850	M3	145.3	0.02
65850	L2	25.4	0.21
65850	2MK3	30.4	0.06
65850	K2	61.8	0.09
65850	MS4	280.5	0.06
65851	M2	20.6	2.16
65851	S2	52.1	0.38
65851	N2	8.3	0.5
65851	K1	206.6	0.34
65851	M4	192.3	0.14
65851	O1	215.9	0.25
65851	M6	56.7	0.05
65851	MK3	18.7	0.05
65851	S4	56.2	0.01
65851	MN4	187.9	0.06
65851	NU2	0	0.1
65851	MU2	72.9	0.05
65851	2N2	9.8	0.05
65851	OO1	137.5	0.02
65851	LDA2	18.1	0.02
65851	S1	164.6	0.04
65851	M1	238.4	0.05
65851	J1	248.3	0.02
65851	SSA	44.1	0.15
65851	SA	118.6	0.22
65851	RHO1	262.1	0.03
65851	Q1	195.6	0.05
65851	T2	39.5	0.07
65851	R2	315.1	0.01
65851	2Q1	91.3	0.01
65851	P1	204.3	0.1
65851	2SM2	131.5	0.01
65851	M3	116.8	0.02
65851	L2	353.4	0.13
65851	2MK3	17.4	0.06
65851	K2	48.7	0.08
65851	M8	154.1	0.01
65851	MS4	250.2	0.07
65852	M2	24.7	1.84
65852	S2	50.6	0.28
65852	N2	6.6	0.37
65852	K1	208.5	0.28
65852	M4	24.5	0.04
65852	O1	213.1	0.21
65852	M6	126.5	0.04
65852	MK3	70.7	0.01
65852	S4	96.5	0.01
65852	MN4	353.4	0.03
65852	NU2	8.7	0.09
65852	MU2	74.5	0.03
65852	2N2	354.5	0.05
65852	OO1	225.7	0.01
65852	LDA2	25.5	0.04
65852	S1	181.4	0.03
65852	M1	280.4	0.01
65852	J1	210.9	0.01
65852	SSA	25.5	0.21
65852	SA	173.3	0.19
65852	RHO1	211.1	0.01
65852	Q1	211.6	0.04
65852	T2	29.8	0.03
65852	R2	282.8	0.02
65852	2Q1	188.6	0.01
65852	P1	207.8	0.09
65852	M3	106.6	0.03
65852	L2	36.2	0.1
65852	2MK3	71	0.02
65852	K2	47.2	0.07
65852	M8	221	0.01
65852	MS4	359.1	0.02
65853	M2	56.3	1.69
65853	S2	96.8	0.2
65853	N2	45.8	0.31
65853	K1	228.1	0.22
65853	M4	8.8	0.15
65853	O1	235.7	0.21
65853	M6	246.4	0.07
65853	MK3	128.4	0.05
65853	S4	123.8	0.01
65853	MN4	7.8	0.07
65853	NU2	24	0.08
65853	MU2	163.3	0.06
65853	2N2	50.5	0.05
65853	OO1	350.8	0.02
65853	LDA2	76.4	0.04
65853	S1	192.4	0.07
65853	M1	332.5	0.03
65853	J1	281.1	0.02
65853	SSA	50.1	0.17
65853	SA	170.9	0.27
65853	RHO1	81.7	0.01
65853	Q1	216.5	0.05
65853	T2	130.5	0.02
65853	R2	29.1	0.02
65853	2Q1	273.8	0.01
65853	P1	223.6	0.07
65853	M3	141.6	0.03
65853	L2	59.5	0.13
65853	2MK3	104	0.04
65853	K2	86.8	0.07
65853	M8	207.6	0.02
65853	MS4	46.9	0.05
65854	M2	67.8	1.6
65854	S2	103.9	0.2
65854	N2	58.6	0.31
65854	K1	234.8	0.23
65854	M4	37	0.15
65854	O1	243.8	0.18
65854	M6	285.2	0.08
65854	MK3	131.5	0.03
65854	S4	189.1	0.01
65854	MN4	28.2	0.07
65854	NU2	40.8	0.09
65854	MU2	173.1	0.06
65854	2N2	41.3	0.01
65854	OO1	193.3	0.01
65854	LDA2	61	0.05
65854	S1	193.6	0.05
65854	M1	281.6	0.04
65854	J1	309.7	0.01
65854	MM	3.6	0.07
65854	SSA	138.7	0.12
65854	SA	131.7	0.31
65854	MSF	306.6	0.12
65854	MF	5.2	0.08
65854	RHO1	299.8	0.01
65854	Q1	211.5	0.04
65854	T2	82.6	0.02
65854	R2	285.2	0.01
65854	2Q1	236.3	0.01
65854	P1	234.6	0.07
65854	2SM2	283	0.01
65854	M3	141.1	0.02
65854	L2	55.8	0.17
65854	2MK3	105	0.04
65854	K2	93.1	0.06
65854	M8	274.7	0.02
65854	MS4	72.7	0.05
65855	M2	50.1	2.13
65855	S2	84.4	0.31
65855	N2	37.1	0.44
65855	K1	230.2	0.31
65855	M4	274.9	0.2
65855	O1	234.3	0.24
65855	M6	232.7	0.09
65855	MK3	60.7	0.05
65855	MN4	263.4	0.09
65855	NU2	31.1	0.1
65855	MU2	118.2	0.07
65855	2N2	34.3	0.05
65855	OO1	246.6	0.01
65855	LDA2	41.5	0.06
65855	S1	190.5	0.09
65855	M1	289.9	0.01
65855	J1	272.9	0.01
65855	MM	9.5	0.12
65855	SSA	42.9	0.15
65855	SA	184.8	0.16
65855	MSF	34.7	0.13
65855	RHO1	235.5	0.01
65855	Q1	234.2	0.05
65855	T2	85.2	0.03
65855	R2	319.9	0.02
65855	2Q1	238.4	0.01
65855	P1	219.6	0.11
65855	M3	176.5	0.04
65855	L2	43.7	0.15
65855	2MK3	62.4	0.05
65855	K2	81.1	0.08
65855	M8	99.4	0.01
65855	MS4	307.3	0.06
65856	M2	27.5	2.77
65856	S2	67	0.4
65856	N2	19.7	0.6
65856	K1	213.8	0.37
65856	M4	225.3	0.28
65856	O1	217.1	0.29
65856	M6	138.8	0.06
65856	MK3	21.4	0.08
65856	S4	37.1	0.01
65856	MN4	219.2	0.12
65856	NU2	5.3	0.1
65856	S6	12.9	0.01
65856	MU2	83.8	0.14
65856	2N2	27.6	0.09
65856	OO1	212.1	0.04
65856	LDA2	341.8	0.05
65856	S1	152.9	0.04
65856	M1	270.4	0.03
65856	J1	264.5	0.03
65856	SSA	50.5	0.17
65856	SA	176.3	0.26
65856	Q1	200	0.07
65856	T2	64	0.07
65856	R2	306.8	0.03
65856	2Q1	257.4	0.01
65856	P1	205.7	0.13
65856	2SM2	230.5	0.01
65856	M3	136.3	0.09
65856	L2	9.1	0.25
65856	2MK3	11	0.08
65856	K2	50.6	0.09
65856	M8	308	0.02
65856	MS4	265.5	0.09
65857	M2	25.1	2.57
65857	S2	54.4	0.32
65857	N2	10	0.54
65857	K1	205.8	0.4
65857	M4	224.8	0.23
65857	O1	213.1	0.28
65857	M6	167.1	0.08
65857	NU2	12	0.1
65857	MU2	203.4	0.04
65857	2N2	354.7	0.07
65857	OO1	197.7	0.01
65857	LDA2	38.8	0.02
65857	M1	209.3	0.02
65857	J1	201.7	0.02
65857	SSA	50.5	0.17
65857	SA	176.3	0.26
65857	RHO1	216.4	0.01
65857	Q1	216.9	0.05
65857	T2	53.3	0.02
65857	2Q1	220.7	0.01
65857	P1	206.3	0.13
65857	L2	40.3	0.07
65857	K2	56.8	0.09
65857	M8	6.1	0.01
65858	M2	6.9	2.29
65858	S2	31.5	0.38
65858	N2	354.6	0.52
65858	K1	197.9	0.33
65858	M4	139.4	0.07
65858	O1	202.3	0.24
65858	M6	39.3	0.04
65858	MK3	305.1	0.02
65858	S4	263.1	0.01
65858	MN4	128.6	0.04
65858	NU2	339.3	0.11
65858	S6	266.5	0.01
65858	MU2	28.3	0.08
65858	2N2	340.1	0.09
65858	OO1	176.7	0.01
65858	LDA2	2.6	0.04
65858	S1	136.8	0.03
65858	M1	273.2	0.02
65858	J1	192.3	0.02
65858	SSA	50.5	0.17
65858	SA	176.3	0.26
65858	RHO1	180.8	0.01
65858	Q1	204.8	0.05
65858	T2	65.3	0.03
65858	R2	263.1	0.03
65858	2Q1	19.6	0.01
65858	P1	200.2	0.11
65858	2SM2	32.9	0.02
65858	M3	100.4	0.05
65858	L2	341.7	0.09
65858	2MK3	325.4	0.03
65858	K2	28.6	0.11
65858	M8	91.5	0.02
65858	MS4	170.6	0.02
65859	M2	22	2.68
65859	S2	47.5	0.44
65859	N2	11.5	0.58
65859	K1	211.9	0.36
65859	M4	241.3	0.18
65859	O1	207.3	0.3
65859	M6	166.1	0.05
65859	MK3	17.8	0.07
65859	S4	11.1	0.02
65859	MN4	230.3	0.09
65859	NU2	13	0.11
65859	S6	7.6	0.01
65859	MU2	85.8	0.13
65859	2N2	348.9	0.09
65859	OO1	216.6	0.06
65859	LDA2	337.9	0.08
65859	S1	180.7	0.04
65859	M1	178.6	0.01
65859	J1	258.7	0.01
65859	SSA	50.5	0.17
65859	SA	176.3	0.26
65859	RHO1	204.8	0.02
65859	Q1	205.5	0.05
65859	T2	72.5	0.05
65859	R2	12.1	0.09
65859	2Q1	45.7	0.02
65859	P1	215.6	0.13
65859	2SM2	232.7	0.01
65859	M3	130.1	0.06
65859	L2	7.5	0.22
65859	2MK3	34	0.04
65859	K2	50.8	0.07
65859	M8	215.5	0.01
65859	MS4	274.8	0.06
65860	M2	10.4	2.57
65860	S2	36.1	0.39
65860	N2	354.9	0.56
65860	K1	199.7	0.34
65860	M4	209.6	0.11
65860	O1	203.4	0.26
65860	M6	135.3	0.02
65860	MK3	4.4	0.03
65860	MN4	201.4	0.05
65860	NU2	351.4	0.11
65860	MU2	40	0.08
65860	2N2	343.3	0.07
65860	OO1	217.3	0.02
65860	LDA2	356.1	0.04
65860	S1	173.9	0.06
65860	M1	243.3	0.02
65860	J1	213.5	0.02
65860	SSA	50.5	0.17
65860	SA	176.3	0.26
65860	RHO1	198	0.01
65860	Q1	198.9	0.06
65860	T2	19.9	0.05
65860	R2	263.8	0.02
65860	2Q1	207.1	0.01
65860	P1	198.3	0.12
65860	M3	114.8	0.06
65860	L2	5	0.11
65860	2MK3	30.6	0.02
65860	K2	37.1	0.1
65860	MS4	237.7	0.03
65861	M2	49.7	3.58
65861	S2	95.9	0.57
65861	N2	44.1	0.82
65861	K1	200	0.39
65861	M4	279.6	0.42
65861	O1	230.1	0.22
65861	M6	179.2	0.17
65861	S4	48.3	0.01
65861	NU2	44.9	0.16
65861	S6	114.6	0.01
65861	MU2	201.8	0.09
65861	2N2	38.6	0.11
65861	OO1	169.9	0.01
65861	LDA2	71.1	0.03
65861	M1	214.9	0.02
65861	J1	185.1	0.02
65861	RHO1	243	0.01
65861	Q1	245	0.04
65861	T2	94.1	0.03
65861	2Q1	259.9	0.01
65861	P1	202.3	0.13
65861	L2	55.2	0.1
65861	K2	99.7	0.16
65861	M8	20.5	0.03
65862	M2	40.7	3.3
65862	S2	76.8	0.51
65862	N2	30.2	0.7
65862	K1	221.3	0.28
65862	M4	260	0.27
65862	O1	218.3	0.27
65862	M6	142.4	0.1
65862	S4	97.8	0.02
65862	NU2	31.6	0.13
65862	S6	46.7	0.01
65862	MU2	281.5	0.01
65862	2N2	19.7	0.09
65862	OO1	221	0.01
65862	LDA2	57.4	0.02
65862	M1	219	0.02
65862	J1	221	0.02
65862	SSA	51.8	0.2
65862	SA	176	0.28
65862	RHO1	217.7	0.01
65862	Q1	217.6	0.05
65862	T2	75.4	0.03
65862	2Q1	216.9	0.01
65862	P1	221.1	0.09
65862	L2	51.3	0.09
65862	K2	79.7	0.14
65862	M8	354.8	0.02
65863	M2	9.6	2.9
65863	S2	33.3	0.5
65863	N2	356.3	0.67
65863	K1	198.9	0.35
65863	M4	210.1	0.1
65863	O1	202.4	0.26
65863	M6	22.1	0.04
65863	MK3	15.9	0.02
65863	S4	16.1	0.03
65863	MN4	203.3	0.04
65863	NU2	346.7	0.14
65863	MU2	23.4	0.09
65863	2N2	332.7	0.07
65863	OO1	239.2	0.01
65863	LDA2	13.9	0.05
65863	S1	182.7	0.06
65863	M1	212.8	0.02
65863	J1	224.4	0.02
65863	SSA	50.5	0.17
65863	SA	176.3	0.26
65863	Q1	194.1	0.06
65863	T2	8.8	0.03
65863	R2	302.7	0.03
65863	2Q1	160.3	0.01
65863	P1	202.4	0.12
65863	2SM2	86.7	0.01
65863	M3	135.8	0.06
65863	L2	347.2	0.12
65863	2MK3	18.2	0.03
65863	K2	36.9	0.11
65863	M8	111.3	0.01
65863	MS4	245.2	0.05
65864	M2	25.5	3.22
65864	S2	55.8	0.54
65864	N2	11.8	0.68
65864	K1	211.8	0.29
65864	M4	252.2	0.21
65864	O1	206	0.23
65864	M6	108.2	0.05
65864	S4	75.2	0.03
65864	NU2	13.6	0.13
65864	S6	13.1	0.01
65864	MU2	355.2	0.08
65864	2N2	357.9	0.09
65864	OO1	216.2	0.01
65864	LDA2	39.6	0.02
65864	M1	208.4	0.02
65864	J1	213.6	0.02
65864	SSA	51.8	0.2
65864	SA	176	0.28
65864	RHO1	204.5	0.01
65864	Q1	203.4	0.04
65864	T2	54.6	0.03
65864	2Q1	201.8	0.01
65864	P1	211.6	0.1
65864	L2	39.6	0.09
65864	K2	58.3	0.15
65864	M8	336.8	0.01
65865	M2	35.1	3.97
65865	S2	69.9	0.64
65865	N2	28	0.77
65865	K1	205.1	0.43
65865	M4	261.4	0.32
65865	O1	218.3	0.3
65865	M6	223.8	0.1
65865	S4	299.3	0.02
65865	NU2	28.9	0.15
65865	MU2	0.9	0.1
65865	2N2	20.8	0.1
65865	OO1	191.8	0.01
65865	LDA2	50.8	0.03
65865	M1	211.7	0.02
65865	J1	198.5	0.02
65865	SSA	51.8	0.2
65865	SA	176	0.28
65865	RHO1	223.9	0.01
65865	Q1	224.7	0.06
65865	T2	68.4	0.04
65865	R2	72.3	0.01
65865	2Q1	231.2	0.01
65865	P1	206.1	0.14
65865	L2	42.5	0.11
65865	K2	72.7	0.17
65865	M8	6.1	0.04
65866	M2	34.2	3.8
65866	S2	71.3	0.56
65866	N2	22.6	0.76
65866	K1	213.5	0.39
65866	M4	290.5	0.22
65866	O1	216	0.27
65866	M6	201.5	0.05
65866	MK3	53.1	0.05
65866	S4	85.9	0.04
65866	MN4	278.2	0.1
65866	NU2	17.2	0.16
65866	MU2	103.6	0.16
65866	2N2	32.8	0.05
65866	OO1	211	0.01
65866	LDA2	14.1	0.14
65866	S1	169.4	0.07
65866	M1	214.6	0.02
65866	J1	212.3	0.02
65866	SSA	58.8	0.2
65866	SA	173.6	0.29
65866	RHO1	216.9	0.01
65866	Q1	212.6	0.07
65866	T2	65.5	0.08
65866	2Q1	218.3	0.01
65866	P1	211.7	0.13
65866	2SM2	140.5	0.04
65866	M3	173.5	0.1
65866	L2	18.2	0.32
65866	2MK3	63.2	0.04
65866	K2	61.8	0.15
65866	M8	356	0.03
65866	MS4	326	0.12
65867	M2	17.9	3.32
65867	S2	45.8	0.52
65867	N2	2.2	0.72
65867	K1	200.7	0.36
65867	M4	248.1	0.14
65867	O1	206.5	0.26
65867	M6	60.4	0.02
65867	MK3	33.1	0.03
65867	S4	49.4	0.02
65867	MN4	241.9	0.07
65867	NU2	355.4	0.14
65867	MU2	50.2	0.1
65867	2N2	349.1	0.09
65867	OO1	213.3	0.02
65867	LDA2	5.6	0.06
65867	S1	168.1	0.06
65867	M1	249.2	0.02
65867	J1	228	0.02
65867	SSA	51.8	0.2
65867	SA	176	0.28
65867	RHO1	204.7	0.01
65867	Q1	198.9	0.06
65867	T2	30.7	0.06
65867	R2	285.6	0.04
65867	2Q1	212.2	0.01
65867	P1	199.8	0.13
65867	2SM2	122.4	0.01
65867	M3	152.1	0.08
65867	L2	12.2	0.14
65867	2MK3	77	0.02
65867	K2	45.9	0.13
65867	MS4	274.4	0.08
65868	M2	30.7	3.46
65868	S2	52.8	0.69
65868	N2	19.5	0.86
65868	K1	219.5	0.36
65868	M4	214.8	0.22
65868	O1	214.4	0.25
65868	M6	141.7	0.08
65868	S4	47.2	0.02
65868	NU2	21	0.17
65868	S6	41	0.01
65868	MU2	8.6	0.08
65868	2N2	8.3	0.11
65868	OO1	224.5	0.01
65868	LDA2	40.9	0.02
65868	M1	217	0.02
65868	J1	221.9	0.02
65868	SSA	51.8	0.2
65868	SA	176	0.28
65868	RHO1	212.3	0.01
65868	Q1	211.9	0.05
65868	T2	51.9	0.04
65868	R2	53.7	0.01
65868	2Q1	209.5	0.01
65868	P1	219.1	0.12
65868	L2	41.9	0.1
65868	K2	54.6	0.19
65868	M8	271.9	0.02
65869	M2	30.5	3.45
65869	S2	51.7	0.69
65869	N2	19.5	0.85
65869	K1	218.8	0.35
65869	M4	204.7	0.2
65869	O1	214.7	0.25
65869	M6	134.3	0.08
65869	S4	52.9	0.02
65869	NU2	20.9	0.16
65869	S6	32.3	0.01
65869	MU2	9.4	0.08
65869	2N2	8.4	0.11
65869	OO1	222.9	0.01
65869	LDA2	40.3	0.02
65869	M1	216.8	0.02
65869	J1	220.8	0.02
65869	SSA	51.8	0.2
65869	SA	176	0.28
65869	RHO1	212.9	0.01
65869	Q1	212.7	0.05
65869	T2	50.8	0.04
65869	R2	52.5	0.01
65869	2Q1	210.6	0.01
65869	P1	218.5	0.11
65869	L2	41.6	0.1
65869	K2	53.4	0.19
65869	M8	276	0.01
65870	M2	21.2	3.16
65870	S2	41.5	0.63
65870	N2	7	0.76
65870	K1	211	0.33
65870	M4	219.8	0.11
65870	O1	208.7	0.23
65870	M6	96.2	0.05
65870	S4	23.8	0.03
65870	NU2	8.9	0.15
65870	MU2	0.9	0.08
65870	2N2	352.9	0.1
65870	OO1	213.4	0.01
65870	LDA2	30.6	0.02
65870	M1	209.9	0.02
65870	J1	212.2	0.02
65870	SSA	51.8	0.2
65870	SA	176	0.28
65870	RHO1	207.7	0.01
65870	Q1	207.6	0.05
65870	T2	40.7	0.04
65870	R2	42.4	0.01
65870	2Q1	206.4	0.01
65870	P1	210.9	0.11
65870	L2	35.4	0.09
65870	K2	43.2	0.17
65870	M8	146.2	0.01
65871	M2	24.1	3.27
65871	S2	44.6	0.65
65871	N2	11	0.8
65871	K1	214	0.34
65871	M4	215.3	0.14
65871	O1	211.1	0.24
65871	M6	108.8	0.06
65871	S4	37.5	0.02
65871	NU2	12.7	0.15
65871	S6	23.5	0.01
65871	MU2	3.7	0.08
65871	2N2	357.8	0.1
65871	OO1	216.9	0.01
65871	LDA2	33.6	0.02
65871	M1	212.6	0.02
65871	J1	215.4	0.02
65871	SSA	51.8	0.2
65871	SA	176	0.28
65871	RHO1	209.9	0.01
65871	Q1	209.7	0.05
65871	T2	43.7	0.04
65871	R2	45.4	0.01
65871	2Q1	208.3	0.01
65871	P1	213.8	0.11
65871	L2	37.3	0.09
65871	K2	46.2	0.18
65871	M8	171.2	0.01
65872	M2	28.7	3.46
65872	S2	64.4	0.54
65872	N2	20	0.8
65872	K1	206.5	0.36
65872	M4	245.2	0.17
65872	O1	211	0.27
65872	M6	145.1	0.08
65872	S4	84	0.02
65872	NU2	21.1	0.16
65872	S6	201.2	0.01
65872	MU2	352.8	0.08
65872	2N2	11.2	0.1
65872	OO1	204.8	0.01
65872	LDA2	45.3	0.02
65872	M1	209.5	0.02
65872	J1	206.1	0.02
65872	SSA	51.8	0.2
65872	SA	176	0.28
65872	RHO1	212	0.01
65872	Q1	212.6	0.05
65872	T2	62.9	0.03
65872	2Q1	213.8	0.01
65872	P1	206.8	0.12
65872	L2	37.5	0.1
65872	K2	67.3	0.15
65872	M8	336.5	0.01
65873	M2	37.2	3.41
65873	S2	76.9	0.51
65873	N2	30.8	0.77
65873	K1	212.3	0.37
65873	M4	276.5	0.29
65873	O1	217.9	0.27
65873	M6	177	0.08
65873	S4	82.1	0.02
65873	NU2	31.7	0.15
65873	S6	233.1	0.01
65873	MU2	357.3	0.08
65873	2N2	24.4	0.1
65873	OO1	209.6	0.01
65873	LDA2	55.7	0.02
65873	M1	215.8	0.02
65873	J1	211.5	0.02
65873	SSA	51.8	0.2
65873	SA	176	0.28
65873	RHO1	219.3	0.01
65873	Q1	220	0.05
65873	T2	75.2	0.03
65873	2Q1	221.7	0.01
65873	P1	212.7	0.12
65873	L2	43.6	0.1
65873	K2	80	0.14
65873	M8	353.1	0.01
65874	M2	20.7	3.32
65874	S2	52.9	0.53
65874	N2	8.3	0.8
65874	K1	196.5	0.36
65874	M4	268.2	0.13
65874	O1	205.4	0.26
65874	M6	116.1	0.03
65874	S4	62.7	0.03
65874	NU2	10	0.15
65874	S6	128.5	0.01
65874	MU2	348.4	0.08
65874	2N2	355.9	0.11
65874	OO1	187.8	0.01
65874	LDA2	35.6	0.02
65874	M1	201	0.02
65874	J1	192.3	0.02
65874	SSA	51.8	0.2
65874	SA	176	0.28
65874	RHO1	209.2	0.01
65874	Q1	209.9	0.05
65874	T2	51.7	0.03
65874	2Q1	214.1	0.01
65874	P1	197.2	0.12
65874	L2	33.1	0.09
65874	K2	55.5	0.14
65874	M8	272.6	0.01
65875	M2	23.7	3.29
65875	S2	56	0.51
65875	N2	13.4	0.76
65875	K1	202.8	0.35
65875	M4	265.6	0.1
65875	O1	204.5	0.25
65875	M6	116	0.03
65875	S4	60.6	0.03
65875	NU2	14.7	0.15
65875	MU2	351.4	0.08
65875	2N2	3.1	0.1
65875	OO1	205.3	0.01
65875	LDA2	38.7	0.02
65875	M1	204.5	0.02
65875	J1	205	0.02
65875	SSA	51.8	0.2
65875	SA	176	0.28
65875	RHO1	204.7	0.01
65875	Q1	204.5	0.05
65875	T2	54.6	0.03
65875	2Q1	205.1	0.01
65875	P1	202.9	0.12
65875	L2	34.2	0.09
65875	K2	58.5	0.14
65875	M8	252.2	0.01
65876	M2	31	3.52
65876	S2	67.5	0.56
65876	N2	22.8	0.82
65876	K1	206.7	0.37
65876	M4	258.3	0.15
65876	O1	211.4	0.27
65876	M6	153.7	0.08
65876	S4	93	0.03
65876	NU2	23.8	0.16
65876	S6	189.7	0.01
65876	MU2	354.2	0.09
65876	2N2	14.5	0.11
65876	OO1	204.8	0.01
65876	LDA2	48.1	0.03
65876	M1	209.7	0.02
65876	J1	206.2	0.02
65876	SSA	51.8	0.2
65876	SA	176	0.28
65876	RHO1	212.3	0.01
65876	Q1	212.9	0.05
65876	T2	66	0.03
65876	2Q1	214.1	0.01
65876	P1	207	0.12
65876	L2	39.2	0.1
65876	K2	70.5	0.15
65876	M8	312.5	0.02
65877	M2	27	3.31
65877	S2	60.7	0.5
65877	N2	16.7	0.75
65877	K1	203.2	0.35
65877	M4	280.6	0.13
65877	O1	209.4	0.26
65877	M6	156.7	0.03
65877	S4	58.6	0.02
65877	NU2	18.1	0.14
65877	MU2	353.1	0.08
65877	2N2	6.6	0.1
65877	OO1	200.3	0.01
65877	LDA2	42.7	0.02
65877	M1	207.1	0.02
65877	J1	202.9	0.02
65877	SSA	54.7	0.23
65877	SA	196.6	0.28
65877	RHO1	210.7	0.01
65877	Q1	211.3	0.05
65877	T2	59.3	0.03
65877	2Q1	213.2	0.01
65877	P1	203.6	0.11
65877	L2	37.2	0.09
65877	K2	63.5	0.14
65877	M8	321.9	0.01
65878	M2	41.5	3.83
65878	S2	83.8	0.59
65878	N2	33.4	0.78
65878	K1	209.8	0.46
65878	M4	231.6	0.32
65878	O1	230.2	0.32
65878	M6	144.4	0.05
65878	S4	346.8	0.02
65878	NU2	34.5	0.15
65878	S6	314.8	0.01
65878	MU2	359.2	0.09
65878	2N2	25.3	0.1
65878	OO1	189.5	0.01
65878	LDA2	61.1	0.03
65878	M1	219.9	0.02
65878	J1	199.7	0.03
65878	SSA	54.7	0.23
65878	SA	196.6	0.28
65878	RHO1	238.9	0.01
65878	Q1	240.3	0.06
65878	T2	82.1	0.04
65878	2Q1	250.4	0.01
65878	P1	211.4	0.15
65878	L2	49.6	0.11
65878	K2	87.2	0.16
65878	M8	332.5	0.03
65879	M2	23.4	3.2
65879	S2	51.1	0.52
65879	N2	8.1	0.74
65879	K1	201.2	0.35
65879	M4	303.6	0.09
65879	O1	208	0.25
65879	M6	192.5	0.02
65879	MK3	67.1	0.03
65879	S4	2.2	0.03
65879	MN4	284.4	0.06
65879	NU2	359.6	0.14
65879	MU2	52.6	0.09
65879	2N2	357.4	0.1
65879	OO1	216.3	0.02
65879	LDA2	7.4	0.05
65879	S1	170.3	0.06
65879	M1	213.2	0.01
65879	J1	229.1	0.02
65879	SSA	47.7	0.37
65879	SA	168.2	0.37
65879	RHO1	210.8	0.01
65879	Q1	201.6	0.06
65879	T2	30.3	0.05
65879	R2	291.3	0.02
65879	2Q1	214.6	0.01
65879	P1	202.7	0.12
65879	2SM2	77.2	0.01
65879	M3	171.3	0.05
65879	L2	17.2	0.19
65879	2MK3	96.4	0.03
65879	K2	53.1	0.13
65879	MS4	285.9	0.04
65880	M2	32	3.4
65880	S2	67.3	0.53
65880	N2	21.8	0.79
65880	K1	204.3	0.36
65880	M4	261.8	0.14
65880	O1	212.3	0.26
65880	M6	155.6	0.04
65880	S4	31.5	0.03
65880	NU2	23.2	0.15
65880	MU2	356.5	0.08
65880	2N2	11.7	0.1
65880	OO1	198.8	0.01
65880	LDA2	48.4	0.02
65880	M1	208.9	0.02
65880	J1	202	0.02
65880	SSA	54.7	0.23
65880	SA	196.6	0.28
65880	RHO1	214.6	0.01
65880	Q1	215.9	0.05
65880	T2	65.8	0.03
65880	2Q1	218.2	0.01
65880	P1	204.9	0.12
65880	L2	42.1	0.1
65880	K2	70.1	0.14
65880	M8	326.4	0.01
65881	M2	28.1	3.17
65881	S2	58.6	0.48
65881	N2	15.4	0.73
65881	K1	199.4	0.33
65881	M4	315.3	0.07
65881	O1	208.8	0.25
65881	M6	187.4	0.02
65881	S4	13.8	0.02
65881	NU2	17.1	0.14
65881	S6	346.9	0.01
65881	MU2	357.5	0.08
65881	2N2	2.6	0.1
65881	OO1	191.9	0.01
65881	LDA2	42.3	0.02
65881	M1	204.7	0.02
65881	J1	196.4	0.02
65881	SSA	54.7	0.23
65881	SA	196.6	0.28
65881	RHO1	211.8	0.01
65881	Q1	212.6	0.05
65881	T2	57.5	0.03
65881	2Q1	216.2	0.01
65881	P1	200	0.11
65881	L2	40.9	0.09
65881	K2	61.1	0.13
65881	M8	299.6	0.01
65882	M2	54.8	3.06
65882	S2	94.4	0.45
65882	N2	54.4	0.65
65882	K1	236.3	0.36
65882	M4	348.2	0.26
65882	O1	233.2	0.25
65882	M6	265.3	0.09
65882	S4	81.1	0.02
65882	NU2	54.4	0.12
65882	S6	207.8	0.01
65882	MU2	15.6	0.07
65882	2N2	54	0.09
65882	OO1	238.9	0.01
65882	LDA2	73	0.02
65882	M1	234.5	0.02
65882	J1	237.4	0.02
65882	SSA	54.7	0.23
65882	SA	196.6	0.28
65882	RHO1	231.7	0.01
65882	Q1	232	0.05
65882	T2	92.5	0.03
65882	2Q1	230.2	0.01
65882	P1	236.1	0.12
65882	L2	55.5	0.09
65882	K2	97.5	0.12
65882	M8	123	0.01
65883	M2	36.3	3.12
65883	S2	67.7	0.51
65883	N2	19.7	0.68
65883	K1	209.5	0.35
65883	M4	207.5	0.13
65883	O1	218	0.26
65883	M6	165.8	0.03
65883	MK3	31.7	0.06
65883	S4	353.4	0.02
65883	MN4	205	0.07
65883	NU2	19.2	0.16
65883	MU2	70.2	0.11
65883	2N2	340.1	0.09
65883	OO1	200.9	0.01
65883	LDA2	30.4	0.08
65883	S1	174.3	0.06
65883	M1	261.7	0.03
65883	J1	205.2	0.02
65883	RHO1	221.7	0.01
65883	Q1	217.2	0.06
65883	T2	45.9	0.07
65883	R2	307	0.04
65883	2Q1	226.4	0.01
65883	P1	207.2	0.12
65883	2SM2	96.2	0.01
65883	M3	183	0.03
65883	L2	29.2	0.13
65883	2MK3	45.1	0.03
65883	K2	66.1	0.13
65883	M8	317.4	0.02
65883	MS4	236.8	0.07
65884	M2	37.4	3
65884	S2	67	0.46
65884	N2	25.2	0.62
65884	K1	212	0.33
65884	M4	222	0.11
65884	O1	216.9	0.26
65884	M6	161.8	0.03
65884	MK3	36.9	0.05
65884	S4	359.9	0.02
65884	MN4	223.8	0.06
65884	NU2	21.5	0.13
65884	MU2	92.1	0.11
65884	2N2	31.1	0.08
65884	OO1	211.2	0.03
65884	LDA2	16.8	0.07
65884	S1	161.2	0.05
65884	M1	268.7	0.01
65884	J1	276.8	0.02
65884	SSA	54.7	0.23
65884	SA	196.6	0.28
65884	RHO1	201.3	0.02
65884	Q1	210.1	0.04
65884	T2	104.7	0.05
65884	R2	236.8	0.06
65884	2Q1	308.2	0.01
65884	P1	208.8	0.11
65884	2SM2	45.5	0.03
65884	M3	179.2	0.05
65884	L2	15.5	0.16
65884	2MK3	43.8	0.03
65884	K2	48.2	0.14
65884	M8	328	0.02
65884	MS4	247.8	0.06
65885	M2	45.2	2.83
65885	S2	70.9	0.41
65885	N2	39.4	0.56
65885	K1	218.2	0.34
65885	M4	265	0.1
65885	O1	227.6	0.27
65885	M6	195.6	0.04
65885	MK3	64.1	0.05
65885	S4	17.1	0.03
65885	MN4	266.1	0.07
65885	NU2	18.1	0.1
65885	MU2	112.9	0.09
65885	2N2	30.4	0.1
65885	LDA2	19.3	0.07
65885	S1	163	0.05
65885	J1	234.1	0.04
65885	SSA	54.7	0.23
65885	SA	196.6	0.28
65885	Q1	225.7	0.07
65885	T2	67.1	0.09
65885	R2	13.6	0.07
65885	P1	228	0.13
65885	M3	213.1	0.05
65885	L2	26.3	0.19
65885	2MK3	56.6	0.06
65885	K2	60	0.13
65885	M8	2.6	0.02
65885	MS4	283.9	0.05
65886	M2	59.7	2.37
65886	S2	98	0.3
65886	N2	57.8	0.41
65886	K1	221.8	0.29
65886	M4	321.3	0.14
65886	O1	248.5	0.22
65886	M6	248.6	0.07
65886	S4	28.5	0.01
65886	NU2	58	0.08
65886	S6	135.8	0.01
65886	MU2	21.8	0.06
65886	2N2	55.7	0.05
65886	OO1	198.5	0.01
65886	LDA2	77.4	0.02
65886	M1	235.2	0.02
65886	J1	210.3	0.02
65886	SSA	54.7	0.23
65886	SA	196.6	0.28
65886	RHO1	259.6	0.01
65886	Q1	261.3	0.04
65886	T2	96.5	0.02
65886	2Q1	271.6	0.01
65886	P1	223.8	0.1
65886	L2	61.4	0.07
65886	K2	101.1	0.08
65886	M8	79.2	0.02
65887	M2	26.8	2.93
65887	S2	57.3	0.19
65887	N2	9.9	0.62
65887	K1	200.7	0.4
65887	M4	152.4	0.06
65887	O1	216	0.27
65887	M6	153.3	0.02
65887	MK3	24	0.04
65887	S4	340.6	0.03
65887	MN4	170.4	0.03
65887	NU2	357.6	0.12
65887	MU2	52.6	0.08
65887	2N2	351.8	0.08
65887	OO1	183.1	0.04
65887	LDA2	358.3	0.05
65887	S1	141.4	0.1
65887	M1	230.7	0.02
65887	J1	224.2	0.01
65887	SSA	54.7	0.23
65887	SA	119.6	0.28
65887	RHO1	353.4	0.01
65887	Q1	215.1	0.06
65887	T2	2.2	0.14
65887	R2	291.4	0.27
65887	2Q1	125.3	0.01
65887	P1	186.1	0.1
65887	M3	160	0.04
65887	L2	27	0.13
65887	2MK3	356.2	0.01
65887	K2	146.4	0.09
65887	M8	273.6	0.01
65887	MS4	203.3	0.04
65888	M2	16.3	2.81
65888	S2	37.6	0.44
65888	N2	353.7	0.62
65888	K1	192.8	0.34
65888	M4	354.5	0.03
65888	O1	205.4	0.25
65888	M6	138.1	0.01
65888	MK3	86.1	0.01
65888	S4	293.7	0.02
65888	MN4	310.8	0.02
65888	NU2	1.3	0.12
65888	MU2	4.2	0.09
65888	2N2	339.8	0.07
65888	OO1	207.4	0.03
65888	LDA2	24	0.03
65888	S1	156.3	0.05
65888	M1	216.1	0.01
65888	J1	199.5	0.02
65888	SSA	54.7	0.23
65888	SA	119.6	0.28
65888	RHO1	264.9	0.02
65888	Q1	193.4	0.05
65888	T2	23.5	0.05
65888	R2	257.6	0.03
65888	P1	190.3	0.12
65888	2SM2	31.8	0.02
65888	M3	154.1	0.04
65888	L2	45.2	0.06
65888	2MK3	157.3	0.03
65888	K2	41.6	0.1
65888	MS4	123.2	0.01
65889	M2	41	2.99
65889	S2	75.6	0.46
65889	N2	38	0.6
65889	K1	208.7	0.34
65889	M4	218.4	0.16
65889	O1	225	0.29
65889	M6	149.1	0.02
65889	S4	27.6	0.04
65889	NU2	38.4	0.11
65889	S6	304.9	0.01
65889	MU2	202.9	0.07
65889	2N2	34.8	0.08
65889	OO1	196.7	0.01
65889	LDA2	57.3	0.02
65889	M1	217.8	0.02
65889	J1	203.7	0.02
65889	SSA	54.7	0.23
65889	SA	196.6	0.28
65889	RHO1	231.2	0.01
65889	Q1	232.2	0.06
65889	T2	74.2	0.03
65889	2Q1	239.3	0.01
65889	P1	209.9	0.11
65889	L2	44.4	0.08
65889	K2	78.4	0.12
65889	M8	320.4	0.03
65890	M2	32.9	2.95
65890	S2	61.2	0.45
65890	N2	14.7	0.65
65890	K1	208	0.35
65890	M4	193.6	0.1
65890	O1	215.9	0.26
65890	M6	124.7	0.02
65890	MK3	28.3	0.04
65890	S4	339.7	0.02
65890	MN4	192.9	0.05
65890	NU2	11.7	0.12
65890	MU2	69.4	0.09
65890	2N2	350.6	0.09
65890	OO1	208.9	0.02
65890	LDA2	10.2	0.05
65890	S1	177.5	0.05
65890	M1	261.7	0.01
65890	J1	245.1	0.02
65890	SSA	54.7	0.23
65890	SA	196.6	0.28
65890	RHO1	234.4	0.01
65890	Q1	210	0.05
65890	T2	49.4	0.05
65890	R2	290.4	0.03
65890	2Q1	223.6	0.01
65890	P1	206.4	0.12
65890	2SM2	99.1	0.01
65890	M3	171.9	0.03
65890	L2	37.8	0.13
65890	2MK3	46.2	0.02
65890	K2	67.3	0.1
65890	M8	288.2	0.01
65890	MS4	223.4	0.05
65891	M2	43.4	2.92
65891	S2	73.5	0.45
65891	N2	33.9	0.61
65891	K1	225.9	0.37
65891	M4	230.8	0.15
65891	O1	215.8	0.23
65891	M6	92	0.03
65891	S4	356.7	0.03
65891	NU2	35.2	0.12
65891	S6	146.8	0.01
65891	MU2	210.1	0.07
65891	2N2	24.4	0.08
65891	OO1	235.8	0.01
65891	LDA2	57.4	0.02
65891	M1	220.8	0.02
65891	J1	230.7	0.02
65891	SSA	54.7	0.23
65891	SA	196.6	0.28
65891	RHO1	211.5	0.01
65891	Q1	210.9	0.05
65891	T2	72.3	0.03
65891	2Q1	205.9	0.01
65891	P1	225.1	0.12
65891	L2	52.8	0.08
65891	K2	75.9	0.12
65891	M8	297.5	0.03
65892	M2	157.5	1
65892	S2	221.7	0.03
65892	N2	168.2	0.24
65892	K1	312.6	0.26
65892	M4	145.1	0.16
65892	O1	322	0.17
65892	M6	134.7	0.04
65892	S4	155.9	0.02
65892	NU2	166.7	0.05
65892	S6	190.3	0.01
65892	MU2	290	0.02
65892	2N2	178.9	0.03
65892	OO1	303.2	0.01
65892	LDA2	187.3	0.01
65892	M1	317.3	0.01
65892	J1	307.9	0.01
65892	RHO1	326.1	0.01
65892	Q1	326.7	0.03
65892	P1	313.3	0.09
65892	L2	146.7	0.03
65892	K2	226.9	0.01
65892	M8	102.2	0.01
65893	M2	51.9	2.17
65893	S2	86.6	0.23
65893	N2	40.3	0.38
65893	K1	231.2	0.34
65893	M4	355	0.15
65893	O1	229.2	0.36
65893	M6	184.1	0.06
65893	S4	231.1	0.01
65893	NU2	41.8	0.08
65893	MU2	17.2	0.05
65893	2N2	28.6	0.05
65893	OO1	233.1	0.02
65893	LDA2	68	0.02
65893	M1	230.2	0.03
65893	J1	232.1	0.03
65893	RHO1	228.4	0.01
65893	Q1	228.2	0.07
65893	T2	85.2	0.01
65893	2Q1	227.3	0.01
65893	P1	231	0.11
65893	L2	63.5	0.06
65893	K2	89.4	0.06
65893	M8	133.9	0.01
65894	M2	75.9	2.09
65894	S2	117.9	0.28
65894	N2	66.7	0.4
65894	K1	241.3	0.3
65894	M4	5.7	0.16
65894	O1	245.9	0.24
65894	M6	255.1	0.08
65894	MK3	115.2	0.07
65894	S4	75.2	0.02
65894	MN4	353.9	0.08
65894	NU2	53.6	0.14
65894	MU2	147.8	0.11
65894	2N2	18.8	0.06
65894	OO1	272.6	0.01
65894	LDA2	65.7	0.04
65894	S1	221.8	0.03
65894	M1	340.8	0.03
65894	J1	309.4	0.01
65894	RHO1	240.2	0.02
65894	Q1	247.8	0.06
65894	T2	95	0.05
65894	R2	320.8	0.03
65894	2Q1	192.5	0.01
65894	P1	238.1	0.09
65894	2SM2	56.8	0.02
65894	M3	221.6	0.02
65894	L2	70.3	0.16
65894	2MK3	111.7	0.06
65894	K2	115.7	0.06
65894	M8	150.2	0.02
65894	MS4	37.1	0.05
65895	M2	68.3	1.45
65895	S2	100.6	0.19
65895	N2	56.3	0.3
65895	K1	247.3	0.15
65895	M4	47.1	0.08
65895	O1	243.7	0.11
65895	M6	351.4	0.06
65895	S4	11	0.01
65895	NU2	58	0.06
65895	MU2	35.4	0.04
65895	2N2	44.4	0.04
65895	LDA2	83.5	0.01
65895	M1	245.1	0.01
65895	J1	248.8	0.01
65895	MM	227.6	0.08
65895	SSA	54.9	0.25
65895	SA	189.9	0.38
65895	MSF	197.6	0.13
65895	Q1	242.4	0.02
65895	T2	99.2	0.01
65895	P1	246.9	0.05
65895	L2	80.7	0.04
65895	K2	103.2	0.05
65895	M8	23.9	0.01
65896	M2	46.3	2.1
65896	S2	75.7	0.31
65896	N2	36.4	0.43
65896	K1	228.1	0.28
65896	M4	282.3	0.08
65896	O1	220.6	0.19
65896	M6	266.5	0.03
65896	S4	339.7	0.02
65896	NU2	37.7	0.08
65896	MU2	16.9	0.05
65896	2N2	26.5	0.06
65896	LDA2	59.8	0.01
65896	M1	224.2	0.01
65896	J1	231.4	0.02
65896	SSA	55.4	0.25
65896	SA	190.2	0.38
65896	Q1	217.2	0.04
65896	T2	74.4	0.02
65896	P1	227.5	0.09
65896	L2	56.1	0.06
65896	K2	78.1	0.09
65896	M8	16.4	0.01
65897	M2	45.6	1.77
65897	S2	72.4	0.24
65897	N2	32.2	0.36
65897	K1	225.2	0.21
65897	M4	19.3	0.03
65897	O1	219.3	0.15
65897	M6	270.5	0.06
65897	S4	347.3	0.02
65897	NU2	34	0.07
65897	S6	68.7	0.01
65897	MU2	18.9	0.04
65897	2N2	18.7	0.05
65897	OO1	230.6	0.01
65897	LDA2	58	0.01
65897	M1	222.4	0.01
65897	J1	229.3	0.01
65897	MM	227.6	0.08
65897	SSA	54.9	0.25
65897	SA	189.9	0.38
65897	MSF	197.6	0.13
65897	RHO1	216.5	0.01
65897	Q1	216	0.03
65897	T2	71.2	0.01
65897	P1	224.8	0.07
65897	L2	59.1	0.05
65897	K2	74.6	0.07
65897	M8	301.9	0.01
65898	M2	20.9	2.31
65898	S2	43.6	0.37
65898	N2	5.6	0.52
65898	K1	199.7	0.29
65898	M4	152.3	0.09
65898	O1	205.6	0.21
65898	M6	179.2	0.02
65898	MK3	30.2	0.02
65898	S4	292.6	0.02
65898	MN4	163.2	0.03
65898	NU2	355.7	0.11
65898	MU2	17	0.06
65898	2N2	345.5	0.07
65898	OO1	193.7	0.01
65898	LDA2	29.7	0.03
65898	S1	156.8	0.03
65898	M1	230.1	0.02
65898	J1	219.2	0.01
65898	MM	230.4	0.08
65898	SSA	55.4	0.25
65898	SA	190.2	0.38
65898	MSF	202.7	0.13
65898	RHO1	208.1	0.01
65898	Q1	199.7	0.04
65898	T2	35.4	0.04
65898	2Q1	211.4	0.01
65898	P1	197.3	0.1
65898	2SM2	84.7	0.02
65898	M3	174.2	0.03
65898	L2	11.2	0.08
65898	2MK3	37.8	0.02
65898	K2	41.3	0.1
65898	MS4	162.2	0.04
65899	M2	80.1	1.31
65899	S2	115.5	0.17
65899	N2	72.5	0.25
65899	K1	255.8	0.16
65899	M4	90.4	0.02
65899	O1	245.5	0.09
65899	M6	50.8	0.08
65899	S4	47.4	0.01
65899	NU2	73.6	0.05
65899	MU2	44.5	0.03
65899	2N2	65	0.03
65899	LDA2	96.5	0.01
65899	M1	251.4	0.01
65899	SSA	55.4	0.25
65899	SA	190.2	0.38
65899	Q1	239.6	0.02
65899	T2	114	0.01
65899	P1	255	0.05
65899	L2	87.5	0.04
65899	K2	118.3	0.05
65899	M8	322.2	0.01
65900	M2	20	2.35
65900	S2	43.5	0.38
65900	N2	357.5	0.52
65900	K1	192.1	0.27
65900	M4	117.4	0.04
65900	O1	205.6	0.21
65900	M6	133	0.01
65900	MK3	23.7	0.01
65900	S4	276.1	0.01
65900	MN4	107	0.01
65900	NU2	351.9	0.1
65900	MU2	9.7	0.07
65900	2N2	353.2	0.06
65900	OO1	203.8	0.02
65900	LDA2	66.2	0.02
65900	S1	172.4	0.07
65900	M1	235.8	0.01
65900	J1	206	0.01
65900	MM	230.4	0.08
65900	SSA	55.4	0.25
65900	SA	190.2	0.38
65900	MSF	202.7	0.13
65900	RHO1	249.8	0.02
65900	Q1	196.2	0.05
65900	T2	50.4	0.05
65900	R2	290.1	0.04
65900	2Q1	69.7	0.01
65900	P1	197.9	0.1
65900	2SM2	28.2	0.02
65900	M3	151.4	0.02
65900	L2	55.8	0.04
65900	2MK3	150.8	0.02
65900	K2	40.8	0.09
65900	M8	325.3	0.01
65900	MS4	139	0.03
65901	M2	26.4	2.19
65901	S2	49.9	0.34
65901	N2	8.2	0.47
65901	K1	204.3	0.28
65901	M4	163.8	0.1
65901	O1	211	0.19
65901	M6	195.7	0.03
65901	MK3	22.2	0.03
65901	S4	288.9	0.01
65901	MN4	161.2	0.03
65901	NU2	5.8	0.1
65901	MU2	30.9	0.05
65901	2N2	349.2	0.06
65901	OO1	245.5	0.01
65901	LDA2	39.4	0.03
65901	S1	170.8	0.04
65901	M1	249.7	0.01
65901	J1	209.2	0.02
65901	SSA	52.8	0.31
65901	SA	188.2	0.37
65901	RHO1	240.4	0.01
65901	Q1	207.6	0.04
65901	T2	40.1	0.04
65901	R2	285.7	0.02
65901	2Q1	198.4	0.01
65901	P1	201	0.1
65901	2SM2	73.3	0.01
65901	M3	155.8	0.03
65901	L2	29.9	0.08
65901	2MK3	44.8	0.02
65901	K2	47.6	0.09
65901	M8	353.1	0.01
65901	MS4	179.7	0.04
65902	M2	50.2	1.69
65902	S2	78.5	0.23
65902	N2	34.4	0.33
65902	K1	220.2	0.19
65902	M4	312.3	0.05
65902	O1	226.4	0.13
65902	M6	302.7	0.07
65902	MK3	75.3	0.04
65902	S4	353.5	0.01
65902	MN4	295.6	0.03
65902	NU2	28.8	0.07
65902	MU2	123.9	0.04
65902	2N2	35.1	0.03
65902	OO1	272.5	0.01
65902	LDA2	46.8	0.04
65902	S1	210.3	0.03
65902	J1	224.5	0.01
65902	MM	227.6	0.08
65902	SSA	54.9	0.25
65902	SA	189.9	0.38
65902	MSF	197.6	0.13
65902	Q1	227.9	0.03
65902	T2	74.5	0.03
65902	R2	295.5	0.02
65902	2Q1	238.7	0.01
65902	P1	213.7	0.07
65902	M3	177.4	0.02
65902	L2	56.4	0.1
65902	2MK3	72	0.04
65902	K2	71.5	0.07
65902	M8	38.6	0.01
65902	MS4	287.3	0.01
65903	M2	28.1	2.17
65903	S2	51.5	0.36
65903	N2	10.1	0.49
65903	K1	203.9	0.27
65903	M4	170.5	0.08
65903	O1	212.2	0.2
65903	M6	212.2	0.03
65903	MK3	38.3	0.03
65903	MN4	171.4	0.03
65903	NU2	6.6	0.11
65903	MU2	28.6	0.06
65903	2N2	5.6	0.06
65903	OO1	195.5	0.01
65903	LDA2	34.1	0.04
65903	S1	164.2	0.03
65903	M1	208	0.01
65903	J1	199.8	0.02
65903	MM	230.4	0.08
65903	SSA	55.4	0.25
65903	SA	190.2	0.38
65903	MSF	202.7	0.13
65903	RHO1	215.8	0.01
65903	Q1	201	0.04
65903	T2	51.4	0.02
65903	2Q1	220.5	0.01
65903	P1	196.3	0.09
65903	L2	28.9	0.12
65903	K2	50	0.1
65903	MS4	180.9	0.04
65904	M2	27.5	2.15
65904	S2	49.5	0.3
65904	N2	8.7	0.46
65904	K1	205	0.27
65904	M4	160	0.09
65904	O1	213.1	0.19
65904	M6	195.8	0.04
65904	MK3	19.1	0.03
65904	S4	299.8	0.02
65904	MN4	164.1	0.04
65904	NU2	1.2	0.09
65904	S6	16.4	0.01
65904	MU2	55.9	0.04
65904	2N2	5.9	0.06
65904	OO1	172.8	0.04
65904	LDA2	22.2	0.03
65904	S1	162	0.03
65904	M1	235.6	0.01
65904	J1	155	0.01
65904	MM	230.4	0.08
65904	SSA	55.4	0.25
65904	SA	190.2	0.38
65904	MSF	202.7	0.13
65904	MF	116.2	0.15
65904	RHO1	256.2	0.01
65904	Q1	201.3	0.05
65904	T2	61.3	0.04
65904	R2	197.5	0.01
65904	2Q1	312.9	0.01
65904	P1	191.4	0.09
65904	M3	157.3	0.03
65904	L2	50.3	0.09
65904	2MK3	27.2	0.02
65904	K2	38.5	0.09
65904	M8	350.6	0.01
65904	MS4	175	0.03
65905	M2	61	1.26
65905	S2	87.3	0.19
65905	N2	52.4	0.24
65905	K1	242.1	0.14
65905	M4	63.7	0.06
65905	O1	234.3	0.11
65905	M6	331	0.07
65905	S4	25.1	0.01
65905	NU2	53.5	0.05
65905	MU2	231.5	0.03
65905	2N2	43.8	0.03
65905	LDA2	73.1	0.01
65905	M1	238.1	0.01
65905	J1	245.7	0.01
65905	SSA	55.4	0.25
65905	SA	190.2	0.38
65905	Q1	230.5	0.02
65905	T2	86.3	0.01
65905	P1	241.4	0.05
65905	L2	69.3	0.04
65905	K2	89.5	0.05
65905	M8	40.9	0.01
65906	M2	74.5	0.88
65906	S2	105	0.12
65906	N2	56.3	0.16
65906	K1	247.2	0.09
65906	M4	351.9	0.06
65906	O1	256.4	0.07
65906	M6	10.5	0.05
65906	MK3	124.5	0.03
65906	S4	53.9	0.01
65906	MN4	341.1	0.03
65906	NU2	57	0.04
65906	MU2	158.8	0.02
65906	2N2	30.4	0.02
65906	LDA2	77.6	0.03
65906	S1	221.5	0.02
65906	MM	344.6	0.04
65906	SSA	54.6	0.34
65906	SA	206.2	0.51
65906	MSF	257.5	0.06
65906	Q1	244.9	0.01
65906	T2	103.2	0.02
65906	R2	335.1	0.01
65906	P1	242.3	0.04
65906	M3	230.5	0.01
65906	L2	77	0.07
65906	2MK3	121.8	0.03
65906	K2	99.3	0.03
65906	M8	333	0.01
65906	MS4	11.8	0.01
65907	M2	64.3	1.24
65907	S2	95.2	0.17
65907	N2	49.7	0.26
65907	K1	230.4	0.14
65907	M4	41.9	0.05
65907	O1	240.2	0.1
65907	M6	334.3	0.07
65907	MK3	110.7	0.03
65907	S4	33.8	0.01
65907	MN4	10.5	0.03
65907	NU2	40.7	0.05
65907	MU2	155.2	0.03
65907	2N2	63.2	0.03
65907	OO1	264.8	0.01
65907	LDA2	78	0.04
65907	S1	198.6	0.02
65907	M1	252.3	0.01
65907	J1	244.3	0.01
65907	MM	344.9	0.08
65907	SSA	27.9	0.29
65907	SA	159.5	0.5
65907	MSF	321	0.05
65907	MF	308	0.02
65907	Q1	231.4	0.02
65907	T2	51.8	0.03
65907	P1	227.6	0.05
65907	L2	67.6	0.16
65907	2MK3	109.6	0.03
65907	K2	96.9	0.05
65907	M8	42.6	0.01
65907	MS4	74.6	0.01
65908	M2	15.6	2.48
65908	S2	35.1	0.4
65908	N2	352.9	0.58
65908	K1	193.1	0.36
65908	M4	19.1	0.04
65908	O1	205.5	0.26
65908	M6	92.2	0.02
65908	S4	293.6	0.02
65908	NU2	356	0.11
65908	S6	290.5	0.01
65908	MU2	193.2	0.06
65908	2N2	330.2	0.08
65908	OO1	180.8	0.01
65908	LDA2	24.8	0.02
65908	M1	199.3	0.02
65908	J1	187.1	0.02
65908	SSA	52	0.2
65908	SA	193.3	0.33
65908	RHO1	210.9	0.01
65908	Q1	211.7	0.05
65908	T2	34.3	0.02
65908	2Q1	217.8	0.01
65908	P1	194.1	0.12
65908	L2	38.4	0.07
65908	K2	36.7	0.11
65908	M8	332.2	0.01
65909	M2	108.5	0.44
65909	S2	135.1	0.05
65909	N2	94.1	0.08
65909	K1	279.9	0.07
65909	M4	189.5	0.03
65909	O1	282.4	0.05
65909	M6	120.9	0.03
65909	MK3	174.9	0.01
65909	MN4	158.8	0.01
65909	NU2	94	0.02
65909	MU2	210	0.01
65909	2N2	82.9	0.01
65909	LDA2	114.1	0.01
65909	S1	240.4	0.02
65909	SSA	68.1	0.28
65909	SA	191.3	0.45
65909	Q1	277.5	0.01
65909	T2	121.3	0.01
65909	2Q1	291.3	0.01
65909	P1	269.2	0.02
65909	M3	280.9	0.01
65909	L2	115.8	0.04
65909	2MK3	161.9	0.01
65909	K2	136.4	0.02
65909	MS4	251.7	0.01
65910	M2	130.1	0.4
65910	S2	168.9	0.05
65910	N2	121.6	0.07
65910	K1	286.2	0.07
65910	M4	219.2	0.04
65910	O1	294.7	0.05
65910	M6	184.8	0.05
65910	NU2	123	0.01
65910	MU2	91.1	0.01
65910	2N2	113.1	0.01
65910	Q1	303.1	0.01
65910	P1	286.1	0.02
65910	L2	139.7	0.01
65910	K2	172.3	0.01
65910	M8	288.8	0.01
65911	M2	164.2	0.4
65911	S2	196.6	0.05
65911	N2	147.2	0.07
65911	K1	309.9	0.07
65911	M4	263	0.01
65911	O1	301.9	0.05
65911	M6	258.9	0.02
65911	S4	221.3	0.01
65911	NU2	149.5	0.01
65911	MU2	131.1	0.01
65911	2N2	128.9	0.01
65911	Q1	296.8	0.01
65911	P1	309.2	0.02
65911	L2	180	0.01
65911	K2	199.1	0.01
65912	M2	168.9	0.41
65912	S2	202.3	0.05
65912	N2	155.4	0.08
65912	K1	302.8	0.07
65912	M4	247.3	0.02
65912	O1	305.6	0.06
65912	M6	233.8	0.03
65912	MK3	234.8	0.01
65912	MN4	221.5	0.01
65912	NU2	146.9	0.02
65912	MU2	298.4	0.01
65912	2N2	114.3	0.01
65912	LDA2	179.1	0.01
65912	S1	252.9	0.02
65912	M1	45.5	0.01
65912	Q1	312.2	0.01
65912	T2	176.3	0.01
65912	P1	295.8	0.02
65912	L2	162.8	0.03
65912	2MK3	227	0.01
65912	K2	196.4	0.01
65912	M8	317.1	0.01
65913	M2	27.8	2.04
65913	S2	50.8	0.31
65913	N2	12.7	0.47
65913	K1	206.5	0.31
65913	M4	171.8	0.01
65913	O1	212.1	0.23
65913	M6	120.9	0.04
65913	MK3	76.4	0.02
65913	S4	286.4	0.02
65913	MN4	196.2	0.01
65913	NU2	8.1	0.1
65913	S6	300.8	0.01
65913	MU2	34	0.05
65913	2N2	345.7	0.06
65913	OO1	232.3	0.01
65913	LDA2	56.5	0.03
65913	S1	162.1	0.04
65913	M1	265.5	0.01
65913	J1	207.9	0.02
65913	MM	100.4	0.16
65913	SSA	14.7	0.29
65913	SA	204.9	0.5
65913	MSF	132.6	0.1
65913	MF	98.4	0.06
65913	RHO1	215	0.01
65913	Q1	209.4	0.05
65913	T2	17.7	0.03
65913	R2	286.3	0.02
65913	2Q1	195.4	0.01
65913	P1	200.9	0.1
65913	M3	179.3	0.01
65913	L2	19.1	0.08
65913	2MK3	76.5	0.02
65913	K2	50.1	0.08
65913	MS4	131.3	0.02
65914	M2	35	2.02
65914	S2	57.9	0.31
65914	N2	20.9	0.45
65914	K1	213.7	0.33
65914	M4	235.9	0.02
65914	O1	217.4	0.23
65914	M6	129.5	0.05
65914	MK3	66.8	0.03
65914	S4	300.5	0.03
65914	MN4	211.7	0.02
65914	NU2	20.7	0.1
65914	S6	322.9	0.01
65914	MU2	57.2	0.06
65914	2N2	353.3	0.04
65914	OO1	250.8	0.01
65914	LDA2	62.6	0.03
65914	S1	186.2	0.03
65914	M1	254.4	0.02
65914	J1	236.8	0.02
65914	RHO1	221.3	0.01
65914	Q1	216.5	0.05
65914	T2	55.9	0.03
65914	R2	326.5	0.03
65914	2Q1	226.3	0.01
65914	P1	209.8	0.11
65914	M3	231.9	0.01
65914	L2	14.3	0.09
65914	2MK3	60.9	0.02
65914	K2	62.9	0.07
65914	MS4	186.4	0.02
65915	M2	14.9	2.23
65915	S2	34.5	0.37
65915	N2	352.4	0.52
65915	K1	195.3	0.34
65915	M4	54.6	0.04
65915	O1	202.4	0.24
65915	M6	90.8	0.02
65915	MK3	123.8	0.01
65915	S4	258.2	0.02
65915	MN4	42.1	0.01
65915	NU2	354.5	0.1
65915	MU2	357.9	0.07
65915	2N2	333.6	0.07
65915	OO1	196	0.01
65915	LDA2	29.2	0.02
65915	S1	193.4	0.03
65915	M1	211.8	0.01
65915	J1	212.1	0.02
65915	SSA	52	0.2
65915	SA	193.3	0.33
65915	RHO1	212.3	0.01
65915	Q1	196.7	0.05
65915	T2	32.6	0.04
65915	R2	265.2	0.02
65915	2Q1	209.5	0.01
65915	P1	192	0.11
65915	2SM2	48.5	0.01
65915	M3	124.8	0.02
65915	L2	49.8	0.07
65915	2MK3	134	0.02
65915	K2	37.2	0.09
65915	MS4	96.5	0.03
65916	M2	207.9	0.52
65916	S2	244.3	0.05
65916	N2	188.4	0.08
65916	K1	315.7	0.07
65916	M4	338.6	0.02
65916	O1	320.3	0.06
65916	M6	340.4	0.03
65916	MK3	316.5	0.01
65916	MN4	312.9	0.01
65916	NU2	189.9	0.02
65916	MU2	333.1	0.02
65916	LDA2	224.9	0.02
65916	S1	290.8	0.01
65916	SSA	55.4	0.25
65916	SA	190.2	0.38
65916	Q1	331.7	0.01
65916	T2	210.8	0.01
65916	P1	305.8	0.02
65916	M3	39.2	0.01
65916	L2	226.8	0.05
65916	2MK3	298	0.01
65916	K2	233.5	0.02
65916	M8	94.5	0.01
65917	M2	54.9	1.88
65917	S2	88	0.27
65917	N2	44.5	0.4
65917	K1	225.1	0.3
65917	M4	1.3	0.09
65917	O1	227.9	0.24
65917	M6	203.9	0.1
65917	MK3	107.5	0.03
65917	S4	16.3	0.02
65917	MN4	338.2	0.04
65917	NU2	31.6	0.1
65917	S6	1.3	0.01
65917	MU2	109.4	0.06
65917	2N2	20.5	0.05
65917	OO1	262.3	0.01
65917	LDA2	44.5	0.05
65917	S1	196.3	0.03
65917	M1	288.3	0.02
65917	J1	258	0.01
65917	MM	74.8	0.19
65917	SSA	14.8	0.27
65917	SA	209	0.42
65917	MSF	148.2	0.02
65917	MF	302.3	0.01
65917	RHO1	226.5	0.01
65917	Q1	221.7	0.05
65917	T2	82.4	0.02
65917	R2	331.4	0.01
65917	2Q1	247.4	0.01
65917	P1	221.8	0.09
65917	2SM2	146.7	0.01
65917	M3	244	0.01
65917	L2	39	0.1
65917	2MK3	95.2	0.03
65917	K2	87.1	0.08
65917	M8	88.7	0.01
65917	MS4	51.3	0.01
65918	M2	25.1	1.69
65918	S2	47.4	0.26
65918	N2	7.3	0.38
65918	K1	215.1	0.28
65918	M4	0.6	0.05
65918	O1	202.6	0.19
65918	M6	137.8	0.03
65918	S4	219.8	0.01
65918	NU2	9.6	0.08
65918	S6	84.2	0.01
65918	MU2	200.4	0.04
65918	2N2	349.4	0.05
65918	OO1	227.6	0.01
65918	LDA2	35.4	0.01
65918	M1	208.9	0.01
65918	J1	221.3	0.02
65918	SSA	52	0.2
65918	SA	193.3	0.33
65918	RHO1	197.2	0.01
65918	Q1	196.4	0.04
65918	T2	46.5	0.02
65918	2Q1	190.2	0.01
65918	P1	214.2	0.09
65918	L2	42.9	0.05
65918	K2	49.2	0.07
65918	M8	11	0.01
65919	M2	104	0.68
65919	S2	139.5	0.08
65919	N2	101.1	0.13
65919	K1	264.1	0.16
65919	M4	89.4	0.04
65919	O1	265.8	0.13
65919	M6	2.2	0.03
65919	MK3	168.7	0.01
65919	MN4	78.6	0.02
65919	NU2	95.3	0.04
65919	MU2	186.2	0.04
65919	2N2	46.3	0.01
65919	LDA2	108.3	0.03
65919	S1	244	0.03
65919	M1	341.1	0.01
65919	MM	79.2	0.19
65919	SSA	22.6	0.28
65919	SA	206.9	0.48
65919	MSF	82	0.1
65919	MF	113	0.07
65919	RHO1	263.3	0.01
65919	Q1	260.3	0.03
65919	T2	134.5	0.01
65919	R2	32.9	0.01
65919	P1	257.6	0.05
65919	2SM2	299.3	0.01
65919	L2	93.9	0.05
65919	2MK3	156.6	0.01
65919	K2	131.6	0.02
65919	MS4	134.1	0.01
65920	M2	242.9	0.53
65920	S2	284.1	0.06
65920	N2	227.3	0.09
65920	K1	333.6	0.06
65920	M4	82.5	0.06
65920	O1	340.4	0.04
65920	M6	170.4	0.05
65920	MK3	13.5	0.01
65920	MN4	62.7	0.02
65920	NU2	225.2	0.03
65920	MU2	355.6	0.02
65920	2N2	189	0.01
65920	LDA2	261.5	0.01
65920	S1	338.8	0.01
65920	M1	74.6	0.01
65920	MM	128.2	0.15
65920	SSA	13.2	0.37
65920	SA	212.6	0.62
65920	MSF	122	0.06
65920	MF	113.1	0.04
65920	Q1	357.8	0.01
65920	T2	212.6	0.01
65920	P1	355.9	0.01
65920	2SM2	87.2	0.01
65920	M3	101.9	0.01
65920	L2	250.4	0.04
65920	2MK3	4.4	0.02
65920	K2	270.5	0.02
65920	M8	355.1	0.01
65920	MS4	132.3	0.01
65921	M2	227.3	0.63
65921	S2	265.7	0.07
65921	N2	213.9	0.1
65921	K1	324.7	0.07
65921	M4	37.8	0.05
65921	O1	330.9	0.05
65921	M6	96.7	0.05
65921	MK3	350.7	0.01
65921	MN4	16.3	0.01
65921	NU2	208.1	0.03
65921	MU2	344.3	0.03
65921	2N2	168.8	0.02
65921	LDA2	243.8	0.02
65921	S1	324.7	0.01
65921	M1	61.8	0.01
65921	MM	126.1	0.16
65921	SSA	15.6	0.33
65921	SA	213.2	0.58
65921	MSF	107.3	0.06
65921	MF	104.8	0.04
65921	Q1	343.2	0.01
65921	T2	211.2	0.01
65921	P1	344	0.01
65921	2SM2	69	0.01
65921	M3	76.3	0.01
65921	L2	229.4	0.05
65921	2MK3	340	0.02
65921	K2	257.5	0.02
65921	M8	235.2	0.01
65921	MS4	85.3	0.01
65922	M2	256.9	0.19
65922	S2	279.6	0.02
65922	N2	238.5	0.03
65922	K1	337.2	0.02
65922	M4	136.8	0.04
65922	O1	2	0.02
65922	M6	258.4	0.03
65922	NU2	241	0.01
65922	P1	339	0.01
65922	L2	271.4	0.02
65922	K2	281.3	0.01
65923	M2	10.9	1.95
65923	S2	32.4	0.35
65923	N2	349.6	0.48
65923	K1	196.4	0.33
65923	O1	200.9	0.25
65923	NU2	352.4	0.1
65923	MU2	353.1	0.06
65923	2N2	328.4	0.07
65923	OO1	191.8	0.01
65923	LDA2	20.8	0.01
65923	M1	198.5	0.02
65923	J1	194.2	0.02
65923	SSA	52.4	0.25
65923	SA	197.5	0.34
65923	Q1	197.9	0.05
65923	T2	32.3	0.02
65923	P1	190.7	0.11
65923	L2	31	0.08
65923	K2	33.9	0.07
65924	M2	11.2	1.87
65924	S2	31.8	0.31
65924	N2	349.1	0.44
65924	K1	196.8	0.32
65924	M4	74.7	0.03
65924	O1	201.4	0.24
65924	M6	349.2	0.01
65924	MK3	133.6	0.01
65924	S4	233.6	0.02
65924	MN4	64.6	0.01
65924	NU2	345.7	0.09
65924	S6	206.4	0.01
65924	MU2	355.1	0.06
65924	2N2	332.6	0.06
65924	OO1	205.7	0.02
65924	LDA2	57.3	0.02
65924	S1	157.7	0.03
65924	M1	214.8	0.01
65924	J1	206.5	0.02
65924	SSA	49.2	0.2
65924	SA	195.3	0.32
65924	RHO1	196.2	0.01
65924	Q1	196.2	0.05
65924	T2	12.9	0.03
65924	R2	247.5	0.01
65924	2Q1	155.6	0.01
65924	P1	195.6	0.1
65924	2SM2	43.8	0.01
65924	M3	73.8	0.01
65924	L2	43.5	0.05
65924	2MK3	126.7	0.01
65924	K2	34.8	0.08
65924	MS4	99.2	0.03
65925	M2	21	1.47
65925	S2	48.9	0.22
65925	N2	358.3	0.32
65925	K1	204.3	0.27
65925	M4	82.2	0.01
65925	O1	209.2	0.2
65925	M6	138.8	0.02
65925	S4	258.5	0.01
65925	NU2	351.2	0.06
65925	MU2	10.9	0.04
65925	2N2	335	0.03
65925	OO1	210.4	0.01
65925	LDA2	39.6	0.02
65925	S1	104.4	0.01
65925	M1	225.1	0.01
65925	J1	236	0.01
65925	RHO1	200.5	0.02
65925	Q1	196.1	0.05
65925	T2	0.4	0.02
65925	R2	253.6	0.03
65925	P1	214.1	0.08
65925	2SM2	50.5	0.01
65925	M3	87.9	0.01
65925	L2	50.4	0.04
65925	2MK3	99.5	0.01
65925	K2	43.9	0.06
65925	M8	208.4	0.01
65925	MS4	124.6	0.02
65926	M2	37.1	1.17
65926	S2	58.9	0.14
65926	N2	18.1	0.26
65926	K1	208.4	0.22
65926	M4	327.3	0.03
65926	O1	225.3	0.17
65926	M6	191.6	0.03
65926	S4	310.9	0.01
65926	NU2	20.6	0.05
65926	MU2	15.4	0.03
65926	2N2	359.1	0.03
65926	OO1	191.4	0.01
65926	LDA2	47.2	0.01
65926	M1	216.8	0.01
65926	J1	199.9	0.01
65926	RHO1	232.6	0.01
65926	Q1	233.6	0.03
65926	T2	57.9	0.01
65926	P1	209.6	0.08
65926	L2	56.1	0.03
65926	K2	60.6	0.04
65927	M2	67.2	0.52
65927	S2	93.5	0.07
65927	N2	57.3	0.1
65927	K1	224	0.09
65927	M4	93.8	0.04
65927	O1	232.4	0.08
65927	M6	310.8	0.04
65927	NU2	58.7	0.02
65927	MU2	40.8	0.01
65927	2N2	46.9	0.01
65927	J1	221.2	0.01
65927	Q1	235.6	0.01
65927	P1	224.8	0.03
65927	L2	77.3	0.01
65927	K2	95.8	0.02
65927	M8	359	0.01
65928	M2	115	0.21
65928	S2	147.1	0.03
65928	N2	115.5	0.03
65928	K1	209.1	0.05
65928	M4	182.6	0.02
65928	O1	248.6	0.03
65928	M6	60.9	0.01
65928	NU2	115.5	0.01
65928	MU2	82.9	0.01
65928	Q1	268.2	0.01
65928	P1	212.1	0.02
65928	L2	114.5	0.01
65928	K2	149.7	0.01
65929	M2	7.3	1.69
65929	S2	27	0.26
65929	N2	345.4	0.4
65929	K1	200	0.32
65929	M4	133.2	0.01
65929	O1	206.6	0.25
65929	M6	307.2	0.03
65929	S4	204	0.01
65929	NU2	346.3	0.08
65929	MU2	350.3	0.05
65929	2N2	326.4	0.06
65929	OO1	217.2	0.02
65929	LDA2	27.2	0.02
65929	S1	174.1	0.02
65929	M1	218	0.01
65929	J1	211	0.02
65929	SSA	49.2	0.2
65929	SA	195.3	0.32
65929	RHO1	209.3	0.01
65929	Q1	198.7	0.05
65929	T2	12.5	0.03
65929	R2	231.5	0.01
65929	2Q1	213	0.01
65929	P1	201.6	0.11
65929	M3	49.2	0.01
65929	L2	41.3	0.04
65929	K2	28.8	0.07
65929	MS4	91.3	0.02
65930	M2	5.5	1.74
65930	S2	27.1	0.29
65930	N2	347.5	0.39
65930	K1	201.3	0.35
65930	M4	104	0.01
65930	O1	203.5	0.26
65930	M6	293.9	0.03
65930	S4	232.4	0.02
65930	NU2	341.4	0.09
65930	S6	135	0.02
65930	MU2	345.2	0.06
65930	2N2	336.1	0.06
65930	OO1	199	0.01
65930	LDA2	15.4	0.01
65930	S1	155.1	0.02
65930	M1	202.3	0.02
65930	J1	200.2	0.02
65930	RHO1	204.3	0.01
65930	Q1	198.7	0.07
65930	T2	2.6	0.04
65930	2Q1	205.6	0.01
65930	P1	208.6	0.11
65930	2SM2	15.8	0.02
65930	L2	348.8	0.04
65930	K2	24.9	0.08
65930	MS4	91.4	0.02
65931	M2	7.2	1.63
65931	S2	28.2	0.25
65931	N2	348.6	0.38
65931	K1	201.6	0.33
65931	M4	114.9	0.01
65931	O1	206	0.24
65931	M6	314.1	0.03
65931	S4	220.6	0.01
65931	MN4	124	0.01
65931	NU2	347.6	0.08
65931	S6	135.4	0.01
65931	MU2	346.2	0.05
65931	2N2	335.3	0.06
65931	OO1	228	0.01
65931	LDA2	47.6	0.02
65931	S1	184.5	0.03
65931	M1	251.1	0.02
65931	J1	205.1	0.02
65931	SSA	49.2	0.2
65931	SA	195.3	0.32
65931	RHO1	221.3	0.01
65931	Q1	192	0.06
65931	T2	19.9	0.03
65931	R2	256.4	0.01
65931	P1	200.8	0.11
65931	2SM2	52.6	0.01
65931	M3	28.7	0.01
65931	L2	348.1	0.04
65931	2MK3	143.5	0.01
65931	K2	28.2	0.07
65931	M8	339.4	0.01
65931	MS4	94	0.02
65932	M2	119.8	0.34
65932	S2	165.3	0.03
65932	N2	97.9	0.07
65932	K1	284.4	0.06
65932	M4	165.7	0.02
65932	O1	281.9	0.08
65932	M6	33.5	0.01
65932	NU2	100.5	0.01
65932	MU2	263.7	0.01
65932	2N2	75.3	0.01
65932	J1	285.3	0.01
65932	Q1	280.5	0.01
65932	P1	284.8	0.02
65932	L2	142.1	0.01
65932	K2	167.3	0.01
65933	M2	37.7	0.735
65933	S2	51.3	0.108
65933	N2	11.1	0.167
65933	K1	234.8	0.164
65933	M4	257.5	0.02
65933	O1	245.3	0.144
65933	M6	214	0.01
65933	S4	72	0.003
65933	NU2	14.6	0.033
65933	S6	113.3	0.003
65933	MU2	223.5	0.016
65933	2N2	344.4	0.023
65933	OO1	224.3	0.007
65933	LDA2	44	0.007
65933	M1	240	0.01
65933	J1	229.6	0.013
65933	RHO1	249.8	0.007
65933	Q1	250.5	0.03
65933	T2	50.8	0.007
65933	2Q1	255.7	0.003
65933	P1	235.6	0.056
65933	L2	64.4	0.02
65933	K2	52.4	0.03
65933	M8	358.1	0.003
65934	M2	20.2	0.99
65934	S2	42.2	0.15
65934	N2	356.8	0.23
65934	K1	219.7	0.19
65934	M4	189.7	0.05
65934	O1	232.7	0.16
65934	M6	193.2	0.01
65934	NU2	359.9	0.05
65934	MU2	197.6	0.02
65934	2N2	333.5	0.03
65934	OO1	206.2	0.01
65934	LDA2	30.4	0.01
65934	M1	226	0.01
65934	J1	212.9	0.01
65934	RHO1	238.4	0.01
65934	Q1	239.3	0.03
65934	T2	41.3	0.01
65934	P1	220.7	0.06
65934	L2	43.5	0.03
65934	K2	44	0.04
65935	M2	39.1	0.68
65935	S2	60.9	0.09
65935	N2	11.2	0.16
65935	K1	241.4	0.16
65935	M4	222.2	0.03
65935	O1	252.7	0.14
65935	M6	194.4	0.02
65935	NU2	14.9	0.03
65935	MU2	17.3	0.02
65935	2N2	343.3	0.02
65935	OO1	230.1	0.01
65935	M1	247	0.01
65935	J1	235.8	0.01
65935	RHO1	257.6	0.01
65935	Q1	258.3	0.03
65935	T2	60	0.01
65935	P1	242.3	0.05
65935	L2	67	0.02
65935	K2	62.6	0.03
65936	M2	35.9	1.23
65936	S2	67.3	0.2
65936	N2	18.1	0.28
65936	K1	234.4	0.19
65936	M4	326.6	0.02
65936	O1	245.8	0.16
65936	M6	112.5	0.04
65936	MK3	253.8	0.01
65936	MN4	303.8	0.01
65936	NU2	19.6	0.06
65936	MU2	61.9	0.03
65936	2N2	346.1	0.05
65936	OO1	261.6	0.01
65936	LDA2	21.2	0.02
65936	S1	297.4	0.01
65936	M1	312.9	0.01
65936	J1	238	0.01
65936	SSA	68.4	0.18
65936	SA	204.5	0.26
65936	Q1	254.3	0.03
65936	T2	50	0.03
65936	R2	299.7	0.01
65936	P1	238.8	0.05
65936	L2	53.8	0.05
65936	K2	60.1	0.05
65937	M2	20.1	1.31
65937	S2	47	0.22
65937	N2	358.5	0.31
65937	K1	222.5	0.2
65937	M4	166.6	0.01
65937	O1	236.6	0.16
65937	M6	48	0.01
65937	S4	264.2	0.01
65937	MN4	161	0.01
65937	NU2	357.4	0.06
65937	MU2	10.5	0.04
65937	2N2	342.4	0.05
65937	OO1	229.3	0.01
65937	LDA2	35.2	0.01
65937	S1	308.5	0.01
65937	M1	247.8	0.01
65937	J1	225.5	0.01
65937	SSA	51.6	0.24
65937	SA	190.6	0.44
65937	RHO1	236.7	0.01
65937	Q1	235.5	0.03
65937	T2	28.5	0.02
65937	R2	272.2	0.01
65937	P1	226.8	0.06
65937	M3	45.6	0.01
65937	L2	47.9	0.05
65937	K2	45.1	0.06
65937	MS4	157.3	0.01
65938	M2	58	1.22
65938	S2	92.5	0.2
65938	N2	44.8	0.22
65938	K1	240.1	0.18
65938	M4	53.2	0.07
65938	O1	253	0.15
65938	M6	177.1	0.04
65938	NU2	46.6	0.04
65938	MU2	223.4	0.03
65938	2N2	31.6	0.03
65938	OO1	227.1	0.01
65938	LDA2	74	0.01
65938	M1	246.5	0.01
65938	J1	233.6	0.01
65938	RHO1	258.6	0.01
65938	Q1	259.5	0.03
65938	T2	91.1	0.01
65938	P1	241	0.06
65938	L2	71.2	0.03
65938	K2	95.3	0.06
65938	M8	163.9	0.01
65939	M2	13.8	1.34
65939	S2	35	0.22
65939	N2	354.1	0.31
65939	K1	219	0.19
65939	M4	187	0.01
65939	O1	236.2	0.15
65939	S4	258.5	0.01
65939	MN4	173.5	0.01
65939	NU2	353.1	0.06
65939	MU2	353.4	0.04
65939	2N2	339.3	0.05
65939	OO1	226.6	0.01
65939	LDA2	37.3	0.01
65939	S1	249.1	0.01
65939	M1	253.7	0.01
65939	J1	216.1	0.01
65939	SSA	68.4	0.18
65939	SA	204.5	0.26
65939	RHO1	230.4	0.01
65939	Q1	232.6	0.03
65939	T2	21.9	0.03
65939	R2	251	0.01
65939	P1	219.6	0.06
65939	2SM2	39.4	0.01
65939	M3	36.3	0.01
65939	L2	15.2	0.03
65939	K2	35.1	0.06
65939	MS4	133.3	0.01
65940	M2	67.1	1.16
65940	S2	106.6	0.17
65940	N2	49.4	0.23
65940	K1	251.6	0.17
65940	M4	75.3	0.08
65940	O1	264.7	0.13
65940	M6	239.7	0.04
65940	MK3	306.5	0.02
65940	MN4	50	0.03
65940	NU2	42.8	0.06
65940	MU2	144.7	0.05
65940	2N2	56.1	0.02
65940	OO1	245.9	0.01
65940	LDA2	57	0.03
65940	S1	348.9	0.01
65940	M1	312.7	0.01
65940	J1	257.4	0.01
65940	RHO1	250.1	0.01
65940	Q1	270.7	0.03
65940	T2	90.2	0.03
65940	R2	186.3	0.01
65940	P1	260.2	0.05
65940	L2	45.8	0.09
65940	2MK3	345.7	0.02
65940	K2	94.2	0.05
65940	M8	256.6	0.01
65940	MS4	118.4	0.03
65941	M2	68.5	1.12
65941	S2	108.7	0.17
65941	N2	55.8	0.28
65941	K1	261.8	0.21
65941	M4	95.2	0.08
65941	O1	267.5	0.13
65941	M6	227.4	0.05
65941	NU2	57.5	0.05
65941	MU2	28.4	0.03
65941	2N2	43	0.04
65941	OO1	256	0.01
65941	LDA2	87.1	0.01
65941	M1	264.6	0.01
65941	J1	258.9	0.01
65941	Q1	270.3	0.02
65941	T2	107.1	0.01
65941	P1	262.2	0.07
65941	L2	81.3	0.03
65941	K2	111.9	0.05
65941	M8	240.4	0.02
65942	M2	76.6	1.11
65942	S2	122.2	0.16
65942	N2	62.1	0.24
65942	K1	267.7	0.2
65942	M4	103.1	0.07
65942	O1	276.8	0.12
65942	M6	224	0.03
65942	NU2	64	0.05
65942	MU2	31.1	0.03
65942	2N2	47.5	0.03
65942	OO1	258.5	0.01
65942	LDA2	97.8	0.01
65942	M1	272.2	0.01
65942	J1	263.1	0.01
65942	Q1	281.3	0.02
65942	T2	120.4	0.01
65942	P1	268.4	0.07
65942	L2	91.2	0.03
65942	K2	125.9	0.05
65942	M8	260.7	0.01
65943	M2	75.7	1.03
65943	S2	120.8	0.16
65943	N2	60.9	0.24
65943	K1	267.9	0.19
65943	M4	122.9	0.06
65943	O1	276.8	0.12
65943	M6	166.5	0.01
65943	NU2	62.9	0.05
65943	MU2	30.6	0.03
65943	2N2	46.2	0.03
65943	OO1	259	0.01
65943	LDA2	96.6	0.01
65943	M1	272.3	0.01
65943	J1	263.5	0.01
65943	Q1	281.3	0.02
65943	T2	119	0.01
65943	P1	268.6	0.06
65943	L2	90.5	0.03
65943	K2	124.4	0.04
65944	M2	52.4	1.04
65944	S2	87.5	0.16
65944	N2	37.7	0.2
65944	K1	247.9	0.15
65944	M4	358.2	0.02
65944	O1	264.4	0.11
65944	M6	119.8	0.01
65944	MK3	263.8	0.01
65944	MN4	343.5	0.01
65944	NU2	34.1	0.05
65944	MU2	122.9	0.03
65944	2N2	42.2	0.02
65944	OO1	253	0.01
65944	LDA2	50	0.02
65944	M1	297.3	0.01
65944	J1	254.1	0.01
65944	RHO1	272.6	0.01
65944	Q1	262.3	0.03
65944	T2	106.7	0.03
65944	R2	89.1	0.01
65944	P1	249.7	0.05
65944	M3	65.6	0.01
65944	L2	56.9	0.07
65944	2MK3	340.6	0.01
65944	K2	80.1	0.04
65944	MS4	62.8	0.01
65945	M2	32.9	1.14
65945	S2	65.5	0.24
65945	N2	12.1	0.25
65945	K1	233.3	0.13
65945	M4	340.8	0.02
65945	O1	257	0.11
65945	M6	88.7	0.02
65945	MK3	228.5	0.01
65945	MN4	301.5	0.01
65945	NU2	15.6	0.03
65945	MU2	64.9	0.03
65945	2N2	341	0.04
65945	OO1	245.7	0.01
65945	LDA2	352.6	0.01
65945	S1	225.5	0.03
65945	J1	239.8	0.01
65945	Q1	257.7	0.03
65945	T2	52.1	0.05
65945	R2	273.2	0.05
65945	P1	257.1	0.04
65945	M3	79.1	0.01
65945	L2	59.6	0.04
65945	K2	38.9	0.06
65945	MS4	52	0.01
65946	M2	15.7	1.26
65946	S2	36.6	0.26
65946	N2	352.1	0.31
65946	K1	219.7	0.16
65946	M4	208.4	0.01
65946	O1	250.8	0.12
65946	MK3	166.7	0.01
65946	S4	266.2	0.01
65946	MN4	181.2	0.01
65946	NU2	351.5	0.06
65946	MU2	0	0.04
65946	2N2	344.3	0.04
65946	OO1	210.6	0.01
65946	LDA2	70.3	0.01
65946	S1	44.1	0.02
65946	M1	236.5	0.01
65946	J1	189.6	0.01
65946	SSA	68.4	0.18
65946	SA	204.5	0.26
65946	RHO1	226.3	0.01
65946	Q1	246.7	0.03
65946	T2	37.5	0.04
65946	R2	98.4	0.02
65946	P1	243.1	0.05
65946	2SM2	66.4	0.01
65946	M3	56.5	0.01
65946	L2	48.2	0.05
65946	2MK3	133.1	0.01
65946	K2	41.5	0.08
65946	MS4	167.7	0.01
65947	M2	20	1.23
65947	S2	45.5	0.22
65947	N2	357.5	0.29
65947	K1	231.8	0.15
65947	M4	161.3	0.02
65947	O1	254	0.11
65947	S4	257.2	0.01
65947	MN4	169.7	0.01
65947	NU2	2.2	0.05
65947	MU2	359.2	0.04
65947	2N2	342.4	0.05
65947	OO1	212.2	0.01
65947	LDA2	47.7	0.01
65947	S1	265.1	0.01
65947	M1	228.2	0.01
65947	J1	227	0.01
65947	SSA	58.3	0.18
65947	SA	190.6	0.27
65947	RHO1	246.3	0.01
65947	Q1	260.9	0.03
65947	T2	30	0.02
65947	R2	232.6	0.01
65947	P1	233.3	0.04
65947	2SM2	46.4	0.01
65947	M3	43.9	0.01
65947	L2	51.1	0.04
65947	K2	47.3	0.06
65947	MS4	159.2	0.01
65948	M2	19.6	1.22
65948	S2	46.7	0.23
65948	N2	357.4	0.28
65948	K1	237.8	0.14
65948	M4	202.7	0.02
65948	O1	262.3	0.11
65948	MN4	190.9	0.01
65948	NU2	359.9	0.06
65948	MU2	355.7	0.04
65948	2N2	336.9	0.04
65948	OO1	213.2	0.01
65948	LDA2	32.2	0.01
65948	M1	250	0.01
65948	J1	225.6	0.01
65948	SSA	46.2	0.2
65948	SA	193.7	0.25
65948	MF	349	0.04
65948	Q1	274.4	0.02
65948	T2	45.5	0.01
65948	P1	235.2	0.04
65948	L2	41.7	0.04
65948	K2	44.4	0.06
65949	M2	41	1.06
65949	S2	72.7	0.19
65949	N2	24.5	0.23
65949	K1	259.7	0.11
65949	M4	323.1	0.01
65949	O1	284.1	0.09
65949	M6	169	0.04
65949	MK3	266.1	0.01
65949	S4	315.7	0.01
65949	MN4	289.5	0.01
65949	NU2	11.6	0.05
65949	MU2	52	0.03
65949	2N2	3.3	0.03
65949	OO1	262	0.01
65949	LDA2	56.4	0.02
65949	J1	245.1	0.01
65949	SSA	58.3	0.18
65949	SA	190.6	0.27
65949	RHO1	288.7	0.01
65949	Q1	285	0.02
65949	T2	63.5	0.02
65949	P1	257.5	0.03
65949	L2	19.8	0.05
65949	K2	69.9	0.05
65950	M2	20.4	1.22
65950	S2	44.5	0.25
65950	N2	0.8	0.28
65950	K1	244.8	0.14
65950	O1	268.7	0.11
65950	NU2	3.4	0.05
65950	MU2	356.7	0.04
65950	2N2	341.2	0.04
65950	SSA	68.7	0.2
65950	SA	198.8	0.29
65950	Q1	280.5	0.02
65950	T2	44.4	0.01
65950	P1	248.4	0.04
65950	L2	23.2	0.03
65950	K2	56.4	0.07
65951	M2	25.8	1.13
65951	S2	53.3	0.21
65951	N2	7.4	0.26
65951	K1	250.5	0.12
65951	M4	143.3	0.05
65951	O1	277.6	0.1
65951	M6	130.6	0.01
65951	MN4	143.1	0.02
65951	NU2	3.7	0.05
65951	MU2	10.3	0.03
65951	2N2	346.5	0.03
65951	OO1	223.3	0.01
65951	LDA2	42.1	0.01
65951	M1	264	0.01
65951	J1	237.1	0.01
65951	SSA	58.3	0.18
65951	SA	190.6	0.27
65951	Q1	276.3	0.03
65951	T2	35.2	0.02
65951	P1	248.4	0.04
65951	L2	8.1	0.04
65951	K2	54	0.06
65951	MS4	166.9	0.03
65952	M2	41	0.98
65952	S2	71.3	0.17
65952	N2	21.5	0.22
65952	K1	263.2	0.1
65952	M4	69.5	0.02
65952	O1	288.4	0.09
65952	M6	169.4	0.04
65952	MK3	275.3	0.01
65952	NU2	17.6	0.05
65952	MU2	45.5	0.02
65952	2N2	6.3	0.03
65952	LDA2	64.5	0.01
65952	M1	275.7	0.01
65952	J1	250.6	0.01
65952	SSA	58.3	0.18
65952	SA	190.6	0.27
65952	Q1	298.2	0.02
65952	T2	61.4	0.02
65952	P1	263.1	0.03
65952	L2	51	0.05
65952	K2	68.9	0.05
65952	MS4	112.4	0.01
65953	M2	64.1	0.889
65953	S2	100.2	0.154
65953	N2	44.2	0.184
65953	K1	282.5	0.095
65953	M4	51	0.052
65953	O1	301.7	0.082
65953	M6	217.7	0.039
65953	MK3	289.2	0.016
65953	S4	41.6	0.003
65953	MN4	24.1	0.023
65953	NU2	48.4	0.049
65953	MU2	120.6	0.016
65953	2N2	35.1	0.02
65953	OO1	256.2	0.007
65953	LDA2	57.5	0.023
65953	S1	50.9	0.003
65953	M1	319.2	0.003
65953	J1	146.5	0.003
65953	SSA	86.9	0.21
65953	SA	214.9	0.43
65953	RHO1	348.3	0.003
65953	Q1	298.4	0.02
65953	T2	78.8	0.02
65953	R2	230	0.003
65953	2Q1	315.8	0.007
65953	P1	265.1	0.026
65953	M3	16.5	0.007
65953	L2	78.7	0.049
65953	2MK3	324.5	0.016
65953	K2	88.9	0.043
65953	M8	209.5	0.013
65953	MS4	101	0.02
65954	M2	65.1	0.73
65954	S2	93.4	0.12
65954	N2	48	0.14
65954	K1	285.7	0.1
65954	M4	60.3	0.03
65954	O1	301.6	0.08
65954	M6	219.9	0.01
65954	NU2	50.3	0.03
65954	MU2	36.8	0.02
65954	2N2	31.1	0.02
65954	LDA2	78.1	0.01
65954	M1	293.5	0.01
65954	J1	277.7	0.01
65954	SSA	58.3	0.18
65954	SA	190.6	0.27
65954	Q1	309.4	0.02
65954	T2	92.1	0.01
65954	P1	286.9	0.03
65954	L2	82.1	0.02
65954	K2	95.5	0.03
65955	M2	96.7	0.66
65955	S2	139.5	0.1
65955	N2	82.7	0.14
65955	K1	304.6	0.08
65955	M4	133.3	0.06
65955	O1	317.7	0.07
65955	M6	306.8	0.02
65955	NU2	84.6	0.03
65955	MU2	53.9	0.02
65955	2N2	68.6	0.02
65955	J1	298.1	0.01
65955	SSA	58.3	0.18
65955	SA	190.6	0.27
65955	Q1	324.2	0.01
65955	T2	137.8	0.01
65955	P1	305.6	0.03
65955	L2	110.8	0.02
65955	K2	143	0.03
65955	M8	352.7	0.01
65956	M2	102.7	0.68
65956	S2	140.7	0.1
65956	N2	85.3	0.16
65956	K1	309.5	0.1
65956	M4	140.3	0.07
65956	O1	322.3	0.07
65956	M6	317.1	0.03
65956	NU2	87.6	0.03
65956	MU2	64.6	0.02
65956	2N2	67.5	0.02
65956	M1	315.3	0.01
65956	J1	301.8	0.01
65956	SSA	58.3	0.18
65956	SA	190.6	0.27
65956	Q1	329.4	0.01
65956	T2	139.2	0.01
65956	P1	310.3	0.03
65956	L2	120.2	0.02
65956	K2	143.8	0.03
65956	M8	14.4	0.01
65957	M2	110.1	0.42
65957	S2	148.3	0.07
65957	N2	85	0.08
65957	K1	313	0.05
65957	M4	154.2	0.02
65957	O1	357.7	0.05
65957	M6	350.7	0.01
65957	NU2	87.9	0.02
65957	MU2	72	0.01
65957	2N2	58.4	0.01
65957	SSA	58.3	0.18
65957	SA	190.6	0.27
65957	Q1	19.8	0.01
65957	P1	316.3	0.02
65957	L2	135.7	0.01
65957	K2	151.2	0.02
65958	M2	119.8	0.32
65958	S2	149.6	0.05
65958	N2	100.7	0.06
65958	K1	335.6	0.05
65958	M4	219.6	0.03
65958	O1	344	0.05
65958	M6	335.5	0.01
65958	NU2	103.3	0.01
65958	MU2	90.1	0.01
65958	2N2	80.5	0.01
65958	SSA	58.3	0.18
65958	SA	190.6	0.27
65958	Q1	348.5	0.01
65958	P1	336.3	0.02
65958	L2	138.8	0.01
65958	K2	151.9	0.01
65959	M2	140	0.26
65959	S2	177.1	0.04
65959	N2	123.3	0.04
65959	K1	344.3	0.04
65959	M4	245.1	0.01
65959	O1	6.3	0.03
65959	M6	3.4	0.01
65959	MK3	77.1	0.01
65959	NU2	133.8	0.01
65959	MU2	249.5	0.01
65959	2N2	144.2	0.01
65959	LDA2	126.9	0.01
65959	S1	77.6	0.01
65959	MM	3.3	0.1
65959	SSA	49.1	0.26
65959	SA	204.2	0.23
65959	MSF	22.3	0.09
65959	MF	34.4	0.02
65959	Q1	357.5	0.01
65959	T2	176.9	0.01
65959	P1	328.6	0.01
65959	L2	181.4	0.02
65959	2MK3	103.6	0.01
65959	K2	174.4	0.01
65960	M2	41	0.797
65960	S2	66.3	0.194
65960	N2	22.9	0.171
65960	K1	337.6	0.213
65960	M4	226.2	0.023
65960	O1	338.8	0.236
65960	M6	113.4	0.01
65960	MN4	212.7	0.016
65960	NU2	24.4	0.036
65960	MU2	7.5	0.026
65960	2N2	5	0.023
65960	OO1	336.3	0.01
65960	LDA2	52.7	0.007
65960	S1	356.8	0.016
65960	M1	338.1	0.016
65960	J1	337	0.016
65960	SSA	51.9	0.138
65960	SA	198.7	0.318
65960	MF	356.5	0.039
65960	RHO1	339.3	0.01
65960	Q1	326.4	0.059
65960	T2	66.2	0.01
65960	R2	66.3	0.003
65960	2Q1	339.9	0.007
65960	P1	339.5	0.069
65960	L2	59	0.023
65960	K2	64.7	0.052
65960	MS4	211.6	0.013
65961	M2	164.6	0.18
65961	S2	229	0.05
65961	N2	121	0.02
65961	K1	33.7	0.24
65961	M4	80	0.05
65961	O1	26.8	0.24
65961	M6	56.1	0.02
65961	MK3	264.6	0.03
65961	MN4	71.3	0.02
65961	NU2	175.6	0.01
65961	MU2	359.6	0.03
65961	LDA2	185.8	0.01
65961	S1	139.2	0.01
65961	M1	79.1	0.01
65961	J1	88.2	0.01
65961	MM	359.7	0.04
65961	SSA	79.7	0.13
65961	SA	186.1	0.35
65961	MSF	18.7	0.06
65961	MF	4	0.05
65961	RHO1	14.5	0.01
65961	Q1	16.8	0.06
65961	R2	188.9	0.01
65961	2Q1	13.6	0.01
65961	P1	38.9	0.07
65961	2SM2	67.6	0.01
65961	M3	161.8	0.01
65961	L2	192.1	0.02
65961	2MK3	254.9	0.02
65961	K2	235.8	0.02
65961	MS4	111.1	0.03
65962	M2	97.3	0.34
65962	S2	140.3	0.09
65962	N2	71.8	0.06
65962	K1	21.5	0.27
65962	M4	28	0.05
65962	O1	17.1	0.25
65962	M6	263.2	0.01
65962	S4	47.1	0.01
65962	NU2	75.3	0.01
65962	MU2	250.6	0.01
65962	2N2	46.6	0.01
65962	OO1	25.6	0.01
65962	M1	19.3	0.02
65962	J1	23.5	0.02
65962	RHO1	15.3	0.01
65962	Q1	15	0.05
65962	T2	138.6	0.01
65962	2Q1	12.8	0.01
65962	P1	21.2	0.09
65962	L2	122.9	0.01
65962	K2	143.8	0.03
65963	M2	126.4	0.43
65963	S2	155.5	0.13
65963	N2	112.2	0.08
65963	K1	28.4	0.3
65963	M4	28.2	0.03
65963	O1	22.7	0.25
65963	M6	299.5	0.01
65963	NU2	114.1	0.02
65963	MU2	294	0.01
65963	2N2	98	0.01
65963	OO1	34	0.01
65963	M1	25.5	0.02
65963	J1	31.1	0.02
65963	RHO1	20.3	0.01
65963	Q1	19.9	0.05
65963	T2	154.4	0.01
65963	2Q1	17.1	0.01
65963	P1	27.9	0.1
65963	L2	140	0.01
65963	K2	157.9	0.04
65964	M2	66.9	0.61
65964	S2	88.2	0.17
65964	N2	48.3	0.12
65964	K1	356.1	0.3
65964	M4	250.7	0.03
65964	O1	352.2	0.31
65964	MN4	232.3	0.02
65964	NU2	53.9	0.02
65964	MU2	7.1	0.02
65964	2N2	35.4	0.02
65964	OO1	359.9	0.01
65964	S1	359.2	0.02
65964	M1	354.1	0.02
65964	J1	358.4	0.02
65964	SSA	56.5	0.13
65964	SA	187.8	0.26
65964	MF	354.6	0.04
65964	RHO1	339.3	0.02
65964	Q1	342.1	0.08
65964	T2	73.8	0.01
65964	2Q1	326.8	0.01
65964	P1	358.7	0.1
65964	L2	95.4	0.02
65964	K2	92.4	0.05
65964	MS4	247.5	0.01
65965	M2	48.7	0.57
65965	S2	69.3	0.17
65965	N2	26.6	0.12
65965	K1	348	0.28
65965	M4	229.8	0.02
65965	O1	349.1	0.28
65965	NU2	29.6	0.02
65965	MU2	224.3	0.01
65965	2N2	4.5	0.02
65965	OO1	347	0.01
65965	M1	348.5	0.02
65965	J1	347.5	0.02
65965	SSA	56.5	0.13
65965	SA	187.8	0.26
65965	RHO1	349.5	0.01
65965	Q1	349.6	0.05
65965	T2	68.5	0.01
65965	2Q1	350.1	0.01
65965	P1	348.1	0.09
65965	L2	70.9	0.02
65965	K2	71	0.05
65966	M2	131.6	1.21
65966	S2	146	0.38
65966	N2	120.1	0.22
65966	K1	0.4	0.46
65966	M4	37.1	0.02
65966	O1	354.5	0.43
65966	M6	104	0.01
65966	NU2	121.7	0.04
65966	2N2	108.7	0.03
65966	OO1	6.2	0.02
65966	LDA2	138.1	0.01
65966	M1	357.5	0.03
65966	J1	3.4	0.03
65966	SSA	56.5	0.13
65966	SA	187.8	0.26
65966	RHO1	352	0.02
65966	Q1	351.6	0.08
65966	T2	145.4	0.02
65966	2Q1	348.6	0.01
65966	P1	0	0.15
65966	L2	143.2	0.03
65966	K2	147.1	0.1
65967	M2	78.7	0.45
65967	S2	92	0.15
65967	N2	66.2	0.1
65967	K1	359.5	0.35
65967	M4	250	0.02
65967	O1	354.3	0.36
65967	MN4	220.3	0.01
65967	NU2	82.1	0.02
65967	MU2	37.5	0.01
65967	2N2	62.1	0.01
65967	OO1	353.9	0.01
65967	S1	4.6	0.02
65967	M1	355.7	0.03
65967	J1	29.1	0.02
65967	SSA	56.5	0.13
65967	SA	187.8	0.26
65967	MF	354.6	0.04
65967	RHO1	338.2	0.01
65967	Q1	345.5	0.09
65967	T2	86	0.01
65967	2Q1	334.9	0.01
65967	P1	356.2	0.11
65967	L2	99.1	0.01
65967	K2	86.9	0.04
65967	MS4	233.7	0.01
65968	M2	193.1	1.34
65968	S2	215.2	0.43
65968	N2	183.6	0.22
65968	K1	35.2	0.58
65968	M4	287.5	0.05
65968	O1	25.8	0.46
65968	NU2	184.9	0.04
65968	MU2	171	0.03
65968	2N2	174.8	0.03
65968	OO1	44.1	0.02
65968	LDA2	203.3	0.01
65968	M1	30.4	0.03
65968	J1	39.4	0.04
65968	SA	150.7	0.27
65968	RHO1	21.9	0.02
65968	Q1	21.3	0.09
65968	T2	214.4	0.03
65968	2Q1	16.8	0.01
65968	P1	34.5	0.19
65968	L2	202	0.04
65968	K2	217	0.12
65969	M2	188.8	1.35
65969	S2	211.4	0.43
65969	N2	175.2	0.24
65969	K1	28.1	0.57
65969	M4	285	0.05
65969	O1	26.6	0.49
65969	S4	345.4	0.01
65969	NU2	177	0.05
65969	MU2	166.4	0.03
65969	2N2	161.9	0.03
65969	OO1	29.7	0.02
65969	LDA2	199.3	0.01
65969	M1	27.2	0.03
65969	J1	28.8	0.04
65969	SSA	66.7	0.1
65969	SA	167.9	0.25
65969	RHO1	25.5	0.02
65969	Q1	25.8	0.1
65969	T2	210.5	0.02
65969	2Q1	25.4	0.01
65969	P1	28	0.19
65969	L2	202.2	0.04
65969	K2	213.2	0.11
65970	M2	155.8	0.93
65970	S2	177.5	0.31
65970	N2	139.8	0.19
65970	K1	9	0.5
65970	M4	124.2	0.01
65970	O1	7.7	0.4
65970	M6	108.9	0.01
65970	S4	312.1	0.01
65970	NU2	142	0.04
65970	MU2	134.4	0.02
65970	2N2	124	0.02
65970	OO1	10.1	0.02
65970	LDA2	165.9	0.01
65970	M1	8.3	0.03
65970	J1	9.5	0.03
65970	SSA	66.7	0.1
65970	SA	167.9	0.25
65970	RHO1	7.3	0.02
65970	Q1	7.2	0.08
65970	T2	176.6	0.02
65970	2Q1	6.6	0.01
65970	P1	8.9	0.16
65970	L2	172	0.03
65970	K2	179.2	0.09
65971	M2	170	0.88
65971	S2	184.1	0.27
65971	N2	151.5	0.17
65971	K1	25.2	0.44
65971	M4	146.8	0.02
65971	O1	13.7	0.44
65971	M6	174.8	0.02
65971	NU2	153.9	0.03
65971	MU2	156	0.02
65971	2N2	133.3	0.02
65971	OO1	36.6	0.02
65971	LDA2	176.5	0.01
65971	M1	19.5	0.03
65971	J1	30.9	0.03
65971	SSA	66.7	0.1
65971	SA	167.9	0.25
65971	RHO1	8.9	0.02
65971	Q1	8.1	0.09
65971	T2	183.6	0.01
65971	2Q1	2.2	0.01
65971	P1	24.4	0.14
65971	L2	188.4	0.03
65971	K2	185.3	0.07
65972	M2	201.3	0.86
65972	S2	224.5	0.25
65972	N2	193.2	0.14
65972	K1	45.7	0.37
65972	M4	272.9	0.03
65972	O1	34.8	0.38
65972	M6	250.4	0.02
65972	S4	357.1	0.01
65972	NU2	194.2	0.03
65972	MU2	178.2	0.02
65972	2N2	184.7	0.02
65972	OO1	58.8	0.02
65972	LDA2	212.1	0.01
65972	M1	40.7	0.03
65972	J1	52.2	0.03
65972	SSA	66.7	0.1
65972	SA	167.9	0.25
65972	RHO1	29.8	0.02
65972	Q1	28.9	0.08
65972	T2	223.7	0.02
65972	2Q1	23.7	0.01
65972	P1	44.9	0.12
65972	L2	208.6	0.02
65972	K2	226.4	0.07
65972	M8	314.7	0.01
65973	M2	171.5	0.86
65973	S2	195.8	0.24
65973	N2	160	0.15
65973	K1	32.8	0.4
65973	M4	166.9	0.03
65973	O1	24.7	0.39
65973	M6	174.1	0.02
65973	NU2	161.6	0.03
65973	MU2	147.2	0.02
65973	2N2	148.6	0.02
65973	OO1	40.8	0.02
65973	LDA2	182.8	0.01
65973	M1	28.8	0.03
65973	J1	36.7	0.03
65973	SSA	66.7	0.1
65973	SA	167.9	0.25
65973	RHO1	21.3	0.01
65973	Q1	20.8	0.08
65973	T2	194.8	0.01
65973	2Q1	16.8	0.01
65973	P1	32.3	0.13
65973	L2	183	0.02
65973	K2	197.7	0.06
65974	M2	144.8	0.89
65974	S2	157.1	0.29
65974	N2	130.2	0.18
65974	K1	9.3	0.48
65974	M4	119.8	0.06
65974	O1	3.3	0.44
65974	M6	130.1	0.03
65974	MK3	314.3	0.03
65974	S4	247.3	0.01
65974	MN4	86.4	0.02
65974	NU2	140.6	0.04
65974	MU2	58.4	0.03
65974	2N2	124.5	0.02
65974	OO1	1.3	0.01
65974	LDA2	196.9	0.01
65974	S1	107.9	0.05
65974	M1	40.7	0.02
65974	J1	15.4	0.03
65974	SSA	42.3	0.13
65974	SA	158.5	0.31
65974	MF	342.7	0.03
65974	RHO1	351.9	0.02
65974	Q1	353.4	0.1
65974	T2	148.4	0.02
65974	R2	52.5	0.01
65974	2Q1	342.1	0.02
65974	P1	6.7	0.16
65974	M3	327.8	0.01
65974	L2	181.1	0.03
65974	2MK3	298.5	0.03
65974	K2	150.3	0.09
65974	MS4	141.9	0.02
65975	M2	172.6	0.76
65975	S2	200.3	0.21
65975	N2	161.6	0.13
65975	K1	35.7	0.42
65975	M4	219.5	0.05
65975	O1	22.3	0.39
65975	M6	220.1	0.03
65975	S4	354.6	0.01
65975	NU2	163.1	0.03
65975	S6	325.2	0.01
65975	MU2	144.9	0.02
65975	2N2	150.6	0.02
65975	OO1	49.1	0.02
65975	LDA2	185.5	0.01
65975	M1	29.1	0.03
65975	J1	42.3	0.03
65975	SSA	66.7	0.1
65975	SA	167.9	0.25
65975	RHO1	16.6	0.01
65975	Q1	15.7	0.08
65975	T2	199.2	0.01
65975	2Q1	9.1	0.01
65975	P1	34.7	0.14
65975	L2	183.6	0.02
65975	K2	202.6	0.06
65975	M8	256	0.01
65976	M2	175.5	0.78
65976	S2	199.3	0.2
65976	N2	165.9	0.13
65976	K1	34.9	0.43
65976	M4	204.7	0.05
65976	O1	23.2	0.41
65976	M6	213	0.03
65976	S4	11.1	0.01
65976	NU2	167.2	0.03
65976	S6	338.3	0.01
65976	MU2	151.7	0.02
65976	2N2	156.4	0.02
65976	OO1	46.5	0.02
65976	LDA2	186.6	0.01
65976	M1	29.1	0.03
65976	J1	40.7	0.03
65976	SSA	66.7	0.1
65976	SA	167.9	0.25
65976	RHO1	18.2	0.02
65976	Q1	17.5	0.08
65976	T2	198.4	0.01
65976	2Q1	11.7	0.01
65976	P1	34	0.14
65976	L2	185.1	0.02
65976	K2	201.3	0.05
65976	M8	212	0.01
65977	M2	178	0.66
65977	S2	182.4	0.24
65977	N2	170.7	0.12
65977	K1	37.9	0.39
65977	M4	241	0.04
65977	O1	32.4	0.39
65977	M6	250.3	0.02
65977	MK3	100.8	0.04
65977	S4	337	0.02
65977	MN4	234	0.01
65977	NU2	173.4	0.02
65977	S6	132.2	0.01
65977	MU2	317.4	0.01
65977	OO1	44.1	0.02
65977	LDA2	183	0.01
65977	S1	189.9	0.04
65977	M1	95.7	0.02
65977	J1	34.1	0.03
65977	SSA	66.7	0.1
65977	SA	167.9	0.25
65977	RHO1	144.7	0.01
65977	Q1	30.7	0.1
65977	T2	278.8	0.02
65977	R2	130.8	0.07
65977	2Q1	45	0.01
65977	P1	46.7	0.12
65977	2SM2	2.4	0.01
65977	M3	340.7	0.01
65977	L2	180	0.04
65977	2MK3	113.5	0.05
65977	K2	201.2	0.06
65977	MS4	281.8	0.02
65978	M2	206.7	0.6
65978	S2	251.8	0.1
65978	N2	196.7	0.09
65978	K1	63.5	0.37
65978	M4	342.3	0.02
65978	O1	53.6	0.35
65978	M6	303.3	0.01
65978	NU2	198	0.02
65978	S6	46	0.01
65978	MU2	161.5	0.01
65978	2N2	186.7	0.01
65978	OO1	73.4	0.02
65978	M1	58.6	0.03
65978	J1	68.4	0.03
65978	SSA	66.7	0.1
65978	SA	167.9	0.25
65978	RHO1	49.4	0.01
65978	Q1	48.7	0.07
65978	T2	250	0.01
65978	2Q1	43.8	0.01
65978	P1	62.8	0.12
65978	L2	216.6	0.02
65978	K2	255.5	0.03
65979	M2	162.7	0.66
65979	S2	207.9	0.17
65979	N2	154.9	0.13
65979	K1	28.4	0.37
65979	M4	183.9	0.03
65979	O1	20.4	0.39
65979	M6	201.3	0.03
65979	MK3	30	0.02
65979	S4	313.3	0.02
65979	MN4	130.3	0.01
65979	NU2	152.4	0.04
65979	S6	106.6	0.01
65979	MU2	18	0.01
65979	2N2	125.7	0.01
65979	OO1	26.5	0.03
65979	LDA2	203.7	0.03
65979	S1	160.4	0.06
65979	M1	279.8	0.01
65979	J1	4	0.03
65979	SSA	66.7	0.1
65979	SA	167.9	0.25
65979	RHO1	83.3	0.02
65979	Q1	22.6	0.08
65979	T2	90.3	0.06
65979	R2	2.5	0.1
65979	2Q1	13.3	0.02
65979	P1	39.7	0.11
65979	M3	2.2	0.01
65979	L2	171.8	0.04
65979	2MK3	42	0.02
65979	K2	209.7	0.11
65979	MS4	215	0.02
65980	M2	157.8	0.48
65980	S2	170.2	0.17
65980	N2	149.5	0.11
65980	K1	27.5	0.41
65980	M4	264.3	0.02
65980	O1	18.1	0.41
65980	M6	93.2	0.01
65980	NU2	150.5	0.02
65980	MU2	145.2	0.01
65980	2N2	141.2	0.01
65980	OO1	36.8	0.02
65980	M1	22.9	0.03
65980	J1	32.1	0.03
65980	SSA	66.7	0.1
65980	SA	167.9	0.25
65980	RHO1	14.3	0.02
65980	Q1	13.5	0.08
65980	T2	169.7	0.01
65980	2Q1	9	0.01
65980	P1	26.8	0.13
65980	L2	166.3	0.01
65980	K2	171.2	0.05
65981	M2	256.9	0.36
65981	S2	275.7	0.1
65981	N2	244	0.06
65981	K1	95	0.29
65981	M4	66.5	0.02
65981	O1	86.8	0.26
65981	MK3	270.1	0.04
65981	NU2	255.8	0.02
65981	MU2	73.4	0.03
65981	2N2	231.3	0.01
65981	OO1	103.1	0.01
65981	LDA2	271.8	0.01
65981	S1	174.8	0.06
65981	M1	148.6	0.01
65981	J1	99	0.02
65981	MM	2.1	0.06
65981	SA	150.7	0.27
65981	MSF	6.7	0.05
65981	RHO1	53.8	0.01
65981	Q1	82.8	0.05
65981	T2	274.8	0.01
65981	R2	249.2	0.01
65981	2Q1	78.6	0.01
65981	P1	101.5	0.08
65981	L2	270.4	0.03
65981	2MK3	256.8	0.04
65981	K2	267.6	0.06
65981	MS4	104.7	0.01
65982	M2	189.2	0.36
65982	S2	190.7	0.1
65982	N2	175.5	0.07
65982	K1	52.5	0.39
65982	M4	253.7	0.01
65982	O1	37.1	0.38
65982	NU2	177.4	0.01
65982	MU2	187.3	0.01
65982	2N2	162.4	0.01
65982	OO1	67.6	0.02
65982	M1	44.7	0.03
65982	J1	59.6	0.03
65982	SSA	66.7	0.1
65982	SA	167.9	0.25
65982	RHO1	30.9	0.01
65982	Q1	29.7	0.08
65982	T2	190.4	0.01
65982	2Q1	21.8	0.01
65982	P1	51.3	0.13
65982	L2	203.1	0.01
65982	K2	191.1	0.03
65983	M2	155.9	0.36
65983	S2	158.8	0.13
65983	N2	143.2	0.07
65983	K1	30.1	0.41
65983	M4	71.9	0.02
65983	O1	21.1	0.38
65983	M6	168.6	0.01
65983	NU2	144.9	0.01
65983	MU2	152.9	0.01
65983	2N2	130.4	0.01
65983	OO1	38.9	0.02
65983	M1	25.6	0.03
65983	J1	34.4	0.03
65983	SSA	66.7	0.1
65983	SA	167.9	0.25
65983	RHO1	17.3	0.01
65983	Q1	16.7	0.07
65983	T2	158.5	0.01
65983	2Q1	12.3	0.01
65983	P1	29.4	0.13
65983	L2	168.2	0.01
65983	K2	159	0.04
65984	M2	214.8	0.36
65984	S2	176.4	0.07
65984	N2	208.4	0.06
65984	K1	57.6	0.38
65984	M4	305.7	0.01
65984	O1	48.5	0.36
65984	M6	304.7	0.01
65984	MK3	185	0.01
65984	S4	339	0.01
65984	NU2	213.4	0.02
65984	MU2	43.1	0.03
65984	OO1	193.1	0.01
65984	LDA2	263.5	0.01
65984	S1	225	0.01
65984	M1	116.6	0.03
65984	J1	38.4	0.03
65984	SSA	66.7	0.1
65984	SA	167.9	0.25
65984	RHO1	17.3	0.01
65984	Q1	54.8	0.08
65984	T2	305	0.03
65984	R2	29.8	0.08
65984	2Q1	139.6	0.01
65984	P1	58.6	0.13
65984	M3	343.3	0.01
65984	L2	227.9	0.02
65984	2MK3	193.5	0.02
65984	K2	202.5	0.12
65984	MS4	355.5	0.01
65985	M2	165	0.36
65985	S2	170.3	0.13
65985	N2	156.3	0.07
65985	K1	40.6	0.42
65985	M4	230.5	0.01
65985	O1	31.9	0.34
65985	M6	206.2	0.01
65985	NU2	157.5	0.01
65985	MU2	159.8	0.01
65985	2N2	147.7	0.01
65985	OO1	49.8	0.01
65985	M1	36.4	0.02
65985	J1	45	0.03
65985	SSA	66.7	0.1
65985	SA	167.9	0.25
65985	RHO1	28.5	0.01
65985	Q1	27.6	0.07
65985	T2	169.8	0.01
65985	2Q1	23.8	0.01
65985	P1	40	0.14
65985	L2	173.4	0.01
65985	K2	170.7	0.04
65986	M2	230	0.48
65986	S2	230.8	0.14
65986	N2	215.4	0.1
65986	K1	69.2	0.48
65986	M4	11.1	0.01
65986	O1	62.7	0.37
65986	M6	71.9	0.01
65986	S4	2	0.01
65986	NU2	217.4	0.02
65986	MU2	229.3	0.01
65986	2N2	200.8	0.01
65986	OO1	75.6	0.02
65986	M1	66	0.03
65986	J1	72.4	0.03
65986	SSA	66.7	0.1
65986	SA	167.9	0.25
65986	RHO1	60	0.01
65986	Q1	59.5	0.07
65986	T2	230.7	0.01
65986	2Q1	56.3	0.01
65986	P1	68.7	0.16
65986	L2	244.6	0.01
65986	K2	230.8	0.04
65987	M2	246.3	0.52
65987	S2	261.6	0.11
65987	N2	238.8	0.08
65987	K1	77.2	0.43
65987	M4	39.9	0.02
65987	O1	65.3	0.41
65987	M6	93.6	0.01
65987	MK3	246.1	0.06
65987	S4	75.6	0.01
65987	NU2	220.3	0.02
65987	MU2	28.7	0.05
65987	2N2	61.6	0.03
65987	OO1	105.1	0.02
65987	LDA2	246.9	0.04
65987	S1	178.5	0.15
65987	M1	178.1	0.03
65987	J1	59.9	0.03
65987	SSA	66.7	0.1
65987	SA	167.9	0.25
65987	RHO1	130.4	0.03
65987	Q1	70.3	0.09
65987	T2	243.3	0.03
65987	R2	155.6	0.08
65987	2Q1	79.8	0.02
65987	P1	106.5	0.13
65987	2SM2	73.2	0.01
65987	M3	96.5	0.01
65987	L2	235.4	0.04
65987	2MK3	231.7	0.07
65987	K2	281.5	0.07
65987	MS4	90	0.01
65988	M2	188.9	0.36
65988	S2	205	0.11
65988	N2	184.4	0.07
65988	K1	55.4	0.39
65988	M4	317.8	0.01
65988	O1	48.6	0.37
65988	S4	353.4	0.01
65988	NU2	185	0.01
65988	MU2	174.4	0.01
65988	2N2	180.5	0.01
65988	OO1	62.5	0.02
65988	M1	52.2	0.03
65988	J1	59.2	0.03
65988	SSA	66.7	0.1
65988	SA	167.9	0.25
65988	RHO1	45.7	0.01
65988	Q1	45.1	0.07
65988	T2	204.4	0.01
65988	2Q1	41.3	0.01
65988	P1	54.9	0.13
65988	L2	193.7	0.01
65988	K2	206.4	0.03
65989	M2	282.3	0.48
65989	S2	300.5	0.11
65989	N2	275.1	0.09
65989	K1	99.5	0.37
65989	M4	84.8	0.02
65989	O1	87.3	0.35
65989	M6	174.8	0.01
65989	NU2	276.6	0.02
65989	MU2	264.9	0.01
65989	2N2	266.2	0.01
65989	OO1	115.3	0.01
65989	M1	94.2	0.02
65989	J1	107.7	0.03
65989	SSA	66.7	0.1
65989	SA	167.9	0.25
65989	RHO1	81.5	0.01
65989	Q1	80.4	0.07
65989	T2	298.2	0.01
65989	2Q1	73.8	0.01
65989	P1	98.6	0.12
65989	L2	285.6	0.01
65989	K2	302.1	0.03
65990	M2	117.8	0.56
65990	S2	127.6	0.19
65990	N2	111.8	0.13
65990	K1	8.7	0.49
65990	M4	56.8	0.01
65990	O1	3	0.45
65990	M6	68.6	0.01
65990	MK3	322.2	0.01
65990	S4	199.3	0.01
65990	MN4	67.2	0.01
65990	NU2	113.3	0.02
65990	MU2	66.7	0.02
65990	2N2	91.7	0.02
65990	OO1	23.5	0.02
65990	LDA2	103.9	0.01
65990	S1	91.6	0.09
65990	M1	28	0.02
65990	J1	41.1	0.02
65990	SSA	66.7	0.1
65990	SA	167.9	0.25
65990	RHO1	346.4	0.02
65990	Q1	352	0.09
65990	R2	156.5	0.03
65990	2Q1	354.1	0.01
65990	P1	359.5	0.12
65990	2SM2	116.2	0.01
65990	M3	289.2	0.01
65990	L2	124.9	0.01
65990	2MK3	317.6	0.03
65990	K2	128.8	0.06
65990	MS4	17.2	0.01
65991	M2	130.4	0.54
65991	S2	141.7	0.24
65991	N2	122.1	0.12
65991	K1	20.4	0.47
65991	M4	57.3	0.04
65991	O1	10.6	0.46
65991	MK3	291.4	0.02
65991	NU2	117.5	0.02
65991	MU2	64	0.03
65991	2N2	73.9	0.02
65991	OO1	48.5	0.02
65991	LDA2	282.7	0.01
65991	S1	111.2	0.03
65991	M1	3.4	0.01
65991	J1	28.4	0.03
65991	RHO1	4	0.03
65991	Q1	2.8	0.1
65991	2Q1	14.4	0.01
65991	P1	13.9	0.15
65991	2SM2	107.9	0.01
65991	L2	207.1	0.01
65991	2MK3	289.1	0.02
65991	K2	133.9	0.08
65991	MS4	65.7	0.03
65992	M2	137.3	0.51
65992	S2	152.5	0.2
65992	N2	132.5	0.1
65992	K1	24.3	0.49
65992	M4	63.3	0.02
65992	O1	14.2	0.45
65992	M6	141.4	0.01
65992	MK3	307.9	0.01
65992	MN4	50.7	0.01
65992	NU2	139.3	0.02
65992	MU2	77.5	0.02
65992	2N2	114.2	0.02
65992	OO1	36	0.01
65992	S1	130.5	0.06
65992	M1	357.2	0.01
65992	J1	29.3	0.03
65992	RHO1	351	0.03
65992	Q1	7	0.09
65992	T2	167.4	0.01
65992	2Q1	10.5	0.01
65992	P1	14.2	0.15
65992	M3	303	0.01
65992	L2	176.3	0.01
65992	2MK3	298	0.02
65992	K2	146.4	0.06
65992	MS4	68.4	0.02
65993	M2	172.1	0.53
65993	S2	187	0.18
65993	N2	165.1	0.1
65993	K1	39.8	0.52
65993	M4	155.4	0.01
65993	O1	27.2	0.49
65993	M6	178.9	0.01
65993	MK3	53.1	0.01
65993	NU2	177.7	0.02
65993	MU2	19.1	0.02
65993	2N2	163.3	0.01
65993	OO1	52.2	0.02
65993	LDA2	207.7	0.01
65993	S1	135.7	0.06
65993	M1	46.5	0.02
65993	J1	74.4	0.02
65993	SSA	48.2	0.14
65993	SA	155	0.35
65993	MF	193.2	0.04
65993	RHO1	356.1	0.02
65993	Q1	15.2	0.09
65993	T2	160	0.01
65993	2Q1	5.6	0.02
65993	P1	46.2	0.16
65993	L2	206.1	0.03
65993	2MK3	29.2	0.01
65993	K2	187.8	0.07
65994	M2	226.5	0.41
65994	S2	261.2	0.15
65994	N2	224.3	0.08
65994	K1	62.8	0.5
65994	M4	351.7	0.01
65994	O1	61.8	0.44
65994	M6	284.4	0.01
65994	S4	100	0.01
65994	NU2	224.6	0.01
65994	MU2	27.2	0.01
65994	2N2	222.2	0.01
65994	OO1	63.6	0.02
65994	M1	62.3	0.03
65994	J1	63.2	0.04
65994	RHO1	61.4	0.02
65994	Q1	61.3	0.09
65994	T2	259.8	0.01
65994	2Q1	60.9	0.01
65994	P1	62.8	0.16
65994	L2	229.6	0.01
65994	K2	264	0.04
65995	M2	197	0.57
65995	S2	211.7	0.19
65995	N2	191.3	0.1
65995	K1	49.9	0.55
65995	M4	230.8	0.01
65995	O1	37.7	0.51
65995	MK3	129	0.01
65995	NU2	198.7	0.03
65995	MU2	20.7	0.03
65995	2N2	193.5	0.01
65995	OO1	62	0.02
65995	LDA2	226.2	0.01
65995	S1	138.5	0.06
65995	M1	79.3	0.02
65995	J1	91.1	0.03
65995	SSA	41	0.11
65995	SA	150.8	0.3
65995	RHO1	4.2	0.02
65995	Q1	26.2	0.1
65995	T2	187.1	0.01
65995	2Q1	9.5	0.02
65995	P1	57.6	0.16
65995	L2	219.8	0.04
65995	K2	215	0.08
65996	M2	205.6	0.63
65996	S2	221.5	0.21
65996	N2	193.5	0.1
65996	K1	63.7	0.51
65996	M4	265.4	0.02
65996	O1	42.9	0.48
65996	M6	317.2	0.02
65996	NU2	195.2	0.02
65996	MU2	189.4	0.02
65996	2N2	181.8	0.01
65996	OO1	84.4	0.02
65996	M1	53.3	0.03
65996	J1	73.7	0.04
65996	SSA	41	0.11
65996	SA	150.8	0.3
65996	RHO1	34	0.02
65996	Q1	32.6	0.1
65996	T2	220.8	0.01
65996	2Q1	22.3	0.01
65996	P1	62.1	0.17
65996	L2	218	0.02
65996	K2	222.8	0.06
65997	M2	214.9	0.66
65997	S2	233.9	0.21
65997	N2	209.6	0.1
65997	K1	56.8	0.58
65997	O1	43.9	0.52
65997	MK3	215.8	0.02
65997	NU2	213.4	0.03
65997	MU2	18.5	0.04
65997	2N2	237.1	0.01
65997	OO1	69.7	0.02
65997	LDA2	242.6	0.02
65997	S1	141.5	0.07
65997	M1	100.2	0.02
65997	J1	106.3	0.03
65997	SSA	38.9	0.19
65997	SA	138.5	0.43
65997	MSF	38	0.04
65997	MF	194	0.06
65997	RHO1	1.6	0.02
65997	Q1	35.3	0.1
65997	T2	233	0.01
65997	R2	171.4	0.01
65997	2Q1	3.2	0.01
65997	P1	65.4	0.17
65997	2SM2	98.3	0.01
65997	L2	227.6	0.05
65997	2MK3	203.4	0.03
65997	K2	232.9	0.1
65998	M2	201	0.72
65998	S2	220.6	0.24
65998	N2	191.5	0.13
65998	K1	55.6	0.49
65998	M4	263.3	0.03
65998	O1	41.8	0.52
65998	M6	311.6	0.03
65998	NU2	192.7	0.02
65998	S6	264.6	0.01
65998	MU2	181.2	0.02
65998	2N2	181.5	0.02
65998	OO1	69.8	0.02
65998	LDA2	209.8	0.01
65998	M1	49	0.04
65998	J1	63	0.04
65998	SSA	41	0.11
65998	SA	150.8	0.3
65998	RHO1	36	0.02
65998	Q1	34.8	0.1
65998	T2	219.9	0.01
65998	2Q1	28.3	0.01
65998	P1	54.6	0.16
65998	L2	210	0.02
65998	K2	222.1	0.06
65999	M2	200.4	0.73
65999	S2	217.6	0.25
65999	N2	195.4	0.13
65999	K1	51.7	0.6
65999	M4	264.4	0.04
65999	O1	39.9	0.54
65999	M6	328.6	0.03
65999	MK3	144.6	0.03
65999	MN4	246.3	0.01
65999	NU2	203.5	0.04
65999	MU2	14.1	0.04
65999	2N2	190.4	0.02
65999	OO1	186.1	0.01
65999	LDA2	213.4	0.02
65999	S1	138.7	0.09
65999	M1	117.2	0.02
65999	J1	103.4	0.03
65999	SSA	59.7	0.08
65999	SA	148.9	0.28
65999	RHO1	10.1	0.02
65999	Q1	26.3	0.1
65999	T2	196.3	0.01
65999	2Q1	7.9	0.03
65999	P1	57.7	0.18
65999	2SM2	83.4	0.01
65999	L2	218.2	0.04
65999	2MK3	136.2	0.03
65999	K2	219.1	0.11
65999	MS4	280.4	0.02
66000	M2	123.1	0.81
66000	S2	141	0.31
66000	N2	120.3	0.15
66000	K1	12.4	0.52
66000	M4	76	0.03
66000	O1	3.6	0.5
66000	MK3	331.7	0.01
66000	MN4	51	0.02
66000	NU2	121.6	0.03
66000	2N2	110.1	0.02
66000	OO1	4.7	0.02
66000	LDA2	131.4	0.01
66000	S1	93.8	0.04
66000	M1	15.7	0.02
66000	J1	20.8	0.03
66000	SSA	48.2	0.12
66000	SA	151.9	0.3
66000	RHO1	341.8	0.02
66000	Q1	348	0.1
66000	T2	119.1	0.02
66000	2Q1	340.8	0.02
66000	P1	12.5	0.17
66000	M3	298.6	0.01
66000	L2	143.1	0.02
66000	2MK3	309	0.01
66000	K2	134.6	0.09
66000	MS4	90.5	0.02
66001	M2	242.2	0.68
66001	S2	262	0.25
66001	N2	237.9	0.12
66001	K1	68.7	0.65
66001	M4	17	0.03
66001	O1	57.9	0.53
66001	NU2	238.5	0.03
66001	MU2	58.5	0.02
66001	2N2	233.5	0.02
66001	OO1	78.8	0.02
66001	M1	63.2	0.04
66001	J1	73.5	0.04
66001	RHO1	53.4	0.02
66001	Q1	52.7	0.1
66001	T2	261.2	0.01
66001	2Q1	47.5	0.01
66001	P1	67.8	0.21
66001	L2	246.4	0.02
66001	K2	263.6	0.07
66002	M2	134	0.94
66002	S2	153.1	0.38
66002	N2	127.5	0.16
66002	K1	14.1	0.61
66002	M4	127.3	0.02
66002	O1	5.1	0.47
66002	S4	294.9	0.01
66002	NU2	128.4	0.03
66002	S6	339.1	0.01
66002	MU2	114.8	0.02
66002	2N2	121	0.02
66002	OO1	23.2	0.02
66002	LDA2	142.9	0.01
66002	M1	9.7	0.03
66002	J1	18.6	0.04
66002	SSA	48.2	0.12
66002	SA	151.9	0.3
66002	RHO1	1.3	0.02
66002	Q1	0.7	0.09
66002	T2	152.4	0.02
66002	2Q1	356.2	0.01
66002	P1	13.5	0.2
66002	L2	140.4	0.03
66002	K2	154.7	0.1
66003	M2	193.7	0.85
66003	S2	246.6	0.35
66003	N2	195.9	0.16
66003	K1	38.2	0.54
66003	M4	321.3	0.05
66003	O1	48.5	0.48
66003	M6	160	0.01
66003	S4	53.7	0.03
66003	NU2	195.6	0.03
66003	MU2	141.5	0.02
66003	2N2	198	0.02
66003	OO1	28.7	0.02
66003	LDA2	217.9	0.01
66003	M1	43.6	0.04
66003	J1	33.5	0.04
66003	SSA	48.2	0.12
66003	SA	151.9	0.3
66003	RHO1	52.8	0.02
66003	Q1	53.3	0.09
66003	T2	244.6	0.02
66003	2Q1	58.5	0.01
66003	P1	38.9	0.18
66003	L2	190.8	0.02
66003	K2	250.9	0.1
66004	M2	236.2	0.7
66004	S2	289.4	0.25
66004	N2	236.9	0.09
66004	K1	86.5	0.36
66004	M4	51.2	0.08
66004	O1	76.3	0.39
66004	M6	275.2	0.02
66004	MK3	239.9	0.12
66004	S4	139.3	0.01
66004	MN4	51.4	0.02
66004	NU2	211.7	0.03
66004	MU2	359.8	0.09
66004	2N2	180	0.05
66004	OO1	155	0.03
66004	LDA2	145.4	0.01
66004	S1	188	0.04
66004	M1	191.2	0.03
66004	J1	95	0.03
66004	RHO1	56.6	0.01
66004	Q1	59	0.07
66004	T2	287.2	0.01
66004	2Q1	52.8	0.04
66004	P1	83.6	0.13
66004	2SM2	20.2	0.01
66004	M3	32.7	0.01
66004	L2	259	0.05
66004	2MK3	222.5	0.11
66004	K2	265.6	0.14
66004	MS4	91.1	0.05
66005	M2	328	0.14
66005	S2	358	0.04
66005	N2	333.8	0.02
66005	K1	166.4	0.11
66005	M4	209.8	0.02
66005	O1	143.9	0.13
66005	OO1	188.8	0.01
66005	M1	155.1	0.01
66005	J1	177.5	0.01
66005	RHO1	134.1	0.01
66005	Q1	132.6	0.03
66005	P1	164.6	0.04
66005	K2	0.3	0.01
66006	M2	300.7	0.34
66006	S2	351.6	0.13
66006	N2	290.4	0.04
66006	K1	135.6	0.22
66006	M4	172.8	0.04
66006	O1	125.8	0.26
66006	M6	75.9	0.01
66006	MK3	340.6	0.07
66006	MN4	160.2	0.01
66006	NU2	279.7	0.01
66006	MU2	74.4	0.05
66006	2N2	249.1	0.04
66006	OO1	118.3	0.01
66006	LDA2	256.3	0.01
66006	S1	187.5	0.03
66006	M1	225.3	0.02
66006	J1	182.8	0.01
66006	RHO1	151.8	0.02
66006	Q1	101.8	0.04
66006	T2	349.5	0.01
66006	2Q1	85.1	0.03
66006	P1	135	0.09
66006	2SM2	71.4	0.01
66006	L2	336.7	0.02
66006	2MK3	323.8	0.07
66006	K2	341.5	0.1
66006	MS4	211	0.03
66007	M2	246.2	0.56
66007	S2	290.2	0.17
66007	N2	245.2	0.09
66007	K1	106.2	0.27
66007	M4	77.1	0.07
66007	O1	81.9	0.37
66007	M6	302.4	0.01
66007	S4	173.4	0.01
66007	NU2	245.3	0.02
66007	MU2	175.8	0.01
66007	2N2	244.3	0.01
66007	OO1	130.4	0.02
66007	M1	94	0.03
66007	J1	118.3	0.03
66007	RHO1	71.4	0.01
66007	Q1	69.7	0.07
66007	T2	288.3	0.01
66007	2Q1	57.7	0.01
66007	P1	104.3	0.09
66007	L2	247	0.01
66007	K2	293.8	0.05
66008	M2	336.8	0.17
66008	S2	356.6	0.04
66008	N2	329.9	0.02
66008	K1	165.2	0.13
66008	M4	227.4	0.02
66008	O1	158.2	0.16
66008	MK3	23.4	0.03
66008	MN4	225.5	0.01
66008	MU2	110.2	0.03
66008	OO1	172.1	0.01
66008	S1	202.7	0.03
66008	M1	161.6	0.01
66008	J1	168.7	0.01
66008	RHO1	155.1	0.01
66008	Q1	154.6	0.03
66008	P1	164.6	0.04
66008	2MK3	7.7	0.03
66008	K2	358.2	0.01
66008	MS4	262.9	0.01
66009	M2	334.6	0.19
66009	S2	17.5	0.04
66009	N2	13.7	0.02
66009	K1	161.6	0.12
66009	M4	206.7	0.02
66009	O1	152.4	0.15
66009	OO1	170.6	0.01
66009	M1	157	0.01
66009	J1	166	0.01
66009	RHO1	148.5	0.01
66009	Q1	147.9	0.03
66009	P1	160.8	0.04
66009	K2	21	0.01
66010	M2	248.5	0.59
66010	S2	299.8	0.18
66010	N2	251.9	0.08
66010	K1	101.2	0.27
66010	M4	73.1	0.1
66010	O1	97.6	0.3
66010	M6	273.8	0.02
66010	S4	169.1	0.01
66010	NU2	251.5	0.01
66010	MU2	174.8	0.01
66010	2N2	255.5	0.01
66010	OO1	104.7	0.01
66010	M1	99.3	0.02
66010	J1	102.9	0.02
66010	RHO1	96	0.01
66010	Q1	95.7	0.06
66010	T2	297.6	0.01
66010	2Q1	93.9	0.01
66010	P1	100.8	0.09
66010	L2	245	0.01
66010	K2	304	0.05
66011	M2	204.5	1.24
66011	S2	244.8	0.41
66011	N2	201.8	0.18
66011	K1	55.6	0.45
66011	M4	324.4	0.07
66011	O1	42.6	0.49
66011	M6	289.2	0.01
66011	S4	72.9	0.02
66011	NU2	202.2	0.04
66011	MU2	138.3	0.03
66011	2N2	199.3	0.02
66011	OO1	68.5	0.02
66011	LDA2	223.2	0.01
66011	M1	49	0.04
66011	J1	62	0.04
66011	RHO1	37	0.02
66011	Q1	36.1	0.1
66011	T2	243.2	0.02
66011	2Q1	29.7	0.01
66011	P1	54.5	0.15
66011	L2	207.1	0.03
66011	K2	248.1	0.11
66012	M2	261.2	0.69
66012	S2	311.2	0.23
66012	N2	253.7	0.11
66012	K1	110.3	0.27
66012	M4	86.8	0.08
66012	O1	93.3	0.37
66012	M6	12	0.01
66012	S4	242.3	0.02
66012	NU2	254.7	0.02
66012	MU2	186	0.02
66012	2N2	246.2	0.01
66012	OO1	127.2	0.02
66012	LDA2	284.4	0.01
66012	M1	101.8	0.03
66012	J1	118.7	0.03
66012	RHO1	86	0.01
66012	Q1	84.8	0.07
66012	T2	309.1	0.01
66012	2Q1	76.4	0.01
66012	P1	108.9	0.09
66012	L2	268.7	0.02
66012	K2	315.2	0.06
66013	M2	270.8	0.7
66013	S2	314.8	0.2
66013	N2	276	0.09
66013	K1	96.1	0.27
66013	M4	92.2	0.06
66013	O1	85.1	0.3
66013	M6	114.6	0.01
66013	S4	201.3	0.01
66013	NU2	275.3	0.02
66013	MU2	201.7	0.02
66013	2N2	281.3	0.01
66013	OO1	107	0.01
66013	LDA2	291.1	0.01
66013	M1	90.5	0.02
66013	J1	101.6	0.02
66013	RHO1	80.3	0.01
66013	Q1	79.5	0.06
66013	T2	312.9	0.01
66013	2Q1	74.1	0.01
66013	P1	95.2	0.09
66013	L2	265.5	0.01
66013	K2	318.4	0.06
66014	M2	243.2	0.79
66014	S2	282.7	0.25
66014	N2	241.8	0.11
66014	K1	90.7	0.26
66014	M4	43.9	0.06
66014	O1	68.4	0.36
66014	M6	42.1	0.01
66014	S4	135.5	0.02
66014	NU2	242	0.02
66014	MU2	178.2	0.02
66014	2N2	240.5	0.02
66014	OO1	112.9	0.02
66014	LDA2	261.4	0.01
66014	M1	79.6	0.03
66014	J1	101.8	0.03
66014	SSA	201.2	0.03
66014	SA	280.6	0.11
66014	RHO1	58.8	0.01
66014	Q1	57.2	0.07
66014	T2	281	0.02
66014	2Q1	46.3	0.01
66014	P1	88.9	0.09
66014	L2	244.4	0.02
66014	K2	285.9	0.07
66015	M2	216.5	1
66015	S2	253.6	0.31
66015	N2	212.4	0.15
66015	K1	71.6	0.34
66015	M4	4.5	0.1
66015	O1	54.3	0.4
66015	S4	99.8	0.02
66015	NU2	212.9	0.03
66015	MU2	153.7	0.02
66015	2N2	208.4	0.02
66015	OO1	88.8	0.02
66015	LDA2	233.6	0.01
66015	M1	62.8	0.03
66015	J1	80.2	0.03
66015	SSA	201.2	0.02
66015	SA	280.6	0.09
66015	RHO1	46.8	0.02
66015	Q1	45.6	0.08
66015	T2	252	0.02
66015	2Q1	37	0.01
66015	P1	70.2	0.11
66015	L2	220.4	0.02
66015	K2	256.6	0.08
66016	M2	188.9	1.25
66016	S2	225.7	0.4
66016	N2	181.9	0.22
66016	K1	35	0.55
66016	M4	252.4	0.03
66016	O1	26.9	0.52
66016	M6	195.7	0.01
66016	MK3	169.1	0.02
66016	MN4	229.5	0.01
66016	NU2	181	0.06
66016	MU2	292	0.05
66016	2N2	183.3	0.02
66016	OO1	106.4	0.01
66016	LDA2	233.1	0.03
66016	S1	135	0.02
66016	M1	90.7	0.02
66016	J1	58.6	0.03
66016	SSA	41.1	0.1
66016	SA	140	0.39
66016	RHO1	359.5	0.03
66016	Q1	11.9	0.12
66016	T2	219.8	0.03
66016	R2	51.4	0.05
66016	2Q1	342	0.02
66016	P1	26.9	0.19
66016	2SM2	87.7	0.02
66016	L2	198.6	0.06
66016	2MK3	160.5	0.03
66016	K2	224.1	0.1
66016	MS4	292	0.02
66017	M2	187	1.18
66017	S2	215.3	0.45
66017	N2	181	0.17
66017	K1	32.3	0.48
66017	M4	285.2	0.06
66017	O1	25.5	0.5
66017	M6	212.9	0.01
66017	S4	335.4	0.02
66017	NU2	181.8	0.03
66017	MU2	158.7	0.03
66017	2N2	174.8	0.02
66017	OO1	40.7	0.02
66017	LDA2	200.4	0.01
66017	M1	29.2	0.04
66017	J1	36.6	0.04
66017	SA	136.4	0.31
66017	RHO1	22.3	0.02
66017	Q1	21.8	0.1
66017	T2	214.2	0.03
66017	2Q1	18.6	0.01
66017	P1	31.8	0.16
66017	L2	194	0.03
66017	K2	217.6	0.12
66018	M2	197.7	1.2
66018	S2	221.2	0.51
66018	N2	189.8	0.19
66018	K1	35.3	0.48
66018	M4	5.7	0.05
66018	O1	31.1	0.47
66018	MK3	161.7	0.09
66018	MN4	12.7	0.03
66018	NU2	197.2	0.05
66018	MU2	316.1	0.06
66018	2N2	155.4	0.04
66018	OO1	87.2	0.07
66018	LDA2	195.3	0.03
66018	S1	116.4	0.03
66018	M1	166.3	0.03
66018	SSA	43.3	0.13
66018	SA	135.7	0.38
66018	RHO1	62.8	0.03
66018	Q1	18.1	0.1
66018	T2	185.6	0.06
66018	R2	54.7	0.09
66018	2Q1	353.7	0.03
66018	P1	45.3	0.17
66018	2SM2	2.9	0.03
66018	L2	218.1	0.07
66018	2MK3	144.1	0.06
66018	K2	185.7	0.18
66018	MS4	25.6	0.06
66019	M2	197.9	1.17
66019	S2	224.8	0.49
66019	N2	193.5	0.22
66019	K1	30.8	0.57
66019	O1	27.6	0.5
66019	MK3	132.8	0.04
66019	NU2	246.2	0.04
66019	MU2	308.4	0.02
66019	2N2	189.1	0.03
66019	OO1	33.9	0.02
66019	LDA2	217.5	0.03
66019	S1	109.3	0.09
66019	M1	29.1	0.04
66019	J1	32.4	0.04
66019	SSA	53.6	0.1
66019	SA	138.8	0.33
66019	RHO1	1.5	0.04
66019	Q1	11.8	0.14
66019	T2	162.3	0.04
66019	2Q1	24.3	0.01
66019	P1	34.3	0.15
66019	2SM2	25.9	0.01
66019	M3	220.6	0.02
66019	L2	253	0.05
66019	2MK3	128.1	0.05
66019	K2	212.3	0.12
66019	MS4	42.3	0.01
66020	M2	208.2	1.19
66020	S2	234.3	0.46
66020	N2	203.5	0.21
66020	K1	36.1	0.6
66020	M4	19	0.01
66020	O1	29.6	0.53
66020	MK3	151.4	0.05
66020	NU2	196.7	0.05
66020	MU2	334.2	0.03
66020	2N2	198.9	0.03
66020	OO1	42.5	0.02
66020	LDA2	220.2	0.01
66020	S1	111.8	0.05
66020	M1	32.8	0.04
66020	J1	46.1	0.04
66020	SSA	43.3	0.13
66020	SA	135.7	0.38
66020	RHO1	26.7	0.02
66020	Q1	16.5	0.12
66020	T2	234.2	0.03
66020	R2	201.8	0.03
66020	2Q1	23	0.01
66020	P1	39.6	0.18
66020	2SM2	64.7	0.01
66020	L2	228.6	0.04
66020	2MK3	133.5	0.05
66020	K2	229.2	0.13
66020	MS4	51.7	0.02
66021	M2	200.3	0.84
66021	S2	221.8	0.31
66021	N2	190.1	0.16
66021	K1	29.8	0.56
66021	M4	352	0.02
66021	O1	24	0.52
66021	MK3	115.8	0.01
66021	NU2	191.6	0.03
66021	MU2	57.7	0.03
66021	2N2	180	0.02
66021	OO1	35.5	0.02
66021	LDA2	210.2	0.01
66021	S1	77.5	0.04
66021	M1	26.8	0.04
66021	J1	44.1	0.04
66021	SSA	47.4	0.12
66021	SA	134	0.38
66021	RHO1	21.5	0.02
66021	Q1	1.9	0.12
66021	T2	221.7	0.02
66021	2Q1	18.1	0.01
66021	P1	31.3	0.17
66021	2SM2	96.8	0.02
66021	L2	235.3	0.04
66021	K2	232.8	0.1
66022	M2	209.3	0.68
66022	S2	235	0.27
66022	N2	211.2	0.12
66022	K1	29.5	0.57
66022	M4	1.4	0.02
66022	O1	27	0.5
66022	M6	162	0.01
66022	S4	211.6	0.01
66022	NU2	210.8	0.02
66022	S6	255.1	0.01
66022	MU2	183.7	0.02
66022	2N2	213.3	0.02
66022	OO1	31.8	0.02
66022	M1	28.2	0.03
66022	J1	30.3	0.04
66022	SSA	47.4	0.12
66022	SA	134	0.38
66022	RHO1	26.2	0.02
66022	Q1	25.9	0.1
66022	T2	234	0.02
66022	2Q1	25	0.01
66022	P1	29.3	0.19
66022	L2	207.9	0.02
66022	K2	237.1	0.07
66023	M2	210.6	0.73
66023	S2	231.2	0.3
66023	N2	199.1	0.11
66023	K1	33.1	0.58
66023	M4	345.7	0.03
66023	O1	24.9	0.5
66023	M6	202.3	0.01
66023	S4	66.5	0.01
66023	NU2	200.6	0.02
66023	MU2	190.6	0.02
66023	2N2	185.2	0.01
66023	OO1	41.4	0.02
66023	LDA2	219.9	0.01
66023	M1	29	0.04
66023	J1	37.3	0.04
66023	SSA	47.4	0.12
66023	SA	134	0.38
66023	RHO1	21.3	0.02
66023	Q1	20.8	0.1
66023	T2	230.2	0.02
66023	2Q1	16.8	0.01
66023	P1	32.5	0.19
66023	L2	220	0.02
66023	K2	232.9	0.08
66024	M2	212.5	0.62
66024	S2	240.9	0.23
66024	N2	193.2	0.1
66024	K1	34.1	0.5
66024	M4	27.6	0.02
66024	O1	32.2	0.44
66024	M6	181.4	0.01
66024	S4	125	0.01
66024	NU2	195.9	0.02
66024	S6	32.2	0.01
66024	MU2	184	0.02
66024	2N2	173.4	0.01
66024	OO1	35.8	0.02
66024	M1	33.1	0.03
66024	J1	35	0.04
66024	SSA	28.7	0.12
66024	SA	145.1	0.25
66024	RHO1	31.2	0.02
66024	Q1	31.2	0.09
66024	T2	239.9	0.01
66024	2Q1	30.3	0.01
66024	P1	34	0.16
66024	L2	232	0.02
66024	K2	243.2	0.06
66025	M2	233.8	0.63
66025	S2	256.9	0.22
66025	N2	214.9	0.12
66025	K1	42.6	0.59
66025	M4	76.4	0.01
66025	O1	36.7	0.47
66025	S4	212.7	0.01
66025	NU2	217.7	0.02
66025	MU2	210.4	0.02
66025	2N2	197.3	0.02
66025	OO1	50.9	0.02
66025	M1	40.3	0.03
66025	J1	47.3	0.04
66025	SSA	47.4	0.12
66025	SA	134	0.38
66025	RHO1	33.8	0.02
66025	Q1	33.3	0.09
66025	T2	256.5	0.01
66025	2Q1	29.8	0.01
66025	P1	42.1	0.19
66025	L2	250.8	0.02
66025	K2	258.9	0.06
66026	M2	220.5	0.64
66026	S2	249.4	0.25
66026	N2	205.5	0.12
66026	K1	33.8	0.57
66026	M4	1.2	0.02
66026	O1	31.8	0.46
66026	M6	225.7	0.01
66026	S4	147.3	0.01
66026	NU2	207.8	0.02
66026	S6	63.5	0.01
66026	MU2	191.9	0.01
66026	2N2	189.7	0.02
66026	OO1	35.6	0.02
66026	M1	32.7	0.03
66026	J1	34.6	0.04
66026	SSA	47.4	0.12
66026	SA	134	0.38
66026	RHO1	31.1	0.02
66026	Q1	30.9	0.09
66026	T2	248.3	0.01
66026	2Q1	30.2	0.01
66026	P1	33.7	0.19
66026	L2	236.3	0.02
66026	K2	251.7	0.07
66027	M2	241.1	0.54
66027	S2	254.1	0.19
66027	N2	237	0.1
66027	K1	34.7	0.59
66027	M4	59.2	0.02
66027	O1	37.5	0.44
66027	M6	38.1	0.01
66027	NU2	237.5	0.02
66027	S6	227.7	0.01
66027	MU2	228.1	0.01
66027	2N2	232.8	0.01
66027	OO1	31.9	0.02
66027	M1	36.1	0.03
66027	J1	33.3	0.04
66027	RHO1	38.6	0.02
66027	Q1	38.8	0.09
66027	T2	253.5	0.01
66027	2Q1	40.2	0.01
66027	P1	34.9	0.19
66027	L2	245.2	0.02
66027	K2	255.1	0.05
66028	M2	242.8	0.4
66028	S2	274.6	0.15
66028	N2	247.3	0.08
66028	K1	42.8	0.49
66028	M4	63.3	0.02
66028	O1	36.9	0.44
66028	S4	203.7	0.01
66028	NU2	247.1	0.02
66028	MU2	210.9	0.01
66028	2N2	250.3	0.01
66028	OO1	48.9	0.02
66028	M1	40	0.03
66028	J1	45.9	0.04
66028	RHO1	34.5	0.02
66028	Q1	34	0.09
66028	T2	273.5	0.01
66028	2Q1	30.5	0.01
66028	P1	42.4	0.16
66028	L2	233.9	0.01
66028	K2	277.1	0.04
66029	M2	232.7	0.31
66029	S2	251.4	0.09
66029	N2	201	0.05
66029	K1	37.3	0.45
66029	M4	77.8	0.02
66029	O1	31.4	0.42
66029	S4	151.2	0.01
66029	NU2	202	0.01
66029	MU2	214.4	0.01
66029	OO1	44	0.02
66029	M1	34.6	0.03
66029	J1	40.7	0.03
66029	SSA	28.7	0.12
66029	SA	145.1	0.25
66029	RHO1	28.9	0.02
66029	Q1	28.4	0.08
66029	T2	250.7	0.01
66029	2Q1	25.5	0.01
66029	P1	36.9	0.15
66029	L2	265.1	0.01
66029	K2	252.8	0.02
66030	M2	256.9	0.41
66030	S2	285	0.13
66030	N2	245.1	0.07
66030	K1	52.8	0.44
66030	M4	75	0.02
66030	O1	45.7	0.4
66030	MK3	254.9	0.03
66030	S4	190.8	0.01
66030	MN4	43.9	0.01
66030	NU2	262	0.02
66030	MU2	58.3	0.02
66030	2N2	258.6	0.01
66030	OO1	101.9	0.02
66030	LDA2	293.6	0.01
66030	S1	85.5	0.03
66030	M1	125.4	0.01
66030	J1	81.1	0.02
66030	SSA	45.5	0.16
66030	SA	145.5	0.36
66030	MSF	32.6	0.06
66030	RHO1	16.8	0.02
66030	Q1	30.7	0.09
66030	T2	305.1	0.01
66030	R2	246.7	0.01
66030	2Q1	344.7	0.01
66030	P1	55.6	0.13
66030	2SM2	148.5	0.01
66030	M3	322.3	0.01
66030	L2	263.1	0.02
66030	2MK3	249.2	0.02
66030	K2	258	0.05
66030	MS4	94.6	0.01
66031	M2	273.7	0.42
66031	S2	298.9	0.14
66031	N2	270.6	0.07
66031	K1	59.5	0.49
66031	M4	120.7	0.02
66031	O1	51.7	0.42
66031	S4	207.3	0.01
66031	NU2	271.7	0.01
66031	MU2	248.4	0.01
66031	2N2	262.5	0.01
66031	OO1	66.4	0.02
66031	M1	55.3	0.03
66031	J1	62.3	0.03
66031	SSA	28.7	0.12
66031	SA	145.1	0.25
66031	RHO1	48.9	0.02
66031	Q1	48.1	0.08
66031	T2	297.7	0.01
66031	2Q1	44	0.01
66031	P1	59	0.16
66031	L2	283.5	0.01
66031	K2	300.7	0.04
66032	M2	273	0.28
66032	S2	290.8	0.08
66032	N2	272.8	0.05
66032	K1	65.5	0.37
66032	M4	112.6	0.01
66032	O1	55.8	0.33
66032	MK3	290.1	0.03
66032	MN4	75.5	0.01
66032	NU2	276.6	0.01
66032	MU2	61.2	0.02
66032	2N2	342.9	0.01
66032	OO1	82	0.02
66032	LDA2	308.9	0.02
66032	S1	46.6	0.02
66032	M1	143.5	0.02
66032	J1	79.3	0.02
66032	SSA	28.7	0.12
66032	SA	145.1	0.25
66032	RHO1	21.1	0.01
66032	Q1	53.5	0.08
66032	T2	24	0.01
66032	R2	359.2	0.01
66032	2Q1	5	0.01
66032	P1	80.4	0.12
66032	2SM2	151.8	0.01
66032	M3	346.5	0.01
66032	L2	285	0.02
66032	2MK3	271.2	0.02
66032	K2	267.4	0.05
66032	MS4	135.7	0.01
66033	M2	313.2	0.23
66033	S2	340.3	0.07
66033	N2	301.8	0.04
66033	K1	85.9	0.37
66033	M4	177.4	0.02
66033	O1	76.2	0.32
66033	NU2	305.1	0.01
66033	MU2	287.7	0.01
66033	2N2	289.6	0.01
66033	OO1	95.5	0.01
66033	M1	81	0.02
66033	J1	90.4	0.03
66033	SSA	28.7	0.12
66033	SA	145.1	0.25
66033	RHO1	72.2	0.01
66033	Q1	71.5	0.06
66033	2Q1	67	0.01
66033	P1	85.2	0.12
66033	L2	325.3	0.01
66033	K2	342.5	0.02
66034	M2	303.2	0.312
66034	S2	341.7	0.102
66034	N2	286.7	0.062
66034	K1	63.1	0.44
66034	M4	236.9	0.01
66034	O1	56.9	0.427
66034	M6	349.2	0.007
66034	S4	48.4	0.007
66034	NU2	288.5	0.013
66034	S6	345.7	0.007
66034	MU2	264.9	0.007
66034	2N2	273.9	0.007
66034	OO1	70.3	0.02
66034	LDA2	321.6	0.003
66034	M1	60.3	0.03
66034	J1	67	0.033
66034	SSA	28.7	0.118
66034	SA	145.1	0.246
66034	RHO1	54	0.016
66034	Q1	53.5	0.082
66034	T2	341.2	0.007
66034	2Q1	50.2	0.01
66034	P1	62.6	0.148
66034	L2	320.2	0.01
66034	K2	344.9	0.026
66034	M8	0.8	0.003
66035	M2	21.6	0.04
66035	S2	59.6	0.02
66035	K1	58.3	0.31
66035	M4	346.7	0.03
66035	O1	48.6	0.29
66035	MK3	51.1	0.01
66035	S4	116.6	0.01
66035	MN4	307.4	0.01
66035	MU2	135.8	0.01
66035	2N2	124.4	0.01
66035	OO1	43.6	0.02
66035	S1	118.2	0.01
66035	M1	36.3	0.01
66035	J1	95.3	0.01
66035	SSA	28.7	0.12
66035	SA	145.1	0.25
66035	RHO1	36.3	0.01
66035	Q1	40.4	0.06
66035	R2	71.4	0.01
66035	2Q1	324.6	0.01
66035	P1	58.5	0.1
66035	L2	14.5	0.01
66035	2MK3	41.9	0.01
66035	MS4	3.8	0.01
66036	M2	128.9	0.13
66036	S2	132.7	0.06
66036	N2	142.9	0.03
66036	K1	33.5	0.49
66036	M4	30.5	0.08
66036	O1	23.2	0.46
66036	M6	316.4	0.03
66036	S4	158.1	0.03
66036	MN4	348.6	0.04
66036	NU2	138.6	0.01
66036	S6	284	0.01
66036	MU2	115.3	0.01
66036	2N2	117.1	0.01
66036	OO1	56.1	0.03
66036	S1	143.5	0.03
66036	M1	50.5	0.03
66036	J1	22.7	0.04
66036	SSA	39.8	0.15
66036	SA	152	0.37
66036	RHO1	2.4	0.02
66036	Q1	13.1	0.09
66036	T2	139.2	0.01
66036	2Q1	18.3	0.01
66036	P1	33.1	0.15
66036	K2	110.9	0.02
66036	MS4	48.4	0.05
66037	M2	130.7	0.12
66037	S2	125.9	0.06
66037	N2	140.7	0.03
66037	K1	33.7	0.48
66037	M4	33.8	0.1
66037	O1	21.9	0.46
66037	M6	317.5	0.05
66037	S4	155.3	0.02
66037	NU2	141.5	0.01
66037	S6	340.2	0.02
66037	OO1	45.5	0.02
66037	M1	27.9	0.03
66037	J1	39.5	0.04
66037	RHO1	16.9	0.02
66037	Q1	16.1	0.09
66037	2Q1	10.2	0.01
66037	P1	32.9	0.16
66037	K2	125.5	0.02
66038	M2	167.6	0.11
66038	S2	195.1	0.04
66038	N2	232.7	0.01
66038	K1	60.6	0.51
66038	M4	121.3	0.02
66038	O1	41.1	0.46
66038	M6	12.4	0.02
66038	S4	247.5	0.01
66038	OO1	80.1	0.02
66038	M1	50.9	0.03
66038	J1	70.3	0.04
66038	SSA	45.3	0.15
66038	SA	149.3	0.37
66038	RHO1	32.7	0.02
66038	Q1	31.4	0.09
66038	2Q1	21.8	0.01
66038	P1	59.2	0.17
66038	K2	197.4	0.01
66039	M2	96.4	0.11
66039	S2	98.4	0.06
66039	N2	102.2	0.03
66039	K1	17.6	0.46
66039	M4	324.1	0.07
66039	O1	6.6	0.45
66039	M6	209.3	0.02
66039	S4	105.5	0.01
66039	S6	225.3	0.01
66039	OO1	28.6	0.02
66039	M1	12.1	0.03
66039	J1	23	0.04
66039	SSA	39.8	0.15
66039	SA	152	0.37
66039	RHO1	1.9	0.02
66039	Q1	1.2	0.09
66039	2Q1	355.8	0.01
66039	P1	16.8	0.15
66039	K2	98.4	0.01
66040	M2	136.1	0.1
66040	S2	149.6	0.04
66040	N2	156.3	0.02
66040	K1	34.8	0.47
66040	M4	346	0.01
66040	O1	25.6	0.45
66040	M6	95.3	0.01
66040	MK3	84.7	0.01
66040	OO1	22.6	0.02
66040	S1	164.7	0.02
66040	M1	67.6	0.02
66040	J1	51.4	0.03
66040	SSA	45.3	0.15
66040	SA	149.3	0.37
66040	RHO1	15.8	0.02
66040	Q1	12	0.1
66040	2Q1	346.3	0.01
66040	P1	37.8	0.15
66040	L2	116.5	0.01
66040	2MK3	69	0.01
66040	K2	118.6	0.03
66041	M2	91	0.11
66041	S2	92.9	0.05
66041	N2	104.5	0.02
66041	K1	17.1	0.47
66041	M4	314.1	0.03
66041	O1	9	0.46
66041	M6	71.7	0.01
66041	S4	84.8	0.01
66041	MN4	281.4	0.02
66041	MU2	84.1	0.01
66041	OO1	37.2	0.02
66041	S1	102.1	0.03
66041	M1	39.3	0.01
66041	J1	22.1	0.03
66041	SSA	68.9	0.16
66041	SA	160.7	0.33
66041	MSF	25.9	0.03
66041	RHO1	351.8	0.02
66041	Q1	354.4	0.1
66041	2Q1	334.9	0.01
66041	P1	16.8	0.15
66041	K2	77.9	0.02
66041	MS4	327.1	0.02
66042	M2	170.1	0.02
66042	S2	157	0.01
66042	K1	106.1	0.15
66042	O1	95.9	0.15
66042	OO1	105.4	0.02
66042	S1	126	0.01
66042	M1	118.2	0.01
66042	SSA	43.2	0.16
66042	SA	148.3	0.29
66042	Q1	91.4	0.03
66042	2Q1	15.8	0.01
66042	P1	112.5	0.04
66043	M2	90.3	0.1
66043	S2	97.3	0.05
66043	N2	105.6	0.02
66043	K1	19.1	0.47
66043	M4	318.1	0.03
66043	O1	10.7	0.45
66043	MN4	282.2	0.01
66043	OO1	27.5	0.02
66043	S1	92.3	0.01
66043	M1	14.9	0.03
66043	J1	23.5	0.03
66043	MM	321.5	0.06
66043	SSA	70.1	0.16
66043	SA	160.1	0.31
66043	MSF	218	0.05
66043	MF	13.7	0.04
66043	RHO1	7.1	0.02
66043	Q1	357.8	0.1
66043	2Q1	2.3	0.01
66043	P1	20	0.15
66043	K2	97.2	0.01
66043	MS4	329	0.01
66044	M2	179.5	0.11
66044	S2	214.2	0.03
66044	N2	211.3	0.02
66044	K1	54.3	0.5
66044	M4	94.1	0.01
66044	O1	43.9	0.48
66044	MK3	194.5	0.02
66044	MN4	76.8	0.01
66044	NU2	163.8	0.01
66044	2N2	186.3	0.03
66044	OO1	50.6	0.04
66044	LDA2	156	0.01
66044	S1	156.2	0.04
66044	M1	59.6	0.03
66044	J1	56.4	0.02
66044	SSA	43.2	0.16
66044	SA	148.3	0.29
66044	RHO1	4.7	0.02
66044	Q1	32.9	0.1
66044	R2	222.7	0.02
66044	2Q1	2.9	0.04
66044	P1	57	0.14
66044	M3	81.8	0.01
66044	L2	194.1	0.01
66044	2MK3	215.2	0.01
66044	K2	206.7	0.05
66044	MS4	101.7	0.01
66045	M2	187.9	0.07
66045	S2	208.8	0.03
66045	N2	173	0.01
66045	K1	68.1	0.47
66045	M4	50.7	0.01
66045	O1	54.3	0.41
66045	OO1	81.3	0.02
66045	M1	61.2	0.03
66045	J1	74.8	0.03
66045	SSA	43.2	0.16
66045	SA	148.3	0.29
66045	RHO1	48.5	0.02
66045	Q1	47.5	0.08
66045	2Q1	40.9	0.01
66045	P1	67	0.15
66045	K2	211.2	0.01
66046	M2	218.2	0.11
66046	S2	249.3	0.08
66046	N2	224.6	0.04
66046	K1	84.8	0.39
66046	M4	203	0.02
66046	O1	63.4	0.42
66046	M6	103.6	0.01
66046	NU2	224	0.01
66046	2N2	230.2	0.01
66046	OO1	105.2	0.02
66046	M1	74	0.03
66046	J1	95.1	0.03
66046	SSA	43.2	0.16
66046	SA	148.3	0.29
66046	RHO1	54	0.02
66046	Q1	53	0.08
66046	T2	248.1	0.01
66046	2Q1	42	0.01
66046	P1	83.2	0.13
66046	K2	251.8	0.02
66047	M2	188	0.12
66047	S2	226.1	0.06
66047	N2	221.9	0.01
66047	K1	61.2	0.53
66047	M4	127.9	0.02
66047	O1	48.3	0.5
66047	MK3	228.3	0.02
66047	S4	329.6	0.01
66047	MN4	98.2	0.02
66047	NU2	192.6	0.01
66047	2N2	179	0.03
66047	OO1	52.5	0.04
66047	LDA2	116.1	0.01
66047	S1	163.8	0.05
66047	M1	72.5	0.03
66047	J1	62.5	0.02
66047	SSA	43.2	0.16
66047	SA	148.3	0.29
66047	RHO1	7.2	0.02
66047	Q1	34.4	0.1
66047	T2	178	0.01
66047	R2	259	0.01
66047	2Q1	18.5	0.02
66047	P1	67	0.16
66047	2SM2	316.4	0.01
66047	L2	164.6	0.01
66047	2MK3	227.3	0.02
66047	K2	202.3	0.05
66047	MS4	143.5	0.01
66048	M2	196.2	0.13
66048	S2	234.9	0.07
66048	N2	228.8	0.02
66048	K1	64.8	0.54
66048	M4	146.4	0.03
66048	O1	51.6	0.5
66048	M6	90.4	0.01
66048	MK3	231	0.02
66048	S4	347.3	0.01
66048	MN4	115.8	0.02
66048	NU2	211.5	0.01
66048	2N2	184.8	0.03
66048	OO1	53.2	0.04
66048	LDA2	128	0.01
66048	S1	167.9	0.05
66048	M1	77.9	0.03
66048	J1	67.2	0.03
66048	SSA	43.2	0.16
66048	SA	148.3	0.29
66048	RHO1	21.9	0.02
66048	Q1	36.9	0.1
66048	T2	173.7	0.01
66048	R2	262.5	0.01
66048	2Q1	27.3	0.02
66048	P1	71	0.16
66048	M3	130.6	0.01
66048	L2	160.3	0.01
66048	2MK3	228.8	0.02
66048	K2	207.4	0.05
66048	MS4	162.9	0.02
66049	M2	193.7	0.08
66049	S2	281.8	0.02
66049	N2	223	0.01
66049	K1	65.4	0.42
66049	M4	78.4	0.01
66049	O1	55.6	0.46
66049	OO1	75.3	0.02
66049	M1	60.5	0.03
66049	J1	70.3	0.04
66049	SSA	43.2	0.16
66049	SA	148.3	0.29
66049	RHO1	51.4	0.02
66049	Q1	50.7	0.09
66049	2Q1	45.8	0.01
66049	P1	64.7	0.14
66050	M2	186.2	0.05
66050	S2	113	0.03
66050	N2	196.5	0.01
66050	K1	64.8	0.39
66050	M4	353.2	0.01
66050	O1	53.7	0.39
66050	OO1	75.9	0.02
66050	M1	59.3	0.03
66050	J1	70.3	0.03
66050	SSA	43.2	0.16
66050	SA	148.3	0.29
66050	RHO1	48.7	0.01
66050	Q1	48.2	0.08
66050	2Q1	42.7	0.01
66050	P1	64	0.13
66050	K2	107.4	0.01
66051	M2	178.6	0.1
66051	S2	203.5	0.04
66051	N2	200.9	0.01
66051	K1	56.7	0.49
66051	M4	52.4	0.01
66051	O1	45.4	0.46
66051	MK3	206.7	0.01
66051	MN4	13.4	0.01
66051	NU2	190.8	0.01
66051	2N2	175.4	0.02
66051	OO1	48.9	0.04
66051	S1	161.6	0.03
66051	M1	70.9	0.03
66051	J1	63.4	0.02
66051	SSA	43.2	0.16
66051	SA	148.3	0.29
66051	RHO1	21.7	0.02
66051	Q1	31.5	0.1
66051	2Q1	18.5	0.02
66051	P1	60.5	0.14
66051	L2	152.3	0.01
66051	2MK3	199	0.01
66051	K2	191.5	0.03
66052	M2	185.4	0.1
66052	S2	203.5	0.05
66052	N2	201.7	0.02
66052	K1	65.4	0.52
66052	M4	31.6	0.01
66052	O1	51.1	0.48
66052	M6	243.1	0.01
66052	OO1	79.6	0.02
66052	M1	58.3	0.03
66052	J1	72.3	0.04
66052	SSA	43.2	0.16
66052	SA	148.3	0.29
66052	RHO1	45.2	0.02
66052	Q1	44	0.09
66052	2Q1	36.9	0.01
66052	P1	64.3	0.17
66052	K2	203.9	0.01
66053	M2	170.3	0.08
66053	S2	163.7	0.03
66053	N2	184.1	0.02
66053	K1	52.2	0.51
66053	O1	42.3	0.5
66053	OO1	29.6	0.05
66053	S1	93.7	0.01
66053	M1	103.2	0.01
66053	J1	78.3	0.02
66053	SSA	43.2	0.16
66053	SA	148.3	0.29
66053	RHO1	22.5	0.02
66053	Q1	30.1	0.11
66053	2Q1	11.6	0.01
66053	P1	54.9	0.15
66053	K2	188	0.03
66054	M2	151.8	0.04
66054	N2	60.4	0.01
66054	K1	98.5	0.24
66054	M4	117.5	0.01
66054	O1	96.8	0.25
66054	M6	276.5	0.01
66054	S4	98	0.01
66054	OO1	100.3	0.01
66054	M1	97.7	0.02
66054	J1	99.4	0.02
66054	RHO1	96.1	0.01
66054	Q1	95.9	0.05
66054	2Q1	95.1	0.01
66054	P1	98.4	0.08
66055	M2	135.7	0.04
66055	S2	136.3	0.02
66055	N2	120.2	0.01
66055	K1	49.2	0.36
66055	M4	321.9	0.02
66055	O1	43.2	0.35
66055	S4	146.1	0.01
66055	OO1	55.3	0.02
66055	M1	46.2	0.03
66055	J1	52.2	0.03
66055	SSA	43.2	0.16
66055	SA	148.3	0.29
66055	RHO1	40.6	0.01
66055	Q1	40.3	0.07
66055	2Q1	37.2	0.01
66055	P1	48.7	0.12
66055	K2	133.8	0.01
66056	M2	175.4	0.02
66056	S2	210.8	0.02
66056	K1	95.7	0.22
66056	O1	94.2	0.23
66056	OO1	97.3	0.01
66056	M1	95	0.02
66056	J1	96.5	0.02
66056	RHO1	93.5	0.01
66056	Q1	93.4	0.04
66056	2Q1	92.6	0.01
66056	P1	95.6	0.07
66056	K2	213.6	0.01
66057	M2	102.1	0.06
66057	S2	128.5	0.05
66057	N2	130.9	0.03
66057	K1	31.5	0.31
66057	M4	307.4	0.03
66057	O1	26.7	0.3
66057	M6	80.5	0.01
66057	S4	149.9	0.01
66057	NU2	127	0.01
66057	OO1	36.3	0.01
66057	M1	29.1	0.02
66057	J1	33.9	0.02
66057	RHO1	24.7	0.01
66057	Q1	24.3	0.06
66057	2Q1	22	0.01
66057	P1	31.1	0.1
66057	K2	130.7	0.01
66057	M8	210.5	0.01
66058	M2	170.6	0.05
66058	S2	222	0.02
66058	N2	207.1	0.01
66058	K1	64.7	0.36
66058	M4	84.4	0.01
66058	O1	55.9	0.38
66058	M6	263.1	0.01
66058	MK3	198.2	0.01
66058	NU2	223.8	0.01
66058	2N2	54.5	0.01
66058	OO1	58.6	0.04
66058	LDA2	143.3	0.01
66058	S1	216.5	0.01
66058	J1	102.8	0.02
66058	SSA	51.3	0.16
66058	SA	156.3	0.26
66058	RHO1	25	0.02
66058	Q1	42.1	0.08
66058	T2	159.9	0.01
66058	P1	57.7	0.1
66058	2MK3	171.3	0.01
66058	K2	201	0.02
66058	MS4	112	0.01
66059	M2	179.8	0.07
66059	S2	207.1	0.03
66059	N2	248.5	0.01
66059	K1	59.6	0.48
66059	M4	105.2	0.01
66059	O1	50.4	0.45
66059	MK3	182	0.02
66059	S4	234	0.01
66059	MN4	80.7	0.01
66059	2N2	323.6	0.02
66059	OO1	47.5	0.04
66059	S1	164.1	0.04
66059	M1	193.7	0.01
66059	J1	127	0.03
66059	SSA	54	0.19
66059	SA	150.6	0.24
66059	RHO1	68.6	0.02
66059	Q1	42.7	0.1
66059	T2	141.7	0.01
66059	R2	210.6	0.01
66059	2Q1	100.3	0.02
66059	P1	54.9	0.14
66059	2MK3	195	0.02
66059	K2	205.5	0.03
66059	MS4	141.4	0.01
66060	M2	159.4	0.059
66060	S2	235.7	0.036
66060	N2	220.1	0.02
66060	K1	60.4	0.518
66060	M4	149.1	0.013
66060	O1	58.3	0.492
66060	M6	303.2	0.007
66060	S4	262.5	0.007
66060	NU2	212	0.003
66060	S6	313.7	0.003
66060	2N2	280.7	0.003
66060	OO1	62.5	0.02
66060	M1	59.4	0.036
66060	J1	61.5	0.039
66060	SSA	54	0.187
66060	SA	150.6	0.236
66060	RHO1	57.4	0.02
66060	Q1	57.3	0.095
66060	T2	232.6	0.003
66060	2Q1	56.3	0.013
66060	P1	60.3	0.171
66060	L2	98.8	0.003
66060	K2	241.9	0.01
66060	M8	23.1	0.003
66061	M2	141.9	0.03
66061	S2	148.8	0.03
66061	N2	273.8	0.02
66061	K1	70.2	0.52
66061	M4	214.6	0.01
66061	O1	67.4	0.5
66061	S4	332	0.01
66061	OO1	73	0.02
66061	M1	68.8	0.04
66061	J1	71.6	0.04
66061	SSA	54	0.19
66061	SA	150.6	0.24
66061	RHO1	66.2	0.02
66061	Q1	66	0.1
66061	2Q1	64.6	0.01
66061	P1	70	0.17
66061	K2	149.3	0.01
66062	M2	132.5	0.05
66062	S2	117.3	0.02
66062	K1	50.6	0.46
66062	O1	41.9	0.45
66062	OO1	56.4	0.04
66062	S1	290	0.01
66062	M1	99.5	0.03
66062	J1	65.9	0.02
66062	SSA	51.3	0.16
66062	SA	156.3	0.26
66062	RHO1	15.7	0.02
66062	Q1	26.6	0.1
66062	2Q1	46.2	0.01
66062	P1	49.9	0.14
66062	K2	222.8	0.02
66063	M2	132.5	0.05
66063	S2	117.3	0.02
66063	K1	50.6	0.46
66063	O1	41.9	0.45
66063	OO1	56.4	0.04
66063	S1	290	0.01
66063	M1	99.5	0.03
66063	J1	65.9	0.02
66063	SSA	51.3	0.16
66063	SA	156.3	0.26
66063	RHO1	15.7	0.02
66063	Q1	26.6	0.1
66063	2Q1	46.2	0.01
66063	P1	49.9	0.14
66063	K2	222.8	0.02
66064	M2	188.7	0.09
66064	S2	294.1	0.07
66064	N2	262.3	0.02
66064	K1	67.2	0.47
66064	M4	199.8	0.01
66064	O1	55	0.54
66064	OO1	79.4	0.02
66064	M1	61.2	0.04
66064	J1	73.2	0.04
66064	SSA	15.7	0.16
66064	SA	156.3	0.26
66064	RHO1	49.8	0.02
66064	Q1	49	0.1
66064	2Q1	43	0.01
66064	P1	66.3	0.15
66064	K2	302.6	0.02
66065	M2	181.5	0.08
66065	S2	290.4	0.04
66065	N2	269.8	0.01
66065	K1	62.7	0.45
66065	M4	150.3	0.01
66065	O1	53.3	0.51
66065	OO1	72.1	0.02
66065	M1	58	0.04
66065	J1	67.3	0.04
66065	SSA	51.3	0.16
66065	SA	156.3	0.26
66065	RHO1	49.3	0.02
66065	Q1	48.6	0.1
66065	2Q1	44	0.01
66065	P1	62	0.15
66065	K2	299.3	0.01
66066	M2	214.9	0.08
66066	S2	209.4	0.06
66066	N2	272.2	0.01
66066	K1	70.3	0.48
66066	M4	181.9	0.02
66066	O1	56.1	0.46
66066	M6	218.3	0.01
66066	OO1	84.4	0.02
66066	M1	63.3	0.03
66066	J1	77.3	0.04
66066	RHO1	50.1	0.02
66066	Q1	49.1	0.09
66066	2Q1	42.1	0.01
66066	P1	69.2	0.16
66066	K2	208.9	0.02
66066	M8	79.5	0.01
66067	M2	214.6	0.08
66067	S2	264.5	0.05
66067	N2	255.8	0.02
66067	K1	70	0.52
66067	M4	202.8	0.01
66067	O1	59.8	0.49
66067	MK3	251.7	0.02
66067	S4	338.7	0.01
66067	MN4	155.4	0.01
66067	2N2	334.6	0.01
66067	OO1	57.2	0.04
66067	S1	211.3	0.07
66067	M1	124.2	0.02
66067	J1	100.8	0.02
66067	SSA	31.7	0.16
66067	SA	128.3	0.35
66067	RHO1	45.9	0.02
66067	Q1	50	0.1
66067	T2	120.6	0.01
66067	R2	262.2	0.01
66067	2Q1	54.7	0.01
66067	P1	73.4	0.14
66067	2MK3	236.1	0.02
66067	K2	230.4	0.04
66068	M2	211.6	0.08
66068	S2	275.5	0.05
66068	N2	267.5	0.02
66068	K1	68.2	0.55
66068	M4	200.1	0.02
66068	O1	71	0.5
66068	S4	12.2	0.01
66068	OO1	65.6	0.02
66068	M1	69.6	0.04
66068	J1	66.9	0.04
66068	RHO1	72.1	0.02
66068	Q1	72.3	0.1
66068	2Q1	72.7	0.01
66068	P1	68.4	0.18
66068	K2	280.8	0.01
66069	M2	260.1	0.08
66069	S2	330.2	0.11
66069	N2	336.4	0.06
66069	K1	102.8	0.55
66069	M4	348.6	0.03
66069	O1	86.8	0.57
66069	NU2	326.2	0.01
66069	2N2	52.7	0.01
66069	OO1	118.8	0.02
66069	M1	94.8	0.04
66069	J1	110.7	0.05
66069	RHO1	79.9	0.02
66069	Q1	78.8	0.11
66069	T2	327.4	0.01
66069	2Q1	70.9	0.02
66069	P1	101.6	0.18
66069	K2	335.9	0.03
66070	M2	153.1	0.08
66070	S2	226.1	0.09
66070	N2	218.2	0.03
66070	K1	45.4	0.46
66070	M4	116.4	0.04
66070	O1	38.5	0.51
66070	S4	274	0.02
66070	NU2	209.5	0.01
66070	OO1	52.3	0.02
66070	M1	41.9	0.04
66070	J1	48.8	0.04
66070	SSA	51.3	0.16
66070	SA	156.3	0.26
66070	RHO1	35.5	0.02
66070	Q1	35	0.1
66070	T2	223.1	0.01
66070	2Q1	31.6	0.01
66070	P1	44.9	0.15
66070	K2	232	0.02
66071	M2	136.7	0.11
66071	S2	168.5	0.08
66071	N2	172.2	0.02
66071	K1	34	0.54
66071	M4	94.5	0.04
66071	O1	29.4	0.49
66071	M6	234	0.01
66071	S4	212.3	0.03
66071	OO1	38.4	0.02
66071	M1	31.7	0.04
66071	J1	36.1	0.04
66071	SSA	51.3	0.16
66071	SA	156.3	0.26
66071	RHO1	27.6	0.02
66071	Q1	27.1	0.1
66071	T2	167.7	0.01
66071	2Q1	24	0.01
66071	P1	33.6	0.18
66071	K2	171.1	0.02
66072	M2	146	0.11
66072	S2	164.8	0.07
66072	N2	177.5	0.03
66072	K1	37.6	0.51
66072	M4	90.5	0.04
66072	O1	31.2	0.48
66072	M6	241.3	0.01
66072	MK3	92.7	0.01
66072	S4	192.7	0.01
66072	MN4	53	0.02
66072	2N2	179.7	0.01
66072	OO1	48	0.02
66072	S1	130.7	0.05
66072	M1	71.9	0.02
66072	J1	48.2	0.03
66072	RHO1	348.6	0.02
66072	Q1	18.9	0.11
66072	T2	128.4	0.01
66072	R2	12.6	0.01
66072	2Q1	353	0.02
66072	P1	35.8	0.15
66072	K2	125.1	0.03
66072	MS4	97.2	0.01
66073	M2	134.4	0.1
66073	S2	143.4	0.05
66073	N2	157.5	0.02
66073	K1	32	0.49
66073	M4	63.7	0.02
66073	O1	23.4	0.48
66073	NU2	155.4	0.01
66073	OO1	40.9	0.02
66073	M1	27.9	0.03
66073	J1	36.4	0.04
66073	RHO1	19.6	0.02
66073	Q1	19.1	0.1
66073	2Q1	14.7	0.01
66073	P1	31.4	0.16
66073	K2	145	0.01
66074	M2	134.9	0.09
66074	S2	155.3	0.06
66074	N2	171.6	0.02
66074	K1	32.4	0.5
66074	M4	72.3	0.03
66074	O1	24.8	0.48
66074	MK3	81.5	0.01
66074	S4	191.6	0.01
66074	MN4	26	0.01
66074	MU2	137.2	0.01
66074	2N2	180.5	0.01
66074	OO1	38.1	0.02
66074	S1	146.6	0.03
66074	M1	53.1	0.02
66074	J1	52.5	0.03
66074	SSA	47.6	0.21
66074	SA	143.6	0.43
66074	RHO1	8.7	0.02
66074	Q1	14.9	0.1
66074	T2	125	0.01
66074	2Q1	358.5	0.02
66074	P1	26.9	0.14
66074	2MK3	63.6	0.01
66074	K2	130.1	0.02
66074	MS4	94.6	0.01
66075	M2	142	0.1
66075	S2	163.5	0.05
66075	N2	202.8	0.03
66075	K1	33.8	0.47
66075	M4	92.5	0.02
66075	O1	28.3	0.51
66075	S4	129.1	0.01
66075	NU2	194.6	0.01
66075	OO1	39.3	0.02
66075	M1	31.1	0.04
66075	J1	36.6	0.04
66075	RHO1	25.9	0.02
66075	Q1	25.6	0.1
66075	2Q1	22.8	0.01
66075	P1	33.4	0.16
66075	K2	165.3	0.01
66075	M8	6.3	0.01
66076	M2	145.6	0.09
66076	S2	167.2	0.06
66076	N2	183.6	0.02
66076	K1	37.1	0.5
66076	M4	92	0.02
66076	O1	29.5	0.47
66076	MK3	108	0.01
66076	S4	211.7	0.01
66076	MN4	42.1	0.01
66076	2N2	191.3	0.01
66076	OO1	41.4	0.02
66076	S1	150.4	0.03
66076	M1	64.3	0.02
66076	J1	50.7	0.03
66076	SSA	40	0.19
66076	SA	141.3	0.38
66076	RHO1	12.6	0.02
66076	Q1	17.4	0.1
66076	T2	112	0.01
66076	2Q1	6.2	0.02
66076	P1	32.8	0.14
66076	2MK3	92.1	0.01
66076	K2	144.7	0.03
66076	MS4	114.4	0.01
66077	M2	170.2	0.07
66077	S2	191.6	0.05
66077	N2	207	0.01
66077	K1	47.8	0.46
66077	M4	121.1	0.02
66077	O1	39.5	0.43
66077	MK3	136.7	0.01
66077	S4	243.7	0.01
66077	MN4	72.2	0.01
66077	2N2	3.8	0.01
66077	OO1	28.2	0.02
66077	S1	217.5	0.02
66077	M1	59.6	0.02
66077	J1	81	0.03
66077	SSA	40	0.19
66077	SA	141.3	0.51
66077	RHO1	35	0.03
66077	Q1	35.9	0.1
66077	2Q1	318.7	0.01
66077	P1	51.5	0.14
66077	2SM2	2.3	0.01
66077	2MK3	89.4	0.01
66077	K2	176.9	0.03
66077	MS4	114.6	0.01
66078	M2	153.1	0.11
66078	S2	179.6	0.07
66078	N2	167.5	0.02
66078	K1	37.6	0.52
66078	M4	104.6	0.03
66078	O1	29.7	0.49
66078	MK3	106.8	0.01
66078	S4	220.5	0.01
66078	MN4	59.9	0.01
66078	NU2	194.2	0.01
66078	MU2	144.9	0.01
66078	2N2	210.1	0.02
66078	OO1	38.5	0.02
66078	LDA2	111.3	0.01
66078	S1	149.7	0.06
66078	M1	87.8	0.01
66078	J1	68.6	0.03
66078	SSA	57.9	0.16
66078	SA	121.9	0.32
66078	RHO1	10.6	0.02
66078	Q1	21.5	0.1
66078	2Q1	0.2	0.03
66078	P1	34.4	0.14
66078	2SM2	231.9	0.01
66078	M3	231	0.01
66078	L2	111.3	0.01
66078	2MK3	84.4	0.01
66078	K2	156.4	0.04
66078	MS4	111.6	0.01
66079	M2	135.5	0.11
66079	S2	185.5	0.07
66079	K1	38.3	0.52
66079	M4	115.9	0.03
66079	O1	26.8	0.53
66079	S4	250.4	0.02
66079	OO1	49.8	0.02
66079	M1	32.6	0.04
66079	J1	44	0.04
66079	RHO1	21.8	0.02
66079	Q1	21.1	0.1
66079	2Q1	15.4	0.01
66079	P1	37.4	0.17
66079	K2	189.6	0.02
66080	M2	181.6	0.14
66080	S2	204.4	0.05
66080	N2	204.9	0.04
66080	K1	56.7	0.54
66080	M4	170.4	0.03
66080	O1	41.9	0.46
66080	M6	284.3	0.01
66080	NU2	200.9	0.01
66080	2N2	230.1	0.01
66080	OO1	71.1	0.02
66080	M1	49.2	0.03
66080	J1	63.7	0.04
66080	SSA	40	0.19
66080	SA	141.3	0.38
66080	RHO1	35.2	0.02
66080	Q1	34.8	0.09
66080	2Q1	28	0.01
66080	P1	55.6	0.18
66080	K2	204.8	0.01
66081	M2	180.3	0.1
66081	S2	210	0.08
66081	N2	219.3	0.03
66081	K1	47.4	0.55
66081	M4	160.5	0.03
66081	O1	39.3	0.55
66081	MK3	158.2	0.02
66081	S4	310	0.01
66081	MN4	134.9	0.01
66081	NU2	268.7	0.01
66081	MU2	143.2	0.01
66081	2N2	144.3	0.02
66081	OO1	53.3	0.06
66081	LDA2	317.7	0.01
66081	S1	182	0.06
66081	M1	98	0.02
66081	J1	38.6	0.03
66081	SSA	40	0.19
66081	SA	141.3	0.38
66081	RHO1	1.1	0.05
66081	Q1	17.7	0.12
66081	T2	159.8	0.01
66081	R2	219.1	0.01
66081	P1	50.3	0.16
66081	2SM2	245.5	0.01
66081	M3	232	0.01
66081	2MK3	134.3	0.01
66081	K2	182.8	0.05
66081	MS4	194.5	0.01
66082	M2	194.4	0.12
66082	S2	208.2	0.11
66082	N2	242.4	0.03
66082	K1	47.7	0.66
66082	M4	166.6	0.03
66082	O1	38.8	0.54
66082	M6	347.8	0.01
66082	S4	343.3	0.01
66082	NU2	235.3	0.01
66082	OO1	57	0.02
66082	M1	43.5	0.04
66082	J1	52.5	0.04
66082	SSA	57.9	0.16
66082	SA	121.9	0.32
66082	RHO1	34.8	0.02
66082	Q1	34.3	0.1
66082	T2	207.5	0.01
66082	2Q1	30.4	0.01
66082	P1	47	0.22
66082	K2	209.3	0.03
66083	M2	181.9	0.1
66083	S2	185.2	0.05
66083	N2	160.4	0.03
66083	K1	49.1	0.49
66083	M4	157.4	0.03
66083	O1	38	0.55
66083	S4	173.4	0.01
66083	NU2	163.3	0.01
66083	OO1	60.3	0.02
66083	M1	43.6	0.04
66083	J1	54.6	0.04
66083	RHO1	33.2	0.02
66083	Q1	32.4	0.1
66083	2Q1	26.9	0.01
66083	P1	48.3	0.16
66083	K2	185.5	0.01
66084	M2	197.9	0.1
66084	S2	221	0.1
66084	N2	256.8	0.03
66084	K1	53	0.63
66084	M4	174.5	0.02
66084	O1	43.7	0.51
66084	M6	344.6	0.01
66084	S4	25.7	0.01
66084	NU2	249	0.01
66084	OO1	62.5	0.02
66084	M1	48.5	0.04
66084	J1	57.9	0.04
66084	RHO1	39.6	0.02
66084	Q1	39.2	0.1
66084	T2	219	0.01
66084	2Q1	34.9	0.01
66084	P1	52.3	0.21
66084	K2	222.9	0.03
66085	M2	182.1	0.12
66085	S2	206.7	0.1
66085	N2	216.9	0.03
66085	K1	45.8	0.56
66085	M4	162.8	0.02
66085	O1	37.7	0.56
66085	MK3	147	0.01
66085	S4	305.5	0.01
66085	MN4	133.9	0.01
66085	NU2	292.6	0.01
66085	MU2	156.4	0.01
66085	2N2	140	0.01
66085	OO1	49.9	0.07
66085	S1	172.4	0.07
66085	M1	94.5	0.02
66085	J1	34.8	0.03
66085	SSA	40.1	0.17
66085	SA	131	0.22
66085	RHO1	0.6	0.05
66085	Q1	16.2	0.12
66085	T2	159.1	0.01
66085	R2	277.4	0.01
66085	P1	46.8	0.16
66085	2SM2	233.1	0.01
66085	M3	217.5	0.01
66085	L2	170.9	0.01
66085	2MK3	129	0.01
66085	K2	178.1	0.04
66085	MS4	202	0.01
66086	M2	189.1	0.11
66086	S2	201.7	0.1
66086	N2	234.7	0.03
66086	K1	45.5	0.66
66086	M4	141.8	0.02
66086	O1	37.3	0.52
66086	M6	265.7	0.01
66086	S4	293.3	0.01
66086	NU2	231.3	0.01
66086	OO1	54.1	0.02
66086	M1	41.5	0.04
66086	J1	49.8	0.04
66086	RHO1	34	0.02
66086	Q1	33.2	0.1
66086	T2	200.3	0.01
66086	2Q1	29.5	0.01
66086	P1	44.9	0.22
66086	K2	202.9	0.03
66087	M2	170.2	0.11
66087	S2	194.5	0.08
66087	N2	195.5	0.02
66087	K1	42.9	0.56
66087	M4	135	0.02
66087	O1	33.2	0.52
66087	MK3	122.5	0.01
66087	S4	255.8	0.01
66087	MN4	93.6	0.01
66087	2N2	217.4	0.01
66087	OO1	28.5	0.02
66087	LDA2	154	0.01
66087	S1	148.1	0.05
66087	M1	62.6	0.02
66087	J1	56.7	0.03
66087	SSA	65.7	0.24
66087	SA	154.2	0.3
66087	RHO1	21.2	0.02
66087	Q1	23.5	0.11
66087	T2	137.7	0.01
66087	2Q1	353.6	0.02
66087	P1	42.2	0.15
66087	2MK3	92	0.01
66087	K2	166.2	0.04
66087	MS4	149.9	0.01
66088	M2	160.3	0.16
66088	S2	185.9	0.09
66088	N2	145.8	0.03
66088	K1	50.1	0.47
66088	M4	132.9	0.03
66088	O1	33.2	0.49
66088	S4	184.9	0.01
66088	NU2	141.7	0.01
66088	OO1	65.7	0.02
66088	M1	40.8	0.03
66088	J1	56.1	0.03
66088	RHO1	26.3	0.02
66088	Q1	25.4	0.09
66088	2Q1	17.8	0.01
66088	P1	48.9	0.16
66088	K2	188.2	0.02
66089	M2	189	0.1
66089	S2	198	0.1
66089	N2	231.4	0.03
66089	K1	44.4	0.65
66089	M4	138.6	0.02
66089	O1	37.1	0.53
66089	S4	305.1	0.01
66089	NU2	223.8	0.01
66089	OO1	52	0.02
66089	M1	40.9	0.04
66089	J1	48.2	0.04
66089	RHO1	34.2	0.02
66089	Q1	33.5	0.1
66089	T2	196.5	0.01
66089	2Q1	30.3	0.01
66089	P1	43.8	0.22
66089	K2	198.8	0.03
66090	M2	175.7	0.13
66090	S2	216	0.11
66090	N2	237.1	0.04
66090	K1	51.5	0.53
66090	M4	185.3	0.02
66090	O1	39.8	0.55
66090	NU2	228.9	0.01
66090	OO1	63.3	0.02
66090	M1	45.7	0.04
66090	J1	57.4	0.04
66090	RHO1	34.7	0.02
66090	Q1	33.9	0.11
66090	T2	214.4	0.01
66090	2Q1	28.1	0.01
66090	P1	50.6	0.18
66090	K2	219.3	0.03
66091	M2	185.5	0.19
66091	S2	202.7	0.09
66091	N2	166	0.05
66091	K1	63.7	0.48
66091	M4	194.4	0.02
66091	O1	41.5	0.48
66091	S4	249.6	0.01
66091	NU2	164.4	0.01
66091	OO1	71.6	0.02
66091	M1	49.5	0.03
66091	J1	65.4	0.03
66091	RHO1	34.5	0.02
66091	Q1	33.2	0.09
66091	2Q1	25.4	0.01
66091	P1	62.2	0.16
66091	K2	204.1	0.02
66092	M2	200.9	0.22
66092	S2	223.4	0.11
66092	N2	178.2	0.06
66092	K1	72.2	0.5
66092	M4	257.9	0.04
66092	O1	47.5	0.48
66092	S4	287.4	0.01
66092	NU2	182.3	0.01
66092	OO1	82.1	0.01
66092	M1	56.9	0.03
66092	J1	75.1	0.03
66092	RHO1	39.6	0.02
66092	Q1	38.3	0.09
66092	T2	220.9	0.01
66092	2Q1	29.2	0.01
66092	P1	70.6	0.16
66092	K2	225.9	0.03
66093	M2	200.6	0.154
66093	S2	226.7	0.105
66093	N2	228.2	0.036
66093	K1	53.9	0.594
66093	M4	236.9	0.023
66093	O1	43.3	0.561
66093	M6	33.9	0.003
66093	MK3	179.3	0.02
66093	S4	6.3	0.01
66093	MN4	191	0.01
66093	NU2	258.3	0.003
66093	MU2	204.7	0.007
66093	2N2	255.3	0.016
66093	OO1	36.5	0.033
66093	LDA2	194.7	0.01
66093	S1	168.5	0.059
66093	M1	100	0.02
66093	J1	75.8	0.026
66093	SSA	62.1	0.161
66093	SA	132.7	0.23
66093	RHO1	32.5	0.023
66093	Q1	33.7	0.121
66093	T2	162.6	0.01
66093	R2	233.6	0.007
66093	2Q1	24.2	0.02
66093	P1	54.5	0.167
66093	2SM2	293.1	0.007
66093	M3	281.6	0.007
66093	L2	185.2	0.01
66093	2MK3	157.5	0.016
66093	K2	187.4	0.059
66093	MS4	271.7	0.01
66094	M2	159.9	0.11
66094	S2	178.7	0.07
66094	N2	174.1	0.03
66094	K1	37	0.5
66094	M4	111.4	0.02
66094	O1	31.2	0.51
66094	S4	214.2	0.01
66094	NU2	174.3	0.01
66094	OO1	42.6	0.02
66094	M1	34	0.04
66094	J1	39.6	0.04
66094	SSA	57	0.19
66094	SA	139.3	0.26
66094	RHO1	29	0.02
66094	Q1	28.4	0.1
66094	2Q1	25.8	0.01
66094	P1	36.5	0.16
66094	K2	180.7	0.02
66095	M2	199.2	0.21
66095	S2	219.2	0.12
66095	N2	193.3	0.05
66095	K1	68.7	0.51
66095	M4	248	0.03
66095	O1	48.4	0.5
66095	S4	322.1	0.01
66095	NU2	196	0.01
66095	OO1	76.8	0.02
66095	M1	56.4	0.04
66095	J1	72.4	0.03
66095	RHO1	41.4	0.02
66095	Q1	40.3	0.1
66095	T2	219.2	0.01
66095	2Q1	33.1	0.01
66095	P1	67.2	0.17
66095	K2	220.8	0.03
66096	M2	200	0.2
66096	S2	222.7	0.115
66096	N2	188.5	0.052
66096	K1	65.6	0.515
66096	M4	248	0.036
66096	O1	44.1	0.512
66096	M6	326.2	0.003
66096	S4	320.5	0.013
66096	NU2	190.4	0.01
66096	S6	212.3	0.003
66096	MU2	176.3	0.003
66096	2N2	173.1	0.003
66096	OO1	78.5	0.016
66096	M1	52.9	0.036
66096	J1	70.4	0.036
66096	SSA	57	0.194
66096	SA	139.3	0.259
66096	RHO1	36.1	0.02
66096	Q1	34.9	0.102
66096	T2	220.7	0.007
66096	2Q1	26.5	0.013
66096	P1	64.1	0.171
66096	L2	205.3	0.007
66096	K2	224.6	0.03
66096	M8	320.6	0.003
66097	M2	206.9	0.16
66097	S2	228.4	0.12
66097	N2	226.5	0.04
66097	K1	57.6	0.59
66097	M4	246.6	0.03
66097	O1	47.1	0.57
66097	M6	26.4	0.01
66097	MK3	184	0.02
66097	S4	33.4	0.01
66097	MN4	205.1	0.01
66097	NU2	141.7	0.01
66097	MU2	27.4	0.01
66097	2N2	134.4	0.02
66097	OO1	54.1	0.05
66097	S1	167.6	0.09
66097	M1	96	0.04
66097	J1	51.9	0.04
66097	SSA	40.7	0.26
66097	SA	138.5	0.44
66097	RHO1	15.5	0.05
66097	Q1	29.7	0.12
66097	T2	214.7	0.01
66097	R2	238.4	0.01
66097	2Q1	8.7	0.01
66097	P1	49.9	0.19
66097	2SM2	260.1	0.01
66097	M3	286.1	0.01
66097	L2	142.7	0.01
66097	2MK3	169.5	0.02
66097	K2	205.5	0.04
66097	MS4	286.7	0.02
66098	M2	168.8	0.12
66098	S2	187.6	0.09
66098	N2	199.3	0.03
66098	K1	39.9	0.56
66098	M4	139.5	0.03
66098	O1	30.7	0.52
66098	MK3	138.6	0.01
66098	S4	262	0.01
66098	MN4	93.1	0.01
66098	MU2	161.4	0.01
66098	2N2	185.9	0.01
66098	OO1	37.9	0.03
66098	S1	133.2	0.05
66098	M1	55.7	0.02
66098	J1	54.3	0.03
66098	SSA	57	0.19
66098	SA	139.3	0.26
66098	RHO1	9.7	0.02
66098	Q1	17	0.12
66098	T2	73.1	0.01
66098	2Q1	352	0.02
66098	P1	40.5	0.14
66098	L2	185.8	0.01
66098	2MK3	108.6	0.01
66098	K2	163.8	0.03
66098	MS4	167.4	0.01
66099	M2	194.7	0.11
66099	S2	206.6	0.08
66099	N2	221.1	0.03
66099	K1	52.4	0.55
66099	M4	180.1	0.02
66099	O1	42	0.55
66099	MK3	187.8	0.01
66099	S4	341	0.01
66099	MN4	146.7	0.01
66099	NU2	315.6	0.01
66099	MU2	161.7	0.01
66099	2N2	204.6	0.01
66099	OO1	43.3	0.07
66099	S1	136.9	0.06
66099	M1	93.5	0.02
66099	J1	35	0.02
66099	SSA	40.7	0.26
66099	SA	138.5	0.44
66099	RHO1	19.6	0.02
66099	Q1	30.7	0.11
66099	T2	136.2	0.01
66099	2Q1	34.2	0.02
66099	P1	52.4	0.15
66099	L2	159.6	0.01
66099	2MK3	164.3	0.01
66099	K2	191.6	0.03
66099	MS4	191.5	0.01
66100	M2	205.7	0.1
66100	S2	216.1	0.09
66100	N2	238.4	0.02
66100	K1	58.5	0.55
66100	M4	223.7	0.02
66100	O1	48.8	0.51
66100	MK3	209.4	0.02
66100	S4	343.6	0.01
66100	MN4	165.9	0.01
66100	2N2	246.2	0.01
66100	OO1	55.6	0.04
66100	S1	137	0.05
66100	M1	105.7	0.02
66100	J1	82.6	0.03
66100	SSA	40.7	0.26
66100	SA	138.5	0.44
66100	RHO1	28.6	0.02
66100	Q1	37.6	0.1
66100	T2	111.2	0.01
66100	R2	241.2	0.01
66100	2Q1	8.9	0.02
66100	P1	60.8	0.14
66100	L2	206.1	0.01
66100	2MK3	193.2	0.02
66100	K2	202.3	0.04
66100	MS4	275.4	0.01
66101	M2	210.7	0.11
66101	S2	222.1	0.09
66101	N2	228	0.03
66101	K1	59.5	0.62
66101	M4	202.5	0.02
66101	O1	48.3	0.58
66101	MK3	209.8	0.02
66101	S4	348.8	0.01
66101	MN4	173	0.01
66101	NU2	225.7	0.01
66101	MU2	195.4	0.01
66101	2N2	230.9	0.01
66101	OO1	50.1	0.05
66101	S1	128.3	0.07
66101	M1	53.9	0.04
66101	J1	65.2	0.05
66101	SSA	57	0.19
66101	SA	139.3	0.26
66101	RHO1	33.9	0.03
66101	Q1	30.4	0.14
66101	T2	221.6	0.01
66101	2Q1	13.1	0.02
66101	P1	63	0.16
66101	L2	193.4	0.01
66101	2MK3	177.8	0.02
66101	K2	196.1	0.05
66102	M2	121.1	0.062
66102	S2	116.4	0.036
66102	N2	141.4	0.016
66102	K1	22	0.43
66102	M4	337.1	0.01
66102	O1	13.6	0.41
66102	M6	9.1	0.003
66102	S4	104.1	0.003
66102	MN4	308.7	0.007
66102	NU2	214.7	0.003
66102	MU2	124	0.003
66102	2N2	124.1	0.007
66102	OO1	34.6	0.013
66102	LDA2	358.8	0.003
66102	S1	347.6	0.023
66102	M1	355.3	0.023
66102	J1	40	0.026
66102	MM	245.8	0.049
66102	SSA	32.4	0.308
66102	SA	163.9	0.394
66102	MSF	340.1	0.075
66102	MF	354.8	0.069
66102	RHO1	351.9	0.02
66102	Q1	9.5	0.092
66102	T2	82.6	0.003
66102	R2	276.9	0.003
66102	2Q1	354.3	0.02
66102	P1	16.3	0.131
66102	2SM2	329.9	0.003
66102	K2	91.8	0.007
66102	MS4	342.4	0.007
66103	M2	116.3	0.06
66103	S2	108.3	0.04
66103	N2	137.6	0.02
66103	K1	18	0.46
66103	O1	10.9	0.44
66103	OO1	32.9	0.02
66103	S1	24.1	0.02
66103	M1	28.4	0.02
66103	J1	33.8	0.03
66103	SSA	58	0.26
66103	SA	159.3	0.31
66103	RHO1	0	0.02
66103	Q1	358.6	0.1
66103	2Q1	338.4	0.02
66103	P1	18.1	0.13
66103	K2	107.6	0.01
66104	M2	201.4	0.098
66104	S2	210.1	0.049
66104	N2	224.8	0.01
66104	K1	50.2	0.522
66104	M4	196.3	0.013
66104	O1	43.5	0.489
66104	M6	271.6	0.003
66104	S4	174.6	0.003
66104	NU2	221.6	0.003
66104	MU2	192.7	0.003
66104	OO1	57	0.02
66104	M1	46.9	0.036
66104	J1	53.6	0.039
66104	SSA	40.7	0.262
66104	SA	138.5	0.436
66104	RHO1	40.6	0.02
66104	Q1	40.1	0.095
66104	T2	209.8	0.003
66104	2Q1	36.7	0.013
66104	P1	49.7	0.174
66104	L2	178	0.003
66104	K2	210.8	0.013
66105	M2	163.7	0.04
66105	S2	148.8	0.03
66105	N2	216	0.01
66105	K1	49.2	0.41
66105	M4	35.1	0.01
66105	O1	39	0.36
66105	OO1	57.2	0.02
66105	M1	46.1	0.02
66105	J1	57.2	0.03
66105	RHO1	22.9	0.01
66105	Q1	32.1	0.08
66105	2Q1	29.6	0.01
66105	P1	51.4	0.13
66105	K2	163.8	0.01
66106	M2	180.4	0.02
66106	S2	176	0.01
66106	N2	218.2	0.01
66106	K1	61.2	0.25
66106	O1	45.8	0.25
66106	2N2	182.2	0.01
66106	OO1	59.4	0.01
66106	S1	334.9	0.04
66106	M1	109.2	0.01
66106	J1	39.2	0.01
66106	RHO1	30.2	0.02
66106	Q1	34.8	0.06
66106	2Q1	36.5	0.01
66106	P1	51.2	0.06
66106	K2	191	0.01
66107	M2	210.9	0.07
66107	S2	199.8	0.04
66107	N2	240.6	0.02
66107	K1	56	0.45
66107	O1	44.3	0.42
66107	MU2	244.4	0.01
66107	2N2	289.5	0.01
66107	OO1	57.7	0.02
66107	S1	14.3	0.04
66107	M1	24.4	0.02
66107	J1	96.1	0.03
66107	RHO1	1	0.02
66107	Q1	42.6	0.1
66107	T2	85.4	0.01
66107	R2	345.3	0.01
66107	2Q1	66.5	0.03
66107	P1	43.2	0.14
66107	K2	189.5	0.01
66108	M2	125.6	0.05
66108	S2	99.9	0.04
66108	N2	145.2	0.02
66108	K1	19.9	0.43
66108	M4	322.3	0.01
66108	O1	12.7	0.42
66108	OO1	38.4	0.01
66108	S1	335.9	0.03
66108	M1	34.5	0.02
66108	J1	22.6	0.02
66108	SSA	52.2	0.15
66108	SA	145.6	0.27
66108	RHO1	354.9	0.02
66108	Q1	359.5	0.1
66108	2Q1	352.8	0.01
66108	P1	19.1	0.14
66108	K2	94.4	0.01
66109	M2	123	0.06
66109	S2	105.5	0.04
66109	N2	141.8	0.02
66109	K1	20.6	0.44
66109	M4	319.6	0.01
66109	O1	12	0.43
66109	MU2	97	0.01
66109	OO1	35.4	0.02
66109	S1	6	0.04
66109	M1	48.9	0.01
66109	J1	12.9	0.02
66109	SSA	58.3	0.18
66109	SA	155.2	0.26
66109	RHO1	5.2	0.01
66109	Q1	357.6	0.11
66109	2Q1	319.7	0.01
66109	P1	20.7	0.14
66109	K2	90.6	0.01
66110	M2	293.1	0.08
66110	S2	315	0.05
66110	N2	325.7	0.02
66110	K1	96.5	0.46
66110	M4	354.7	0.01
66110	O1	83.3	0.43
66110	MK3	11.5	0.02
66110	MN4	313.7	0.01
66110	OO1	97.4	0.05
66110	LDA2	271.9	0.01
66110	S1	72.4	0.04
66110	M1	147.5	0.02
66110	J1	103.4	0.02
66110	MM	340.9	0.04
66110	SSA	63.4	0.29
66110	SA	167.5	0.32
66110	MSF	32.6	0.03
66110	MF	277.2	0.03
66110	RHO1	66.5	0.02
66110	Q1	67.9	0.09
66110	R2	268.3	0.01
66110	2Q1	34	0.01
66110	P1	96.9	0.13
66110	2SM2	137.5	0.01
66110	L2	305.6	0.01
66110	2MK3	355.7	0.02
66110	K2	298.8	0.05
66111	M2	312.3	0.1
66111	S2	291.6	0.05
66111	N2	323.9	0.02
66111	K1	107	0.35
66111	M4	33	0.01
66111	O1	80	0.33
66111	S4	43.5	0.01
66111	S6	58.6	0.01
66111	OO1	134	0.01
66111	M1	93.6	0.02
66111	J1	120.4	0.03
66111	SSA	60.5	0.19
66111	SA	146.7	0.4
66111	RHO1	68.4	0.01
66111	Q1	66.6	0.07
66111	2Q1	53.2	0.01
66111	P1	105	0.11
66111	K2	290	0.01
66112	M2	314.4	0.06
66112	S2	280.7	0.03
66112	N2	335.3	0.02
66112	K1	108.3	0.21
66112	O1	85.5	0.24
66112	M6	126.4	0.01
66112	S4	22.7	0.01
66112	S6	90.5	0.01
66112	OO1	131.2	0.01
66112	M1	97	0.02
66112	J1	119.7	0.02
66112	SSA	44.9	0.25
66112	SA	147.4	0.33
66112	RHO1	75.6	0.01
66112	Q1	74.1	0.05
66112	2Q1	62.8	0.01
66112	P1	106.6	0.07
66112	K2	278	0.01
66113	M2	229	0.04
66113	S2	12	0.07
66113	N2	147.5	0.02
66113	K1	103.9	0.37
66113	M4	8.9	0.02
66113	O1	95	0.41
66113	M6	293.8	0.01
66113	OO1	112.7	0.02
66113	M1	99.5	0.03
66113	J1	108.2	0.03
66113	RHO1	91.3	0.02
66113	Q1	90.7	0.08
66113	2Q1	86.3	0.01
66113	P1	103.2	0.12
66113	K2	23.6	0.02
66114	M2	169.4	0.04
66114	K1	47	0.38
66114	O1	40.3	0.37
66114	OO1	53.7	0.02
66114	M1	43.7	0.03
66114	J1	50.4	0.03
66114	SSA	34.9	0.25
66114	SA	152.4	0.26
66114	RHO1	37.4	0.01
66114	Q1	29.7	0.08
66114	P1	48.8	0.11
66115	M2	163	0.04
66115	S2	154.6	0.02
66115	N2	176.1	0.02
66115	K1	37.4	0.37
66115	O1	30.8	0.37
66115	OO1	33.5	0.02
66115	S1	4.6	0.02
66115	M1	42.1	0.02
66115	J1	41.2	0.02
66115	SSA	49.7	0.2
66115	SA	149.7	0.29
66115	RHO1	17.3	0.02
66115	Q1	19.2	0.08
66115	2Q1	3.6	0.01
66115	P1	37.2	0.12
66115	K2	153.8	0.01
66116	M2	197.9	0.02
66116	S2	172.2	0.02
66116	N2	213.9	0.01
66116	K1	52.9	0.33
66116	M4	52.7	0.01
66116	O1	45.7	0.32
66116	MK3	193.3	0.01
66116	2N2	266	0.01
66116	OO1	62.1	0.02
66116	S1	357.1	0.02
66116	M1	88.5	0.02
66116	J1	39	0.01
66116	SSA	49.7	0.2
66116	SA	149.7	0.29
66116	RHO1	11.5	0.02
66116	Q1	28.3	0.07
66116	2Q1	72.3	0.01
66116	P1	50.6	0.1
66116	2MK3	186.2	0.01
66116	K2	190	0.01
66117	M2	233	0.01
66117	S2	187.6	0.01
66117	N2	259.3	0.01
66117	K1	65.3	0.3
66117	M4	102.2	0.01
66117	O1	56.3	0.29
66117	MK3	244	0.02
66117	2N2	42	0.01
66117	OO1	54.3	0.02
66117	J1	69.1	0.01
66117	MM	320.4	0.12
66117	SSA	95.5	0.12
66117	SA	151.3	0.19
66117	MSF	9.6	0.03
66117	MF	302.7	0.02
66117	RHO1	25.1	0.01
66117	Q1	39.3	0.07
66117	2Q1	313.2	0.01
66117	P1	69.9	0.08
66117	2MK3	224.5	0.02
66117	K2	206.1	0.01
66118	M2	159.6	0.05
66118	S2	148.6	0.03
66118	N2	161.1	0.01
66118	K1	42.1	0.34
66118	M4	338.7	0.01
66118	O1	34.6	0.34
66118	MK3	180.9	0.01
66118	2N2	155.8	0.01
66118	OO1	38.8	0.02
66118	S1	32.5	0.01
66118	M1	61.1	0.01
66118	J1	33.7	0.02
66118	SSA	49.7	0.2
66118	SA	149.7	0.29
66118	RHO1	2.4	0.01
66118	Q1	16.2	0.08
66118	2Q1	301.9	0.01
66118	P1	41.6	0.1
66118	2MK3	187.9	0.01
66119	S2	288.7	0.01
66119	K1	146.9	0.07
66119	O1	135.8	0.07
66119	2N2	87.3	0.01
66119	OO1	138	0.01
66119	S1	229.7	0.01
66119	SSA	49.7	0.2
66119	SA	149.7	0.29
66119	Q1	132.7	0.02
66119	2Q1	217.9	0.01
66119	P1	140.6	0.02
66120	M2	49.6	0.01
66120	S2	327.1	0.01
66120	K1	190.5	0.12
66120	O1	176.4	0.12
66120	OO1	199.7	0.01
66120	S1	147.8	0.02
66120	M1	263.1	0.01
66120	SSA	44.9	0.25
66120	SA	147.4	0.33
66120	RHO1	135.4	0.01
66120	Q1	156.9	0.02
66120	P1	190.6	0.03
66120	K2	72.1	0.01
66121	M2	174.6	0.06
66121	S2	170.5	0.03
66121	N2	178.3	0.02
66121	K1	30.3	0.43
66121	M4	7.1	0.01
66121	O1	22.7	0.42
66121	MN4	331.2	0.01
66121	NU2	196.9	0.01
66121	MU2	141.1	0.01
66121	2N2	122.7	0.01
66121	OO1	36.4	0.02
66121	S1	342.8	0.02
66121	M1	41.8	0.03
66121	J1	32.2	0.03
66121	MM	191.5	0.07
66121	SSA	45.2	0.17
66121	SA	174.5	0.34
66121	MSF	152.7	0.01
66121	MF	354.1	0.01
66121	RHO1	15.6	0.03
66121	Q1	1.6	0.09
66121	2Q1	341.4	0.01
66121	P1	30	0.13
66122	M2	284	0.04
66122	S2	283.8	0.02
66122	N2	303.2	0.01
66122	K1	80.7	0.27
66122	O1	72.3	0.27
66122	MK3	274.1	0.01
66122	2N2	322.3	0.01
66122	OO1	61.1	0.02
66122	S1	320.3	0.01
66122	M1	169.3	0.02
66122	J1	118.4	0.01
66122	SSA	49.7	0.2
66122	SA	149.7	0.29
66122	RHO1	60.3	0.01
66122	Q1	68.6	0.05
66122	2Q1	100.1	0.02
66122	P1	85	0.09
66122	2MK3	263.1	0.01
66122	K2	270.4	0.01
66123	M2	49.7	0.01
66123	S2	357.3	0.01
66123	K1	132.8	0.16
66123	O1	121.1	0.15
66123	MK3	53.9	0.01
66123	2N2	157.5	0.01
66123	OO1	124.8	0.02
66123	S1	276.1	0.04
66123	M1	339	0.01
66123	J1	295.9	0.01
66123	RHO1	114.2	0.01
66123	Q1	105.6	0.03
66123	2Q1	303.2	0.01
66123	P1	140.6	0.03
66123	2MK3	41.6	0.01
66123	K2	338.5	0.01
66124	M2	251.5	0.04
66124	S2	238.2	0.01
66124	N2	252.2	0.02
66124	K1	46.8	0.46
66124	O1	35.6	0.43
66124	MK3	197.7	0.01
66124	NU2	267.5	0.01
66124	MU2	79.2	0.01
66124	2N2	24.5	0.01
66124	OO1	44	0.03
66124	LDA2	195.1	0.01
66124	S1	299.9	0.05
66124	M1	108.8	0.01
66124	J1	50.8	0.01
66124	SSA	49.7	0.2
66124	SA	149.7	0.29
66124	RHO1	23.7	0.02
66124	Q1	23.3	0.1
66124	R2	90.7	0.01
66124	P1	43.8	0.12
66124	M3	34.2	0.01
66124	2MK3	180.5	0.01
66124	K2	196.1	0.02
66125	M2	42.2	0.01
66125	S2	45	0.01
66125	K1	195.4	0.11
66125	O1	178.9	0.1
66125	OO1	198.5	0.01
66125	S1	280.7	0.01
66125	SSA	60.5	0.19
66125	SA	146.7	0.4
66125	Q1	157.6	0.02
66125	P1	188	0.03
66125	K2	66.9	0.01
66126	S2	3.1	0.01
66126	K1	186.8	0.15
66126	M4	47.4	0.01
66126	O1	176.2	0.15
66126	M6	195.7	0.01
66126	S6	105.7	0.01
66126	OO1	197.3	0.01
66126	M1	181.5	0.01
66126	J1	192	0.01
66126	SSA	44.9	0.25
66126	SA	147.4	0.33
66126	RHO1	171.7	0.01
66126	Q1	171	0.03
66126	P1	186	0.05
66126	M8	44.1	0.01
66127	M2	194.7	0.08
66127	S2	159.4	0.03
66127	N2	183.7	0.03
66127	K1	24.2	0.46
66127	M4	35.6	0.01
66127	O1	17.5	0.42
66127	M6	82	0.01
66127	NU2	185.6	0.01
66127	OO1	30.4	0.02
66127	M1	20.8	0.03
66127	J1	27.4	0.03
66127	SSA	45.2	0.17
66127	SA	174.5	0.34
66127	RHO1	14.6	0.02
66127	Q1	14.2	0.08
66127	2Q1	10.9	0.01
66127	P1	23.6	0.15
66127	K2	157.7	0.01
66128	M2	252	0.06
66128	S2	238.5	0.03
66128	N2	241.8	0.02
66128	K1	54.7	0.36
66128	O1	49.3	0.36
66128	OO1	48.8	0.04
66128	S1	298.1	0.01
66128	SSA	49.7	0.2
66128	SA	149.7	0.29
66128	MF	339.3	0.04
66128	Q1	23.6	0.07
66128	P1	52	0.1
66128	K2	229.5	0.02
66129	M2	222.4	0.17
66129	S2	215.8	0.07
66129	N2	214	0.06
66129	K1	26.3	0.5
66129	M4	126.2	0.02
66129	O1	21.7	0.47
66129	M6	256.4	0.01
66129	MK3	310.6	0.01
66129	S4	198.9	0.01
66129	MN4	108.5	0.01
66129	NU2	246.9	0.01
66129	2N2	198.2	0.01
66129	OO1	71.1	0.03
66129	LDA2	327.6	0.01
66129	S1	215.7	0.01
66129	M1	55.7	0.02
66129	J1	30.8	0.03
66129	RHO1	297.6	0.02
66129	Q1	12.4	0.09
66129	R2	30.9	0.01
66129	2Q1	355.4	0.03
66129	P1	23.8	0.16
66129	M3	195	0.01
66129	2MK3	279.9	0.01
66129	K2	244.4	0.01
66129	MS4	158.4	0.01
66130	M2	16.3	0.11
66130	S2	15	0.04
66130	N2	353.3	0.03
66130	K1	82.9	0.16
66130	M4	4.6	0.01
66130	O1	74.4	0.16
66130	MK3	35.4	0.02
66130	MN4	333.6	0.01
66130	NU2	308.1	0.01
66130	MU2	232.3	0.01
66130	2N2	277.4	0.02
66130	OO1	88.7	0.01
66130	LDA2	358.6	0.01
66130	S1	36.9	0.07
66130	M1	81.9	0.01
66130	J1	349.6	0.01
66130	RHO1	65.4	0.01
66130	Q1	59.1	0.04
66130	T2	152.7	0.02
66130	R2	39.7	0.02
66130	2Q1	286.5	0.01
66130	P1	76.5	0.04
66130	M3	78.1	0.01
66130	L2	95.6	0.01
66130	2MK3	26.3	0.03
66130	K2	321.8	0.01
66130	MS4	8.5	0.01
66131	M2	356.9	0.09
66131	S2	348.4	0.03
66131	N2	335.7	0.03
66131	K1	75.8	0.14
66131	M4	325	0.01
66131	O1	68.2	0.13
66131	MK3	11.6	0.01
66131	NU2	353	0.01
66131	2N2	334	0.01
66131	S1	296.4	0.03
66131	M1	116.8	0.01
66131	J1	85.8	0.01
66131	SSA	108.8	0.29
66131	SA	36.8	1.02
66131	RHO1	38.9	0.01
66131	Q1	53.7	0.02
66131	T2	82.9	0.01
66131	R2	54.7	0.01
66131	P1	76.7	0.04
66131	2MK3	3.6	0.01
66131	K2	311.8	0.01
66132	M2	285.2	0.29
66132	S2	282.1	0.1
66132	N2	265.4	0.08
66132	K1	39.5	0.43
66132	M4	209.8	0.01
66132	O1	33.7	0.38
66132	MK3	271.4	0.02
66132	S4	15.1	0.01
66132	MN4	160.8	0.01
66132	NU2	270.8	0.02
66132	MU2	175.8	0.01
66132	2N2	268.7	0.01
66132	OO1	73.2	0.02
66132	S1	270.9	0.03
66132	M1	87.8	0.02
66132	J1	42.5	0.02
66132	SSA	60.5	0.11
66132	SA	103.4	0.38
66132	RHO1	359.1	0.01
66132	Q1	19.2	0.07
66132	R2	26.3	0.02
66132	2Q1	15.7	0.02
66132	P1	30.3	0.13
66132	2SM2	76.9	0.01
66132	M3	255.5	0.01
66132	L2	328.9	0.01
66132	2MK3	267.1	0.03
66132	K2	254.1	0.02
66133	M2	256.8	0.335
66133	S2	254.2	0.118
66133	N2	209.2	0.118
66133	K1	28.5	0.515
66133	M4	189.6	0.033
66133	O1	20.3	0.486
66133	M6	312.4	0.007
66133	S4	159.1	0.01
66133	NU2	215.6	0.023
66133	S6	233.6	0.007
66133	MU2	76.5	0.01
66133	2N2	161.7	0.016
66133	OO1	36.8	0.02
66133	LDA2	255.6	0.003
66133	M1	24.5	0.036
66133	J1	32.6	0.039
66133	RHO1	16.8	0.02
66133	Q1	16.2	0.095
66133	T2	254.3	0.007
66133	2Q1	12.1	0.013
66133	P1	27.9	0.171
66133	L2	304.3	0.01
66133	K2	254	0.033
66133	M8	205.6	0.003
66134	M2	253.7	0.34
66134	S2	252.1	0.13
66134	N2	226.8	0.09
66134	K1	22.6	0.5
66134	M4	197.1	0.03
66134	O1	21.9	0.43
66134	S4	359.4	0.01
66134	NU2	230.3	0.02
66134	MU2	256.2	0.01
66134	2N2	200	0.01
66134	OO1	23.5	0.02
66134	M1	22.3	0.03
66134	J1	23.1	0.03
66134	SSA	60.5	0.11
66134	SA	103.4	0.38
66134	RHO1	21.3	0.02
66134	Q1	21.5	0.09
66134	T2	253.2	0.01
66134	2Q1	21.2	0.01
66134	P1	22.5	0.16
66134	L2	281.2	0.01
66134	K2	251.8	0.04
66135	M2	1.4	0.25
66135	S2	18.4	0.08
66135	N2	6.1	0.08
66135	K1	87.4	0.53
66135	M4	218.4	0.02
66135	O1	84	0.42
66135	NU2	5.5	0.02
66135	S6	205	0.01
66135	2N2	10.8	0.01
66135	OO1	90.7	0.02
66135	M1	85.7	0.03
66135	J1	89	0.03
66135	SSA	298.4	0.1
66135	SA	102.1	0.44
66135	RHO1	82.5	0.02
66135	Q1	82.3	0.08
66135	2Q1	80.6	0.01
66135	P1	87.1	0.18
66135	K2	19.8	0.02
66135	M8	36	0.01
66136	M2	351.7	0.23
66136	S2	358.6	0.1
66136	N2	343.6	0.04
66136	K1	78	0.41
66136	M4	189.2	0.01
66136	O1	69.3	0.42
66136	NU2	344.6	0.01
66136	MU2	161	0.01
66136	2N2	335.5	0.01
66136	OO1	86.7	0.02
66136	M1	73.7	0.03
66136	J1	82.3	0.03
66136	RHO1	65.6	0.02
66136	Q1	65	0.08
66136	T2	358.3	0.01
66136	2Q1	60.7	0.01
66136	P1	77.3	0.14
66136	L2	359.8	0.01
66136	K2	359.1	0.03
66137	M2	245.9	0.43
66137	S2	236.4	0.14
66137	N2	223.2	0.12
66137	K1	22.7	0.54
66137	M4	34.5	0.02
66137	O1	15.9	0.49
66137	M6	300.9	0.01
66137	S4	223.1	0.01
66137	MN4	356.8	0.01
66137	NU2	238.4	0.03
66137	MU2	177.9	0.02
66137	2N2	208.5	0.02
66137	OO1	43.6	0.02
66137	LDA2	25.7	0.01
66137	S1	266	0.01
66137	M1	50.5	0.03
66137	J1	26.3	0.04
66137	SSA	54.7	0.21
66137	SA	148.3	0.33
66137	RHO1	6.6	0.02
66137	Q1	1.1	0.1
66137	T2	253.2	0.01
66137	R2	355	0.01
66137	2Q1	352.3	0.01
66137	P1	14	0.17
66137	2SM2	299.3	0.01
66137	M3	190.1	0.01
66137	L2	312.8	0.01
66137	2MK3	159.1	0.01
66137	K2	261.5	0.01
66138	M2	50.7	0.3
66138	S2	33.2	0.08
66138	N2	23.7	0.07
66138	K1	107.5	0.36
66138	M4	3.9	0.02
66138	O1	96.5	0.32
66138	MK3	75.5	0.02
66138	MN4	340.6	0.01
66138	NU2	34.1	0.02
66138	MU2	274.5	0.02
66138	2N2	14.8	0.01
66138	OO1	121.2	0.02
66138	LDA2	69.9	0.01
66138	S1	138.2	0.03
66138	M1	171	0.01
66138	J1	99.4	0.01
66138	SSA	57.9	0.2
66138	SA	123.9	0.31
66138	RHO1	81.7	0.01
66138	Q1	80.5	0.06
66138	T2	146.6	0.01
66138	R2	19.2	0.01
66138	2Q1	77.6	0.01
66138	P1	105.8	0.09
66138	M3	28.9	0.01
66138	L2	85.3	0.02
66138	2MK3	72.7	0.02
66138	K2	63.1	0.04
66138	MS4	5.4	0.01
66139	M2	48.6	0.23
66139	S2	21.9	0.08
66139	N2	17.1	0.05
66139	K1	109.6	0.4
66139	M4	343.7	0.02
66139	O1	93.1	0.31
66139	M6	234.7	0.01
66139	S4	14.1	0.01
66139	NU2	21.3	0.01
66139	MU2	248.7	0.01
66139	2N2	345.5	0.01
66139	OO1	126.1	0.01
66139	M1	101.4	0.02
66139	J1	117.7	0.02
66139	RHO1	86	0.01
66139	Q1	84.9	0.06
66139	2Q1	76.8	0.01
66139	P1	108.3	0.13
66139	L2	80.2	0.01
66139	K2	19.8	0.02
66140	M2	254.4	0.45
66140	S2	249.7	0.13
66140	N2	233.8	0.12
66140	K1	31.6	0.48
66140	M4	343.1	0.03
66140	O1	26.4	0.43
66140	M6	259.8	0.01
66140	MK3	96.3	0.03
66140	MN4	319.6	0.01
66140	NU2	243.6	0.02
66140	MU2	201	0.02
66140	2N2	198.6	0.02
66140	OO1	57.6	0.02
66140	LDA2	31.5	0.01
66140	S1	281.2	0.02
66140	M1	52.7	0.02
66140	J1	39.9	0.03
66140	SSA	67.5	0.24
66140	SA	143.9	0.36
66140	RHO1	12.4	0.01
66140	Q1	7.8	0.1
66140	T2	291.8	0.01
66140	2Q1	12	0.02
66140	P1	25.6	0.14
66140	2SM2	317.9	0.01
66140	M3	209.5	0.01
66140	L2	310.6	0.01
66140	2MK3	102.7	0.03
66140	K2	313.4	0.03
66140	MS4	351	0.01
66141	M2	322.5	0.17
66141	S2	312	0.06
66141	N2	299.8	0.05
66141	K1	74.9	0.3
66141	O1	66	0.29
66141	MK3	161.4	0.01
66141	NU2	308.3	0.01
66141	MU2	216.5	0.01
66141	2N2	172.8	0.01
66141	OO1	87.1	0.03
66141	S1	316.5	0.02
66141	M1	199.5	0.01
66141	J1	74.7	0.01
66141	SSA	52	0.25
66141	SA	135.7	0.21
66141	RHO1	37.2	0.01
66141	Q1	35.5	0.05
66141	R2	67.5	0.01
66141	2Q1	263.5	0.01
66141	P1	69.2	0.09
66141	L2	68.5	0.01
66141	2MK3	145.7	0.01
66141	K2	26	0.03
66142	M2	29.4	0.17
66142	S2	12	0.05
66142	N2	6	0.04
66142	K1	102.2	0.3
66142	O1	90.6	0.28
66142	MK3	68.5	0.01
66142	NU2	7	0.01
66142	MU2	216	0.01
66142	OO1	116.9	0.03
66142	LDA2	62.9	0.01
66142	S1	312.7	0.01
66142	M1	231.3	0.02
66142	J1	25.6	0.01
66142	SSA	52	0.25
66142	SA	135.7	0.21
66142	Q1	66.2	0.04
66142	T2	42.6	0.01
66142	R2	109.3	0.01
66142	P1	93.3	0.09
66142	L2	68.7	0.01
66142	2MK3	32.6	0.01
66142	K2	36.3	0.03
66143	M2	290.7	0.25
66143	S2	284.7	0.08
66143	N2	268.3	0.06
66143	K1	58.7	0.32
66143	M4	334.9	0.01
66143	O1	50.7	0.31
66143	NU2	305.8	0.02
66143	2N2	212.7	0.02
66143	OO1	63	0.01
66143	S1	321.4	0.02
66143	M1	320.7	0.01
66143	J1	77.7	0.01
66143	SSA	67	0.34
66143	SA	125.7	0.23
66143	RHO1	20.4	0.02
66143	Q1	41.3	0.07
66143	T2	283.3	0.01
66143	2Q1	205.9	0.01
66143	P1	43.6	0.1
66143	L2	10.2	0.01
66143	K2	341.4	0.03
66144	M2	51	0.17
66144	S2	35.1	0.04
66144	N2	36.1	0.03
66144	K1	111.7	0.35
66144	M4	343.4	0.02
66144	O1	97.4	0.34
66144	NU2	43.4	0.02
66144	MU2	258.2	0.02
66144	2N2	155.2	0.01
66144	OO1	95.2	0.03
66144	LDA2	119.2	0.01
66144	S1	315.7	0.03
66144	M1	166.5	0.02
66144	J1	150.6	0.01
66144	SSA	28.1	0.2
66144	SA	159.8	0.31
66144	RHO1	97.4	0.02
66144	Q1	89.7	0.06
66144	T2	109.2	0.02
66144	R2	107.7	0.01
66144	2Q1	136.1	0.01
66144	P1	94.8	0.1
66144	K2	60.2	0.02
66145	M2	275.5	0.4
66145	S2	271.5	0.13
66145	N2	254.4	0.11
66145	K1	40.7	0.43
66145	M4	318.9	0.02
66145	O1	34.6	0.4
66145	MK3	141.2	0.02
66145	NU2	269.5	0.02
66145	MU2	210.3	0.02
66145	2N2	220.4	0.02
66145	OO1	61.4	0.02
66145	S1	306.3	0.04
66145	M1	36.9	0.02
66145	J1	47.1	0.02
66145	SSA	52	0.25
66145	SA	135.7	0.21
66145	RHO1	23.8	0.02
66145	Q1	21.8	0.09
66145	T2	271.7	0.01
66145	2Q1	28.5	0.01
66145	P1	33.1	0.13
66145	L2	5.1	0.01
66145	2MK3	132.8	0.02
66145	K2	338.5	0.03
66146	M2	47.6	0.154
66146	S2	15.8	0.049
66146	N2	87.6	0.023
66146	K1	111.6	0.226
66146	M4	330.8	0.01
66146	O1	102.1	0.217
66146	M6	1.8	0.003
66146	S4	269.9	0.003
66146	NU2	82.3	0.003
66146	S6	88.7	0.003
66146	MU2	251.9	0.003
66146	2N2	127.7	0.003
66146	OO1	121.2	0.01
66146	M1	106.9	0.016
66146	J1	116.4	0.016
66146	RHO1	98	0.01
66146	Q1	97.3	0.043
66146	T2	17.1	0.003
66146	2Q1	92.6	0.007
66146	P1	110.9	0.075
66146	L2	7.5	0.003
66146	K2	13.3	0.013
66146	M8	149.5	0.003
66147	M2	65	0.19
66147	S2	49.6	0.04
66147	N2	37.9	0.05
66147	K1	111.2	0.43
66147	O1	98.6	0.42
66147	NU2	47.6	0.01
66147	MU2	297.4	0.01
66147	OO1	131.1	0.05
66147	LDA2	99.1	0.01
66147	S1	128.3	0.01
66147	M1	202.1	0.01
66147	J1	78.5	0.01
66147	SSA	71.3	0.33
66147	SA	133	0.33
66147	RHO1	101.7	0.02
66147	Q1	82.4	0.08
66147	R2	17.8	0.01
66147	2Q1	50.2	0.01
66147	P1	114.6	0.11
66147	L2	96	0.01
66147	K2	87.1	0.03
66148	M2	59.1	0.17
66148	S2	45.8	0.04
66148	N2	32.8	0.04
66148	K1	110.4	0.37
66148	M4	338.2	0.01
66148	O1	103.5	0.37
66148	MK3	26	0.01
66148	NU2	50.3	0.01
66148	MU2	257.3	0.01
66148	2N2	288.3	0.02
66148	OO1	119.3	0.05
66148	S1	277.7	0.04
66148	M1	227.5	0.02
66148	J1	121.5	0.01
66148	SSA	48.9	0.37
66148	SA	146.4	0.29
66148	RHO1	143.5	0.01
66148	Q1	71.5	0.08
66148	T2	112.9	0.01
66148	R2	90.6	0.01
66148	2Q1	290.6	0.01
66148	P1	113	0.09
66148	2SM2	70.9	0.01
66148	L2	93.6	0.01
66148	K2	72.4	0.03
66148	MS4	342.4	0.01
66149	M2	84.2	0.25
66149	S2	75.6	0.06
66149	N2	62.5	0.06
66149	K1	121.3	0.43
66149	O1	106	0.39
66149	MK3	119.7	0.01
66149	NU2	88.9	0.01
66149	MU2	286.1	0.01
66149	2N2	27	0.02
66149	OO1	131.9	0.03
66149	LDA2	135.2	0.01
66149	S1	140.4	0.01
66149	M1	119.9	0.02
66149	J1	78.8	0.01
66149	SSA	57	0.33
66149	SA	121.5	0.32
66149	RHO1	81.2	0.03
66149	Q1	102	0.07
66149	T2	136.8	0.01
66149	2Q1	40	0.02
66149	P1	131.4	0.12
66149	M3	14	0.01
66149	L2	154.7	0.02
66149	2MK3	92.2	0.01
66149	K2	103	0.04
66150	M2	84.5	0.24
66150	S2	78.4	0.07
66150	N2	63	0.06
66150	K1	120.4	0.43
66150	M4	53.9	0.01
66150	O1	107.8	0.39
66150	NU2	61	0.02
66150	MU2	4.8	0.01
66150	2N2	131.6	0.02
66150	OO1	125	0.04
66150	LDA2	175.1	0.01
66150	S1	88.9	0.02
66150	M1	156.6	0.02
66150	J1	201.3	0.01
66150	SSA	35.4	0.34
66150	SA	141.8	0.43
66150	RHO1	50	0.03
66150	Q1	93.4	0.07
66150	T2	133.4	0.02
66150	R2	72.6	0.01
66150	2Q1	107.8	0.02
66150	P1	130.3	0.1
66150	L2	140.5	0.03
66150	K2	99.7	0.03
66151	M2	80.3	0.31
66151	S2	68.2	0.08
66151	N2	56	0.08
66151	K1	115.7	0.5
66151	M4	95.3	0.01
66151	O1	102.3	0.47
66151	MK3	88.2	0.02
66151	NU2	76.7	0.01
66151	MU2	297.1	0.02
66151	2N2	175.2	0.02
66151	OO1	124.3	0.08
66151	LDA2	115	0.01
66151	S1	128.2	0.02
66151	M1	211.3	0.03
66151	J1	134.6	0.02
66151	SSA	71.3	0.33
66151	SA	133	0.33
66151	RHO1	97.2	0.01
66151	Q1	77.3	0.08
66151	T2	97.8	0.02
66151	2Q1	159.3	0.02
66151	P1	122.3	0.14
66151	L2	148.3	0.01
66151	2MK3	37.8	0.01
66151	K2	110.1	0.05
66151	MS4	86.1	0.01
66152	M2	33.8	0.21
66152	S2	36.1	0.06
66152	N2	8.7	0.06
66152	K1	98.3	0.41
66152	M4	17.5	0.02
66152	O1	90.7	0.39
66152	MK3	344	0.01
66152	S4	253.2	0.01
66152	MN4	352.3	0.01
66152	NU2	359.5	0.01
66152	MU2	252.2	0.01
66152	OO1	131.4	0.06
66152	S1	13.1	0.05
66152	M1	182.1	0.02
66152	J1	130.8	0.02
66152	SSA	55.6	0.28
66152	SA	155.7	0.22
66152	RHO1	358.3	0.02
66152	Q1	61.5	0.06
66152	T2	241.3	0.01
66152	R2	104.7	0.01
66152	P1	91.4	0.11
66152	2MK3	353.9	0.02
66152	K2	71	0.04
66152	MS4	15.5	0.01
66153	M2	266.4	0.44
66153	S2	270.4	0.12
66153	N2	246.7	0.11
66153	K1	35	0.47
66153	M4	326.6	0.02
66153	O1	28.3	0.42
66153	MK3	121.7	0.02
66153	MN4	306	0.01
66153	NU2	233.7	0.02
66153	MU2	178.4	0.02
66153	2N2	183	0.02
66153	OO1	44.5	0.03
66153	S1	231	0.01
66153	M1	68.3	0.01
66153	J1	34.1	0.03
66153	SSA	52	0.25
66153	SA	135.7	0.21
66153	RHO1	16.8	0.01
66153	Q1	10	0.08
66153	T2	256.5	0.03
66153	R2	69.7	0.03
66153	P1	30.6	0.16
66153	M3	194.9	0.01
66153	L2	76	0.01
66153	2MK3	129.9	0.03
66153	K2	317.3	0.05
66153	MS4	334.1	0.01
66154	M2	94.7	0.12
66154	S2	81.3	0.03
66154	N2	96.4	0.03
66154	K1	133	0.34
66154	M4	313.9	0.01
66154	O1	118.2	0.34
66154	NU2	155.2	0.01
66154	MU2	305.4	0.01
66154	2N2	260	0.02
66154	OO1	136.4	0.05
66154	LDA2	239.8	0.01
66154	S1	36.2	0.01
66154	M1	282.1	0.01
66154	J1	166.6	0.01
66154	SSA	68.1	0.38
66154	SA	126.4	0.22
66154	RHO1	117.7	0.02
66154	Q1	115.2	0.08
66154	T2	193.7	0.01
66154	2Q1	256.7	0.02
66154	P1	140.1	0.09
66154	K2	110.5	0.03
66155	M2	24.7	0.19
66155	S2	17.4	0.06
66155	N2	14.5	0.04
66155	K1	96.9	0.37
66155	M4	334.9	0.02
66155	O1	88.5	0.37
66155	NU2	40.3	0.01
66155	2N2	256.1	0.01
66155	OO1	104	0.03
66155	S1	326.9	0.07
66155	M1	325.8	0.02
66155	J1	94	0.02
66155	SSA	76	0.26
66155	SA	124.3	0.24
66155	RHO1	77.1	0.01
66155	Q1	69.1	0.08
66155	T2	234	0.01
66155	2Q1	259.9	0.01
66155	P1	88.5	0.1
66155	L2	71.9	0.01
66155	K2	38	0.04
66156	M2	19.7	0.11
66156	S2	15	0.04
66156	N2	351.5	0.03
66156	K1	100.4	0.38
66156	O1	89.5	0.37
66156	NU2	355.3	0.01
66156	OO1	110.8	0.03
66156	S1	13.3	0.03
66156	M1	94.8	0.03
66156	J1	105.8	0.03
66156	SSA	48.9	0.37
66156	SA	146.4	0.29
66156	RHO1	68.1	0.02
66156	Q1	75.4	0.07
66156	2Q1	78.7	0.01
66156	P1	104.4	0.1
66156	K2	71.6	0.02
66157	M2	262.6	0.55
66157	S2	254.2	0.17
66157	N2	236.9	0.15
66157	K1	23.3	0.57
66157	M4	284.5	0.02
66157	O1	16.3	0.53
66157	MK3	257.9	0.01
66157	MN4	245.9	0.01
66157	NU2	249.5	0.03
66157	MU2	181.3	0.02
66157	2N2	216	0.03
66157	OO1	50.5	0.02
66157	S1	324.6	0.02
66157	M1	48.1	0.01
66157	J1	27.2	0.03
66157	SSA	52	0.25
66157	SA	135.7	0.21
66157	RHO1	5.4	0.02
66157	Q1	2.1	0.12
66157	T2	315.6	0.01
66157	R2	311.3	0.01
66157	2Q1	333	0.01
66157	P1	19.3	0.17
66157	M3	209.5	0.01
66157	2MK3	270.8	0.01
66157	K2	275.7	0.04
66157	MS4	281.1	0.01
66158	M2	290.7	0.26
66158	S2	286.9	0.08
66158	N2	265.3	0.07
66158	K1	60.4	0.46
66158	O1	54.3	0.46
66158	MK3	128.1	0.05
66158	NU2	254.7	0.02
66158	MU2	249.1	0.01
66158	2N2	256	0.01
66158	OO1	105.8	0.05
66158	S1	345.1	0.05
66158	M1	97.6	0.03
66158	J1	58.9	0.01
66158	SSA	48.9	0.41
66158	SA	155.5	0.25
66158	RHO1	38.9	0.02
66158	Q1	34	0.1
66158	T2	340.6	0.01
66158	2Q1	345.2	0.01
66158	P1	54.7	0.13
66158	L2	315.9	0.01
66158	2MK3	117.1	0.04
66158	K2	10.2	0.05
66159	M2	281.5	0.36
66159	S2	289	0.1
66159	N2	257.4	0.09
66159	K1	40.8	0.48
66159	M4	232.7	0.01
66159	O1	33.1	0.46
66159	M6	278.9	0.01
66159	MK3	107.4	0.01
66159	S4	210.2	0.01
66159	MN4	193.1	0.01
66159	NU2	271.3	0.02
66159	MU2	218.4	0.01
66159	2N2	244.1	0.01
66159	OO1	85.1	0.02
66159	S1	320.2	0.04
66159	M1	67.3	0.02
66159	J1	30.7	0.03
66159	SSA	76	0.27
66159	SA	154.9	0.25
66159	RHO1	21.7	0.02
66159	Q1	14.6	0.1
66159	T2	269.2	0.01
66159	R2	133.4	0.01
66159	2Q1	3.2	0.02
66159	P1	35.8	0.14
66159	2SM2	348.2	0.01
66159	L2	330.6	0.01
66159	2MK3	96.3	0.01
66159	K2	344.2	0.02
66160	M2	276.3	0.45
66160	S2	270.6	0.14
66160	N2	252.5	0.12
66160	K1	27.7	0.55
66160	M4	225	0.02
66160	O1	21	0.52
66160	M6	287.9	0.01
66160	MK3	2.3	0.01
66160	S4	347.5	0.01
66160	MN4	210.2	0.01
66160	NU2	258.2	0.02
66160	MU2	190.9	0.02
66160	2N2	245.6	0.02
66160	OO1	57.8	0.02
66160	LDA2	358.5	0.01
66160	S1	266.8	0.01
66160	M1	74.3	0.02
66160	J1	24.9	0.03
66160	SSA	76	0.27
66160	SA	154.9	0.25
66160	RHO1	24	0.03
66160	Q1	358.8	0.12
66160	T2	314.6	0.02
66160	R2	335.5	0.01
66160	2Q1	357.1	0.02
66160	P1	25.6	0.16
66160	2SM2	331.6	0.01
66160	L2	334	0.01
66160	2MK3	26.4	0.01
66160	K2	303	0.03
66160	MS4	239.4	0.01
66161	M2	295.7	0.29
66161	S2	293.1	0.09
66161	N2	274	0.08
66161	K1	53.3	0.43
66161	M4	255.4	0.02
66161	O1	45.5	0.41
66161	NU2	292.1	0.02
66161	MU2	227.7	0.01
66161	2N2	239.3	0.02
66161	OO1	82.3	0.03
66161	S1	352.2	0.03
66161	M1	44.4	0.02
66161	J1	51	0.02
66161	SSA	55.6	0.28
66161	SA	155.7	0.22
66161	RHO1	30.5	0.02
66161	Q1	29.4	0.09
66161	T2	293.2	0.01
66161	2Q1	37.9	0.01
66161	P1	46.6	0.13
66161	L2	317.2	0.01
66161	K2	19.3	0.01
66162	M2	315	0.21
66162	S2	313.8	0.08
66162	N2	293.6	0.06
66162	K1	69.2	0.39
66162	M4	259.8	0.01
66162	O1	60.2	0.38
66162	MK3	154.3	0.01
66162	MN4	163.2	0.01
66162	NU2	290.7	0.01
66162	MU2	236.1	0.01
66162	2N2	197.2	0.01
66162	OO1	100.8	0.05
66162	S1	324.5	0.03
66162	M1	194.8	0.01
66162	J1	88.2	0.02
66162	SSA	55.6	0.28
66162	SA	155.7	0.22
66162	RHO1	24.7	0.02
66162	Q1	31.6	0.08
66162	T2	310.8	0.01
66162	R2	150.2	0.01
66162	P1	65.6	0.11
66162	L2	97.4	0.01
66162	2MK3	149.1	0.01
66162	K2	33.1	0.03
66162	MS4	282.3	0.01
66163	M2	276.1	0.46
66163	S2	267.9	0.11
66163	N2	254.6	0.12
66163	K1	28	0.56
66163	M4	203.3	0.02
66163	O1	20.3	0.53
66163	NU2	270.9	0.03
66163	MU2	197.1	0.02
66163	2N2	228.8	0.02
66163	OO1	46.2	0.02
66163	S1	327	0.05
66163	M1	24.2	0.03
66163	J1	34.5	0.03
66163	SSA	55.2	0.3
66163	SA	157.4	0.25
66163	RHO1	4	0.02
66163	Q1	7	0.12
66163	T2	268.1	0.01
66163	2Q1	349.5	0.01
66163	P1	24.3	0.17
66163	L2	352.1	0.01
66163	K2	275.6	0.02
66163	MS4	224.7	0.01
66164	M2	287.5	0.2
66164	S2	283.3	0.06
66164	N2	265.2	0.05
66164	K1	44.9	0.35
66164	M4	168.9	0.01
66164	O1	37.5	0.34
66164	MK3	94.2	0.01
66164	MN4	115.7	0.01
66164	NU2	276.3	0.01
66164	MU2	215.4	0.01
66164	2N2	184.7	0.01
66164	OO1	90.3	0.02
66164	S1	0.9	0.02
66164	J1	48.5	0.02
66164	SSA	55.6	0.28
66164	SA	155.7	0.22
66164	RHO1	18.2	0.01
66164	Q1	17.6	0.08
66164	T2	305.8	0.01
66164	P1	40.7	0.11
66164	2MK3	95	0.01
66164	K2	338.5	0.01
66165	M2	275.4	0.31
66165	S2	274.6	0.09
66165	N2	253.4	0.08
66165	K1	26.6	0.5
66165	M4	165.8	0.02
66165	O1	18.7	0.48
66165	NU2	253.9	0.02
66165	2N2	242.5	0.01
66165	OO1	36.7	0.02
66165	S1	332.2	0.02
66165	M1	69.2	0.02
66165	J1	28.5	0.03
66165	SSA	64.3	0.24
66165	SA	173.5	0.19
66165	RHO1	358.3	0.03
66165	Q1	0.6	0.11
66165	T2	274.6	0.01
66165	2Q1	341.4	0.01
66165	P1	23.5	0.15
66165	L2	335.5	0.01
66165	K2	279.6	0.02
66166	M2	275.2	0.31
66166	S2	275.9	0.09
66166	N2	252.5	0.08
66166	K1	26.1	0.5
66166	M4	160.5	0.02
66166	O1	19.2	0.48
66166	MN4	133.9	0.01
66166	NU2	258.8	0.02
66166	MU2	199.9	0.01
66166	2N2	247.7	0.01
66166	OO1	39.9	0.02
66166	S1	308.9	0.03
66166	M1	50.4	0.02
66166	J1	28.8	0.03
66166	SSA	69.3	0.24
66166	SA	155.9	0.28
66166	RHO1	9.4	0.02
66166	Q1	2.1	0.1
66166	T2	295.1	0.01
66166	2Q1	341.1	0.01
66166	P1	23.4	0.15
66166	M3	37	0.01
66166	L2	328.5	0.01
66166	K2	281.2	0.02
66166	MS4	180.7	0.01
66167	M2	274.1	0.3
66167	S2	274.5	0.08
66167	N2	253.1	0.08
66167	K1	26	0.49
66167	M4	160.8	0.02
66167	O1	19.1	0.48
66167	MK3	25	0.01
66167	S4	296.2	0.01
66167	MN4	119.4	0.01
66167	NU2	251.8	0.02
66167	MU2	204.1	0.01
66167	2N2	216.7	0.02
66167	OO1	49.5	0.02
66167	S1	319.1	0.03
66167	M1	36.2	0.01
66167	J1	37.1	0.03
66167	SSA	69.3	0.24
66167	SA	155.9	0.28
66167	RHO1	341.8	0.02
66167	Q1	0.1	0.11
66167	T2	292.8	0.01
66167	2Q1	319.2	0.01
66167	P1	27.9	0.16
66167	M3	31.2	0.01
66167	2MK3	26.8	0.01
66167	K2	278.4	0.02
66167	MS4	158.3	0.01
66168	M2	287.6	0.08
66168	S2	295.4	0.03
66168	N2	262.9	0.02
66168	K1	52	0.18
66168	M4	137.4	0.01
66168	O1	46.3	0.18
66168	S4	271.9	0.01
66168	OO1	77.8	0.02
66168	S1	63.5	0.01
66168	M1	130.6	0.01
66168	J1	68.7	0.01
66168	SSA	74.3	0.29
66168	SA	179.9	0.3
66168	Q1	26.8	0.04
66168	T2	208.1	0.01
66168	R2	295	0.01
66168	P1	44.8	0.06
66168	K2	276	0.01
66168	MS4	132.6	0.01
66169	M2	49.9	0.01
66169	K1	196.5	0.04
66169	O1	161.5	0.07
66169	OO1	144.9	0.01
66169	S1	228	0.04
66169	M1	326.7	0.01
66169	Q1	161.5	0.01
66169	T2	7.5	0.01
66169	R2	113	0.03
66169	2Q1	247	0.01
66169	P1	213.3	0.02
66169	2SM2	154.1	0.01
66169	K2	146.8	0.01
66170	M2	319.4	0.05
66170	S2	308.2	0.02
66170	N2	307.9	0.01
66170	K1	73.1	0.12
66170	M4	188.9	0.01
66170	O1	70.6	0.12
66170	MK3	245.6	0.01
66170	OO1	91.9	0.01
66170	S1	159.6	0.02
66170	J1	114.5	0.01
66170	RHO1	205.4	0.01
66170	Q1	44.8	0.03
66170	2Q1	179.7	0.01
66170	P1	85.9	0.04
66170	2MK3	232.3	0.01
66170	K2	348.7	0.01
66171	M2	51.1	0.09
66171	S2	36.6	0.02
66171	N2	33.2	0.02
66171	K1	108.4	0.3
66171	M4	295.4	0.01
66171	O1	97	0.31
66171	MU2	239.4	0.01
66171	2N2	155.4	0.01
66171	OO1	97.5	0.05
66171	S1	200.9	0.04
66171	M1	234.2	0.02
66171	J1	134.5	0.02
66171	RHO1	132.5	0.01
66171	Q1	77.8	0.07
66171	R2	79.3	0.01
66171	2Q1	182.3	0.02
66171	P1	131.1	0.09
66171	L2	87.3	0.01
66171	K2	51.5	0.03
66172	M2	336.1	0.05
66172	S2	354.9	0.02
66172	N2	303.5	0.01
66172	K1	80.6	0.26
66172	M4	141.1	0.01
66172	O1	70	0.25
66172	OO1	73.3	0.02
66172	S1	344.9	0.02
66172	M1	156.1	0.01
66172	J1	124.1	0.01
66172	RHO1	35.3	0.01
66172	Q1	50.4	0.06
66172	2Q1	132	0.01
66172	P1	85.4	0.08
66172	K2	349.6	0.01
66173	M2	245.4	0.14
66173	S2	251.6	0.05
66173	N2	229.5	0.04
66173	K1	45.2	0.37
66173	M4	42.4	0.02
66173	O1	38.8	0.37
66173	M6	202.7	0.01
66173	MK3	86	0.04
66173	MN4	39.8	0.01
66173	NU2	218.2	0.01
66173	MU2	170.6	0.01
66173	2N2	96.6	0.02
66173	OO1	83.6	0.04
66173	S1	325	0.02
66173	M1	94.1	0.01
66173	J1	71.1	0.03
66173	RHO1	45	0.02
66173	Q1	20.6	0.1
66173	2Q1	27.6	0.01
66173	P1	45.9	0.12
66173	M3	96.7	0.01
66173	2MK3	74.1	0.04
66173	K2	344.2	0.05
66173	MS4	48.1	0.01
66174	S2	17	0.01
66174	K1	178.3	0.07
66174	O1	164.7	0.07
66174	OO1	196	0.01
66174	S1	155.4	0.01
66174	J1	216.4	0.01
66174	RHO1	92.1	0.01
66174	Q1	128.9	0.02
66174	R2	341.9	0.01
66174	2Q1	203.9	0.01
66174	P1	181.2	0.03
66175	M2	16.9	0.03
66175	N2	358.5	0.01
66175	K1	117.3	0.11
66175	O1	112	0.12
66175	OO1	124.6	0.02
66175	S1	313.4	0.01
66175	M1	266.1	0.01
66175	Q1	88.6	0.03
66175	P1	118.4	0.03
66175	K2	76.6	0.01
66176	M2	332	0.03
66176	K1	104.7	0.1
66176	O1	99.3	0.1
66176	OO1	123.6	0.01
66176	S1	350.4	0.01
66176	M1	102	0.01
66176	J1	107.4	0.01
66176	SSA	69.9	0.3
66176	SA	161	0.2
66176	Q1	76.4	0.02
66176	P1	103.6	0.03
66177	M2	75.8	0.04
66177	S2	1.8	0.01
66177	N2	24.8	0.01
66177	K1	144.1	0.18
66177	M4	335.4	0.01
66177	O1	120.6	0.18
66177	MU2	306.8	0.01
66177	OO1	150.2	0.02
66177	LDA2	316.2	0.01
66177	S1	194.2	0.1
66177	M1	44.9	0.01
66177	J1	226.6	0.01
66177	SSA	52.8	0.46
66177	SA	138.5	0.31
66177	RHO1	271.5	0.01
66177	Q1	112.2	0.03
66177	T2	108.6	0.01
66177	R2	30.4	0.01
66177	P1	166.6	0.1
66177	K2	63.6	0.02
66178	M2	258.5	0.16
66178	S2	262.2	0.05
66178	N2	237.7	0.04
66178	K1	40.2	0.3
66178	M4	104.3	0.01
66178	O1	33.6	0.31
66178	MK3	137.6	0.01
66178	S4	229.1	0.01
66178	MN4	84.3	0.01
66178	NU2	248.8	0.01
66178	2N2	165.8	0.02
66178	OO1	88.8	0.01
66178	S1	47.3	0.01
66178	J1	52.3	0.02
66178	RHO1	51.8	0.02
66178	Q1	12.1	0.07
66178	T2	244.1	0.01
66178	P1	43.9	0.09
66178	M3	68.2	0.01
66178	L2	274.7	0.01
66178	2MK3	90.2	0.01
66178	K2	356.3	0.01
66178	MS4	90.1	0.01
66179	M2	251.6	0.24
66179	S2	256.7	0.07
66179	N2	233.8	0.06
66179	K1	28.3	0.42
66179	M4	95.9	0.02
66179	O1	20.6	0.42
66179	MK3	114.8	0.02
66179	S4	238.8	0.01
66179	MN4	62.4	0.01
66179	NU2	244.8	0.01
66179	MU2	193.6	0.01
66179	2N2	233	0.02
66179	OO1	70.2	0.01
66179	S1	349.7	0.01
66179	M1	18.3	0.03
66179	J1	52.3	0.03
66179	SSA	58.3	0.31
66179	SA	180.2	0.2
66179	RHO1	4.5	0.02
66179	Q1	6.5	0.1
66179	T2	254.9	0.01
66179	2Q1	355.7	0.01
66179	P1	29.1	0.13
66179	M3	51	0.01
66179	L2	301.6	0.01
66179	2MK3	90.7	0.02
66179	K2	353.9	0.02
66179	MS4	106.7	0.01
66180	M2	65.5	0.05
66180	S2	5.9	0.01
66180	N2	38.6	0.01
66180	K1	137.2	0.21
66180	O1	116.6	0.22
66180	MK3	79.3	0.01
66180	2N2	127.7	0.01
66180	OO1	150.3	0.03
66180	S1	181.9	0.08
66180	M1	190.9	0.02
66180	J1	103	0.01
66180	SSA	61.5	0.21
66180	SA	110.2	0.3
66180	RHO1	97.3	0.01
66180	Q1	96.9	0.04
66180	2Q1	185.6	0.01
66180	P1	139.3	0.09
66180	L2	113.8	0.01
66180	2MK3	71.9	0.01
66180	K2	56.1	0.02
66181	M2	262.3	0.29
66181	S2	264.5	0.08
66181	N2	241.2	0.07
66181	K1	26.3	0.57
66181	O1	20	0.55
66181	NU2	243.9	0.01
66181	OO1	32.6	0.02
66181	M1	36.5	0.05
66181	J1	29.5	0.04
66181	MM	353.3	0.06
66181	SSA	53.9	0.37
66181	SA	173.9	0.38
66181	MF	118.1	0.13
66181	RHO1	17.3	0.02
66181	Q1	1	0.11
66181	2Q1	13.7	0.02
66181	P1	26	0.18
66181	K2	264.5	0.02
66182	M2	352.7	0.05
66182	S2	347.9	0.01
66182	N2	339.9	0.01
66182	K1	98.4	0.19
66182	M4	215.3	0.01
66182	O1	87.8	0.21
66182	OO1	107.5	0.02
66182	S1	279.7	0.01
66182	M1	343.8	0.01
66182	J1	111.2	0.01
66182	SSA	58.2	0.33
66182	SA	146	0.09
66182	RHO1	60.6	0.01
66182	Q1	76	0.05
66182	2Q1	251.8	0.01
66182	P1	101.1	0.05
66182	K2	43	0.01
66183	M2	17.6	0.06
66183	S2	335.5	0.02
66183	N2	357.2	0.02
66183	K1	107.8	0.21
66183	O1	93.7	0.21
66183	MK3	18.5	0.01
66183	OO1	111.6	0.03
66183	S1	170.8	0.04
66183	M1	252.4	0.01
66183	J1	179.4	0.01
66183	RHO1	78	0.01
66183	Q1	77.4	0.05
66183	R2	340.3	0.01
66183	2Q1	137.6	0.01
66183	P1	115.6	0.07
66183	L2	50.4	0.01
66183	K2	43.2	0.01
66184	M2	20.3	0.05
66184	S2	14.3	0.02
66184	N2	5.4	0.01
66184	K1	107.9	0.2
66184	O1	95.2	0.21
66184	OO1	120.9	0.03
66184	S1	326.5	0.01
66184	M1	323.1	0.01
66184	J1	104.8	0.01
66184	SSA	58.1	0.34
66184	SA	178.9	0.08
66184	RHO1	85.6	0.01
66184	Q1	84.3	0.05
66184	2Q1	250.7	0.01
66184	P1	114.9	0.06
66184	K2	36.2	0.01
66185	M2	22.9	0.02
66185	S2	6.3	0.01
66185	K1	116	0.12
66185	O1	107.6	0.13
66185	OO1	124.5	0.01
66185	S1	16.2	0.02
66185	J1	148.9	0.01
66185	SSA	37.5	0.4
66185	SA	205.6	0.29
66185	RHO1	78.8	0.01
66185	Q1	90.2	0.03
66185	P1	114.5	0.04
66185	K2	51.6	0.01
66186	M2	260.1	0.27
66186	S2	269.3	0.07
66186	N2	240.7	0.07
66186	K1	24.5	0.52
66186	M4	115.4	0.02
66186	O1	16.8	0.53
66186	NU2	240.6	0.02
66186	2N2	221.3	0.01
66186	OO1	45.1	0.02
66186	S1	291.9	0.01
66186	M1	64.8	0.02
66186	J1	25.2	0.03
66186	SSA	58.3	0.31
66186	SA	180.2	0.2
66186	RHO1	1.3	0.03
66186	Q1	0.7	0.12
66186	2Q1	337	0.02
66186	P1	28.5	0.16
66186	L2	279.5	0.01
66186	K2	266.9	0.02
66187	M2	53.4	0.03
66187	S2	81.8	0.01
66187	N2	24.2	0.01
66187	K1	123.8	0.18
66187	O1	112.9	0.16
66187	2N2	198.9	0.01
66187	OO1	174.2	0.01
66187	S1	147.7	0.02
66187	M1	207.8	0.01
66187	J1	160.2	0.01
66187	SSA	58.8	0.23
66187	SA	196.1	0.18
66187	RHO1	92.2	0.01
66187	Q1	92.2	0.04
66187	T2	257.6	0.01
66187	2Q1	287.6	0.01
66187	P1	116.8	0.04
66187	2MK3	37.8	0.01
66187	K2	50	0.02
66188	M2	266.7	0.19
66188	S2	273.3	0.05
66188	N2	247	0.05
66188	K1	34.8	0.42
66188	O1	28.8	0.43
66188	MK3	77.6	0.01
66188	NU2	249.8	0.01
66188	MU2	186.6	0.01
66188	OO1	55.8	0.02
66188	S1	322.8	0.02
66188	M1	99.3	0.01
66188	J1	55.3	0.02
66188	SSA	49.6	0.26
66188	SA	186.1	0.22
66188	RHO1	25.8	0.03
66188	Q1	12.2	0.1
66188	T2	279.4	0.01
66188	2Q1	0.7	0.01
66188	P1	37.3	0.13
66188	M3	74.1	0.01
66188	2MK3	69.6	0.01
66188	K2	320.3	0.02
66189	M2	260	0.21
66189	S2	267.9	0.06
66189	N2	241.2	0.05
66189	K1	30.7	0.45
66189	O1	23.5	0.46
66189	MK3	67.8	0.01
66189	NU2	251.5	0.01
66189	MU2	191.1	0.01
66189	2N2	183	0.01
66189	OO1	36.9	0.02
66189	S1	337.7	0.02
66189	J1	52.9	0.03
66189	SSA	46.6	0.26
66189	SA	186.1	0.22
66189	RHO1	26.6	0.02
66189	Q1	10.1	0.1
66189	T2	283.7	0.01
66189	2Q1	344	0.01
66189	P1	33.1	0.14
66189	M3	68.2	0.01
66189	2MK3	58.1	0.01
66189	K2	302.1	0.02
66190	M2	258.4	0.24
66190	S2	265.1	0.07
66190	N2	234	0.06
66190	K1	28	0.52
66190	O1	21.5	0.52
66190	NU2	237.2	0.01
66190	OO1	34.5	0.02
66190	M1	24.7	0.04
66190	J1	31.2	0.04
66190	MM	202	0.06
66190	SSA	56.2	0.28
66190	SA	206.6	0.27
66190	MSF	219.6	0.03
66190	MF	321.5	0.1
66190	RHO1	18.7	0.02
66190	Q1	3.4	0.13
66190	2Q1	15	0.01
66190	P1	32.7	0.17
66190	K2	265.1	0.02
66191	M2	274.3	0.21
66191	S2	285.8	0.06
66191	N2	256.8	0.05
66191	K1	36.5	0.43
66191	O1	29	0.43
66191	MK3	110.4	0.01
66191	NU2	260.3	0.01
66191	MU2	205.5	0.01
66191	2N2	216.3	0.01
66191	OO1	57.6	0.02
66191	S1	8.7	0.01
66191	M1	58.5	0.02
66191	J1	39.6	0.03
66191	SSA	49.6	0.26
66191	SA	186.1	0.22
66191	RHO1	15.2	0.02
66191	Q1	12.6	0.09
66191	T2	287.2	0.01
66191	2Q1	4.6	0.01
66191	P1	36.3	0.13
66191	M3	78.7	0.01
66191	L2	339.4	0.01
66191	2MK3	96.1	0.01
66191	K2	312.4	0.01
66192	M2	144.4	1.59
66192	S2	138.4	0.64
66192	N2	122.7	0.37
66192	K1	210.8	1.14
66192	M4	269.9	0.01
66192	O1	194.2	0.71
66192	S4	241.6	0.01
66192	NU2	125.6	0.07
66192	MU2	150.4	0.04
66192	2N2	101	0.05
66192	OO1	227.5	0.03
66192	LDA2	141.6	0.01
66192	M1	202.6	0.05
66192	J1	219.2	0.06
66192	SSA	261	0.05
66192	SA	175.7	0.26
66192	RHO1	187	0.03
66192	Q1	185.9	0.14
66192	T2	138.6	0.04
66192	R2	138.1	0.01
66192	2Q1	177.7	0.02
66192	P1	209.6	0.38
66192	L2	166.1	0.05
66192	K2	137.9	0.17
66193	M2	143.6	1.63
66193	S2	139.6	0.66
66193	N2	122.6	0.38
66193	K1	208.9	1.16
66193	M4	313.2	0.01
66193	O1	192.2	0.69
66193	S4	230.5	0.01
66193	NU2	125.4	0.07
66193	MU2	147.5	0.04
66193	2N2	101.6	0.05
66193	OO1	225.7	0.03
66193	LDA2	141.7	0.01
66193	M1	200.6	0.05
66193	J1	217.3	0.06
66193	SSA	261	0.05
66193	SA	175.7	0.26
66193	RHO1	185	0.03
66193	Q1	183.8	0.13
66193	T2	139.8	0.04
66193	R2	139.5	0.01
66193	2Q1	175.4	0.02
66193	P1	207.7	0.38
66193	L2	164.5	0.05
66193	K2	139.3	0.18
66194	M2	144.7	1.85
66194	S2	142.6	0.78
66194	N2	125.1	0.43
66194	K1	209.3	1.16
66194	M4	251.7	0.01
66194	O1	192.7	0.71
66194	M6	52.1	0.02
66194	S4	213.6	0.01
66194	NU2	127.8	0.09
66194	MU2	146.8	0.05
66194	2N2	105.5	0.06
66194	OO1	225.9	0.03
66194	LDA2	143.7	0.01
66194	M1	201	0.05
66194	J1	217.5	0.06
66194	SA	179.3	0.23
66194	RHO1	185.5	0.03
66194	Q1	184.4	0.14
66194	T2	142.7	0.05
66194	R2	142.5	0.01
66194	2Q1	176.2	0.02
66194	P1	208	0.38
66194	L2	164.3	0.05
66194	K2	142.4	0.21
66195	M2	142.3	1.68
66195	S2	137.9	0.71
66195	N2	123.7	0.4
66195	K1	207.1	1.12
66195	M4	273.3	0.02
66195	O1	191.6	0.7
66195	NU2	126.2	0.08
66195	MU2	146.9	0.04
66195	2N2	105	0.05
66195	OO1	222.4	0.03
66195	LDA2	140.3	0.01
66195	M1	199.4	0.05
66195	J1	214.7	0.06
66195	SA	184.3	0.23
66195	RHO1	185.1	0.03
66195	Q1	184	0.13
66195	T2	138	0.04
66195	2Q1	176.3	0.02
66195	P1	205.9	0.37
66195	L2	161	0.05
66195	K2	137.5	0.19
66196	M2	143.2	1.82
66196	S2	140.2	0.75
66196	N2	123.8	0.43
66196	K1	208	1.14
66196	O1	192.4	0.72
66196	M6	61.4	0.01
66196	NU2	128.8	0.08
66196	MU2	93	0.05
66196	2N2	97.5	0.05
66196	OO1	241.1	0.04
66196	LDA2	128.8	0.01
66196	S1	338.8	0.01
66196	M1	220.4	0.04
66196	J1	220.6	0.07
66196	SA	179.3	0.23
66196	RHO1	184.3	0.03
66196	Q1	184.7	0.13
66196	T2	127.3	0.05
66196	R2	140.1	0.01
66196	2Q1	182.1	0.01
66196	P1	205.5	0.36
66196	M3	346.1	0.01
66196	L2	144	0.05
66196	K2	134.3	0.22
66197	M2	144	1.68
66197	S2	141.2	0.7
66197	N2	123.7	0.39
66197	K1	208.8	1.13
66197	O1	192.3	0.69
66197	M6	343.1	0.01
66197	S4	218.8	0.01
66197	NU2	126.4	0.08
66197	MU2	146.7	0.04
66197	2N2	103.5	0.05
66197	OO1	225.3	0.03
66197	LDA2	142.7	0.01
66197	M1	200.6	0.05
66197	J1	217	0.06
66197	SSA	261	0.05
66197	SA	175.7	0.26
66197	RHO1	185.2	0.03
66197	Q1	184.1	0.13
66197	T2	141.3	0.04
66197	R2	141.1	0.01
66197	2Q1	175.8	0.02
66197	P1	207.6	0.37
66197	L2	164.2	0.05
66197	K2	141	0.19
66198	M2	142	1.64
66198	S2	138.6	0.67
66198	N2	121.7	0.38
66198	K1	207	1.09
66198	O1	191.8	0.7
66198	NU2	126.5	0.08
66198	MU2	85.4	0.06
66198	2N2	94.2	0.05
66198	OO1	244.2	0.03
66198	LDA2	141.5	0.01
66198	M1	221	0.04
66198	J1	221	0.07
66198	SSA	261	0.05
66198	SA	175.7	0.26
66198	RHO1	180.6	0.02
66198	Q1	184.4	0.12
66198	T2	131.9	0.04
66198	R2	77.4	0.01
66198	2Q1	177.2	0.02
66198	P1	203.1	0.34
66198	M3	346.8	0.01
66198	L2	132	0.03
66198	K2	130.4	0.19
66199	M2	144.4	1.66
66199	S2	140.2	0.67
66199	N2	124.1	0.39
66199	K1	208	1.1
66199	M4	282.4	0.01
66199	O1	192.7	0.71
66199	NU2	126.2	0.07
66199	MU2	84.2	0.05
66199	2N2	97.3	0.05
66199	OO1	239.5	0.04
66199	LDA2	142.4	0.01
66199	S1	312.8	0.02
66199	M1	218	0.04
66199	J1	218.4	0.07
66199	SSA	280.2	0.05
66199	SA	183.4	0.21
66199	RHO1	186.2	0.03
66199	Q1	184.4	0.13
66199	T2	128.8	0.04
66199	R2	140.1	0.01
66199	2Q1	177.5	0.02
66199	P1	203.3	0.35
66199	M3	354.2	0.01
66199	L2	148	0.05
66199	K2	133.1	0.2
66200	M2	145.5	1.69
66200	S2	141.1	0.67
66200	N2	123.7	0.4
66200	K1	207.7	1.13
66200	O1	192.3	0.72
66200	NU2	130.2	0.08
66200	MU2	88.1	0.06
66200	2N2	95.1	0.05
66200	OO1	236.9	0.04
66200	LDA2	166.4	0.01
66200	S1	314.1	0.01
66200	M1	222.6	0.04
66200	J1	219.1	0.07
66200	SA	184.4	0.22
66200	RHO1	182.1	0.03
66200	Q1	185	0.13
66200	T2	129.7	0.04
66200	R2	167.5	0.01
66200	2Q1	186.1	0.01
66200	P1	204.6	0.35
66200	M3	350.1	0.01
66200	L2	134.2	0.03
66200	K2	135.5	0.2
66201	M2	145.6	1.73
66201	S2	140.8	0.68
66201	N2	124	0.41
66201	K1	207.7	1.14
66201	O1	192.4	0.73
66201	NU2	131	0.08
66201	MU2	88.7	0.06
66201	2N2	96.7	0.05
66201	OO1	238.1	0.04
66201	LDA2	143.3	0.01
66201	S1	329.4	0.01
66201	M1	220.1	0.04
66201	J1	220	0.07
66201	SSA	282	0.06
66201	SA	181.6	0.19
66201	MF	135.8	0.02
66201	RHO1	185.8	0.03
66201	Q1	184	0.13
66201	T2	129	0.04
66201	R2	140.7	0.01
66201	2Q1	177.1	0.02
66201	P1	204.1	0.36
66201	M3	352.8	0.01
66201	L2	167.2	0.05
66201	K2	134.7	0.2
66202	M2	146.8	1.67
66202	S2	143.1	0.66
66202	N2	125.3	0.39
66202	K1	208.9	1.12
66202	M4	284.3	0.01
66202	O1	193.5	0.72
66202	S4	270.2	0.01
66202	NU2	132.2	0.08
66202	MU2	88.9	0.06
66202	2N2	97.9	0.05
66202	OO1	236.6	0.04
66202	LDA2	154.6	0.01
66202	S1	290.7	0.01
66202	M1	219	0.04
66202	J1	221.3	0.07
66202	SSA	265.5	0.04
66202	SA	177.9	0.25
66202	RHO1	186	0.03
66202	Q1	185.6	0.13
66202	T2	129.4	0.04
66202	2Q1	182.1	0.02
66202	P1	205.3	0.35
66202	2SM2	347.5	0.01
66202	M3	349.7	0.01
66202	L2	155.3	0.03
66202	K2	135.3	0.19
66203	M2	154.8	1.65
66203	S2	149.1	0.6
66203	N2	133	0.39
66203	K1	211.7	1.16
66203	M4	282.5	0.01
66203	O1	196.7	0.73
66203	NU2	137.2	0.08
66203	MU2	93.3	0.05
66203	2N2	105.5	0.05
66203	OO1	246.7	0.04
66203	LDA2	155.1	0.01
66203	S1	323.6	0.02
66203	M1	222.5	0.04
66203	J1	222.1	0.07
66203	SA	176	0.24
66203	RHO1	186	0.03
66203	Q1	187.6	0.13
66203	T2	138.7	0.03
66203	R2	113.9	0.01
66203	2Q1	188.1	0.01
66203	P1	207.8	0.37
66203	2SM2	332.4	0.01
66203	M3	357.4	0.01
66203	L2	169	0.06
66203	K2	141.4	0.17
66204	M2	156.4	1.63
66204	S2	150.8	0.58
66204	N2	133.2	0.38
66204	K1	212.4	1.16
66204	M4	288.8	0.01
66204	O1	197.2	0.73
66204	NU2	140.1	0.07
66204	MU2	94.8	0.05
66204	2N2	104.2	0.05
66204	OO1	241.2	0.04
66204	LDA2	177.7	0.01
66204	S1	307.9	0.02
66204	M1	220.7	0.04
66204	J1	226.2	0.07
66204	SA	176	0.24
66204	MF	158.4	0.02
66204	RHO1	189.1	0.03
66204	Q1	189.4	0.13
66204	T2	139.5	0.03
66204	R2	113.3	0.01
66204	2Q1	185.6	0.01
66204	P1	207.5	0.37
66204	2SM2	336.3	0.01
66204	M3	1.8	0.01
66204	L2	167.2	0.02
66204	K2	143.1	0.17
66205	M2	158.3	1.6
66205	S2	151.3	0.56
66205	N2	133.2	0.37
66205	K1	211.4	1.16
66205	M4	275.6	0.01
66205	O1	198.4	0.72
66205	S4	311.1	0.01
66205	NU2	136.5	0.07
66205	MU2	165.3	0.04
66205	2N2	108.1	0.05
66205	OO1	224.5	0.03
66205	LDA2	155	0.01
66205	M1	204.9	0.05
66205	J1	217.9	0.06
66205	SA	156.8	0.26
66205	RHO1	192.8	0.03
66205	Q1	191.9	0.14
66205	T2	151.6	0.03
66205	2Q1	185.5	0.02
66205	P1	210.5	0.38
66205	L2	183.4	0.05
66205	K2	150.7	0.15
66206	M2	162.6	1.61
66206	S2	156.7	0.53
66206	N2	138.7	0.38
66206	K1	214.8	1.19
66206	M4	305.8	0.02
66206	O1	200.2	0.75
66206	MK3	29.2	0.02
66206	NU2	147.5	0.08
66206	MU2	92.6	0.05
66206	2N2	106.9	0.04
66206	OO1	245.5	0.04
66206	LDA2	186.5	0.02
66206	S1	323.6	0.05
66206	M1	223.4	0.05
66206	J1	224.8	0.07
66206	SSA	280.1	0.06
66206	SA	195.6	0.17
66206	RHO1	168.5	0.02
66206	Q1	192.2	0.13
66206	T2	153.6	0.03
66206	2Q1	170.5	0.02
66206	P1	211.7	0.39
66206	L2	199.4	0.04
66206	K2	150.1	0.14
66207	M2	168.1	1.64
66207	S2	163.7	0.49
66207	N2	144	0.38
66207	K1	214.7	1.19
66207	O1	198.8	0.74
66207	NU2	150.2	0.07
66207	MU2	103.1	0.05
66207	2N2	114.6	0.05
66207	OO1	242.2	0.04
66207	LDA2	188.1	0.01
66207	S1	315.5	0.02
66207	M1	222.2	0.05
66207	J1	225.6	0.07
66207	SSA	279.1	0.1
66207	SA	191.9	0.18
66207	MF	123.7	0.02
66207	RHO1	194.8	0.03
66207	Q1	190.7	0.13
66207	T2	151.7	0.03
66207	2Q1	186.5	0.01
66207	P1	211.9	0.38
66207	L2	187.2	0.04
66207	K2	156.1	0.14
66208	M2	174.8	1.6
66208	S2	173.7	0.45
66208	N2	147.9	0.35
66208	K1	218.7	1.14
66208	M4	321.6	0.01
66208	O1	202.3	0.71
66208	M6	262.3	0.01
66208	S4	256.4	0.01
66208	NU2	151.5	0.07
66208	S6	167.8	0.01
66208	MU2	175.8	0.04
66208	2N2	121.1	0.05
66208	OO1	235.1	0.03
66208	LDA2	174.3	0.01
66208	M1	210.5	0.05
66208	J1	226.8	0.06
66208	SSA	279.1	0.1
66208	SA	191.9	0.18
66208	RHO1	195.2	0.03
66208	Q1	194.1	0.14
66208	T2	173.8	0.03
66208	2Q1	186	0.02
66208	P1	217.5	0.38
66208	L2	201.4	0.05
66208	K2	173.6	0.12
66209	M2	181.3	1.61
66209	S2	180.1	0.43
66209	N2	155	0.37
66209	K1	219.6	1.2
66209	O1	203.5	0.75
66209	NU2	160.9	0.07
66209	MU2	114.7	0.04
66209	2N2	125.4	0.05
66209	OO1	246.4	0.04
66209	LDA2	213.6	0.01
66209	S1	317.1	0.03
66209	M1	224.9	0.04
66209	J1	232.3	0.07
66209	SSA	264.6	0.07
66209	SA	198.5	0.2
66209	MF	138.1	0.04
66209	RHO1	197	0.02
66209	Q1	194.8	0.13
66209	T2	165.3	0.02
66209	2Q1	191.7	0.02
66209	P1	215.8	0.38
66209	M3	7	0.01
66209	L2	213.4	0.04
66209	K2	170.6	0.12
66210	M2	189.9	1.65
66210	S2	197.8	0.4
66210	N2	168.9	0.36
66210	K1	228.4	1.17
66210	M4	113.2	0.06
66210	O1	212.1	0.72
66210	M6	116.9	0.02
66210	MK3	198.5	0.04
66210	MN4	93.9	0.02
66210	NU2	166.5	0.07
66210	MU2	220.3	0.01
66210	2N2	147.5	0.05
66210	OO1	253.9	0.04
66210	LDA2	149.3	0.03
66210	S1	7.4	0.05
66210	M1	239.7	0.05
66210	J1	245.7	0.06
66210	RHO1	178.8	0.02
66210	Q1	208.2	0.12
66210	T2	230.2	0.02
66210	R2	173.5	0.04
66210	2Q1	179.6	0.01
66210	P1	220.2	0.33
66210	2SM2	338.2	0.01
66210	M3	312.9	0.01
66210	L2	167.1	0.07
66210	2MK3	206	0.04
66210	K2	175.4	0.14
66210	M8	74.1	0.01
66210	MS4	122.4	0.03
66211	M2	194.4	1.61
66211	S2	196.5	0.47
66211	N2	173.1	0.37
66211	K1	228.7	1.16
66211	M4	144	0.08
66211	O1	213.9	0.72
66211	M6	147.1	0.04
66211	NU2	176	0.07
66211	MU2	309	0.04
66211	2N2	151.9	0.05
66211	OO1	243.5	0.03
66211	LDA2	195.3	0.01
66211	M1	221.4	0.05
66211	J1	236	0.06
66211	RHO1	207.6	0.03
66211	Q1	206.6	0.14
66211	T2	196.4	0.03
66211	2Q1	199.2	0.02
66211	P1	227.6	0.38
66211	L2	215.7	0.05
66211	K2	196.7	0.13
66211	M8	101.4	0.01
66212	M2	195	1.66
66212	S2	200.6	0.48
66212	N2	174	0.37
66212	K1	229.5	1.15
66212	M4	146.6	0.09
66212	O1	214.2	0.73
66212	M6	148.9	0.05
66212	NU2	176.8	0.07
66212	MU2	248.2	0.02
66212	2N2	153.1	0.05
66212	OO1	244.8	0.03
66212	LDA2	197.4	0.01
66212	M1	221.9	0.05
66212	J1	237.1	0.06
66212	SSA	264.6	0.07
66212	SA	198.5	0.2
66212	MF	138.1	0.04
66212	RHO1	207.5	0.03
66212	Q1	206.6	0.14
66212	T2	200.3	0.03
66212	2Q1	199	0.02
66212	P1	228.4	0.38
66212	L2	215.9	0.05
66212	K2	201.1	0.13
66212	M8	108	0.01
66213	M2	193	1.69
66213	S2	199.1	0.47
66213	N2	171.3	0.4
66213	K1	228.7	1.16
66213	M4	139.1	0.07
66213	O1	214.9	0.73
66213	M6	141	0.03
66213	S4	202.2	0.01
66213	NU2	174.2	0.08
66213	MU2	186.6	0.04
66213	2N2	149.7	0.05
66213	OO1	242.4	0.03
66213	LDA2	195.8	0.01
66213	M1	221.8	0.05
66213	J1	235.5	0.06
66213	RHO1	209	0.03
66213	Q1	208.1	0.14
66213	T2	198.9	0.03
66213	2Q1	201.3	0.02
66213	P1	227.6	0.38
66213	L2	214.5	0.05
66213	K2	199.6	0.13
66213	M8	78.3	0.01
66214	M2	184.1	1.78
66214	S2	189.6	0.47
66214	N2	158.4	0.39
66214	K1	217.3	1.15
66214	M4	283	0.01
66214	O1	203.3	0.74
66214	NU2	161.9	0.08
66214	S6	107.8	0.01
66214	MU2	178.7	0.04
66214	2N2	132.6	0.05
66214	OO1	231.4	0.03
66214	LDA2	186.7	0.01
66214	M1	210.4	0.05
66214	J1	224.3	0.06
66214	SSA	286.9	0.13
66214	SA	221.4	0.12
66214	RHO1	197.2	0.03
66214	Q1	196.3	0.14
66214	T2	189.3	0.03
66214	2Q1	189.3	0.02
66214	P1	216.3	0.38
66214	L2	209.8	0.05
66214	K2	190	0.13
66215	M2	208.2	1.89
66215	S2	216.2	0.45
66215	N2	183.2	0.4
66215	K1	225.4	1.21
66215	M4	136.8	0.07
66215	O1	208.4	0.75
66215	M6	7.3	0.01
66215	MK3	124.1	0.06
66215	MN4	112	0.03
66215	NU2	189.9	0.09
66215	MU2	100.2	0.02
66215	2N2	153.3	0.04
66215	OO1	260	0.04
66215	LDA2	214.3	0.02
66215	S1	282.6	0.02
66215	M1	237.5	0.04
66215	J1	244.3	0.06
66215	SSA	272.3	0.1
66215	SA	200.2	0.14
66215	MF	153.1	0.05
66215	RHO1	200	0.03
66215	Q1	202.4	0.13
66215	T2	204.6	0.03
66215	2Q1	208.6	0.02
66215	P1	222.1	0.37
66215	2SM2	37.3	0.01
66215	M3	37.6	0.01
66215	L2	229.6	0.06
66215	2MK3	92.2	0.05
66215	K2	206	0.13
66215	MS4	149	0.03
66216	M2	213.3	1.99
66216	S2	220.7	0.46
66216	N2	187	0.42
66216	K1	226.8	1.23
66216	M4	135.9	0.1
66216	O1	209.7	0.76
66216	MK3	124	0.09
66216	MN4	108.6	0.04
66216	NU2	191.6	0.09
66216	MU2	88.1	0.02
66216	2N2	154.1	0.05
66216	OO1	262.7	0.04
66216	LDA2	215	0.03
66216	S1	276.5	0.02
66216	M1	248.5	0.04
66216	J1	248.5	0.06
66216	SSA	286.9	0.13
66216	SA	221.4	0.12
66216	RHO1	198.4	0.03
66216	Q1	202.7	0.13
66216	T2	201.8	0.03
66216	2Q1	186.3	0.02
66216	P1	223.8	0.39
66216	M3	29.8	0.03
66216	L2	225.5	0.06
66216	2MK3	91.5	0.06
66216	K2	211.5	0.13
66216	MS4	147.1	0.04
66217	M2	218.9	2.11
66217	S2	227.2	0.47
66217	N2	193.5	0.44
66217	K1	229.5	1.25
66217	M4	135.2	0.08
66217	O1	212.8	0.76
66217	M6	70.7	0.02
66217	MK3	118.8	0.08
66217	MN4	110	0.03
66217	NU2	199	0.09
66217	MU2	76.7	0.02
66217	2N2	160.1	0.05
66217	OO1	263.6	0.05
66217	LDA2	204.9	0.03
66217	S1	273.2	0.02
66217	M1	254.4	0.04
66217	J1	255.6	0.06
66217	SSA	286.9	0.13
66217	SA	221.4	0.12
66217	RHO1	202.5	0.03
66217	Q1	207.3	0.13
66217	T2	217.9	0.03
66217	2Q1	182.6	0.01
66217	P1	227.1	0.39
66217	2SM2	48.4	0.02
66217	M3	37.6	0.03
66217	L2	226.4	0.08
66217	2MK3	86.1	0.07
66217	K2	217.3	0.15
66217	MS4	150.5	0.03
66218	M2	223.6	2.32
66218	S2	236.5	0.53
66218	N2	199.5	0.48
66218	K1	232.1	1.29
66218	M4	141	0.06
66218	O1	214.8	0.77
66218	M6	59.7	0.02
66218	MK3	113.3	0.08
66218	MN4	112.9	0.02
66218	NU2	198.4	0.1
66218	MU2	41.3	0.02
66218	2N2	172.9	0.05
66218	OO1	275	0.04
66218	LDA2	217.5	0.04
66218	S1	271.5	0.04
66218	M1	254	0.05
66218	J1	265.5	0.07
66218	SSA	286.9	0.13
66218	SA	221.4	0.12
66218	RHO1	177.1	0.04
66218	Q1	215.7	0.14
66218	T2	181.5	0.03
66218	R2	250.8	0.02
66218	2Q1	242.2	0.02
66218	P1	231.1	0.41
66218	2SM2	69.1	0.02
66218	M3	43.3	0.03
66218	L2	224.9	0.1
66218	2MK3	81.5	0.08
66218	K2	216.2	0.15
66218	MS4	173.6	0.02
66219	M2	235.5	2.47
66219	S2	246.6	0.54
66219	N2	213.4	0.51
66219	K1	238.3	1.31
66219	M4	179	0.03
66219	O1	221.7	0.79
66219	M6	79.3	0.02
66219	MK3	115.2	0.07
66219	MN4	149.3	0.01
66219	NU2	193.3	0.11
66219	MU2	45.1	0.03
66219	2N2	194.1	0.05
66219	OO1	290.6	0.04
66219	LDA2	187.4	0.01
66219	S1	280.6	0.06
66219	M1	267	0.05
66219	J1	271.9	0.06
66219	SSA	286.9	0.13
66219	SA	221.4	0.12
66219	RHO1	195	0.04
66219	Q1	219.9	0.14
66219	T2	196.7	0.04
66219	R2	23.9	0.04
66219	2Q1	229	0.02
66219	P1	237.5	0.4
66219	2SM2	31.3	0.02
66219	M3	42.7	0.03
66219	L2	233.9	0.13
66219	2MK3	86.5	0.09
66219	K2	228.6	0.17
66220	M2	238	2.71
66220	S2	253.3	0.6
66220	N2	216	0.54
66220	K1	239.5	1.32
66220	M4	340.4	0.04
66220	O1	223.9	0.79
66220	M6	48.2	0.03
66220	MK3	83	0.07
66220	MN4	318.3	0.02
66220	NU2	216.5	0.13
66220	MU2	9	0.06
66220	2N2	199.1	0.06
66220	OO1	281.7	0.05
66220	LDA2	218.6	0.06
66220	S1	229	0.04
66220	M1	274.4	0.05
66220	J1	275.4	0.07
66220	SSA	286.9	0.13
66220	SA	221.4	0.12
66220	MF	139.6	0.04
66220	RHO1	217.3	0.03
66220	Q1	221.4	0.14
66220	T2	225.9	0.03
66220	R2	47.5	0.01
66220	2Q1	236.1	0.02
66220	P1	238.8	0.41
66220	2SM2	56.2	0.03
66220	L2	233.2	0.12
66220	2MK3	65.7	0.11
66220	K2	238.9	0.2
66220	MS4	3	0.03
66221	M2	241.7	2.86
66221	S2	259.8	0.63
66221	N2	219.8	0.59
66221	K1	240.9	1.36
66221	M4	2.1	0.04
66221	O1	225.1	0.81
66221	M6	55.3	0.04
66221	MK3	93	0.1
66221	MN4	13	0.02
66221	NU2	227.5	0.12
66221	MU2	11	0.07
66221	2N2	208.2	0.04
66221	OO1	279.2	0.04
66221	LDA2	216	0.06
66221	S1	222.6	0.05
66221	M1	268.3	0.05
66221	J1	282.5	0.06
66221	SSA	286.9	0.13
66221	SA	221.4	0.12
66221	RHO1	195.3	0.03
66221	Q1	225.9	0.15
66221	T2	234	0.04
66221	R2	260.6	0.01
66221	2Q1	214.8	0.02
66221	P1	237.4	0.42
66221	2SM2	47.4	0.03
66221	M3	3.8	0.03
66221	L2	229.5	0.18
66221	2MK3	77.5	0.13
66221	K2	238.1	0.2
66221	M8	119.2	0.01
66221	MS4	7.1	0.03
66222	M2	246.7	3.04
66222	S2	264.2	0.65
66222	N2	225.6	0.59
66222	K1	244	1.38
66222	M4	10.2	0.06
66222	O1	228.9	0.81
66222	M6	49.9	0.06
66222	MK3	95.6	0.1
66222	MN4	356.7	0.03
66222	NU2	226.8	0.14
66222	MU2	25.7	0.07
66222	2N2	199.6	0.07
66222	OO1	283.2	0.04
66222	LDA2	212.2	0.04
66222	S1	218.3	0.07
66222	M1	272.4	0.05
66222	J1	281.9	0.06
66222	SSA	286.9	0.13
66222	SA	221.4	0.12
66222	RHO1	215.5	0.04
66222	Q1	228.1	0.15
66222	T2	249.3	0.03
66222	R2	264.9	0.01
66222	2Q1	215.9	0.03
66222	P1	240.8	0.45
66222	2SM2	75	0.03
66222	M3	354.4	0.02
66222	L2	237.1	0.19
66222	2MK3	80.6	0.15
66222	K2	244.6	0.24
66222	M8	105.8	0.01
66222	MS4	23.3	0.04
66223	M2	237.2	2.9
66223	S2	254.8	0.66
66223	N2	216.8	0.59
66223	K1	240	1.33
66223	M4	316.8	0.07
66223	O1	224.5	0.78
66223	M6	43.9	0.03
66223	MK3	73.1	0.06
66223	MN4	300.2	0.03
66223	NU2	216.4	0.13
66223	MU2	353.2	0.07
66223	2N2	199.9	0.06
66223	OO1	288.1	0.04
66223	LDA2	215.3	0.06
66223	S1	223.8	0.05
66223	M1	272.8	0.05
66223	J1	276	0.07
66223	SSA	265.9	0.07
66223	SA	181.7	0.18
66223	MF	149.6	0.06
66223	RHO1	222.6	0.03
66223	Q1	222.1	0.14
66223	T2	222.6	0.03
66223	R2	58.6	0.02
66223	2Q1	217.8	0.02
66223	P1	239.3	0.41
66223	2SM2	57.8	0.03
66223	M3	127.9	0.02
66223	L2	233.6	0.16
66223	2MK3	60.2	0.12
66223	K2	239.1	0.21
66223	MS4	343.4	0.04
66224	M2	250.1	3.13
66224	S2	273.8	0.7
66224	N2	232.7	0.63
66224	K1	246.9	1.3
66224	M4	1.6	0.16
66224	O1	232.8	0.74
66224	M6	44.1	0.07
66224	MK3	66.8	0.1
66224	S4	96.4	0.01
66224	MN4	342.8	0.07
66224	NU2	227.1	0.15
66224	MU2	357.2	0.13
66224	2N2	220.2	0.06
66224	OO1	307.7	0.04
66224	LDA2	224.2	0.08
66224	S1	214.9	0.1
66224	M1	283.5	0.06
66224	J1	300.3	0.06
66224	SSA	272.3	0.1
66224	SA	200.2	0.14
66224	RHO1	227	0.03
66224	Q1	235.1	0.13
66224	T2	229	0.04
66224	R2	43.9	0.03
66224	2Q1	246.5	0.01
66224	P1	246.1	0.4
66224	2SM2	68.9	0.04
66224	M3	146.7	0.04
66224	L2	241.2	0.22
66224	2MK3	68	0.16
66224	K2	254.3	0.22
66224	M8	96.2	0.02
66224	MS4	24.3	0.09
66225	M2	239.6	2.53
66225	S2	254.9	0.53
66225	N2	217.5	0.52
66225	K1	242.1	1.31
66225	M4	81.2	0.01
66225	O1	226.5	0.77
66225	M6	71.1	0.01
66225	MK3	95.4	0.09
66225	MN4	39.9	0.01
66225	NU2	223.7	0.14
66225	MU2	357.5	0.03
66225	2N2	175	0.08
66225	OO1	271.4	0.05
66225	LDA2	252.5	0.08
66225	S1	325.5	0.05
66225	M1	269.7	0.06
66225	J1	274.2	0.07
66225	SSA	288.3	0.12
66225	SA	227.8	0.1
66225	MF	147.5	0.04
66225	RHO1	236.1	0.03
66225	Q1	223.3	0.14
66225	T2	250.7	0.08
66225	R2	12.2	0.04
66225	2Q1	175.1	0.02
66225	P1	240.1	0.37
66225	2SM2	61.2	0.03
66225	M3	112.1	0.01
66225	L2	229.7	0.12
66225	2MK3	66.5	0.1
66225	K2	233.4	0.19
66225	MS4	50.8	0.01
66226	M2	221.5	2.192
66226	S2	234.6	0.545
66226	N2	196.4	0.44
66226	K1	229.9	1.243
66226	M4	114.5	0.075
66226	O1	215.7	0.758
66226	M6	64.2	0.01
66226	S4	206.4	0.003
66226	NU2	199.8	0.085
66226	S6	225.5	0.003
66226	MU2	208.2	0.052
66226	2N2	171.5	0.059
66226	OO1	244.1	0.033
66226	LDA2	227.6	0.016
66226	M1	222.9	0.056
66226	J1	236.9	0.059
66226	SSA	288.3	0.121
66226	SA	227.8	0.105
66226	MF	147.5	0.043
66226	RHO1	209.6	0.03
66226	Q1	208.7	0.148
66226	T2	234	0.033
66226	R2	235.2	0.003
66226	2Q1	201.6	0.02
66226	P1	228.8	0.413
66226	L2	246.5	0.062
66226	K2	235.7	0.148
66226	M8	224.8	0.003
66227	M2	223.3	2.23
66227	S2	234.4	0.5
66227	N2	199.5	0.46
66227	K1	232.7	1.24
66227	M4	138.2	0.05
66227	O1	216.2	0.76
66227	M6	32	0.02
66227	MK3	105.3	0.06
66227	MN4	119.5	0.02
66227	NU2	205.2	0.1
66227	MU2	36.1	0.03
66227	2N2	173.9	0.05
66227	OO1	276.4	0.04
66227	LDA2	217.4	0.03
66227	S1	282.4	0.04
66227	M1	256.9	0.04
66227	J1	258.3	0.06
66227	SSA	272.5	0.1
66227	SA	187.8	0.13
66227	MF	153.2	0.06
66227	RHO1	209.8	0.03
66227	Q1	211.3	0.13
66227	T2	219.7	0.03
66227	R2	68.3	0.01
66227	2Q1	215.2	0.02
66227	P1	230.1	0.38
66227	2SM2	42.8	0.02
66227	M3	121.9	0.01
66227	L2	236.7	0.1
66227	2MK3	72.4	0.07
66227	K2	222.2	0.15
66227	MS4	161.3	0.02
66228	M2	221	2.08
66228	S2	228.9	0.53
66228	N2	197.2	0.45
66228	K1	231.2	1.25
66228	M4	130	0.08
66228	O1	215.4	0.72
66228	M6	79.9	0.02
66228	NU2	200.4	0.09
66228	MU2	213.1	0.05
66228	2N2	173.4	0.06
66228	OO1	246.9	0.03
66228	LDA2	224.7	0.01
66228	M1	223.3	0.05
66228	J1	239	0.06
66228	SSA	288.3	0.12
66228	SA	227.8	0.1
66228	MF	147.5	0.04
66228	RHO1	208.5	0.03
66228	Q1	207.5	0.14
66228	T2	228.6	0.03
66228	2Q1	199.7	0.02
66228	P1	230	0.42
66228	L2	244.6	0.06
66228	K2	229.6	0.14
66229	M2	222.4	2.16
66229	S2	231.5	0.51
66229	N2	199.1	0.4
66229	K1	231.3	1.26
66229	M4	155.1	0.05
66229	O1	216.6	0.76
66229	M6	39	0.03
66229	S4	282.7	0.01
66229	NU2	202.2	0.08
66229	MU2	213.4	0.05
66229	2N2	175.7	0.05
66229	OO1	246	0.03
66229	LDA2	226.6	0.02
66229	M1	224	0.05
66229	J1	238.6	0.06
66229	SSA	288.3	0.12
66229	SA	227.8	0.1
66229	MF	147.5	0.04
66229	RHO1	210.3	0.03
66229	Q1	209.3	0.15
66229	T2	231.1	0.03
66229	2Q1	202	0.02
66229	P1	230.2	0.42
66229	L2	245.8	0.06
66229	K2	232.2	0.14
66229	M8	182.4	0.01
66230	M2	214.8	1.8
66230	S2	222	0.42
66230	N2	189.2	0.4
66230	K1	229.4	1.19
66230	M4	166.5	0.06
66230	O1	212.6	0.74
66230	M6	29.8	0.01
66230	MK3	143.8	0.05
66230	MN4	150.3	0.02
66230	NU2	198.6	0.08
66230	MU2	108.3	0.02
66230	2N2	160.1	0.04
66230	OO1	249.9	0.03
66230	LDA2	224.6	0.03
66230	S1	219.7	0.02
66230	M1	235.3	0.04
66230	J1	246.2	0.07
66230	SSA	272.3	0.1
66230	SA	200.2	0.14
66230	MF	153.1	0.05
66230	RHO1	221.7	0.02
66230	Q1	207.3	0.13
66230	T2	203.3	0.03
66230	2Q1	208	0.02
66230	P1	227.2	0.38
66230	2SM2	45.3	0.01
66230	L2	243.3	0.06
66230	2MK3	104.7	0.04
66230	K2	214.1	0.12
66230	MS4	177.7	0.03
66231	M2	300.4	1.96
66231	S2	301.2	0.37
66231	N2	274.1	0.42
66231	K1	281.2	1.04
66231	M4	161.5	0.12
66231	O1	255.8	0.52
66231	M6	337.6	0.07
66231	S4	347.5	0.01
66231	NU2	277.7	0.08
66231	MU2	55.8	0.05
66231	2N2	247.9	0.06
66231	OO1	306.7	0.02
66231	LDA2	300.8	0.01
66231	M1	268.6	0.04
66231	J1	293.9	0.04
66231	RHO1	244.9	0.02
66231	Q1	243.1	0.1
66231	T2	301.2	0.02
66231	2Q1	230.5	0.01
66231	P1	279.3	0.34
66231	L2	326.7	0.06
66231	K2	301.3	0.1
66231	M8	183.3	0.01
66232	M2	219.7	2.01
66232	S2	229.1	0.47
66232	N2	195.3	0.44
66232	K1	229.9	1.24
66232	M4	186.4	0.04
66232	O1	214.2	0.74
66232	M6	119.9	0.01
66232	S4	293.8	0.01
66232	NU2	198.5	0.09
66232	MU2	210.2	0.05
66232	2N2	170.8	0.06
66232	OO1	245.6	0.03
66232	LDA2	224.1	0.01
66232	M1	222.1	0.05
66232	J1	237.7	0.06
66232	SSA	272.3	0.1
66232	SA	200.2	0.14
66232	MF	153.1	0.05
66232	RHO1	207.3	0.03
66232	Q1	206.3	0.14
66232	T2	228.7	0.03
66232	2Q1	198.6	0.02
66232	P1	228.7	0.41
66232	L2	244.1	0.06
66232	K2	229.9	0.13
66233	M2	215.5	1.85
66233	S2	222.4	0.43
66233	N2	190	0.39
66233	K1	230.6	1.19
66233	M4	181	0.06
66233	O1	212.9	0.73
66233	M6	36.5	0.01
66233	MK3	139.9	0.04
66233	MN4	161.5	0.02
66233	NU2	199.8	0.07
66233	MU2	112.4	0.02
66233	2N2	160.4	0.04
66233	OO1	242.2	0.04
66233	LDA2	215.9	0.03
66233	S1	272.2	0.03
66233	M1	239.9	0.04
66233	J1	245.7	0.07
66233	SSA	272.3	0.1
66233	SA	200.2	0.14
66233	MF	153.1	0.05
66233	RHO1	222.3	0.02
66233	Q1	207.4	0.12
66233	T2	237.9	0.02
66233	2Q1	238.1	0.01
66233	P1	228.5	0.38
66233	2SM2	40.7	0.01
66233	L2	245.1	0.06
66233	2MK3	95.3	0.04
66233	K2	213.1	0.14
66233	MS4	192	0.03
66234	M2	223.1	2.02
66234	S2	233.6	0.47
66234	N2	197.1	0.43
66234	K1	233.1	1.23
66234	M4	207.8	0.04
66234	O1	216.9	0.75
66234	M6	92.4	0.02
66234	MK3	149.2	0.04
66234	MN4	187.1	0.02
66234	NU2	200.6	0.09
66234	MU2	99.2	0.02
66234	2N2	171.6	0.04
66234	OO1	261.2	0.03
66234	LDA2	225.1	0.03
66234	S1	250.7	0.03
66234	M1	249.8	0.03
66234	J1	254.9	0.06
66234	SSA	259.8	0.1
66234	SA	223.9	0.16
66234	RHO1	220.5	0.03
66234	Q1	210.5	0.13
66234	T2	200.2	0.04
66234	2Q1	216.3	0.01
66234	P1	229.8	0.39
66234	2SM2	62.6	0.01
66234	L2	246.3	0.07
66234	2MK3	96.1	0.04
66234	K2	225.9	0.13
66234	MS4	216.8	0.02
66235	M2	215.2	1.32
66235	S2	228.4	0.29
66235	N2	190.6	0.25
66235	K1	240.4	0.94
66235	M4	355.4	0.07
66235	O1	228.6	0.52
66235	M6	30.2	0.02
66235	MK3	353.3	0.08
66235	S4	28.7	0.01
66235	MN4	347	0.03
66235	NU2	183.2	0.06
66235	MU2	31	0.05
66235	2N2	129.8	0.05
66235	OO1	288.3	0.03
66235	LDA2	177.1	0.02
66235	S1	30.6	0.01
66235	M1	256.8	0.01
66235	J1	288.4	0.03
66235	SSA	285.3	0.1
66235	SA	217.7	0.2
66235	RHO1	218.8	0.03
66235	Q1	241.5	0.09
66235	T2	234.4	0.03
66235	R2	262	0.02
66235	2Q1	251.7	0.03
66235	P1	239.9	0.26
66235	2SM2	31.9	0.01
66235	M3	304.3	0.02
66235	L2	216.4	0.06
66235	2MK3	350.9	0.08
66235	K2	202.1	0.12
66235	M8	137.1	0.01
66235	MS4	17.5	0.04
66236	M2	190.4	1.8
66236	S2	196.3	0.45
66236	N2	164.1	0.4
66236	K1	219.9	1.26
66236	O1	204.1	0.77
66236	NU2	170	0.08
66236	MU2	124.5	0.04
66236	2N2	135.3	0.05
66236	OO1	249.8	0.04
66236	LDA2	221.1	0.01
66236	S1	316.3	0.05
66236	M1	227.2	0.04
66236	J1	233.8	0.08
66236	SSA	263.3	0.11
66236	SA	213.3	0.19
66236	RHO1	198.4	0.03
66236	Q1	196.7	0.14
66236	T2	189.4	0.02
66236	2Q1	197.9	0.02
66236	P1	215	0.39
66236	M3	10.8	0.01
66236	L2	219.7	0.03
66236	K2	187	0.12
66237	M2	29.8	1.12
66237	S2	50.9	0.21
66237	N2	10.8	0.2
66237	K1	330.7	0.65
66237	M4	326.6	0.05
66237	O1	326	0.44
66237	M6	155.4	0.05
66237	S4	45.1	0.01
66237	NU2	13.3	0.04
66237	MU2	8.2	0.03
66237	2N2	351.8	0.03
66237	OO1	335.3	0.02
66237	LDA2	39.7	0.01
66237	M1	328.3	0.03
66237	J1	332.9	0.04
66237	RHO1	324.4	0.02
66237	Q1	323.8	0.09
66237	T2	50.5	0.01
66237	2Q1	320.8	0.01
66237	P1	330.3	0.21
66237	L2	48.6	0.03
66237	K2	52.7	0.06
66238	M2	239.4	2.1
66238	S2	253.2	0.51
66238	N2	213.6	0.42
66238	K1	239.3	1.2
66238	M4	36.2	0.01
66238	O1	225.6	0.73
66238	M6	97.5	0.03
66238	S4	5.4	0.01
66238	NU2	217	0.08
66238	MU2	225.4	0.05
66238	2N2	187.7	0.06
66238	OO1	252.9	0.03
66238	LDA2	245.8	0.01
66238	M1	232.5	0.05
66238	J1	246	0.06
66238	SSA	286.9	0.13
66238	SA	221.4	0.12
66238	RHO1	219.7	0.03
66238	Q1	218.9	0.14
66238	T2	252.6	0.03
66238	2Q1	212.1	0.02
66238	P1	238.2	0.4
66238	L2	265.1	0.06
66238	K2	254.3	0.14
66239	M2	318.1	1.312
66239	S2	325.1	0.223
66239	N2	293.6	0.239
66239	K1	298.1	0.758
66239	M4	166.3	0.059
66239	O1	278.5	0.42
66239	M6	328	0.049
66239	MK3	170	0.095
66239	MN4	143.3	0.02
66239	NU2	297.3	0.066
66239	MU2	129.8	0.069
66239	2N2	246.4	0.02
66239	OO1	342.8	0.02
66239	LDA2	300.5	0.026
66239	S1	118.2	0.033
66239	J1	37.3	0.01
66239	SSA	285	0.197
66239	RHO1	280.5	0.036
66239	Q1	290.3	0.069
66239	2Q1	316.4	0.013
66239	P1	283.8	0.223
66239	2SM2	154	0.016
66239	M3	258.8	0.03
66239	L2	350.5	0.098
66239	2MK3	159.2	0.108
66239	K2	311	0.095
66239	MS4	193	0.033
66240	M2	270.2	1.75
66240	S2	287.7	0.31
66240	N2	249.3	0.32
66240	K1	261.7	0.97
66240	M4	54.9	0.03
66240	O1	245.7	0.53
66240	M6	194.2	0.02
66240	NU2	252.2	0.06
66240	MU2	252.8	0.04
66240	2N2	228.5	0.04
66240	OO1	277.7	0.02
66240	LDA2	278.4	0.01
66240	M1	253.7	0.04
66240	J1	269.7	0.04
66240	SSA	285.7	0.2
66240	RHO1	238.8	0.02
66240	Q1	237.7	0.1
66240	T2	287	0.02
66240	2Q1	229.8	0.01
66240	P1	260.5	0.32
66240	L2	291.1	0.05
66240	K2	289.1	0.09
66241	M2	26.2	1.03
66241	S2	47.1	0.19
66241	N2	8.2	0.19
66241	K1	328.9	0.65
66241	M4	312.2	0.03
66241	O1	324	0.43
66241	M6	117.6	0.02
66241	S4	17.6	0.01
66241	NU2	10.6	0.04
66241	MU2	5.3	0.03
66241	2N2	350.1	0.03
66241	OO1	333.9	0.02
66241	LDA2	36.1	0.01
66241	M1	326.6	0.03
66241	J1	331.3	0.04
66241	SSA	285.7	0.2
66241	RHO1	322.1	0.02
66241	Q1	321.6	0.08
66241	T2	46	0.01
66241	2Q1	320.4	0.01
66241	P1	328.6	0.21
66241	L2	44.3	0.03
66241	K2	48.7	0.05
66242	M2	302.2	1.43
66242	S2	317.4	0.28
66242	N2	277.1	0.27
66242	K1	282.8	0.85
66242	M4	142.5	0.05
66242	O1	267.2	0.51
66242	M6	279.7	0.03
66242	MK3	156.4	0.09
66242	MN4	132	0.01
66242	NU2	288.4	0.07
66242	MU2	104.9	0.07
66242	OO1	354.3	0.03
66242	LDA2	285	0.04
66242	S1	306.3	0.04
66242	M1	8	0.06
66242	SSA	285.7	0.2
66242	RHO1	263.3	0.02
66242	Q1	277.6	0.08
66242	T2	298	0.02
66242	2Q1	215.8	0.02
66242	P1	283	0.23
66242	2SM2	117.2	0.02
66242	M3	216.4	0.01
66242	L2	300.4	0.09
66242	2MK3	142.9	0.14
66242	K2	306.7	0.13
66242	MS4	158.3	0.03
66243	M2	257.5	1.97
66243	S2	271.3	0.41
66243	N2	232.5	0.37
66243	K1	251.8	1.1
66243	M4	346.7	0.06
66243	O1	234.4	0.66
66243	M6	135.1	0.04
66243	MK3	101.7	0.05
66243	MN4	328.4	0.02
66243	NU2	243.2	0.09
66243	MU2	63.4	0.06
66243	2N2	206	0.05
66243	OO1	308.1	0.03
66243	LDA2	247.7	0.05
66243	S1	261.2	0.06
66243	M1	271.1	0.04
66243	J1	287.4	0.03
66243	SSA	259.8	0.1
66243	SA	223.9	0.16
66243	RHO1	233.1	0.03
66243	Q1	239	0.1
66243	T2	241.3	0.03
66243	R2	182.3	0.02
66243	2Q1	280.3	0.01
66243	P1	254.7	0.29
66243	2SM2	97.1	0.02
66243	M3	174.2	0.03
66243	L2	280.6	0.14
66243	2MK3	90.2	0.1
66243	K2	257.9	0.16
66243	MS4	27.1	0.02
66244	M2	283.2	1.63
66244	S2	298.1	0.32
66244	N2	258.8	0.31
66244	K1	271	0.9
66244	M4	125	0.04
66244	O1	255.4	0.52
66244	M6	250.4	0.04
66244	MK3	128.8	0.1
66244	MN4	104	0.01
66244	NU2	268.3	0.08
66244	MU2	90.5	0.07
66244	2N2	236.6	0.03
66244	OO1	328.5	0.02
66244	LDA2	279.2	0.04
66244	S1	298.3	0.04
66244	M1	350.5	0.03
66244	J1	349.9	0.01
66244	MM	34.4	0.05
66244	SSA	264.8	0.14
66244	SA	144.6	0.09
66244	MSF	18.1	0.1
66244	MF	184.3	0.13
66244	RHO1	247.7	0.03
66244	Q1	263.4	0.08
66244	T2	265.1	0.02
66244	R2	172.7	0.01
66244	2Q1	264.9	0.01
66244	P1	269.9	0.26
66244	2SM2	123	0.02
66244	M3	210.1	0.02
66244	L2	298.9	0.11
66244	2MK3	118.6	0.14
66244	K2	287.8	0.15
66244	MS4	150.8	0.03
66245	M2	358.3	0.93
66245	S2	22.7	0.19
66245	N2	338.5	0.16
66245	K1	319.8	0.69
66245	M4	231.3	0.04
66245	O1	309.6	0.45
66245	M6	2.1	0.03
66245	S4	311.8	0.01
66245	NU2	341.2	0.03
66245	MU2	333.9	0.02
66245	2N2	318.6	0.02
66245	OO1	329.7	0.02
66245	LDA2	9.7	0.01
66245	M1	314.7	0.03
66245	J1	324.9	0.03
66245	SSA	285.7	0.2
66245	RHO1	305.5	0.02
66245	Q1	304.6	0.09
66245	T2	21.8	0.01
66245	2Q1	298.2	0.01
66245	P1	319	0.23
66245	L2	18.2	0.03
66245	K2	24.5	0.05
66246	M2	260.6	1.96
66246	S2	273.5	0.42
66246	N2	233.8	0.39
66246	K1	253.7	1.1
66246	M4	30.8	0.04
66246	O1	237.2	0.66
66246	M6	147.3	0.03
66246	MK3	117.2	0.06
66246	MN4	347.1	0.01
66246	NU2	237	0.08
66246	MU2	66.7	0.05
66246	2N2	206.8	0.05
66246	OO1	296.4	0.04
66246	LDA2	264.4	0.04
66246	S1	228.9	0.05
66246	M1	327.6	0.05
66246	J1	288	0.05
66246	SSA	259.8	0.1
66246	SA	223.9	0.16
66246	RHO1	230.1	0.03
66246	Q1	234.3	0.1
66246	T2	273.4	0.03
66246	2Q1	220.7	0.02
66246	P1	258.2	0.32
66246	2SM2	93.6	0.01
66246	M3	162	0.02
66246	L2	271.2	0.08
66246	2MK3	92.7	0.1
66246	K2	265.6	0.17
66246	MS4	65.7	0.03
66247	M2	15	0.95
66247	S2	31.9	0.17
66247	N2	356.7	0.17
66247	K1	323.5	0.63
66247	M4	267.9	0.02
66247	O1	317.8	0.42
66247	M6	52.2	0.03
66247	NU2	359.1	0.03
66247	MU2	357.7	0.02
66247	2N2	338.4	0.02
66247	OO1	329.2	0.02
66247	LDA2	23	0.01
66247	M1	320.8	0.03
66247	J1	326.1	0.03
66247	SSA	285.7	0.2
66247	RHO1	315.5	0.02
66247	Q1	315.1	0.08
66247	T2	31.5	0.01
66247	2Q1	313.4	0.01
66247	P1	323	0.21
66247	L2	33.3	0.03
66247	K2	33.2	0.05
66248	M2	257.7	2.03
66248	S2	273.2	0.39
66248	N2	235.8	0.35
66248	K1	256.8	1.13
66248	M4	73.5	0.13
66248	O1	237.9	0.66
66248	M6	179.4	0.03
66248	NU2	238.7	0.07
66248	S6	302.2	0.01
66248	MU2	241.8	0.05
66248	2N2	213.9	0.05
66248	OO1	275.6	0.03
66248	LDA2	265.1	0.01
66248	M1	247.4	0.05
66248	J1	266.1	0.05
66248	SSA	259.8	0.1
66248	SA	223.9	0.16
66248	RHO1	229.7	0.02
66248	Q1	228.5	0.13
66248	T2	272.6	0.02
66248	2Q1	218.8	0.02
66248	P1	255.4	0.37
66248	L2	279.8	0.06
66248	K2	274.3	0.11
66248	M8	53.3	0.01
66249	M2	289.4	1.66
66249	S2	303	0.32
66249	N2	264.1	0.31
66249	K1	273.7	0.98
66249	M4	140.2	0.08
66249	O1	257.5	0.55
66249	M6	246.7	0.03
66249	MK3	135.5	0.12
66249	MN4	113.7	0.03
66249	NU2	267.5	0.08
66249	MU2	85.8	0.07
66249	2N2	262.1	0.06
66249	OO1	321.3	0.03
66249	LDA2	285.3	0.05
66249	M1	307.5	0.04
66249	SSA	339.3	0.2
66249	RHO1	239.9	0.02
66249	Q1	259.8	0.09
66249	P1	282.8	0.26
66249	2SM2	129.3	0.02
66249	M3	203.5	0.05
66249	L2	285	0.16
66249	2MK3	125.4	0.16
66249	K2	290.2	0.17
66249	MS4	155.9	0.04
66250	M2	338.5	1.21
66250	S2	355.9	0.22
66250	N2	304.3	0.22
66250	K1	302.5	0.73
66250	M4	213	0.09
66250	O1	294.2	0.36
66250	M6	17.3	0.03
66250	MK3	199.8	0.1
66250	S4	238.6	0.01
66250	MN4	191.8	0.03
66250	NU2	333.2	0.03
66250	MU2	151.5	0.07
66250	2N2	311.7	0.03
66250	OO1	62.5	0.01
66250	LDA2	326.5	0.05
66250	S1	267.7	0.08
66250	M1	209.4	0.01
66250	J1	43.6	0.03
66250	SSA	285.7	0.2
66250	RHO1	287	0.02
66250	Q1	295.7	0.05
66250	T2	352.4	0.02
66250	R2	65.6	0.02
66250	2Q1	315.9	0.02
66250	P1	308.1	0.27
66250	2SM2	171.2	0.01
66250	M3	280.7	0.03
66250	L2	355.6	0.1
66250	2MK3	191.3	0.1
66250	K2	337	0.1
66250	M8	251.6	0.01
66250	MS4	240.5	0.04
66251	M2	256.6	1.78
66251	S2	277.8	0.29
66251	N2	230.9	0.32
66251	K1	256.5	0.94
66251	M4	100.9	0.16
66251	O1	253.6	0.56
66251	M6	227	0.02
66251	S4	210.4	0.01
66251	NU2	234.3	0.06
66251	MU2	236.3	0.04
66251	2N2	205.6	0.04
66251	OO1	259	0.02
66251	LDA2	265.9	0.01
66251	M1	255	0.04
66251	J1	257.9	0.04
66251	SSA	286.9	0.13
66251	SA	221.4	0.12
66251	RHO1	252.2	0.02
66251	Q1	252.2	0.11
66251	T2	276.8	0.02
66251	2Q1	250.3	0.01
66251	P1	256.2	0.31
66251	L2	282.6	0.05
66251	K2	279.6	0.08
66251	M8	68.3	0.01
66252	M2	265.1	2.28
66252	S2	284.7	0.47
66252	N2	248.6	0.39
66252	K1	263.1	1.15
66252	M4	97.8	0.09
66252	O1	244.8	0.64
66252	M6	201.3	0.05
66252	NU2	250.8	0.08
66252	S6	30.1	0.01
66252	MU2	245.6	0.06
66252	2N2	232	0.05
66252	OO1	281.4	0.03
66252	LDA2	274.2	0.02
66252	M1	253.9	0.05
66252	J1	272.2	0.05
66252	SSA	259.8	0.1
66252	SA	223.9	0.16
66252	RHO1	236.8	0.02
66252	Q1	235.8	0.12
66252	T2	284	0.03
66252	2Q1	227.5	0.02
66252	P1	261.7	0.38
66252	L2	281.9	0.06
66252	K2	286.3	0.13
66253	M2	273.3	2.339
66253	S2	299.3	0.554
66253	N2	258.2	0.443
66253	K1	264.2	1.217
66253	M4	72.1	0.069
66253	O1	253.5	0.712
66253	M6	226.6	0.069
66253	S4	151.1	0.01
66253	NU2	260.2	0.085
66253	MU2	247.5	0.056
66253	2N2	243.2	0.059
66253	OO1	273.8	0.03
66253	LDA2	285.2	0.016
66253	M1	258.7	0.049
66253	J1	268.9	0.056
66253	SSA	259.8	0.095
66253	SA	223.9	0.157
66253	RHO1	249.3	0.026
66253	Q1	248.5	0.138
66253	T2	298.2	0.033
66253	R2	301.5	0.003
66253	2Q1	243.7	0.02
66253	P1	263.4	0.404
66253	L2	288.3	0.066
66253	K2	301.3	0.151
66253	M8	263.5	0.007
66254	M2	193.5	1.68
66254	S2	203.7	0.4
66254	N2	165.3	0.37
66254	K1	223.2	1.12
66254	M4	28.7	0.03
66254	O1	212.6	0.7
66254	S4	41.4	0.01
66254	NU2	169.1	0.07
66254	MU2	183.3	0.04
66254	2N2	136.9	0.05
66254	OO1	233.7	0.03
66254	LDA2	198.2	0.01
66254	M1	217.9	0.05
66254	J1	228.4	0.06
66254	SSA	272.5	0.19
66254	SA	263	0.24
66254	RHO1	208.1	0.03
66254	Q1	207.4	0.13
66254	T2	203.2	0.02
66254	2Q1	202.2	0.02
66254	P1	222.4	0.37
66254	L2	221.9	0.05
66254	K2	204.5	0.11
66255	M2	195.3	1.87
66255	S2	205.3	0.46
66255	N2	169.4	0.41
66255	K1	223.4	1.22
66255	O1	208	0.76
66255	NU2	174.9	0.08
66255	MU2	133.1	0.05
66255	2N2	141.7	0.05
66255	OO1	250.5	0.04
66255	LDA2	228.7	0.01
66255	S1	327.9	0.04
66255	M1	228.7	0.05
66255	J1	236.3	0.07
66255	SSA	255.5	0.11
66255	SA	227.4	0.23
66255	RHO1	199.6	0.03
66255	Q1	197.9	0.14
66255	T2	201.3	0.02
66255	R2	155.5	0.01
66255	2Q1	201.4	0.02
66255	P1	220.4	0.38
66255	M3	357.8	0.01
66255	L2	226.2	0.04
66255	K2	195.6	0.13
66256	M2	196.6	1.98
66256	S2	211.2	0.49
66256	N2	170.9	0.42
66256	K1	222.8	1.22
66256	O1	207.1	0.77
66256	S4	305	0.01
66256	NU2	174.3	0.08
66256	MU2	181.8	0.05
66256	2N2	145.2	0.06
66256	OO1	238.6	0.03
66256	LDA2	203.4	0.01
66256	M1	215	0.06
66256	J1	230.7	0.06
66256	SSA	272.5	0.19
66256	SA	263	0.24
66256	RHO1	200.3	0.03
66256	Q1	199.3	0.15
66256	T2	210.7	0.03
66256	2Q1	191.5	0.02
66256	P1	221.7	0.4
66256	L2	222.3	0.06
66256	K2	212.4	0.13
66257	M2	200.9	1.97
66257	S2	218.3	0.49
66257	N2	174.5	0.43
66257	K1	225.6	1.2
66257	O1	208.4	0.79
66257	S4	270.5	0.01
66257	NU2	178.1	0.08
66257	MU2	183.4	0.05
66257	2N2	148.2	0.06
66257	OO1	242.8	0.03
66257	LDA2	208.9	0.01
66257	M1	217.1	0.06
66257	J1	234.1	0.06
66257	SSA	272.5	0.19
66257	SA	263	0.24
66257	RHO1	201.1	0.03
66257	Q1	199.9	0.15
66257	T2	217.6	0.03
66257	2Q1	191.4	0.02
66257	P1	224.3	0.4
66257	L2	227.2	0.06
66257	K2	219.7	0.13
66258	M2	221.7	1.89
66258	S2	230.5	0.38
66258	N2	194.2	0.37
66258	K1	248.3	1.22
66258	M4	334.5	0.04
66258	O1	226.8	0.66
66258	M6	292.3	0.01
66258	MK3	358.6	0.08
66258	S4	18.7	0.01
66258	MN4	335.2	0.02
66258	NU2	208.1	0.08
66258	MU2	1.1	0.02
66258	2N2	151.1	0.03
66258	OO1	236.3	0.01
66258	LDA2	222.3	0.01
66258	S1	107.6	0.18
66258	M1	275.2	0.05
66258	J1	273.1	0.08
66258	SSA	264.1	0.12
66258	SA	255	0.21
66258	MF	149	0.05
66258	RHO1	262.1	0.02
66258	Q1	229.8	0.1
66258	T2	81.5	0.07
66258	R2	302	0.14
66258	2Q1	141.8	0.01
66258	P1	242.8	0.47
66258	2SM2	59	0.01
66258	M3	33.9	0.02
66258	L2	223.7	0.05
66258	2MK3	355.9	0.06
66258	K2	250.1	0.14
66258	MS4	334.3	0.02
66259	M2	214.8	2.29
66259	S2	236	0.61
66259	N2	190.6	0.49
66259	K1	232.2	1.35
66259	M4	213	0.04
66259	O1	217.5	0.8
66259	M6	246	0.02
66259	S4	55.2	0.01
66259	NU2	193.8	0.09
66259	MU2	193.6	0.06
66259	2N2	166.3	0.07
66259	OO1	247	0.03
66259	LDA2	224.6	0.02
66259	M1	224.9	0.06
66259	J1	239.6	0.06
66259	SSA	264.1	0.12
66259	SA	255	0.21
66259	MF	149	0.05
66259	RHO1	211.1	0.03
66259	Q1	210.1	0.15
66259	T2	235.1	0.04
66259	2Q1	202.8	0.02
66259	P1	231.2	0.45
66259	L2	239	0.07
66259	K2	237.7	0.17
66260	M2	215.1	2.3
66260	S2	236.6	0.57
66260	N2	190.5	0.49
66260	K1	233.4	1.32
66260	M4	200.6	0.04
66260	O1	217.2	0.82
66260	M6	284.7	0.02
66260	MK3	197.5	0.02
66260	MN4	177.4	0.02
66260	NU2	194.5	0.1
66260	MU2	173	0.03
66260	2N2	164.2	0.06
66260	OO1	265.9	0.04
66260	LDA2	215.8	0.02
66260	S1	35	0.04
66260	M1	252.4	0.04
66260	J1	248.3	0.07
66260	SSA	264.1	0.12
66260	SA	255	0.21
66260	MF	149	0.05
66260	RHO1	210.3	0.03
66260	Q1	211.3	0.14
66260	T2	235.8	0.03
66260	R2	237.5	0.01
66260	2Q1	216.4	0.02
66260	P1	231.2	0.41
66260	L2	225.2	0.05
66260	K2	228.3	0.15
66260	MS4	239.1	0.02
66261	M2	220.2	2.39
66261	S2	243.7	0.63
66261	N2	198.5	0.5
66261	K1	235	1.34
66261	M4	202.6	0.09
66261	O1	221	0.79
66261	M6	294.2	0.07
66261	S4	31.9	0.01
66261	NU2	201.3	0.1
66261	S6	181	0.01
66261	MU2	196.8	0.06
66261	2N2	176.6	0.07
66261	OO1	249.1	0.03
66261	LDA2	231.1	0.02
66261	M1	228.1	0.06
66261	J1	242	0.06
66261	SSA	264.1	0.12
66261	SA	255	0.21
66261	MF	149	0.05
66261	RHO1	215	0.03
66261	Q1	214	0.15
66261	T2	242.8	0.04
66261	R2	244.3	0.01
66261	2Q1	207.1	0.02
66261	P1	234	0.44
66261	L2	242	0.07
66261	K2	245.6	0.17
66261	M8	304.8	0.01
66262	M2	231.9	1.55
66262	S2	265.4	0.35
66262	N2	229.1	0.31
66262	K1	249.6	0.83
66262	M4	44.1	0.12
66262	O1	255.5	0.54
66262	S4	188.4	0.01
66262	NU2	229.4	0.06
66262	MU2	199.9	0.04
66262	2N2	225.2	0.04
66262	OO1	245.1	0.02
66262	LDA2	247.1	0.01
66262	M1	252.5	0.04
66262	J1	247.8	0.04
66262	SSA	262.1	0.13
66262	SA	261.4	0.23
66262	MF	152	0.05
66262	RHO1	257.3	0.02
66262	Q1	257.9	0.1
66262	T2	263.9	0.02
66262	2Q1	259.4	0.01
66262	P1	249.9	0.28
66262	L2	236	0.04
66262	K2	268	0.1
66263	M2	211	2.35
66263	S2	231.7	0.6
66263	N2	185.2	0.5
66263	K1	227.8	1.28
66263	O1	212.6	0.79
66263	NU2	191.2	0.1
66263	MU2	154	0.05
66263	2N2	158.8	0.06
66263	OO1	255	0.05
66263	LDA2	230.9	0.02
66263	S1	4.3	0.03
66263	M1	242.5	0.04
66263	J1	240	0.07
66263	SSA	262.1	0.13
66263	SA	261.4	0.23
66263	MF	152	0.05
66263	RHO1	206.7	0.03
66263	Q1	205.5	0.14
66263	T2	225.8	0.03
66263	R2	232.4	0.01
66263	2Q1	204.9	0.02
66263	P1	225.2	0.4
66263	L2	235.6	0.04
66263	K2	223.6	0.17
66264	M2	216.2	2.19
66264	S2	236.9	0.55
66264	N2	190.6	0.47
66264	K1	228.7	1.21
66264	M4	157.5	0.01
66264	O1	217.4	0.73
66264	M6	164.1	0.01
66264	S4	86.3	0.01
66264	NU2	194.1	0.09
66264	MU2	195.6	0.05
66264	2N2	165.1	0.06
66264	OO1	239.9	0.03
66264	LDA2	225.8	0.02
66264	M1	223.1	0.05
66264	J1	234.3	0.06
66264	SSA	262.1	0.13
66264	SA	261.4	0.23
66264	RHO1	212.6	0.03
66264	Q1	211.8	0.14
66264	T2	236.1	0.03
66264	2Q1	206.2	0.02
66264	P1	227.8	0.4
66264	L2	241.3	0.06
66264	K2	238.7	0.15
66264	M8	165.8	0.01
66265	M2	218.9	2.4
66265	S2	241	0.65
66265	N2	193.5	0.51
66265	K1	230.1	1.32
66265	M4	242.5	0.02
66265	O1	214.2	0.85
66265	M6	205	0.01
66265	MK3	234.1	0.02
66265	S4	345.4	0.01
66265	NU2	196.8	0.1
66265	MU2	158.6	0.06
66265	2N2	165.6	0.06
66265	OO1	230.8	0.05
66265	LDA2	247.6	0.02
66265	S1	225.4	0.02
66265	M1	206.3	0.07
66265	J1	245.4	0.09
66265	SSA	262.1	0.13
66265	SA	261.4	0.23
66265	MF	152	0.05
66265	RHO1	195.8	0.04
66265	Q1	204.7	0.15
66265	T2	245.2	0.04
66265	R2	91.4	0.01
66265	2Q1	175	0.04
66265	P1	224.8	0.4
66265	M3	327.7	0.01
66265	L2	256.4	0.05
66265	2MK3	182.7	0.01
66265	K2	229.7	0.16
66266	M2	216.5	2.44
66266	S2	239	0.65
66266	N2	190.7	0.51
66266	K1	230.9	1.4
66266	O1	214.6	0.86
66266	NU2	196	0.1
66266	MU2	158.2	0.05
66266	2N2	165.9	0.06
66266	OO1	262.2	0.05
66266	LDA2	244.3	0.02
66266	S1	354.1	0.03
66266	M1	240.6	0.05
66266	J1	242.8	0.09
66266	SA	274	0.29
66266	RHO1	200.8	0.03
66266	Q1	206.5	0.15
66266	T2	231.5	0.04
66266	2Q1	201.9	0.02
66266	P1	227.4	0.43
66266	L2	240.6	0.06
66266	K2	232.7	0.17
66267	M2	299.6	1.63
66267	S2	339.6	0.35
66267	N2	281	0.28
66267	K1	295.8	0.91
66267	M4	168	0.13
66267	O1	288.7	0.62
66267	M6	161.7	0.04
66267	S4	279.6	0.02
66267	NU2	283.5	0.05
66267	MU2	259.4	0.04
66267	2N2	262.2	0.04
66267	OO1	302.6	0.03
66267	LDA2	318.1	0.01
66267	M1	292.3	0.04
66267	J1	299.2	0.05
66267	RHO1	286	0.02
66267	Q1	285.1	0.12
66267	T2	337.9	0.02
66267	2Q1	282	0.02
66267	P1	295.2	0.3
66267	L2	318	0.05
66267	K2	342.8	0.1
66267	M8	36	0.01
66268	M2	225.3	2.68
66268	S2	251.1	0.71
66268	N2	200.7	0.55
66268	K1	235.2	1.32
66268	M4	200.7	0.03
66268	O1	220.5	0.81
66268	M6	331.1	0.01
66268	MK3	191.9	0.02
66268	MN4	183.9	0.01
66268	NU2	203.6	0.11
66268	MU2	182.1	0.04
66268	2N2	174.6	0.07
66268	OO1	266.3	0.04
66268	LDA2	224	0.02
66268	S1	46.7	0.01
66268	M1	246.5	0.05
66268	J1	249.4	0.08
66268	SA	283.3	0.34
66268	MF	155.7	0.05
66268	RHO1	213.3	0.03
66268	Q1	214.3	0.14
66268	T2	244.4	0.04
66268	R2	252.1	0.01
66268	2Q1	213.3	0.01
66268	P1	233.3	0.41
66268	L2	241.4	0.07
66268	K2	244.6	0.19
66268	MS4	252.9	0.01
66269	M2	230.6	2.45
66269	S2	258	0.67
66269	N2	207	0.51
66269	K1	238.7	1.24
66269	O1	223.8	0.79
66269	M6	329.8	0.02
66269	S4	3.3	0.01
66269	NU2	216	0.1
66269	MU2	187.8	0.03
66269	2N2	186.1	0.06
66269	OO1	260.1	0.05
66269	LDA2	235.1	0.03
66269	S1	17.3	0.01
66269	M1	210.2	0.05
66269	J1	259.7	0.08
66269	SA	283.3	0.34
66269	MF	155.7	0.05
66269	RHO1	213.8	0.03
66269	Q1	216.3	0.14
66269	T2	257.6	0.05
66269	R2	130.3	0.04
66269	2Q1	201.2	0.03
66269	P1	232.1	0.38
66269	M3	2.2	0.01
66269	L2	253.8	0.06
66269	K2	241.1	0.19
66269	MS4	329.4	0.01
66270	M2	255.9	2.54
66270	S2	289.3	0.61
66270	N2	236	0.47
66270	K1	255.2	1.19
66270	M4	7.6	0.04
66270	O1	241.1	0.72
66270	M6	75.9	0.04
66270	S4	100.5	0.01
66270	NU2	238.7	0.09
66270	MU2	222.4	0.06
66270	2N2	216.1	0.06
66270	OO1	269.2	0.03
66270	LDA2	271.4	0.02
66270	M1	248.2	0.05
66270	J1	262.1	0.06
66270	RHO1	235.1	0.03
66270	Q1	234.2	0.14
66270	T2	288	0.04
66270	2Q1	227.3	0.02
66270	P1	254.2	0.39
66270	L2	275.6	0.07
66270	K2	292	0.16
66270	M8	216.2	0.01
66271	M2	250.5	2.56
66271	S2	286.3	0.66
66271	N2	227.9	0.45
66271	K1	250.1	1.25
66271	M4	33	0.03
66271	O1	243.1	0.75
66271	M6	66.1	0.04
66271	S4	133.1	0.01
66271	NU2	230.9	0.09
66271	MU2	214.9	0.06
66271	2N2	205	0.06
66271	OO1	257	0.03
66271	LDA2	266.9	0.02
66271	M1	246.6	0.05
66271	J1	253.5	0.06
66271	SSA	234	0.09
66271	SA	285.9	0.04
66271	MF	183	0.08
66271	RHO1	240	0.03
66271	Q1	239.6	0.14
66271	T2	284.8	0.04
66271	R2	287.7	0.01
66271	2Q1	236.4	0.02
66271	P1	249.6	0.42
66271	L2	273.1	0.07
66271	K2	289.2	0.18
66272	M2	230.8	2.57
66272	S2	261.3	0.69
66272	N2	207.3	0.53
66272	K1	237.7	1.29
66272	M4	278.9	0.03
66272	O1	223.3	0.79
66272	M6	339.6	0.01
66272	MK3	287.2	0.02
66272	S4	37.6	0.01
66272	MN4	268.4	0.01
66272	NU2	216.7	0.1
66272	MU2	207.6	0.03
66272	2N2	188.2	0.06
66272	OO1	254.4	0.05
66272	LDA2	237	0.03
66272	S1	339.1	0.05
66272	M1	222.2	0.05
66272	J1	260.7	0.08
66272	SSA	234	0.09
66272	SA	285.9	0.4
66272	MF	183	0.08
66272	RHO1	217.2	0.04
66272	Q1	219.9	0.13
66272	T2	269.4	0.05
66272	R2	161.9	0.05
66272	2Q1	211	0.03
66272	P1	227.3	0.38
66272	2SM2	136.6	0.01
66272	L2	253.1	0.07
66272	2MK3	4.6	0.01
66272	K2	241	0.21
66272	MS4	324.3	0.02
66273	M2	245.5	2.48
66273	S2	282.8	0.6
66273	N2	224.4	0.5
66273	K1	249.6	1.24
66273	M4	355.5	0.06
66273	O1	236.2	0.75
66273	M6	18.2	0.08
66273	MK3	33.3	0.03
66273	MN4	332.9	0.02
66273	NU2	217	0.1
66273	MU2	302	0.03
66273	2N2	196.9	0.06
66273	OO1	293.5	0.06
66273	LDA2	244.2	0.03
66273	S1	104.2	0.01
66273	M1	196.9	0.02
66273	J1	283.1	0.06
66273	SSA	234	0.09
66273	SA	285.9	0.4
66273	MF	183	0.08
66273	RHO1	262.4	0.04
66273	Q1	236.5	0.11
66273	T2	322.3	0.06
66273	R2	239.3	0.06
66273	2Q1	212.4	0.04
66273	P1	245.3	0.35
66273	2SM2	95.5	0.01
66273	L2	258.2	0.1
66273	2MK3	32.9	0.04
66273	K2	270	0.18
66273	M8	112.3	0.01
66273	MS4	9.6	0.04
66274	M2	235.5	2.99
66274	S2	262.1	0.74
66274	N2	214.4	0.67
66274	K1	238	1.42
66274	M4	234.7	0.05
66274	O1	224.8	0.85
66274	M6	314.8	0.03
66274	S4	258.7	0.01
66274	NU2	217.2	0.13
66274	MU2	208.9	0.07
66274	2N2	193.2	0.09
66274	OO1	251.3	0.04
66274	LDA2	247.9	0.02
66274	M1	231.5	0.06
66274	J1	244.6	0.07
66274	SSA	234	0.09
66274	SA	285.9	0.4
66274	MF	183	0.08
66274	RHO1	219.1	0.03
66274	Q1	218.3	0.16
66274	T2	261.1	0.04
66274	R2	263.2	0.01
66274	2Q1	211.7	0.02
66274	P1	237.1	0.47
66274	L2	256.7	0.08
66274	K2	264.3	0.2
66274	M8	236.6	0.01
66275	M2	231.2	2.91
66275	S2	259.3	0.79
66275	N2	207.5	0.6
66275	K1	238.1	1.42
66275	M4	198.8	0.04
66275	O1	221.4	0.86
66275	M6	298.3	0.03
66275	MK3	196.9	0.01
66275	MN4	180.3	0.02
66275	NU2	210.4	0.12
66275	MU2	203.9	0.05
66275	2N2	182.5	0.07
66275	OO1	274.4	0.05
66275	LDA2	223.2	0.02
66275	S1	5.4	0.04
66275	M1	257.9	0.05
66275	J1	256	0.08
66275	SSA	234	0.09
66275	SA	285.9	0.4
66275	MF	183	0.08
66275	RHO1	211.9	0.03
66275	Q1	214.2	0.15
66275	T2	251.7	0.05
66275	R2	213.6	0.01
66275	2Q1	214.4	0.02
66275	P1	233.9	0.44
66275	2SM2	54.2	0.01
66275	L2	235.9	0.07
66275	2MK3	349	0.01
66275	K2	250.6	0.21
66275	M8	260.4	0.01
66275	MS4	239.9	0.02
66276	M2	225	2.92
66276	S2	250.6	0.8
66276	N2	200.3	0.61
66276	K1	235	1.44
66276	O1	218.5	0.89
66276	NU2	208.4	0.12
66276	MU2	171.3	0.07
66276	2N2	171.6	0.07
66276	OO1	266.7	0.06
66276	LDA2	269.6	0.02
66276	S1	37.3	0.02
66276	M1	244.2	0.06
66276	J1	246.7	0.09
66276	MM	174.7	0.09
66276	SSA	258.7	0.06
66276	SA	281.6	0.4
66276	MF	155	0.06
66276	RHO1	213.8	0.03
66276	Q1	212.6	0.16
66276	T2	257.3	0.05
66276	R2	251.7	0.01
66276	2Q1	191.2	0.02
66276	P1	232.7	0.45
66276	L2	251.3	0.07
66276	K2	240.7	0.21
66277	M2	272	1.77
66277	S2	309.3	0.41
66277	N2	251.7	0.31
66277	K1	273	0.92
66277	M4	116.4	0.12
66277	O1	273.7	0.56
66277	M6	84.7	0.03
66277	S4	218.1	0.02
66277	NU2	254.4	0.06
66277	MU2	234.5	0.04
66277	2N2	231.8	0.04
66277	OO1	271.8	0.02
66277	LDA2	289.4	0.01
66277	M1	273.3	0.04
66277	J1	272.3	0.05
66277	RHO1	274.3	0.02
66277	Q1	274.2	0.11
66277	T2	307.8	0.02
66277	2Q1	275	0.01
66277	P1	273.1	0.31
66277	L2	292	0.05
66277	K2	312.3	0.11
66277	M8	299.1	0.01
66278	M2	229	2.53
66278	S2	251.1	0.89
66278	N2	205.8	0.51
66278	K1	239.5	1.15
66278	M4	64.8	0.14
66278	O1	231.9	0.74
66278	M6	92.9	0.04
66278	MK3	78.9	0.13
66278	S4	103.3	0.02
66278	MN4	46.4	0.06
66278	NU2	198.3	0.11
66278	MU2	90.7	0.03
66278	2N2	169.9	0.04
66278	OO1	286.4	0.06
66278	LDA2	222	0.04
66278	S1	227	0.07
66278	M1	150	0.02
66278	J1	266.9	0.06
66278	SSA	234	0.09
66278	SA	285.9	0.4
66278	MF	183	0.08
66278	RHO1	228.1	0.03
66278	Q1	234.7	0.12
66278	T2	224.1	0.14
66278	R2	75.4	0.3
66278	2Q1	233.9	0.03
66278	P1	243.1	0.32
66278	2SM2	57.3	0.01
66278	M3	238	0.04
66278	L2	252	0.09
66278	2MK3	35.1	0.11
66278	K2	202.5	0.21
66278	MS4	82	0.1
66279	M2	261.1	2.33
66279	S2	308.1	0.71
66279	N2	239.9	0.46
66279	K1	263.9	1.1
66279	M4	115.7	0.25
66279	O1	259.7	0.66
66279	M6	39.7	0.04
66279	MK3	115.8	0.26
66279	S4	191	0.02
66279	MN4	94.7	0.1
66279	NU2	238	0.06
66279	MU2	9.5	0.09
66279	2N2	191.9	0.07
66279	OO1	318.7	0.06
66279	LDA2	315.3	0.04
66279	S1	38.2	0.08
66279	M1	48.6	0.05
66279	J1	319.6	0.05
66279	SSA	198	0.05
66279	SA	286.2	0.36
66279	MF	183.4	0.09
66279	RHO1	306.1	0.04
66279	Q1	258.8	0.09
66279	T2	307.4	0.1
66279	R2	165.6	0.18
66279	2Q1	247.9	0.06
66279	P1	237.9	0.29
66279	2SM2	105.8	0.03
66279	M3	271.9	0.04
66279	L2	272.5	0.15
66279	2MK3	81.5	0.24
66279	K2	272.7	0.28
66279	M8	301.1	0.01
66279	MS4	152.2	0.13
66280	M2	242.6	2.88
66280	S2	273	0.77
66280	N2	220	0.58
66280	K1	245.8	1.37
66280	M4	250.4	0.1
66280	O1	229.1	0.83
66280	M6	358.5	0.05
66280	MK3	247.6	0.04
66280	S4	354.4	0.01
66280	MN4	229.9	0.04
66280	NU2	221.8	0.12
66280	MU2	252	0.05
66280	2N2	195.3	0.06
66280	OO1	285	0.04
66280	LDA2	223	0.03
66280	S1	7.7	0.04
66280	M1	272.7	0.05
66280	J1	266.3	0.07
66280	SSA	198	0.05
66280	SA	286.2	0.36
66280	MF	183.4	0.09
66280	RHO1	217.1	0.03
66280	Q1	223.6	0.14
66280	T2	266.1	0.05
66280	R2	184.9	0.01
66280	2Q1	226.9	0.02
66280	P1	242.1	0.42
66280	2SM2	72.4	0.01
66280	M3	227.9	0.01
66280	L2	241.4	0.09
66280	2MK3	308.6	0.01
66280	K2	265.5	0.2
66280	M8	15.9	0.01
66280	MS4	286.6	0.06
66281	M2	230.6	2.84
66281	S2	256.7	0.77
66281	N2	205.5	0.58
66281	K1	238.4	1.35
66281	M4	180.2	0.06
66281	O1	219.7	0.87
66281	M6	50.9	0.02
66281	NU2	208.9	0.11
66281	MU2	204.5	0.07
66281	2N2	180.4	0.08
66281	OO1	257.1	0.04
66281	LDA2	242.7	0.02
66281	M1	229.1	0.06
66281	J1	247.7	0.07
66281	SSA	198	0.05
66281	SA	286.2	0.36
66281	MF	183.4	0.09
66281	RHO1	211.7	0.03
66281	Q1	210.4	0.17
66281	T2	255.7	0.05
66281	R2	257.8	0.01
66281	2Q1	201.2	0.02
66281	P1	237	0.45
66281	L2	255.7	0.08
66281	K2	258.8	0.21
66281	M8	318.1	0.01
66282	M2	253.1	2.88
66282	S2	290.8	0.79
66282	N2	235.6	0.54
66282	K1	254	1.36
66282	M4	74.2	0.13
66282	O1	242.4	0.88
66282	M6	30.2	0.07
66282	S4	180.1	0.03
66282	NU2	237.9	0.1
66282	S6	305.1	0.01
66282	MU2	215.3	0.07
66282	2N2	218.1	0.07
66282	OO1	265.5	0.04
66282	LDA2	270.7	0.02
66282	M1	248.2	0.06
66282	J1	259.8	0.07
66282	RHO1	237.4	0.03
66282	Q1	236.6	0.17
66282	T2	289.4	0.05
66282	R2	292.5	0.01
66282	2Q1	230.9	0.02
66282	P1	253.2	0.45
66282	L2	270.5	0.08
66282	K2	293.9	0.21
66282	M8	201.6	0.01
66283	M2	260.9	3.26
66283	S2	291.9	0.78
66283	N2	239.9	0.63
66283	K1	257.2	1.26
66283	M4	29.8	0.04
66283	O1	242.7	0.85
66283	M6	31.2	0.06
66283	MK3	106.3	0.06
66283	S4	142.4	0.01
66283	MN4	24.6	0.02
66283	NU2	240.7	0.13
66283	MU2	342.9	0.04
66283	2N2	212.8	0.08
66283	OO1	301.9	0.06
66283	LDA2	246.4	0.05
66283	S1	167.5	0.08
66283	M1	182.2	0.01
66283	J1	287.5	0.06
66283	SSA	183	0.15
66283	SA	308.7	0.37
66283	MF	187.9	0.09
66283	RHO1	248.5	0.05
66283	Q1	244.1	0.14
66283	T2	298.2	0.02
66283	R2	345.7	0.1
66283	2Q1	233.7	0.05
66283	P1	253.8	0.4
66283	2SM2	112.7	0.03
66283	L2	276.6	0.12
66283	2MK3	67.4	0.09
66283	K2	298.3	0.22
66283	M8	97.4	0.01
66283	MS4	64.4	0.04
66284	M2	250.6	3.05
66284	S2	278.5	0.82
66284	N2	226.8	0.62
66284	K1	248.4	1.36
66284	M4	245.9	0.05
66284	O1	232.5	0.85
66284	M6	39.2	0.02
66284	MK3	169.7	0.02
66284	S4	18.3	0.01
66284	MN4	225.5	0.01
66284	NU2	230	0.1
66284	MU2	233.3	0.02
66284	2N2	191.4	0.08
66284	OO1	287.1	0.04
66284	LDA2	266.1	0.03
66284	S1	15.7	0.03
66284	M1	289	0.04
66284	J1	268	0.07
66284	SSA	184.1	0.17
66284	SA	307.2	0.36
66284	RHO1	239.8	0.03
66284	Q1	225	0.14
66284	T2	257	0.03
66284	R2	268.6	0.01
66284	2Q1	212.2	0.01
66284	P1	246.8	0.41
66284	2SM2	106.8	0.02
66284	M3	21.6	0.01
66284	L2	267.5	0.09
66284	2MK3	102.6	0.03
66284	K2	271.2	0.23
66284	MS4	296.9	0.03
66285	M2	261.6	3.17
66285	S2	293.8	0.79
66285	N2	239.5	0.6
66285	K1	254.5	1.32
66285	M4	109.1	0.03
66285	O1	239.6	0.8
66285	M6	124.1	0.04
66285	MK3	113.3	0.08
66285	S4	160	0.01
66285	MN4	79.1	0.02
66285	NU2	240.9	0.13
66285	MU2	356.5	0.06
66285	2N2	214	0.06
66285	OO1	294.3	0.04
66285	LDA2	257.3	0.07
66285	S1	24.5	0.04
66285	M1	302.6	0.05
66285	J1	282.8	0.05
66285	SSA	183	0.15
66285	SA	308.7	0.37
66285	MF	187.9	0.09
66285	RHO1	239.9	0.02
66285	Q1	240	0.14
66285	T2	296.4	0.05
66285	R2	356.4	0.01
66285	2Q1	253.7	0.02
66285	P1	251.4	0.37
66285	2SM2	121.5	0.03
66285	M3	15.4	0.01
66285	L2	267.4	0.15
66285	2MK3	91.4	0.1
66285	K2	283.4	0.25
66285	MS4	107.6	0.02
66286	M2	300.3	2.59
66286	S2	335.2	0.6
66286	N2	280	0.46
66286	K1	280.7	0.97
66286	M4	170.7	0.26
66286	O1	268.8	0.55
66286	M6	266.9	0.04
66286	MK3	149.2	0.22
66286	S4	249.7	0.01
66286	MN4	154.6	0.09
66286	NU2	282.8	0.1
66286	MU2	58.7	0.1
66286	2N2	233.1	0.07
66286	OO1	358	0.02
66286	LDA2	293.4	0.07
66286	S1	53.8	0.01
66286	M1	13.2	0.05
66286	J1	339	0.04
66286	RHO1	313.6	0.02
66286	Q1	276.5	0.1
66286	T2	332.4	0.04
66286	R2	353.4	0.04
66286	2Q1	232.1	0.01
66286	P1	281.8	0.25
66286	2SM2	156.8	0.04
66286	M3	342.1	0.03
66286	L2	311.5	0.13
66286	2MK3	135.8	0.22
66286	K2	322.4	0.23
66286	M8	117.5	0.02
66286	MS4	198.3	0.13
66287	M2	52.2	0.83
66287	S2	84.3	0.17
66287	N2	33.6	0.13
66287	K1	12.4	0.53
66287	M4	22.4	0.17
66287	O1	19.8	0.22
66287	M6	10.3	0.02
66287	MK3	327.2	0.15
66287	MN4	2.7	0.05
66287	NU2	57.4	0.03
66287	MU2	162.3	0.03
66287	2N2	356.6	0.04
66287	OO1	81.3	0.02
66287	LDA2	6.5	0.01
66287	S1	188.9	0.14
66287	M1	58.4	0.04
66287	J1	46.5	0.03
66287	RHO1	20.2	0.01
66287	Q1	23.1	0.05
66287	T2	123.5	0.02
66287	R2	151.8	0.06
66287	2Q1	343.8	0.02
66287	P1	309.5	0.18
66287	2SM2	279.3	0.01
66287	M3	112.7	0.02
66287	L2	89.1	0.06
66287	2MK3	314.7	0.11
66287	K2	85.3	0.09
66287	M8	77	0.01
66287	MS4	52.8	0.09
66288	M2	20.2	1
66288	S2	64.7	0.22
66288	N2	355.5	0.17
66288	K1	338.3	0.53
66288	M4	306.5	0.18
66288	O1	354	0.23
66288	M6	249.4	0.02
66288	MK3	276	0.15
66288	S4	67.5	0.01
66288	MN4	283.7	0.06
66288	NU2	358.2	0.05
66288	MU2	151.5	0.05
66288	2N2	247.8	0.04
66288	LDA2	54.8	0.03
66288	S1	7	0.14
66288	M1	21.8	0.03
66288	J1	56.8	0.04
66288	RHO1	36.9	0.02
66288	Q1	348.3	0.06
66288	T2	54.4	0.04
66288	R2	75.9	0.04
66288	2Q1	70.8	0.01
66288	P1	9.1	0.08
66288	2SM2	232.5	0.02
66288	M3	146.4	0.03
66288	L2	0.2	0.05
66288	2MK3	259.1	0.11
66288	K2	54.5	0.09
66288	M8	29.9	0.01
66288	MS4	341.7	0.08
66289	M2	31.2	0.85
66289	S2	59.9	0.2
66289	N2	11.4	0.13
66289	K1	357.9	0.44
66289	M4	345.8	0.23
66289	O1	6.7	0.23
66289	M6	333.3	0.05
66289	MK3	296.3	0.16
66289	S4	74.8	0.01
66289	MN4	326.3	0.07
66289	NU2	38.4	0.03
66289	MU2	132.5	0.03
66289	2N2	337.1	0.04
66289	OO1	81.3	0.02
66289	LDA2	343.6	0.02
66289	S1	255	0.11
66289	M1	42.1	0.05
66289	J1	35.1	0.03
66289	Q1	12.1	0.05
66289	T2	69.4	0.03
66289	R2	136.3	0.06
66289	2Q1	333	0.01
66289	P1	342.4	0.1
66289	2SM2	258.1	0.01
66289	M3	115	0.02
66289	L2	62.8	0.05
66289	2MK3	283.7	0.13
66289	K2	61.9	0.1
66289	M8	46.7	0.01
66289	MS4	20.1	0.13
66290	M2	106.4	0.45
66290	S2	145.8	0.1
66290	N2	92.1	0.09
66290	K1	45.9	0.3
66290	M4	112.8	0.09
66290	O1	62.8	0.18
66290	M6	121.5	0.02
66290	S4	289.2	0.02
66290	NU2	94	0.02
66290	MU2	78.6	0.01
66290	2N2	76.9	0.01
66290	M1	55.4	0.01
66290	J1	44.1	0.01
66290	RHO1	69	0.01
66290	Q1	67.4	0.03
66290	T2	145.6	0.01
66290	P1	47.2	0.1
66290	L2	116.4	0.01
66290	K2	149.4	0.03
66291	M2	153.4	0.39
66291	S2	189.8	0.12
66291	N2	141	0.07
66291	K1	32.5	0.35
66291	M4	205.4	0.09
66291	O1	61	0.19
66291	M6	255.4	0.03
66291	S4	259.9	0.01
66291	NU2	143.3	0.01
66291	MU2	117.6	0.01
66291	2N2	128.8	0.01
66291	OO1	11.3	0.01
66291	M1	47.1	0.02
66291	J1	22.4	0.02
66291	RHO1	77.6	0.01
66291	Q1	76.4	0.03
66291	T2	188.4	0.01
66291	P1	34.1	0.11
66291	L2	163.1	0.01
66291	K2	192.7	0.03
66292	M2	58.6	0.87
66292	S2	104.1	0.2
66292	N2	32.8	0.16
66292	K1	355.5	0.46
66292	M4	39.5	0.18
66292	O1	24.2	0.22
66292	M6	28.3	0.01
66292	MK3	341.6	0.16
66292	S4	152.5	0.01
66292	MN4	16.1	0.06
66292	NU2	29.6	0.04
66292	MU2	186.8	0.04
66292	2N2	279.8	0.04
66292	OO1	162.5	0.01
66292	LDA2	103.9	0.04
66292	S1	356.2	0.22
66292	M1	32.6	0.02
66292	J1	69.5	0.04
66292	RHO1	48.2	0.01
66292	Q1	7.4	0.06
66292	T2	106.2	0.03
66292	R2	111.8	0.05
66292	2Q1	38.1	0.01
66292	P1	55	0.1
66292	2SM2	270.2	0.02
66292	M3	204.3	0.04
66292	L2	38.2	0.03
66292	2MK3	325.1	0.12
66292	K2	98	0.09
66292	MS4	76.9	0.08
66293	M2	42.4	1.04
66293	S2	76.5	0.22
66293	N2	40.6	0.15
66293	K1	358.3	0.6
66293	M4	4.5	0.17
66293	O1	7.9	0.28
66293	M6	290.6	0.01
66293	S4	170.3	0.01
66293	NU2	40.6	0.03
66293	MU2	8	0.03
66293	2N2	34.9	0.02
66293	OO1	346.1	0.01
66293	LDA2	58.1	0.01
66293	M1	2.8	0.02
66293	J1	352.5	0.02
66293	RHO1	11.5	0.01
66293	Q1	12.9	0.05
66293	T2	75.6	0.01
66293	2Q1	22.4	0.01
66293	P1	358.9	0.2
66293	L2	42.9	0.03
66293	K2	79.3	0.06
66293	M8	89.6	0.01
66294	M2	358.1	1.23
66294	S2	29.2	0.28
66294	N2	346.9	0.19
66294	K1	333.3	0.61
66294	M4	267.2	0.28
66294	O1	332.7	0.29
66294	M6	200.6	0.02
66294	S4	55.1	0.02
66294	NU2	348.3	0.04
66294	MU2	326.8	0.03
66294	2N2	335.3	0.03
66294	OO1	332.5	0.01
66294	LDA2	12.6	0.01
66294	M1	332.8	0.02
66294	J1	333.4	0.02
66294	RHO1	332.7	0.01
66294	Q1	332.3	0.05
66294	T2	28.1	0.02
66294	2Q1	331.1	0.01
66294	P1	333.2	0.2
66294	L2	8.8	0.03
66294	K2	31.8	0.08
66294	M8	347	0.02
66295	M2	340.6	1.39
66295	S2	15.3	0.33
66295	N2	318.1	0.25
66295	K1	314.3	0.57
66295	M4	249	0.27
66295	O1	314.8	0.3
66295	M6	175.7	0.02
66295	MK3	214.9	0.19
66295	S4	2.6	0.01
66295	MN4	228	0.09
66295	NU2	314.3	0.05
66295	MU2	90.7	0.05
66295	2N2	283.4	0.02
66295	OO1	29.2	0.01
66295	LDA2	338	0.05
66295	S1	114.9	0.03
66295	M1	23.2	0.03
66295	J1	7.9	0.02
66295	Q1	324.8	0.06
66295	T2	31	0.05
66295	R2	74.3	0.02
66295	2Q1	288.3	0.01
66295	P1	300.8	0.13
66295	2SM2	204.6	0.02
66295	M3	135.8	0.02
66295	L2	348.3	0.09
66295	2MK3	203.9	0.16
66295	K2	1.8	0.14
66295	M8	273.8	0.01
66295	MS4	284.3	0.13
66296	M2	307.3	2.39
66296	S2	340.2	0.57
66296	N2	292.6	0.41
66296	K1	287.8	0.92
66296	M4	193.3	0.3
66296	O1	277.2	0.5
66296	M6	299.3	0.05
66296	S4	321.7	0.02
66296	NU2	294.6	0.08
66296	S6	98.8	0.01
66296	MU2	274.3	0.06
66296	2N2	277.9	0.06
66296	OO1	297.7	0.02
66296	LDA2	322.5	0.02
66296	M1	282.4	0.04
66296	J1	292.7	0.04
66296	RHO1	272.4	0.02
66296	Q1	272.2	0.1
66296	T2	338.9	0.03
66296	2Q1	266.9	0.01
66296	P1	287	0.3
66296	L2	322	0.07
66296	K2	342.9	0.15
66296	M8	161.6	0.02
66297	M2	326.5	1.82
66297	S2	358.9	0.43
66297	N2	313.2	0.3
66297	K1	306.6	0.73
66297	M4	229.4	0.37
66297	O1	298.5	0.38
66297	M6	352.3	0.02
66297	S4	9.3	0.02
66297	NU2	314.9	0.06
66297	MU2	294	0.04
66297	2N2	299.8	0.04
66297	OO1	314.1	0.02
66297	LDA2	341.5	0.01
66297	M1	302.5	0.03
66297	J1	310.3	0.03
66297	RHO1	295.6	0.01
66297	Q1	294.7	0.07
66297	T2	357.4	0.03
66297	2Q1	290.8	0.01
66297	P1	305.9	0.24
66297	L2	339.9	0.05
66297	K2	1.4	0.11
66297	M8	257.7	0.03
66298	M2	291.8	2.78
66298	S2	325.5	0.66
66298	N2	271.6	0.5
66298	K1	274.8	1.06
66298	M4	145.5	0.22
66298	O1	261.5	0.62
66298	M6	233.5	0.04
66298	MK3	133.5	0.2
66298	S4	213.9	0.01
66298	MN4	130.7	0.08
66298	NU2	274.2	0.12
66298	MU2	50.5	0.1
66298	2N2	229.2	0.07
66298	OO1	332.7	0.02
66298	LDA2	279	0.08
66298	S1	128.4	0.01
66298	M1	4.7	0.06
66298	J1	325.1	0.05
66298	RHO1	301.2	0.02
66298	Q1	267.7	0.1
66298	T2	314	0.04
66298	R2	14.8	0.02
66298	2Q1	227.2	0.02
66298	P1	275.3	0.29
66298	2SM2	148.7	0.04
66298	M3	330.8	0.03
66298	L2	302.4	0.13
66298	2MK3	121.6	0.21
66298	K2	312.3	0.23
66298	M8	74	0.01
66298	MS4	171.9	0.11
66299	M2	244	2.82
66299	S2	270	0.78
66299	N2	218.5	0.58
66299	K1	245.1	1.35
66299	M4	205.5	0.09
66299	O1	228.8	0.86
66299	M6	297.8	0.01
66299	MK3	196.3	0.04
66299	MN4	180.1	0.03
66299	NU2	220.7	0.12
66299	MU2	192.6	0.06
66299	2N2	184.3	0.07
66299	OO1	269	0.04
66299	LDA2	273.4	0.02
66299	S1	3.1	0.05
66299	M1	253.6	0.06
66299	J1	254.2	0.09
66299	SSA	183	0.15
66299	SA	308.7	0.37
66299	MF	187.9	0.09
66299	RHO1	222.3	0.02
66299	Q1	216.4	0.15
66299	T2	267.5	0.05
66299	2Q1	158.4	0.01
66299	P1	242.6	0.43
66299	M3	267.3	0.01
66299	L2	266.1	0.08
66299	2MK3	200	0.02
66299	K2	265.3	0.22
66299	MS4	244.6	0.04
66300	M2	281.9	3.82
66300	S2	323.4	0.88
66300	N2	260.7	0.63
66300	K1	268.8	1.23
66300	M4	20.5	0.24
66300	O1	257.9	0.67
66300	M6	117.6	0.2
66300	S4	186.1	0.02
66300	NU2	263.5	0.12
66300	MU2	240.5	0.09
66300	2N2	239.5	0.09
66300	OO1	279.4	0.03
66300	LDA2	301.2	0.03
66300	M1	263.4	0.05
66300	J1	274.1	0.05
66300	SA	289.8	0.52
66300	MF	161.8	0.08
66300	RHO1	253.2	0.03
66300	Q1	252.5	0.13
66300	T2	321.7	0.05
66300	R2	325	0.01
66300	2Q1	247.3	0.02
66300	P1	267.9	0.41
66300	L2	303.1	0.11
66300	K2	326.8	0.24
66300	M8	208.1	0.03
66301	M2	264.1	3.86
66301	S2	299.6	0.97
66301	N2	237.9	0.74
66301	K1	257.1	1.43
66301	M4	336.6	0.22
66301	O1	242.6	0.87
66301	M6	90.8	0.11
66301	S4	70.5	0.04
66301	NU2	241.5	0.14
66301	2N2	211.7	0.1
66301	OO1	271.6	0.04
66301	LDA2	113.5	0.03
66301	M1	249.8	0.06
66301	J1	264.3	0.07
66301	RHO1	236.4	0.03
66301	Q1	235.3	0.17
66301	T2	299.5	0.06
66301	R2	299.5	0.01
66301	2Q1	228.1	0.02
66301	P1	257.1	0.47
66301	L2	290.3	0.11
66301	K2	299.5	0.26
66301	M8	170.7	0.02
66302	M2	259.7	3.69
66302	S2	291.2	0.98
66302	N2	233.6	0.77
66302	K1	254.8	1.4
66302	M4	317	0.2
66302	O1	239.2	0.87
66302	M6	62.9	0.11
66302	S4	57.2	0.03
66302	NU2	237.1	0.15
66302	2N2	207.3	0.1
66302	OO1	270.4	0.04
66302	LDA2	274.4	0.03
66302	M1	246.9	0.06
66302	J1	262.5	0.07
66302	RHO1	232.4	0.03
66302	Q1	231.3	0.17
66302	T2	291.1	0.06
66302	R2	291.2	0.01
66302	2Q1	223.6	0.02
66302	P1	254.7	0.46
66302	L2	286	0.1
66302	K2	291.1	0.27
66302	M8	143.4	0.01
66303	M2	253.7	3.22
66303	S2	284.4	0.86
66303	N2	229.7	0.65
66303	K1	251.1	1.43
66303	M4	352.6	0.05
66303	O1	235.4	0.87
66303	M6	45.3	0.03
66303	MK3	10.9	0.01
66303	MN4	335.6	0.02
66303	NU2	228.6	0.14
66303	MU2	253.2	0.03
66303	2N2	204.6	0.07
66303	OO1	292.6	0.05
66303	LDA2	269.3	0.03
66303	S1	40.7	0.02
66303	M1	270.3	0.05
66303	J1	267.6	0.08
66303	SA	289.8	0.52
66303	MF	161.8	0.08
66303	RHO1	208.7	0.04
66303	Q1	230.2	0.15
66303	T2	270.5	0.06
66303	R2	285.6	0.01
66303	2Q1	221	0.02
66303	P1	249.2	0.45
66303	L2	266.3	0.11
66303	2MK3	64.3	0.02
66303	K2	279.6	0.23
66303	MS4	30.5	0.03
66304	M2	240.7	3.23
66304	S2	271.3	0.89
66304	N2	217.9	0.67
66304	K1	244	1.39
66304	M4	210	0.09
66304	O1	228.4	0.85
66304	M6	19.9	0.06
66304	MK3	191.2	0.03
66304	MN4	195.2	0.03
66304	NU2	218.6	0.13
66304	MU2	240.8	0.05
66304	2N2	193	0.08
66304	OO1	278	0.05
66304	LDA2	230	0.03
66304	S1	31.3	0.04
66304	M1	268.2	0.05
66304	J1	259.9	0.07
66304	MM	171.2	0.08
66304	SA	289.6	0.41
66304	MF	190.3	0.09
66304	RHO1	220.7	0.03
66304	Q1	222.4	0.15
66304	T2	277.6	0.05
66304	R2	210.1	0.02
66304	2Q1	233.7	0.02
66304	P1	239.9	0.43
66304	2SM2	80.7	0.02
66304	L2	243.1	0.1
66304	2MK3	108.8	0.01
66304	K2	264.3	0.24
66304	M8	11.3	0.01
66304	MS4	254.7	0.04
66305	M2	253.6	3.66
66305	S2	289	0.98
66305	N2	234.4	0.73
66305	K1	250.9	1.42
66305	M4	305.2	0.2
66305	O1	235.8	0.85
66305	M6	41.5	0.13
66305	MK3	314.9	0.04
66305	S4	54.7	0.01
66305	MN4	287.6	0.07
66305	NU2	230	0.15
66305	MU2	303.4	0.11
66305	2N2	188	0.11
66305	OO1	293.3	0.04
66305	LDA2	225.8	0.06
66305	S1	73	0.02
66305	M1	297.5	0.04
66305	J1	281	0.08
66305	MM	306.8	0.05
66305	SSA	203.9	0.05
66305	SA	277.8	0.29
66305	MSF	21.5	0.1
66305	MF	164.6	0.08
66305	RHO1	234.3	0.02
66305	Q1	235.2	0.14
66305	T2	296.4	0.06
66305	R2	265.9	0.02
66305	2Q1	210.5	0.02
66305	P1	248.7	0.42
66305	2SM2	101	0.03
66305	M3	72.9	0.02
66305	L2	254.5	0.12
66305	2MK3	41	0.05
66305	K2	282.5	0.28
66305	M8	105.6	0.03
66305	MS4	345.8	0.11
66306	M2	248.3	1.99
66306	S2	275.5	0.51
66306	N2	224.6	0.4
66306	K1	263.2	0.81
66306	M4	98.8	0.31
66306	O1	266.8	0.46
66306	M6	233.2	0.04
66306	S4	162.4	0.02
66306	NU2	227.8	0.08
66306	MU2	221.1	0.05
66306	2N2	200.6	0.05
66306	OO1	259.5	0.02
66306	LDA2	260.9	0.01
66306	M1	265	0.03
66306	J1	261.5	0.04
66306	MM	171.2	0.08
66306	SA	289.6	0.41
66306	MF	190.3	0.09
66306	RHO1	268.9	0.02
66306	Q1	268.6	0.09
66306	T2	274.5	0.03
66306	2Q1	270.6	0.01
66306	P1	263.4	0.27
66306	L2	271.3	0.06
66306	K2	277.8	0.14
66306	M8	32.6	0.01
66307	M2	234.9	3.06
66307	S2	262	0.87
66307	N2	210.2	0.64
66307	K1	239.6	1.41
66307	O1	223.8	0.86
66307	NU2	213.3	0.13
66307	MU2	184.9	0.07
66307	2N2	183.4	0.07
66307	OO1	266.3	0.05
66307	LDA2	260.2	0.02
66307	S1	346.6	0.02
66307	M1	244.1	0.05
66307	J1	252.8	0.09
66307	SSA	125.8	0.05
66307	SA	286.5	0.56
66307	RHO1	209.7	0.03
66307	Q1	216	0.15
66307	T2	257.4	0.05
66307	R2	258.4	0.01
66307	2Q1	205.4	0.02
66307	P1	235.8	0.44
66307	L2	258.6	0.07
66307	K2	254.4	0.24
66308	M2	238.1	3.07
66308	S2	267	0.9
66308	N2	211.1	0.62
66308	K1	240.6	1.4
66308	O1	224.6	0.9
66308	M6	132.5	0.01
66308	S4	341.1	0.01
66308	NU2	214.7	0.12
66308	S6	209.6	0.01
66308	MU2	209.3	0.07
66308	2N2	184.1	0.08
66308	OO1	256.8	0.04
66308	LDA2	251.5	0.02
66308	M1	232.7	0.07
66308	J1	248.7	0.07
66308	SA	289.9	0.41
66308	MF	164.6	0.06
66308	RHO1	217.6	0.04
66308	Q1	216.6	0.17
66308	T2	265.8	0.05
66308	R2	268.1	0.01
66308	2Q1	208.6	0.02
66308	P1	239.4	0.46
66308	L2	265.2	0.09
66308	K2	269.3	0.24
66309	M2	246.2	2.59
66309	S2	272.5	0.76
66309	N2	222.3	0.55
66309	K1	248.5	1.63
66309	M4	58.8	0.04
66309	O1	231.6	1
66309	M6	184.2	0.02
66309	MK3	325.3	0.05
66309	MN4	28	0.02
66309	NU2	226.5	0.1
66309	MU2	202.5	0.08
66309	2N2	196.6	0.07
66309	OO1	283.5	0.05
66309	LDA2	270	0.01
66309	S1	29.3	0.04
66309	M1	263.4	0.06
66309	J1	264.8	0.09
66309	SA	289.9	0.41
66309	MF	164.6	0.06
66309	RHO1	219.6	0.03
66309	Q1	223.8	0.18
66309	T2	267.2	0.04
66309	R2	288	0.01
66309	2Q1	227.4	0.02
66309	P1	246.8	0.51
66309	L2	265.6	0.04
66309	2MK3	321.6	0.03
66309	K2	266.9	0.19
66309	MS4	68.6	0.02
66310	M2	258	2.19
66310	S2	283.5	0.65
66310	N2	233.9	0.48
66310	K1	252.2	1.78
66310	M4	66.1	0.03
66310	O1	233.5	1.08
66310	M6	187.2	0.03
66310	MK3	5	0.04
66310	S4	89.1	0.01
66310	MN4	33.6	0.01
66310	NU2	238.6	0.1
66310	MU2	216.9	0.08
66310	2N2	220.9	0.07
66310	OO1	283.9	0.05
66310	LDA2	260.1	0.01
66310	S1	45.6	0.07
66310	M1	261.1	0.06
66310	J1	261.2	0.09
66310	SA	289.9	0.41
66310	MF	164.6	0.06
66310	RHO1	232.5	0.05
66310	Q1	226	0.19
66310	T2	272.2	0.04
66310	R2	227.9	0.01
66310	2Q1	211.3	0.03
66310	P1	243.9	0.56
66310	2SM2	295.1	0.01
66310	M3	313.1	0.02
66310	L2	277.4	0.04
66310	2MK3	8.1	0.05
66310	K2	277.8	0.15
66310	MS4	84.2	0.01
66311	M2	266.8	2.01
66311	S2	288.5	0.63
66311	N2	243.5	0.44
66311	K1	254.7	1.77
66311	M4	85.6	0.03
66311	O1	237.1	1.1
66311	M6	195	0.04
66311	S4	356.4	0.01
66311	NU2	246.6	0.09
66311	MU2	245	0.05
66311	2N2	220.2	0.06
66311	OO1	272.5	0.05
66311	LDA2	276.8	0.01
66311	M1	246	0.08
66311	J1	263.6	0.09
66311	SA	289.9	0.41
66311	MF	164.6	0.06
66311	RHO1	229.5	0.04
66311	Q1	228.4	0.21
66311	T2	287.6	0.04
66311	R2	289.4	0.01
66311	2Q1	219.6	0.03
66311	P1	253.4	0.59
66311	L2	290.1	0.06
66311	K2	290.3	0.17
66312	M2	307.1	1.69
66312	S2	326.4	0.48
66312	N2	280.1	0.38
66312	K1	261.8	2.19
66312	M4	100.3	0.05
66312	O1	241.6	1.28
66312	M6	196.2	0.05
66312	MK3	22.4	0.07
66312	MN4	68.1	0.03
66312	NU2	286.7	0.07
66312	MU2	234	0.09
66312	2N2	248.6	0.05
66312	OO1	301.6	0.08
66312	LDA2	51.8	0.02
66312	S1	15.6	0.06
66312	M1	273.8	0.07
66312	J1	286	0.13
66312	MM	187.7	0.08
66312	SA	287.6	0.33
66312	MF	146.8	0.05
66312	RHO1	233.2	0.04
66312	Q1	232.8	0.22
66312	T2	335.5	0.03
66312	2Q1	221.8	0.02
66312	P1	259.4	0.68
66312	M3	142.1	0.01
66312	L2	31.9	0.04
66312	2MK3	19.3	0.07
66312	K2	332.7	0.09
66312	MS4	118.5	0.03
66313	M2	349.7	2.25
66313	S2	12.6	0.56
66313	N2	320	0.48
66313	K1	270.7	2.51
66313	M4	60.5	0.13
66313	O1	249.8	1.47
66313	M6	246.3	0.03
66313	MK3	332.8	0.09
66313	MN4	29.7	0.05
66313	NU2	331.5	0.09
66313	MU2	239.6	0.09
66313	2N2	286.8	0.06
66313	OO1	317	0.1
66313	LDA2	44.3	0.04
66313	S1	51.2	0.05
66313	M1	303.2	0.08
66313	J1	302.4	0.13
66313	MM	184.6	0.07
66313	SA	292	0.27
66313	MF	144.3	0.07
66313	RHO1	240.4	0.05
66313	Q1	242.3	0.25
66313	T2	14.1	0.04
66313	2Q1	242.4	0.03
66313	P1	269.5	0.79
66313	2SM2	290.6	0.01
66313	M3	228.7	0.01
66313	L2	44.1	0.09
66313	2MK3	341.1	0.06
66313	K2	16.8	0.17
66313	MS4	83.5	0.07
66314	M2	3.4	2.9
66314	S2	29.6	0.72
66314	N2	331.3	0.56
66314	K1	275.9	2.51
66314	M4	180.9	0.06
66314	O1	253.9	1.38
66314	M6	296.4	0.02
66314	S4	140.3	0.01
66314	NU2	335.6	0.11
66314	MU2	337.1	0.07
66314	2N2	299.2	0.08
66314	OO1	297.8	0.06
66314	LDA2	15.6	0.02
66314	M1	265	0.1
66314	J1	286.7	0.11
66314	SSA	231.1	0.11
66314	SA	292.9	0.25
66314	MF	140.5	0.07
66314	RHO1	244.5	0.05
66314	Q1	243.1	0.27
66314	T2	28.6	0.04
66314	R2	30.7	0.01
66314	2Q1	232.2	0.04
66314	P1	274.2	0.83
66314	L2	35.4	0.08
66314	K2	31.8	0.19
66315	M2	4.1	3.36
66315	S2	29.5	0.84
66315	N2	333.5	0.68
66315	K1	274.8	2.74
66315	M4	183.4	0.09
66315	O1	251.9	1.53
66315	M6	85.1	0.03
66315	MK3	73	0.1
66315	S4	211.5	0.01
66315	MN4	141	0.04
66315	NU2	345.1	0.14
66315	MU2	237.2	0.11
66315	2N2	318.2	0.08
66315	OO1	320.2	0.11
66315	LDA2	37.9	0.07
66315	S1	42.1	0.04
66315	M1	308.6	0.07
66315	J1	307.9	0.11
66315	MM	187.7	0.08
66315	SA	287.6	0.33
66315	MF	146.8	0.05
66315	RHO1	247.1	0.06
66315	Q1	247.2	0.26
66315	T2	33.6	0.05
66315	R2	30.4	0.01
66315	2Q1	236.2	0.03
66315	P1	273.9	0.85
66315	2SM2	271.2	0.02
66315	M3	350.4	0.03
66315	L2	65.4	0.13
66315	2MK3	48.8	0.11
66315	K2	28.5	0.24
66315	MS4	199.9	0.05
66316	M2	4.8	3.49
66316	S2	29.6	0.89
66316	N2	333.2	0.62
66316	K1	273.1	2.96
66316	M4	179	0.11
66316	O1	249.4	1.56
66316	M6	87.4	0.06
66316	NU2	337.4	0.12
66316	MU2	340	0.09
66316	2N2	301.5	0.08
66316	OO1	296.9	0.07
66316	LDA2	16.3	0.02
66316	M1	261.4	0.11
66316	J1	284.9	0.12
66316	MM	184.6	0.07
66316	SA	292	0.27
66316	MF	144.3	0.07
66316	RHO1	239.2	0.06
66316	Q1	237.6	0.31
66316	T2	28.6	0.05
66316	R2	30.6	0.01
66316	2Q1	225.9	0.04
66316	P1	271.4	0.98
66316	L2	36.4	0.1
66316	K2	31.6	0.24
66317	M2	15.2	3.43
66317	S2	52.5	0.95
66317	N2	1.8	0.72
66317	K1	283.2	2.87
66317	M4	256.5	0.13
66317	O1	254.7	1.37
66317	M6	341.2	0.08
66317	S4	17.1	0.06
66317	NU2	3.6	0.14
66317	S6	343.4	0.01
66317	MU2	92.6	0.08
66317	2N2	348.4	0.1
66317	OO1	311.6	0.06
66317	LDA2	32.5	0.02
66317	M1	269	0.1
66317	J1	297.3	0.11
66317	SSA	231.1	0.11
66317	SA	292.9	0.25
66317	MF	140.5	0.07
66317	RHO1	242.5	0.05
66317	Q1	240.6	0.27
66317	T2	51	0.06
66317	R2	53.9	0.01
66317	2Q1	226.5	0.04
66317	P1	281	0.95
66317	L2	28.5	0.1
66317	K2	55.5	0.26
66318	M2	27.7	4.37
66318	S2	57.6	1.06
66318	N2	4.2	0.81
66318	K1	287.5	2.92
66318	M4	331.3	0.09
66318	O1	260.5	1.51
66318	M6	117.3	0.04
66318	NU2	7.4	0.16
66318	MU2	358	0.1
66318	2N2	340.7	0.1
66318	OO1	314.5	0.06
66318	LDA2	41.6	0.03
66318	M1	274.1	0.1
66318	J1	300.9	0.12
66318	SSA	231.1	0.11
66318	SA	292.9	0.25
66318	MF	140.5	0.07
66318	RHO1	248.9	0.06
66318	Q1	247.1	0.29
66318	T2	56.4	0.06
66318	R2	58.8	0.01
66318	2Q1	233.7	0.04
66318	P1	285.5	0.96
66318	L2	51.4	0.12
66318	K2	60.1	0.29
66318	M8	302.5	0.01
66319	M2	11.8	3.74
66319	S2	37.8	0.93
66319	N2	341.2	0.74
66319	K1	277.9	2.75
66319	M4	207.7	0.06
66319	O1	255.1	1.51
66319	M6	292	0.02
66319	MK3	74.9	0.12
66319	S4	267.8	0.01
66319	MN4	184.1	0.03
66319	NU2	359.4	0.15
66319	MU2	232.6	0.12
66319	2N2	311.8	0.06
66319	OO1	338.6	0.12
66319	LDA2	48.8	0.07
66319	S1	35.2	0.07
66319	M1	294.1	0.11
66319	J1	319	0.14
66319	SSA	214.6	0.09
66319	SA	289.4	0.24
66319	RHO1	222.9	0.05
66319	Q1	250.6	0.25
66319	T2	39.8	0.06
66319	R2	38.9	0.01
66319	2Q1	255.1	0.02
66319	P1	277.2	0.84
66319	2SM2	293	0.02
66319	M3	152.4	0.03
66319	L2	53.3	0.2
66319	2MK3	44.6	0.1
66319	K2	39.6	0.27
66319	MS4	243.1	0.04
66320	M2	26.2	4.41
66320	S2	55.8	1.06
66320	N2	359.7	0.85
66320	K1	285.7	2.77
66320	M4	281.7	0.1
66320	O1	263.4	1.53
66320	M6	121.7	0.05
66320	MK3	126.9	0.08
66320	S4	267.3	0.01
66320	MN4	250.2	0.04
66320	NU2	6.1	0.19
66320	MU2	205.2	0.09
66320	2N2	339.6	0.1
66320	OO1	19.1	0.1
66320	LDA2	45.8	0.09
66320	S1	328.3	0.07
66320	M1	309.7	0.06
66320	J1	331.8	0.16
66320	SSA	231.1	0.11
66320	SA	292.9	0.25
66320	MF	140.5	0.07
66320	RHO1	268.6	0.06
66320	Q1	261.2	0.24
66320	T2	43.5	0.08
66320	R2	173.9	0.02
66320	2Q1	219.7	0.04
66320	P1	286.7	0.8
66320	2SM2	280.2	0.04
66320	M3	222.9	0.01
66320	L2	65.2	0.2
66320	2MK3	42.6	0.01
66320	K2	51.6	0.3
66320	MS4	310.9	0.06
66321	M2	26.5	3.74
66321	S2	57.2	0.91
66321	N2	1.5	0.72
66321	K1	285.8	2.46
66321	M4	282.6	0.09
66321	O1	261.1	1.32
66321	M6	124.5	0.04
66321	S4	283.8	0.01
66321	NU2	4.9	0.14
66321	MU2	355.7	0.09
66321	2N2	336.5	0.1
66321	OO1	310.6	0.06
66321	LDA2	40.7	0.03
66321	M1	273.6	0.1
66321	J1	298.1	0.1
66321	SSA	231.1	0.11
66321	SA	292.9	0.25
66321	MF	140.5	0.07
66321	RHO1	250.5	0.05
66321	Q1	248.9	0.26
66321	T2	56	0.05
66321	R2	58.4	0.01
66321	2Q1	236.5	0.03
66321	P1	284	0.81
66321	L2	51.5	0.1
66321	K2	59.7	0.25
66322	M2	30.3	4.79
66322	S2	62	1.13
66322	N2	4.5	0.91
66322	K1	289.6	2.88
66322	M4	294.4	0.16
66322	O1	266.4	1.55
66322	M6	143.8	0.1
66322	MK3	145.8	0.1
66322	S4	334.8	0.01
66322	MN4	265.4	0.07
66322	NU2	10.6	0.21
66322	MU2	193	0.08
66322	2N2	345.2	0.11
66322	OO1	5.6	0.09
66322	LDA2	46.8	0.09
66322	S1	63.5	0.06
66322	M1	309	0.06
66322	J1	331.4	0.17
66322	SSA	231.1	0.11
66322	SA	292.9	0.25
66322	MF	140.5	0.07
66322	RHO1	269.8	0.08
66322	Q1	264.7	0.23
66322	T2	69.9	0.05
66322	R2	118.3	0.04
66322	2Q1	238.2	0.03
66322	P1	285.3	0.88
66322	2SM2	273.4	0.05
66322	M3	254.8	0.02
66322	L2	64.4	0.22
66322	2MK3	267.3	0.02
66322	K2	58.8	0.32
66322	M8	18.8	0.01
66322	MS4	313.7	0.1
66323	M2	10.6	3.52
66323	S2	37	0.88
66323	N2	340.8	0.71
66323	K1	277	2.74
66323	M4	200.2	0.07
66323	O1	254.6	1.51
66323	M6	313.6	0.03
66323	MK3	78.1	0.11
66323	MN4	174	0.03
66323	NU2	354.9	0.15
66323	MU2	236.6	0.11
66323	2N2	308.7	0.08
66323	OO1	328.9	0.1
66323	LDA2	48.4	0.07
66323	S1	44.2	0.05
66323	M1	319.8	0.09
66323	J1	315.2	0.13
66323	SSA	231.1	0.11
66323	SA	292.9	0.25
66323	MF	140.5	0.07
66323	RHO1	246.6	0.05
66323	Q1	249.9	0.25
66323	T2	37.1	0.05
66323	R2	38	0.01
66323	2Q1	251.5	0.03
66323	P1	276.6	0.85
66323	2SM2	282.6	0.03
66323	M3	342.4	0.02
66323	L2	56.1	0.15
66323	2MK3	46.7	0.11
66323	K2	37.9	0.26
66323	MS4	229.9	0.04
66324	M2	11.6	3.31
66324	S2	37.1	0.846
66324	N2	345.3	0.614
66324	K1	276.9	2.654
66324	M4	181.5	0.062
66324	O1	258.3	1.532
66324	M6	327.2	0.039
66324	S4	294.8	0.003
66324	NU2	348.8	0.118
66324	S6	36.9	0.003
66324	MU2	346.1	0.079
66324	2N2	319	0.079
66324	OO1	295.4	0.066
66324	LDA2	23.4	0.023
66324	M1	267.7	0.108
66324	J1	286.1	0.121
66324	SSA	231.1	0.108
66324	SA	292.9	0.253
66324	MF	140.5	0.072
66324	RHO1	250.4	0.059
66324	Q1	249.1	0.295
66324	T2	36.1	0.049
66324	R2	38.1	0.007
66324	2Q1	240	0.039
66324	P1	275.4	0.876
66324	L2	38.1	0.092
66324	K2	39.2	0.23
66324	M8	244.1	0.003
66325	M2	15.5	3.37
66325	S2	43.4	0.83
66325	N2	346.3	0.67
66325	K1	281.1	2.61
66325	M4	267.2	0.08
66325	O1	259.9	1.52
66325	M6	350.9	0.03
66325	S4	284.5	0.02
66325	NU2	350.2	0.13
66325	MU2	347.6	0.08
66325	2N2	317.1	0.09
66325	OO1	302.1	0.07
66325	LDA2	28.4	0.02
66325	M1	270.5	0.11
66325	J1	291.5	0.12
66325	SSA	231.1	0.11
66325	SA	292.9	0.25
66325	MF	140.5	0.07
66325	RHO1	250.8	0.06
66325	Q1	249.4	0.3
66325	T2	42.3	0.05
66325	R2	44.5	0.01
66325	2Q1	239	0.04
66325	P1	279.5	0.87
66325	L2	44.7	0.1
66325	K2	45.6	0.23
66325	M8	284.8	0.01
66326	M2	10.7	3.42
66326	S2	36.2	0.83
66326	N2	341.9	0.68
66326	K1	278.3	2.71
66326	M4	185.7	0.07
66326	O1	255.4	1.48
66326	M6	324.7	0.06
66326	S4	274.1	0.01
66326	NU2	345.7	0.13
66326	MU2	345.2	0.08
66326	2N2	313	0.09
66326	OO1	301.1	0.06
66326	LDA2	22.5	0.02
66326	M1	267	0.1
66326	J1	289.6	0.12
66326	SSA	231.1	0.11
66326	SA	292.9	0.25
66326	MF	140.5	0.07
66326	RHO1	245.6	0.06
66326	Q1	244.1	0.29
66326	T2	35.2	0.05
66326	R2	37.2	0.01
66326	2Q1	232.8	0.04
66326	P1	276.6	0.9
66326	L2	39.6	0.1
66326	K2	38.3	0.23
66327	M2	12	3.53
66327	S2	37.6	0.87
66327	N2	344.4	0.68
66327	K1	278.1	2.77
66327	M4	186.1	0.07
66327	O1	254.6	1.51
66327	M6	328.7	0.07
66327	S4	244.1	0.01
66327	NU2	348.1	0.13
66327	S6	228.1	0.01
66327	MU2	346.4	0.09
66327	2N2	316.7	0.09
66327	OO1	301.7	0.07
66327	LDA2	23.9	0.02
66327	M1	266.5	0.11
66327	J1	289.8	0.12
66327	SSA	231.1	0.11
66327	SA	292.9	0.25
66327	MF	140.5	0.07
66327	RHO1	244.5	0.06
66327	Q1	242.9	0.29
66327	T2	36.6	0.05
66327	R2	38.6	0.01
66327	2Q1	231.3	0.04
66327	P1	276.4	0.92
66327	L2	39.6	0.1
66327	K2	39.6	0.24
66328	M2	341.1	1.81
66328	S2	357	0.49
66328	N2	311.3	0.42
66328	K1	270.2	2.22
66328	M4	111.9	0.05
66328	O1	251.3	1.31
66328	M6	199.6	0.05
66328	S4	38.4	0.01
66328	NU2	315.4	0.08
66328	MU2	325.2	0.04
66328	2N2	281.6	0.06
66328	OO1	289	0.06
66328	LDA2	348.5	0.01
66328	M1	260.8	0.09
66328	J1	279.5	0.1
66328	SSA	221	0.13
66328	SA	280.4	0.28
66328	RHO1	243.2	0.05
66328	Q1	242	0.25
66328	T2	356.4	0.03
66328	2Q1	232.6	0.03
66328	P1	268.8	0.73
66328	L2	10.9	0.05
66328	K2	358.3	0.13
66329	M2	10.8	3.45
66329	S2	35.3	0.84
66329	N2	342.1	0.7
66329	K1	277.8	2.61
66329	M4	183.8	0.07
66329	O1	257	1.54
66329	M6	323	0.06
66329	S4	203.4	0.02
66329	NU2	346	0.14
66329	MU2	346.3	0.08
66329	2N2	313.5	0.09
66329	OO1	298.8	0.07
66329	LDA2	22.1	0.02
66329	M1	267.5	0.11
66329	J1	288.2	0.12
66329	SSA	231.1	0.11
66329	SA	292.9	0.25
66329	MF	140.5	0.07
66329	RHO1	248	0.06
66329	Q1	246.6	0.3
66329	T2	34.3	0.05
66329	R2	36.2	0.01
66329	2Q1	236.2	0.04
66329	P1	276.3	0.86
66329	L2	39.4	0.1
66329	K2	37.3	0.23
66330	M2	9.7	3.44
66330	S2	35.5	0.84
66330	N2	344.3	0.69
66330	K1	277.3	2.6
66330	M4	184.3	0.07
66330	O1	257.4	1.55
66330	M6	325	0.06
66330	S4	222.4	0.01
66330	NU2	347.7	0.13
66330	MU2	344	0.08
66330	2N2	318.8	0.09
66330	OO1	297.2	0.07
66330	LDA2	21.6	0.02
66330	M1	267.5	0.11
66330	J1	287.2	0.12
66330	SSA	231.1	0.11
66330	SA	292.9	0.25
66330	MF	140.5	0.07
66330	RHO1	248.9	0.06
66330	Q1	247.6	0.3
66330	T2	34.4	0.05
66330	R2	36.5	0.01
66330	2Q1	237.8	0.04
66330	P1	275.8	0.86
66330	L2	35.1	0.1
66330	K2	37.6	0.23
66330	M8	211.3	0.01
66331	M2	18.3	3.37
66331	S2	42	0.85
66331	N2	349.4	0.68
66331	K1	282	2.57
66331	M4	12	0.01
66331	O1	258	1.47
66331	M6	134.8	0.07
66331	S4	211	0.01
66331	NU2	353.3	0.13
66331	MU2	354.6	0.08
66331	2N2	320.5	0.09
66331	OO1	305.9	0.06
66331	LDA2	29.3	0.02
66331	M1	270.1	0.1
66331	J1	293.8	0.11
66331	RHO1	247.8	0.06
66331	Q1	246.2	0.29
66331	T2	41.1	0.05
66331	R2	43	0.01
66331	2Q1	234.4	0.04
66331	P1	280.2	0.85
66331	L2	47.1	0.1
66331	K2	43.9	0.23
66331	M8	13	0.02
66332	M2	18.1	3.18
66332	S2	43.5	0.79
66332	N2	346.2	0.65
66332	K1	279.6	2.68
66332	M4	58.1	0.02
66332	O1	256.6	1.48
66332	M6	149.1	0.07
66332	MK3	82.1	0.1
66332	MN4	20	0.01
66332	NU2	355.8	0.12
66332	MU2	259	0.11
66332	2N2	326.4	0.08
66332	OO1	322	0.1
66332	LDA2	58.8	0.05
66332	S1	25.7	0.1
66332	M1	306.9	0.05
66332	J1	313	0.12
66332	SSA	221	0.13
66332	SA	280.4	0.28
66332	RHO1	262.9	0.08
66332	Q1	252.6	0.23
66332	T2	43.5	0.06
66332	R2	97.5	0.01
66332	2Q1	229.5	0.04
66332	P1	275.7	0.83
66332	2SM2	315.7	0.03
66332	M3	1.6	0.04
66332	L2	81.4	0.1
66332	2MK3	68.1	0.14
66332	K2	45.6	0.24
66332	M8	60	0.02
66332	MS4	46.9	0.02
66333	M2	344.6	1.91
66333	S2	4.7	0.49
66333	N2	313.7	0.43
66333	K1	269.6	2.42
66333	M4	135.5	0.03
66333	O1	247.5	1.37
66333	M6	215.7	0.04
66333	MK3	53.5	0.06
66333	S4	111.1	0.01
66333	MN4	101.4	0.01
66333	NU2	316.1	0.08
66333	MU2	250.4	0.1
66333	2N2	309.1	0.07
66333	OO1	305.8	0.09
66333	LDA2	66.6	0.04
66333	S1	21.7	0.08
66333	M1	285	0.06
66333	J1	286.2	0.12
66333	SSA	221	0.13
66333	SA	280.4	0.28
66333	RHO1	254.5	0.06
66333	Q1	239	0.22
66333	T2	12.6	0.04
66333	R2	301	0.01
66333	2Q1	217.3	0.04
66333	P1	264.4	0.76
66333	2SM2	301.2	0.02
66333	M3	332.7	0.02
66333	L2	63.8	0.05
66333	2MK3	38.9	0.08
66333	K2	20.6	0.1
66333	MS4	130.5	0.02
66334	M2	16.7	3.1
66334	S2	42.9	0.78
66334	N2	347.4	0.63
66334	K1	281.4	2.47
66334	M4	77.1	0.05
66334	O1	259	1.43
66334	M6	154.3	0.07
66334	S4	205.8	0.01
66334	NU2	351.3	0.12
66334	MU2	350.6	0.08
66334	2N2	318	0.08
66334	OO1	303.9	0.06
66334	LDA2	29	0.02
66334	M1	270.3	0.1
66334	J1	292.6	0.11
66334	MM	184.6	0.07
66334	SA	292	0.27
66334	MF	144.3	0.07
66334	RHO1	249.4	0.05
66334	Q1	247.8	0.28
66334	T2	41.9	0.05
66334	R2	44	0.01
66334	2Q1	236.7	0.04
66334	P1	279.8	0.82
66334	L2	46.1	0.09
66334	K2	45.1	0.21
66334	M8	37.8	0.02
66335	M2	18.1	2.31
66335	S2	44.6	0.56
66335	N2	349.1	0.48
66335	K1	282.2	2.56
66335	M4	236.3	0.02
66335	O1	259.4	1.41
66335	M6	234.2	0.04
66335	MK3	172.2	0.04
66335	MN4	195.4	0.01
66335	NU2	357.7	0.1
66335	MU2	254.9	0.07
66335	2N2	316.7	0.05
66335	OO1	336.1	0.14
66335	LDA2	54.3	0.04
66335	S1	52	0.1
66335	M1	296.7	0.1
66335	J1	314	0.14
66335	MM	141.5	0.04
66335	SSA	227.1	0.09
66335	SA	276.9	0.21
66335	RHO1	227.5	0.06
66335	Q1	250.5	0.23
66335	T2	44.5	0.04
66335	R2	300.5	0.01
66335	2Q1	276.3	0.01
66335	P1	281.1	0.79
66335	2SM2	285.2	0.01
66335	M3	235	0.01
66335	L2	56.2	0.1
66335	2MK3	110.7	0.02
66335	K2	34	0.16
66335	M8	113.6	0.01
66335	MS4	220.9	0.01
66336	M2	16.9	2.23
66336	S2	42.6	0.55
66336	N2	345.9	0.5
66336	K1	279.7	2.79
66336	M4	117.3	0.02
66336	O1	254.6	1.47
66336	S4	163.5	0.01
66336	NU2	350	0.1
66336	MU2	351	0.05
66336	2N2	315	0.07
66336	OO1	304.7	0.06
66336	LDA2	28.8	0.02
66336	M1	267.2	0.1
66336	J1	292.1	0.11
66336	SSA	236.5	0.08
66336	SA	280.1	0.16
66336	MF	132.4	0.08
66336	RHO1	244	0.06
66336	Q1	242.2	0.29
66336	T2	41.6	0.03
66336	2Q1	229.8	0.04
66336	P1	277.9	0.92
66336	L2	47.8	0.06
66336	K2	44.7	0.15
66337	M2	22.4	2.38
66337	S2	50.2	0.58
66337	N2	354.7	0.5
66337	K1	283.1	2.65
66337	M4	158.5	0.02
66337	O1	260.5	1.49
66337	M6	59.4	0.01
66337	MK3	12.7	0.01
66337	MN4	120	0.01
66337	NU2	2.2	0.1
66337	MU2	268	0.05
66337	2N2	326.9	0.06
66337	OO1	325.7	0.1
66337	LDA2	56.7	0.03
66337	S1	24.9	0.1
66337	M1	309.3	0.07
66337	J1	321.4	0.14
66337	MM	141.5	0.04
66337	SSA	227.1	0.09
66337	SA	276.9	0.21
66337	RHO1	253.7	0.05
66337	Q1	253.7	0.25
66337	T2	42.4	0.04
66337	2Q1	253.8	0.03
66337	P1	280.6	0.82
66337	2SM2	278.2	0.01
66337	L2	60.4	0.08
66337	2MK3	334.4	0.02
66337	K2	50.8	0.16
66337	MS4	164	0.01
66338	M2	27.1	2.55
66338	S2	54.4	0.62
66338	N2	359.7	0.53
66338	K1	285.6	2.77
66338	M4	174.6	0.02
66338	O1	261	1.53
66338	M6	68.4	0.02
66338	S4	199.3	0.01
66338	NU2	3.3	0.1
66338	MU2	359.8	0.06
66338	2N2	332.2	0.07
66338	OO1	310.1	0.07
66338	LDA2	39.8	0.02
66338	M1	273.4	0.11
66338	J1	297.8	0.12
66338	MM	141.5	0.04
66338	SSA	227.1	0.09
66338	SA	276.9	0.21
66338	RHO1	250.6	0.06
66338	Q1	248.8	0.3
66338	T2	53.3	0.04
66338	R2	55.5	0.01
66338	2Q1	236.8	0.04
66338	P1	283.7	0.92
66338	L2	54.4	0.07
66338	K2	56.6	0.17
66339	M2	24.8	2.5
66339	S2	53.2	0.61
66339	N2	355.8	0.54
66339	K1	286.3	2.57
66339	M4	126.4	0.01
66339	O1	262.3	1.44
66339	M6	26	0.01
66339	NU2	359.6	0.1
66339	MU2	356.4	0.06
66339	2N2	326.7	0.07
66339	OO1	310.3	0.06
66339	LDA2	38	0.02
66339	M1	274.3	0.1
66339	J1	298.2	0.11
66339	SSA	236.5	0.08
66339	SA	280.1	0.16
66339	MF	132.4	0.08
66339	RHO1	252	0.06
66339	Q1	250.3	0.28
66339	T2	52.1	0.04
66339	2Q1	238.4	0.04
66339	P1	284.5	0.85
66339	L2	53.9	0.07
66339	K2	55.6	0.17
66340	M2	15.4	2.03
66340	S2	41.3	0.49
66340	N2	348.7	0.42
66340	K1	281.3	2.58
66340	M4	139.4	0.05
66340	O1	259.1	1.45
66340	M6	201.9	0.01
66340	S4	178.1	0.01
66340	NU2	352.3	0.08
66340	MU2	349.6	0.05
66340	2N2	321.9	0.06
66340	OO1	303.6	0.06
66340	LDA2	27.4	0.01
66340	M1	270.3	0.1
66340	J1	292.3	0.11
66340	SSA	227.5	0.07
66340	SA	274.5	0.25
66340	MF	156.4	0.07
66340	RHO1	249.5	0.06
66340	Q1	248	0.28
66340	T2	40.3	0.03
66340	2Q1	236.9	0.04
66340	P1	279.6	0.85
66340	L2	42	0.06
66340	K2	43.4	0.13
66341	M2	4.7	1.87
66341	S2	28.3	0.44
66341	N2	337.9	0.38
66341	K1	277.7	2.5
66341	M4	143.8	0.05
66341	O1	255	1.39
66341	M6	195.4	0.03
66341	S4	169.3	0.01
66341	NU2	341.6	0.08
66341	S6	173.9	0.01
66341	MU2	341.2	0.05
66341	2N2	311.2	0.05
66341	OO1	300.4	0.06
66341	LDA2	15.6	0.01
66341	M1	266.4	0.1
66341	J1	289	0.11
66341	SSA	221	0.13
66341	SA	280.4	0.28
66341	RHO1	245.2	0.05
66341	Q1	243.7	0.27
66341	T2	27.3	0.03
66341	2Q1	232.4	0.04
66341	P1	276	0.83
66341	L2	31.4	0.05
66341	K2	30.1	0.12
66342	M2	357.2	1.73
66342	S2	17.7	0.41
66342	N2	324.8	0.37
66342	K1	275	2.46
66342	M4	87.1	0.06
66342	O1	253.3	1.43
66342	M6	206.1	0.03
66342	MK3	1.4	0.06
66342	S4	79.3	0.01
66342	MN4	53.6	0.03
66342	NU2	336.1	0.07
66342	MU2	245.4	0.08
66342	2N2	315.2	0.06
66342	OO1	316.2	0.1
66342	LDA2	53.8	0.04
66342	S1	11.8	0.08
66342	M1	293.2	0.05
66342	J1	302.9	0.11
66342	SSA	221	0.13
66342	SA	280.4	0.28
66342	RHO1	257.8	0.06
66342	Q1	244.4	0.24
66342	T2	20.5	0.03
66342	R2	281	0.01
66342	2Q1	205.5	0.04
66342	P1	270.9	0.74
66342	2SM2	277.5	0.01
66342	M3	300	0.03
66342	L2	58.4	0.06
66342	2MK3	11.8	0.06
66342	K2	36	0.11
66342	MS4	107.2	0.04
66343	M2	344.4	1.69
66343	S2	4.2	0.41
66343	N2	316.6	0.35
66343	K1	270.7	2.4
66343	M4	141.9	0.04
66343	O1	249.2	1.34
66343	M6	199.2	0.04
66343	S4	142	0.01
66343	NU2	320.3	0.07
66343	MU2	324.6	0.04
66343	2N2	288.9	0.05
66343	OO1	292.2	0.06
66343	LDA2	353.6	0.01
66343	M1	260	0.1
66343	J1	281.3	0.1
66343	SSA	221	0.13
66343	SA	280.4	0.28
66343	RHO1	240	0.05
66343	Q1	238.5	0.26
66343	T2	3.4	0.02
66343	2Q1	227.9	0.04
66343	P1	269.1	0.79
66343	L2	12	0.05
66343	K2	5.8	0.11
66344	M2	10.6	1.83
66344	S2	35.7	0.43
66344	N2	343	0.39
66344	K1	280.4	2.49
66344	M4	124.6	0.05
66344	O1	258.7	1.42
66344	M6	237.2	0.02
66344	MK3	27.5	0.04
66344	S4	157	0.01
66344	MN4	92	0.02
66344	NU2	350.1	0.08
66344	MU2	266.6	0.06
66344	2N2	309.4	0.04
66344	OO1	325.7	0.1
66344	LDA2	60	0.03
66344	S1	26.8	0.08
66344	M1	298	0.08
66344	J1	315.1	0.14
66344	MM	168.8	0.03
66344	SSA	227.5	0.07
66344	SA	274.5	0.25
66344	MSF	265.1	0.02
66344	MF	156.4	0.07
66344	RHO1	245.9	0.04
66344	Q1	250.7	0.24
66344	T2	39.9	0.04
66344	R2	313.6	0.01
66344	2Q1	253.5	0.03
66344	P1	278	0.77
66344	2SM2	289.1	0.01
66344	L2	52.4	0.07
66344	2MK3	19.5	0.03
66344	K2	44	0.11
66344	MS4	134	0.03
66345	M2	4.3	1.86
66345	S2	27	0.45
66345	N2	338	0.39
66345	K1	277.5	2.48
66345	M4	142.3	0.05
66345	O1	254.7	1.4
66345	M6	203.2	0.03
66345	S4	139.6	0.01
66345	NU2	341.5	0.08
66345	MU2	341.6	0.05
66345	2N2	311.6	0.05
66345	OO1	300.3	0.06
66345	LDA2	14.8	0.01
66345	M1	266.2	0.1
66345	J1	288.8	0.11
66345	SSA	221	0.13
66345	SA	280.4	0.28
66345	RHO1	245	0.05
66345	Q1	243.5	0.27
66345	T2	26	0.03
66345	2Q1	232.1	0.04
66345	P1	275.8	0.82
66345	L2	30.7	0.05
66345	K2	28.8	0.12
66346	M2	0.5	1.88
66346	S2	22	0.47
66346	N2	330.5	0.41
66346	K1	276.4	2.48
66346	M4	121.9	0.08
66346	O1	255.7	1.43
66346	M6	202.5	0.03
66346	MK3	24.6	0.1
66346	S4	149.6	0.01
66346	MN4	89.2	0.04
66346	NU2	340.1	0.08
66346	MU2	260.8	0.09
66346	2N2	279.6	0.05
66346	OO1	332.9	0.1
66346	LDA2	69.3	0.03
66346	S1	57.1	0.06
66346	M1	287.5	0.1
66346	J1	303.5	0.14
66346	MM	187.7	0.08
66346	SA	287.6	0.33
66346	MF	146.8	0.05
66346	RHO1	246	0.05
66346	Q1	245.9	0.25
66346	T2	24.5	0.03
66346	2Q1	243.5	0.02
66346	P1	274.9	0.8
66346	2SM2	317	0.01
66346	M3	44.6	0.02
66346	L2	53.1	0.07
66346	2MK3	15.7	0.07
66346	K2	38.7	0.13
66346	MS4	142.4	0.05
66347	M2	340.1	1.71
66347	S2	0.3	0.44
66347	N2	310.3	0.39
66347	K1	270.9	2.34
66347	M4	110	0.03
66347	O1	247.2	1.35
66347	M6	199.5	0.04
66347	MK3	53.3	0.05
66347	S4	134.6	0.01
66347	MN4	77.4	0.02
66347	NU2	321.4	0.07
66347	MU2	249.8	0.09
66347	2N2	259	0.04
66347	OO1	314.5	0.1
66347	LDA2	77.8	0.02
66347	S1	37	0.08
66347	M1	273.1	0.08
66347	J1	295.8	0.13
66347	MM	187.7	0.08
66347	SA	287.6	0.33
66347	MF	146.8	0.05
66347	RHO1	226.2	0.04
66347	Q1	237.2	0.23
66347	T2	7.4	0.03
66347	2Q1	234.4	0.02
66347	P1	267.4	0.73
66347	2SM2	314.7	0.01
66347	M3	91.7	0.01
66347	L2	50	0.08
66347	2MK3	35.6	0.07
66347	K2	8.1	0.09
66347	MS4	118.2	0.02
66348	M2	348.6	1.44
66348	S2	10	0.35
66348	N2	320.4	0.31
66348	K1	273.2	2.02
66348	M4	107.3	0.06
66348	O1	252.6	1.15
66348	M6	195.4	0.04
66348	S4	142	0.01
66348	NU2	324.2	0.06
66348	MU2	327.2	0.04
66348	2N2	292	0.04
66348	OO1	293.9	0.05
66348	LDA2	358.6	0.01
66348	M1	263	0.08
66348	J1	283.5	0.09
66348	SSA	221	0.13
66348	SA	280.4	0.28
66348	RHO1	243.7	0.04
66348	Q1	242.3	0.22
66348	T2	9.2	0.02
66348	2Q1	232	0.03
66348	P1	271.6	0.67
66348	L2	16.7	0.04
66348	K2	11.8	0.1
66349	M2	272.2	4.934
66349	S2	305.8	1.604
66349	N2	249.8	1.033
66349	K1	262.6	1.506
66349	M4	309.1	0.033
66349	O1	244.3	0.971
66349	M6	122.7	0.013
66349	S4	250	0.013
66349	NU2	252.8	0.2
66349	MU2	238.6	0.118
66349	2N2	227.3	0.138
66349	OO1	281	0.043
66349	LDA2	287.8	0.036
66349	M1	253.5	0.069
66349	J1	271.8	0.075
66349	SSA	161.1	0.102
66349	SA	273.7	0.377
66349	RHO1	236.4	0.036
66349	Q1	235.1	0.187
66349	T2	304.5	0.095
66349	R2	307.2	0.013
66349	2Q1	226	0.026
66349	P1	261.3	0.499
66349	L2	294.7	0.138
66349	K2	308.6	0.436
66349	M8	212.6	0.007
66350	M2	272.3	4.94
66350	S2	304.1	1.52
66350	N2	251.9	0.99
66350	K1	263.4	1.53
66350	M4	297.2	0.04
66350	O1	244.1	0.98
66350	M6	153.6	0.01
66350	S4	24.9	0.01
66350	NU2	254.7	0.19
66350	S6	43.9	0.01
66350	MU2	240.6	0.12
66350	2N2	231.6	0.13
66350	OO1	282.6	0.04
66350	LDA2	287.1	0.04
66350	M1	253.8	0.07
66350	J1	272.9	0.08
66350	SSA	161.1	0.1
66350	SA	273.7	0.38
66350	RHO1	235.9	0.04
66350	Q1	234.6	0.19
66350	T2	302.9	0.09
66350	R2	305.4	0.01
66350	2Q1	225	0.03
66350	P1	261.9	0.51
66350	L2	292.7	0.14
66350	K2	306.7	0.41
66350	M8	215	0.01
66351	M2	268.7	6.04
66351	S2	299.5	1.92
66351	N2	242.3	1.16
66351	K1	262.5	1.68
66351	M4	289	0.04
66351	O1	244.5	1
66351	M6	233.4	0.01
66351	S4	9.2	0.02
66351	NU2	245.8	0.23
66351	MU2	335.3	0.14
66351	2N2	215.9	0.15
66351	OO1	280.6	0.04
66351	LDA2	283	0.04
66351	M1	253.6	0.07
66351	J1	271.5	0.08
66351	SSA	161.1	0.1
66351	SA	273.7	0.38
66351	MF	173	0.09
66351	RHO1	236.7	0.04
66351	Q1	235.5	0.19
66351	T2	298.3	0.11
66351	R2	300.8	0.02
66351	2Q1	226.5	0.03
66351	P1	261.2	0.55
66351	L2	295	0.17
66351	K2	302	0.52
66352	M2	269.2	5.93
66352	S2	304.5	1.9
66352	N2	241.6	1.18
66352	K1	257.6	1.66
66352	M4	310.2	0.03
66352	O1	245.3	1
66352	S4	26.3	0.02
66352	NU2	245.3	0.23
66352	MU2	330.7	0.14
66352	2N2	214.1	0.16
66352	OO1	270	0.04
66352	LDA2	285.6	0.04
66352	M1	251.5	0.07
66352	J1	263.8	0.08
66352	SSA	161.1	0.1
66352	SA	273.7	0.38
66352	RHO1	240	0.04
66352	Q1	239.1	0.19
66352	T2	303.1	0.11
66352	R2	305.9	0.02
66352	2Q1	233	0.03
66352	P1	256.7	0.55
66352	L2	296.7	0.17
66352	K2	307.4	0.52
66352	M8	202.9	0.01
66353	M2	272.6	5
66353	S2	304.2	1.54
66353	N2	253.4	1.04
66353	K1	261.7	1.58
66353	M4	262.3	0.04
66353	O1	248.4	1
66353	M6	100.2	0.02
66353	S4	316.9	0.01
66353	NU2	255.9	0.2
66353	MU2	241	0.12
66353	2N2	234.1	0.14
66353	OO1	275.1	0.04
66353	LDA2	287.3	0.04
66353	M1	255.1	0.07
66353	J1	268.4	0.08
66353	SSA	161.1	0.1
66353	SA	273.1	0.38
66353	MF	173	0.09
66353	RHO1	242.7	0.04
66353	Q1	241.8	0.19
66353	T2	302.9	0.09
66353	R2	305.5	0.01
66353	2Q1	235.2	0.03
66353	P1	260.7	0.52
66353	L2	291.9	0.14
66353	K2	306.8	0.42
66353	M8	224.5	0.01
66354	M2	270.1	6.17
66354	S2	301.8	2.05
66354	N2	245.6	1.25
66354	K1	261.1	1.68
66354	M4	291.6	0.05
66354	O1	244.9	1.02
66354	MK3	9.8	0.02
66354	S4	16.3	0.01
66354	MN4	273.2	0.02
66354	NU2	250	0.24
66354	MU2	231.3	0.13
66354	2N2	219.6	0.15
66354	OO1	292.1	0.06
66354	LDA2	277.9	0.04
66354	S1	45	0.05
66354	M1	276.3	0.05
66354	J1	275.5	0.1
66354	SSA	161.1	0.1
66354	SA	273.7	0.38
66354	MF	173	0.09
66354	RHO1	241	0.04
66354	Q1	237.4	0.18
66354	T2	296.9	0.11
66354	R2	340.5	0.03
66354	2Q1	236.6	0.02
66354	P1	258.5	0.53
66354	2SM2	98.5	0.01
66354	M3	336.4	0.06
66354	L2	281.3	0.14
66354	2MK3	53.1	0.01
66354	K2	295.2	0.56
66354	MS4	332.5	0.04
66355	M2	269.5	3.72
66355	S2	301.6	1.16
66355	N2	241.2	0.77
66355	K1	263.1	1.38
66355	M4	283.5	0.01
66355	O1	245.8	0.9
66355	NU2	245	0.15
66355	MU2	331.5	0.09
66355	2N2	212.9	0.1
66355	OO1	280.5	0.04
66355	LDA2	284.4	0.03
66355	M1	254.5	0.07
66355	J1	271.8	0.07
66355	RHO1	238.3	0.04
66355	Q1	237.2	0.17
66355	T2	300.3	0.07
66355	R2	302.9	0.01
66355	2Q1	228.5	0.02
66355	P1	261.8	0.46
66355	L2	297.8	0.1
66355	K2	304.2	0.31
66355	M8	15.6	0.01
66356	M2	269.3	3.72
66356	S2	301.2	1.1
66356	N2	243	0.78
66356	K1	263.2	1.45
66356	M4	294.3	0.01
66356	O1	247	0.89
66356	NU2	246.5	0.15
66356	MU2	331.2	0.09
66356	2N2	216.7	0.1
66356	OO1	279.4	0.04
66356	LDA2	284.1	0.03
66356	M1	255.1	0.06
66356	J1	271.2	0.07
66356	RHO1	240	0.03
66356	Q1	239	0.17
66356	T2	299.9	0.07
66356	R2	302.5	0.01
66356	2Q1	230.9	0.02
66356	P1	262	0.48
66356	L2	295.7	0.1
66356	K2	303.8	0.3
66357	M2	333.6	1.2
66357	S2	357.9	0.33
66357	N2	310.2	0.24
66357	K1	334.1	0.6
66357	M4	248.5	0.2
66357	O1	348.9	0.39
66357	M6	210.2	0.03
66357	S4	246	0.01
66357	NU2	313.4	0.05
66357	MU2	43.4	0.03
66357	2N2	286.9	0.03
66357	OO1	319.3	0.02
66357	LDA2	344.8	0.01
66357	M1	341.4	0.03
66357	J1	326.8	0.03
66357	RHO1	355.2	0.02
66357	Q1	356.2	0.08
66357	T2	356.9	0.02
66357	2Q1	3.5	0.01
66357	P1	335.2	0.2
66357	L2	356.9	0.03
66357	K2	359.8	0.09
66358	M2	272.9	6.35
66358	S2	304.3	2.22
66358	N2	246.8	1.35
66358	K1	260.9	1.74
66358	M4	272.3	0.11
66358	O1	246.4	1
66358	M6	355	0.01
66358	S4	41.9	0.02
66358	NU2	250.3	0.26
66358	MU2	336.5	0.15
66358	2N2	220.8	0.18
66358	OO1	275.5	0.04
66358	LDA2	287.5	0.05
66358	M1	253.7	0.07
66358	J1	268.1	0.08
66358	SSA	161.1	0.1
66358	SA	273.7	0.38
66358	RHO1	240.2	0.04
66358	Q1	239.2	0.19
66358	T2	303	0.13
66358	R2	305.5	0.02
66358	2Q1	232	0.03
66358	P1	259.8	0.57
66358	L2	298.9	0.18
66358	K2	306.8	0.6
66359	M2	271.3	6.12
66359	S2	305	2
66359	N2	249.6	1.26
66359	K1	262.3	1.57
66359	M4	334.2	0.05
66359	O1	243.2	1.01
66359	M6	31.7	0.01
66359	S4	314.3	0.01
66359	NU2	252.5	0.24
66359	S6	315.5	0.01
66359	MU2	237.5	0.15
66359	2N2	227.9	0.17
66359	OO1	281.4	0.04
66359	LDA2	286.9	0.04
66359	M1	252.9	0.07
66359	J1	271.8	0.08
66359	SSA	161.1	0.1
66359	SA	273.7	0.38
66359	RHO1	235.1	0.04
66359	Q1	233.8	0.2
66359	T2	303.7	0.12
66359	R2	306.4	0.02
66359	2Q1	224.3	0.03
66359	P1	260.9	0.52
66359	L2	293	0.17
66359	K2	307.8	0.54
66359	M8	18	0.01
66360	M2	267.2	3.86
66360	S2	301.5	1.25
66360	N2	240.8	0.75
66360	K1	260.3	1.38
66360	M4	236	0.02
66360	O1	244.5	0.87
66360	M6	59.1	0.01
66360	NU2	244.4	0.15
66360	S6	23	0.01
66360	MU2	326.4	0.09
66360	2N2	214.4	0.1
66360	OO1	276.2	0.04
66360	LDA2	283.1	0.03
66360	M1	252.5	0.06
66360	J1	268.2	0.07
66360	RHO1	237.7	0.03
66360	Q1	236.6	0.17
66360	T2	300.1	0.08
66360	R2	302.8	0.01
66360	2Q1	228.7	0.02
66360	P1	259.1	0.46
66360	L2	293.7	0.11
66360	K2	304.3	0.34
66361	M2	271.7	6.44
66361	S2	304.8	2.1
66361	N2	244.6	1.33
66361	K1	262.9	1.6
66361	M4	269	0.16
66361	O1	244.8	1.02
66361	M6	351.3	0.01
66361	S4	295.2	0.03
66361	NU2	248.2	0.26
66361	S6	225	0.01
66361	MU2	334.3	0.15
66361	2N2	217.4	0.18
66361	OO1	281.1	0.04
66361	LDA2	287.1	0.05
66361	M1	253.9	0.07
66361	J1	272	0.08
66361	RHO1	237	0.04
66361	Q1	235.8	0.2
66361	T2	303.4	0.12
66361	R2	306.1	0.02
66361	2Q1	226.7	0.03
66361	P1	261.6	0.53
66361	L2	298.9	0.18
66361	K2	307.4	0.57
66362	M2	270.4	6.37
66362	S2	305.4	2.15
66362	N2	242.4	1.3
66362	K1	260.2	1.58
66362	M4	268.8	0.08
66362	O1	244.8	1.01
66362	S4	280.3	0.03
66362	NU2	246.2	0.25
66362	S6	214.5	0.01
66362	MU2	235.4	0.15
66362	2N2	214.4	0.17
66362	OO1	275.5	0.04
66362	LDA2	286.6	0.05
66362	M1	252.5	0.07
66362	J1	267.8	0.08
66362	RHO1	238.2	0.04
66362	Q1	237.2	0.2
66362	T2	304	0.13
66362	R2	306.8	0.02
66362	2Q1	229.6	0.03
66362	P1	259	0.52
66362	L2	298.4	0.18
66362	K2	308.2	0.58
66362	M8	336.6	0.01
66363	M2	272.3	6.49
66363	S2	302.7	2.15
66363	N2	241.3	1.17
66363	K1	261.7	1.71
66363	M4	297.1	0.13
66363	O1	245.5	1.03
66363	M6	13.6	0.01
66363	S4	290.6	0.04
66363	NU2	245.4	0.23
66363	MU2	337.8	0.16
66363	2N2	210.2	0.15
66363	OO1	277.8	0.05
66363	LDA2	286.4	0.05
66363	M1	253.7	0.07
66363	J1	269.7	0.08
66363	RHO1	238.6	0.04
66363	Q1	237.5	0.2
66363	T2	301.5	0.13
66363	R2	303.9	0.02
66363	2Q1	229.5	0.03
66363	P1	260.5	0.56
66363	L2	303.4	0.18
66363	K2	305.2	0.58
66363	M8	220.8	0.02
66364	M2	271.3	4.18
66364	S2	304.9	1.42
66364	N2	250.1	0.9
66364	K1	260.5	1.41
66364	M4	260.4	0.02
66364	O1	247.1	0.91
66364	M6	46.3	0.03
66364	NU2	253	0.17
66364	S6	47.8	0.01
66364	MU2	237.7	0.1
66364	2N2	229	0.12
66364	OO1	274.1	0.04
66364	LDA2	286.9	0.03
66364	M1	253.9	0.07
66364	J1	267.3	0.07
66364	SSA	161.1	0.1
66364	SA	273.7	0.38
66364	MF	173	0.09
66364	RHO1	241.3	0.03
66364	Q1	240.4	0.17
66364	T2	303.5	0.08
66364	R2	306.2	0.01
66364	2Q1	233.7	0.02
66364	P1	259.5	0.47
66364	L2	292.5	0.12
66364	K2	307.6	0.39
66364	M8	268.9	0.01
66365	M2	273	4.44
66365	S2	307	1.52
66365	N2	252.1	0.95
66365	K1	261.3	1.43
66365	M4	217.1	0.02
66365	O1	248	0.92
66365	M6	104.2	0.03
66365	NU2	254.8	0.18
66365	MU2	238.9	0.1
66365	2N2	231.2	0.12
66365	OO1	274.7	0.04
66365	LDA2	288.8	0.03
66365	M1	254.8	0.07
66365	J1	268	0.07
66365	SSA	161.1	0.1
66365	SA	273.7	0.38
66365	MF	173	0.09
66365	RHO1	242.3	0.04
66365	Q1	241.4	0.18
66365	T2	305.7	0.09
66365	R2	308.4	0.01
66365	2Q1	234.8	0.02
66365	P1	260.3	0.47
66365	L2	293.9	0.12
66365	K2	309.7	0.41
66365	M8	223.8	0.01
66366	M2	272.7	6.42
66366	S2	303.4	2.18
66366	N2	247	1.27
66366	K1	263.6	1.76
66366	M4	267.2	0.15
66366	O1	246.4	1.04
66366	M6	300.2	0.01
66366	S4	346.7	0.02
66366	NU2	250.5	0.25
66366	MU2	336.6	0.15
66366	2N2	221.4	0.17
66366	OO1	281	0.05
66366	LDA2	286.9	0.05
66366	M1	255.1	0.08
66366	J1	272.3	0.08
66366	RHO1	239	0.04
66366	Q1	237.8	0.2
66366	T2	302.1	0.13
66366	R2	304.6	0.02
66366	2Q1	229.2	0.03
66366	P1	262.3	0.58
66366	L2	298.3	0.18
66366	K2	305.8	0.59
66366	M8	158.8	0.01
66367	M2	274.7	6.77
66367	S2	305.2	2.18
66367	N2	251.1	1.33
66367	K1	262	1.64
66367	M4	249.1	0.11
66367	O1	249.8	1.02
66367	M6	352.6	0.03
66367	S4	44.6	0.08
66367	NU2	254.3	0.26
66367	S6	92.5	0.03
66367	MU2	341	0.16
66367	2N2	227.6	0.18
66367	OO1	274.1	0.04
66367	LDA2	288.9	0.05
66367	M1	256	0.07
66367	J1	268	0.08
66367	RHO1	244.6	0.04
66367	Q1	243.8	0.2
66367	T2	304	0.13
66367	R2	306.4	0.02
66367	2Q1	237.8	0.03
66367	P1	261.1	0.54
66367	L2	298.2	0.19
66367	K2	307.7	0.59
66367	M8	53.4	0.02
66368	M2	273.4	6.55
66368	S2	304.1	2.17
66368	N2	246.4	1.37
66368	K1	263.4	1.73
66368	M4	260.5	0.2
66368	O1	245.9	1.04
66368	M6	11.2	0.02
66368	S4	14.8	0.04
66368	NU2	250	0.27
66368	MU2	338	0.16
66368	2N2	219.4	0.18
66368	OO1	280.8	0.05
66368	LDA2	287.6	0.05
66368	M1	254.7	0.08
66368	J1	272	0.08
66368	RHO1	238.5	0.04
66368	Q1	237.3	0.2
66368	T2	302.9	0.13
66368	R2	305.3	0.02
66368	2Q1	228.6	0.03
66368	P1	262.1	0.57
66368	L2	300.3	0.18
66368	K2	306.6	0.59
66368	M8	13	0.01
66369	M2	275.7	4.07
66369	S2	307.6	1.35
66369	N2	251.3	0.84
66369	K1	263.1	1.53
66369	M4	281.4	0.01
66369	O1	248	0.94
66369	M6	138	0.01
66369	MK3	258.9	0.02
66369	NU2	255.7	0.16
66369	MU2	233.2	0.1
66369	2N2	226.1	0.1
66369	OO1	295.2	0.05
66369	LDA2	292.1	0.02
66369	S1	43.1	0.03
66369	M1	275.9	0.05
66369	J1	275.4	0.09
66369	SA	271.1	0.35
66369	MF	196.8	0.1
66369	RHO1	238.8	0.03
66369	Q1	240.5	0.17
66369	T2	298	0.07
66369	2Q1	238	0.02
66369	P1	260	0.48
66369	2SM2	91.7	0.01
66369	M3	326.3	0.01
66369	L2	287.6	0.09
66369	2MK3	212.9	0.02
66369	K2	300.2	0.36
66369	MS4	340.5	0.01
66370	M2	270.7	5.84
66370	S2	301.4	1.97
66370	N2	244	1.16
66370	K1	262.3	1.7
66370	M4	227.9	0.09
66370	O1	246.4	0.99
66370	M6	65.2	0.02
66370	S4	16	0.02
66370	NU2	247.6	0.22
66370	S6	34.8	0.01
66370	MU2	333.9	0.14
66370	2N2	217.4	0.15
66370	OO1	278.5	0.04
66370	LDA2	284.9	0.04
66370	M1	254.5	0.07
66370	J1	270.4	0.08
66370	RHO1	239.5	0.04
66370	Q1	238.5	0.19
66370	T2	300.2	0.11
66370	R2	302.7	0.02
66370	2Q1	230.5	0.03
66370	P1	261.1	0.56
66370	L2	297.3	0.16
66370	K2	303.9	0.54
66370	M8	356.2	0.01
66371	M2	273.2	6.41
66371	S2	304.1	2.15
66371	N2	250.5	1.21
66371	K1	264.1	1.79
66371	M4	262.6	0.15
66371	O1	246.4	1.02
66371	M6	353.1	0.01
66371	S4	348	0.02
66371	NU2	253.6	0.24
66371	MU2	337.2	0.15
66371	2N2	227.9	0.16
66371	OO1	281.8	0.04
66371	LDA2	287.5	0.05
66371	M1	255.3	0.07
66371	J1	272.9	0.08
66371	RHO1	238.8	0.04
66371	Q1	237.6	0.2
66371	T2	302.8	0.13
66371	R2	305.3	0.02
66371	2Q1	228.9	0.03
66371	P1	262.8	0.59
66371	L2	295.9	0.18
66371	K2	306.6	0.58
66371	M8	111.6	0.01
66372	M2	274.4	6.51
66372	S2	304.5	2.23
66372	N2	247.3	1.3
66372	K1	263.9	1.78
66372	M4	275.8	0.17
66372	O1	247.5	1.04
66372	M6	23.3	0.02
66372	S4	324.7	0.04
66372	NU2	250.9	0.25
66372	MU2	340.1	0.16
66372	2N2	220.1	0.17
66372	OO1	280.3	0.05
66372	LDA2	288.4	0.05
66372	M1	255.8	0.08
66372	J1	272	0.08
66372	RHO1	240.5	0.04
66372	Q1	239.4	0.2
66372	T2	303.3	0.13
66372	R2	305.7	0.02
66372	2Q1	231.3	0.03
66372	P1	262.7	0.59
66372	L2	301.6	0.18
66372	K2	306.9	0.61
66372	M8	84	0.01
66373	M2	273.4	6.45
66373	S2	304.2	2.13
66373	N2	245.3	1.34
66373	K1	264.1	1.73
66373	M4	260.5	0.21
66373	O1	246.3	1.03
66373	M6	13.1	0.01
66373	S4	18.8	0.04
66373	NU2	249.1	0.26
66373	MU2	337.8	0.15
66373	2N2	217.2	0.18
66373	OO1	281.9	0.05
66373	LDA2	287.7	0.05
66373	M1	255.3	0.07
66373	J1	272.9	0.08
66373	RHO1	238.7	0.04
66373	Q1	237.5	0.2
66373	T2	303	0.12
66373	R2	305.5	0.02
66373	2Q1	228.7	0.03
66373	P1	262.8	0.57
66373	L2	301.5	0.18
66373	K2	306.7	0.58
66373	M8	224.5	0.01
66374	M2	273.4	4.93
66374	S2	303.7	1.69
66374	N2	252.1	1
66374	K1	261	1.57
66374	M4	243	0.07
66374	O1	247.6	0.93
66374	M6	108.4	0.02
66374	NU2	255	0.19
66374	MU2	335.5	0.12
66374	2N2	230.8	0.13
66374	OO1	274.4	0.04
66374	LDA2	287.5	0.04
66374	M1	254.4	0.07
66374	J1	267.6	0.07
66374	RHO1	241.9	0.04
66374	Q1	241	0.18
66374	T2	302.5	0.1
66374	R2	305	0.01
66374	2Q1	234.3	0.02
66374	P1	260	0.52
66374	L2	294.7	0.14
66374	K2	306.2	0.46
66374	M8	89.9	0.02
66375	M2	275.4	6.01
66375	S2	306.1	2.06
66375	N2	253.1	1.21
66375	K1	262.6	1.64
66375	M4	246.3	0.19
66375	O1	248.3	1
66375	M6	40.9	0.01
66375	S4	323.7	0.02
66375	NU2	256.1	0.24
66375	S6	209	0.01
66375	MU2	338.8	0.14
66375	2N2	230.7	0.16
66375	OO1	276.8	0.04
66375	LDA2	289.6	0.04
66375	M1	255.5	0.07
66375	J1	269.6	0.08
66375	RHO1	242.2	0.04
66375	Q1	241.2	0.19
66375	T2	304.9	0.12
66375	R2	307.3	0.02
66375	2Q1	234.1	0.03
66375	P1	261.5	0.54
66375	L2	297.8	0.17
66375	K2	308.6	0.56
66375	M8	150.4	0.01
66376	M2	279.1	6.15
66376	S2	311.1	2.12
66376	N2	257.6	1.23
66376	K1	264.9	1.64
66376	M4	254.2	0.2
66376	O1	250.6	1.01
66376	M6	86.1	0.03
66376	S4	336.5	0.02
66376	NU2	260.5	0.24
66376	S6	219	0.01
66376	MU2	341.2	0.15
66376	2N2	236.1	0.16
66376	OO1	279.1	0.04
66376	LDA2	294	0.04
66376	M1	257.8	0.07
66376	J1	271.9	0.08
66376	RHO1	244.5	0.04
66376	Q1	243.6	0.2
66376	T2	309.8	0.12
66376	R2	312.4	0.02
66376	2Q1	236.5	0.03
66376	P1	263.8	0.54
66376	L2	300.6	0.17
66376	K2	313.7	0.57
66376	M8	116.5	0.01
66377	M2	290.7	6.25
66377	S2	326.8	2.16
66377	N2	273.2	1.26
66377	K1	271.5	1.61
66377	M4	159.6	0.11
66377	O1	257.6	1.03
66377	M6	116.8	0.11
66377	S4	239.1	0.04
66377	NU2	275.5	0.25
66377	S6	251.1	0.01
66377	MU2	348.7	0.15
66377	2N2	255.7	0.17
66377	OO1	285.5	0.05
66377	LDA2	307.4	0.04
66377	M1	264.6	0.07
66377	J1	278.4	0.08
66377	RHO1	251.6	0.04
66377	Q1	250.6	0.2
66377	T2	325.4	0.13
66377	R2	328.3	0.02
66377	2Q1	243.7	0.03
66377	P1	270.5	0.53
66377	L2	308.2	0.17
66377	K2	329.7	0.59
66377	M8	39.7	0.01
66378	M2	293	6.39
66378	S2	329.2	2.21
66378	N2	275.8	1.28
66378	K1	271.8	1.61
66378	M4	132.6	0.18
66378	O1	258.8	1.03
66378	M6	127	0.13
66378	S4	241.1	0.06
66378	NU2	278.1	0.25
66378	S6	10.9	0.01
66378	MU2	351	0.15
66378	2N2	258.7	0.17
66378	OO1	284.8	0.05
66378	LDA2	309.8	0.05
66378	M1	265.3	0.07
66378	J1	278.2	0.08
66378	SSA	161.1	0.1
66378	SA	273.7	0.38
66378	RHO1	253.2	0.04
66378	Q1	252.3	0.2
66378	T2	327.8	0.13
66378	R2	330.7	0.02
66378	2Q1	245.8	0.03
66378	P1	270.8	0.53
66378	L2	310.2	0.18
66378	K2	332.1	0.6
66378	M8	345.4	0.03
66379	M2	286.9	5.98
66379	S2	320.7	2.09
66379	N2	266.6	1.21
66379	K1	266.5	1.64
66379	M4	15.3	0.1
66379	O1	252.4	0.98
66379	M6	82.5	0.11
66379	S4	166.8	0.01
66379	NU2	269.4	0.24
66379	MU2	345.7	0.14
66379	2N2	246.3	0.16
66379	OO1	280.6	0.04
66379	LDA2	302.6	0.04
66379	M1	259.5	0.07
66379	J1	273.5	0.08
66379	RHO1	246.4	0.04
66379	Q1	245.4	0.19
66379	T2	319.3	0.12
66379	R2	322	0.02
66379	2Q1	238.5	0.03
66379	P1	265.5	0.54
66379	L2	307.2	0.17
66379	K2	323.4	0.57
66379	M8	88.1	0.02
66380	M2	272.7	3.53
66380	S2	305	1.1
66380	N2	248.3	0.72
66380	K1	261.2	1.4
66380	O1	243.2	0.88
66380	NU2	251.6	0.14
66380	S6	149.3	0.01
66380	MU2	329.6	0.09
66380	2N2	224	0.1
66380	OO1	279.3	0.04
66380	LDA2	287.7	0.03
66380	M1	252.3	0.06
66380	J1	270.2	0.07
66380	RHO1	235.4	0.03
66380	Q1	234.2	0.17
66380	T2	303.7	0.07
66380	R2	306.3	0.01
66380	2Q1	225.3	0.02
66380	P1	259.9	0.47
66380	L2	297.1	0.1
66380	K2	307.6	0.3
66380	M8	120.9	0.01
66381	M2	283	6.42
66381	S2	319.7	2.1
66381	N2	263.4	1.24
66381	K1	267.9	1.59
66381	M4	47.5	0.12
66381	O1	250.7	0.98
66381	M6	284.1	0.02
66381	S4	130.5	0.02
66381	NU2	266	0.24
66381	MU2	341.4	0.15
66381	2N2	243.7	0.16
66381	OO1	285	0.04
66381	LDA2	300	0.05
66381	M1	259.4	0.07
66381	J1	276.4	0.08
66381	RHO1	243.4	0.04
66381	Q1	242.2	0.19
66381	T2	318.2	0.12
66381	R2	321.1	0.02
66381	2Q1	233.7	0.03
66381	P1	266.6	0.52
66381	L2	302.7	0.18
66381	K2	322.6	0.57
66381	M8	130.7	0.01
66382	M2	287	6.3
66382	S2	322.2	2
66382	N2	264.4	1.14
66382	K1	272.4	1.69
66382	M4	112.2	0.08
66382	O1	253.4	0.97
66382	M6	125.3	0.09
66382	S4	142.1	0.02
66382	NU2	267.5	0.22
66382	S6	15.9	0.01
66382	MU2	345.9	0.15
66382	2N2	241.9	0.15
66382	OO1	291.3	0.04
66382	LDA2	303.3	0.04
66382	M1	263	0.07
66382	J1	281.8	0.08
66382	RHO1	245.3	0.04
66382	Q1	244	0.19
66382	T2	320.8	0.12
66382	R2	323.6	0.02
66382	2Q1	234.6	0.03
66382	P1	270.9	0.56
66382	L2	309.6	0.18
66382	K2	325	0.54
66382	M8	28	0.02
66383	M2	279.7	5.75
66383	S2	313.2	1.77
66383	N2	255.9	1.1
66383	K1	265.8	1.58
66383	M4	354.3	0.07
66383	O1	247.4	0.98
66383	M6	77.5	0.02
66383	S4	53.2	0.01
66383	NU2	259.1	0.21
66383	MU2	338.6	0.14
66383	2N2	232	0.15
66383	OO1	284.2	0.04
66383	LDA2	295.3	0.04
66383	M1	256.7	0.07
66383	J1	274.9	0.08
66383	RHO1	239.5	0.04
66383	Q1	238.3	0.19
66383	T2	311.9	0.1
66383	R2	314.6	0.01
66383	2Q1	229.2	0.03
66383	P1	264.4	0.52
66383	L2	303.5	0.16
66383	K2	315.9	0.48
66383	M8	36	0.02
66384	M2	279.7	4.95
66384	S2	316.1	1.68
66384	N2	252.1	0.98
66384	K1	264	1.53
66384	M4	14.6	0.1
66384	O1	247.7	0.98
66384	M6	38.3	0.02
66384	NU2	255.8	0.19
66384	MU2	243.3	0.12
66384	2N2	224.5	0.13
66384	OO1	280.3	0.04
66384	LDA2	296.6	0.04
66384	M1	255.9	0.07
66384	J1	272.1	0.08
66384	RHO1	240.7	0.04
66384	Q1	239.7	0.19
66384	T2	314.6	0.1
66384	R2	317.5	0.01
66384	2Q1	231.6	0.03
66384	P1	262.8	0.51
66384	L2	307.3	0.14
66384	K2	319	0.46
66385	M2	276.3	5.3
66385	S2	305.7	1.77
66385	N2	254.1	0.96
66385	K1	262.8	1.69
66385	M4	358.1	0.08
66385	O1	246.5	0.94
66385	S4	46.9	0.01
66385	NU2	257.1	0.19
66385	MU2	247	0.13
66385	2N2	232	0.13
66385	OO1	279.1	0.04
66385	LDA2	289.9	0.04
66385	M1	254.7	0.07
66385	J1	270.8	0.08
66385	SA	274.8	0.4
66385	MF	176.8	0.09
66385	RHO1	239.5	0.04
66385	Q1	238.4	0.18
66385	T2	304.5	0.1
66385	R2	306.8	0.01
66385	2Q1	230.3	0.02
66385	P1	261.5	0.56
66385	L2	298.5	0.15
66385	K2	308	0.48
66385	M8	144.6	0.01
66386	M2	279.4	5.65
66386	S2	313.6	1.88
66386	N2	254.3	1.21
66386	K1	259.9	1.63
66386	M4	21.8	0.1
66386	O1	251.2	0.99
66386	M6	285	0.01
66386	S4	39.1	0.02
66386	NU2	257.6	0.24
66386	MU2	337.3	0.13
66386	2N2	229.2	0.16
66386	OO1	268.5	0.04
66386	LDA2	295.3	0.04
66386	M1	255.6	0.07
66386	J1	264.1	0.08
66386	RHO1	247.5	0.04
66386	Q1	246.9	0.19
66386	T2	312.3	0.11
66386	R2	315	0.02
66386	2Q1	242.7	0.03
66386	P1	259.2	0.54
66386	L2	304.4	0.16
66386	K2	316.4	0.51
66387	M2	273.8	3.63
66387	S2	304.9	1.16
66387	N2	249.2	0.75
66387	K1	259.9	1.52
66387	O1	244.4	0.92
66387	NU2	253.6	0.14
66387	MU2	228.7	0.09
66387	2N2	223.8	0.09
66387	OO1	289.1	0.05
66387	LDA2	293	0.03
66387	S1	35.3	0.04
66387	M1	273.4	0.05
66387	J1	272.9	0.09
66387	SA	274.8	0.4
66387	MF	176.8	0.09
66387	RHO1	238.9	0.03
66387	Q1	237.2	0.16
66387	T2	296.6	0.07
66387	R2	306	0.01
66387	2Q1	240.5	0.02
66387	P1	257.6	0.48
66387	L2	288.8	0.08
66387	K2	298.4	0.32
66388	M2	279.3	5.39
66388	S2	310	1.88
66388	N2	255.5	1.07
66388	K1	262.3	1.6
66388	M4	0.6	0.07
66388	O1	248.7	0.96
66388	M6	299.9	0.01
66388	NU2	258.7	0.21
66388	MU2	338.9	0.13
66388	2N2	231.8	0.14
66388	OO1	275.9	0.04
66388	LDA2	293.6	0.04
66388	M1	255.5	0.07
66388	J1	269.1	0.08
66388	RHO1	242.8	0.04
66388	Q1	241.9	0.19
66388	T2	308.8	0.11
66388	R2	311.3	0.02
66388	2Q1	235.1	0.03
66388	P1	261.3	0.53
66388	L2	303	0.15
66388	K2	312.5	0.51
66388	M8	135	0.01
66389	M2	276.6	3.64
66389	S2	309.7	1.14
66389	N2	248.8	0.75
66389	K1	264	1.44
66389	M4	139.4	0.01
66389	O1	246.7	0.94
66389	M6	24.8	0.01
66389	S4	219.3	0.01
66389	NU2	252.5	0.14
66389	MU2	243.4	0.09
66389	2N2	221	0.1
66389	OO1	281.2	0.04
66389	LDA2	291.9	0.03
66389	M1	255.4	0.07
66389	J1	272.5	0.07
66389	SA	274.8	0.4
66389	MF	176.8	0.09
66389	RHO1	239.3	0.04
66389	Q1	238.1	0.18
66389	T2	308.4	0.07
66389	R2	311.1	0.01
66389	2Q1	229.6	0.02
66389	P1	262.7	0.48
66389	L2	304.3	0.1
66389	K2	312.4	0.31
66389	M8	152.8	0.01
66390	M2	280	5.89
66390	S2	312.8	1.94
66390	N2	257.6	1.2
66390	K1	264.3	1.64
66390	M4	8.1	0.09
66390	O1	248.5	0.99
66390	M6	219.6	0.01
66390	S4	31.1	0.02
66390	NU2	260.6	0.23
66390	MU2	247.3	0.14
66390	2N2	235.1	0.16
66390	OO1	280.1	0.04
66390	LDA2	295.3	0.04
66390	M1	256.5	0.07
66390	J1	272.2	0.08
66390	SA	255.6	0.26
66390	MF	176.1	0.08
66390	RHO1	241.7	0.04
66390	Q1	240.7	0.19
66390	T2	311.5	0.11
66390	R2	314.1	0.02
66390	2Q1	232.8	0.03
66390	P1	263.1	0.54
66390	L2	302.3	0.16
66390	K2	315.5	0.53
66391	M2	273.5	3.56
66391	S2	304.8	1.13
66391	N2	251	0.76
66391	K1	263.8	1.56
66391	O1	244.4	0.96
66391	M6	341.2	0.01
66391	NU2	254	0.15
66391	MU2	330.9	0.09
66391	2N2	228.4	0.1
66391	OO1	283.2	0.04
66391	LDA2	288	0.03
66391	M1	254.1	0.07
66391	J1	273.4	0.08
66391	SA	274.8	0.4
66391	MF	176.8	0.09
66391	RHO1	236	0.04
66391	Q1	234.7	0.19
66391	T2	303.5	0.07
66391	R2	306	0.01
66391	2Q1	225.1	0.03
66391	P1	262.3	0.52
66391	L2	296.1	0.1
66391	K2	307.3	0.31
66392	M2	282.4	4.91
66392	S2	314.5	1.61
66392	N2	261.2	1.06
66392	K1	266.2	1.66
66392	M4	35	0.11
66392	O1	247.8	0.97
66392	M6	167.5	0.04
66392	S4	41	0.01
66392	NU2	264.1	0.21
66392	MU2	339	0.12
66392	2N2	240.1	0.14
66392	OO1	284.6	0.04
66392	LDA2	297.3	0.03
66392	M1	257.1	0.07
66392	J1	275.4	0.08
66392	SA	274.8	0.4
66392	MF	176.8	0.09
66392	RHO1	239.9	0.04
66392	Q1	238.7	0.19
66392	T2	313.2	0.1
66392	R2	315.7	0.01
66392	2Q1	229.6	0.03
66392	P1	264.9	0.55
66392	L2	303.5	0.14
66392	K2	317.1	0.44
66392	M8	268.2	0.01
66393	M2	281.2	5.84
66393	S2	313.2	1.96
66393	N2	259.1	1.21
66393	K1	266.7	1.69
66393	M4	21	0.1
66393	O1	248.6	0.99
66393	M6	122.8	0.05
66393	S4	14	0.02
66393	NU2	262	0.24
66393	MU2	338	0.14
66393	2N2	236.9	0.16
66393	OO1	284.9	0.04
66393	LDA2	296.1	0.04
66393	M1	257.7	0.07
66393	J1	275.7	0.08
66393	SA	274.8	0.4
66393	MF	176.8	0.09
66393	RHO1	240.8	0.04
66393	Q1	239.5	0.19
66393	T2	311.9	0.11
66393	R2	314.5	0.02
66393	2Q1	230.5	0.03
66393	P1	265.3	0.56
66393	L2	303.3	0.16
66393	K2	315.8	0.53
66393	M8	308.4	0.01
66394	M2	328.4	4.01
66394	S2	10.1	1.25
66394	N2	317.3	0.75
66394	K1	296	1.32
66394	M4	196.4	0.09
66394	O1	284.5	0.87
66394	M6	261.2	0.12
66394	S4	278.3	0.03
66394	NU2	318.8	0.15
66394	S6	160.7	0.01
66394	MU2	17.9	0.1
66394	2N2	306.3	0.1
66394	OO1	307.5	0.04
66394	LDA2	347.8	0.03
66394	M1	290.3	0.06
66394	J1	301.7	0.07
66394	RHO1	279.6	0.03
66394	Q1	278.8	0.17
66394	T2	8.4	0.08
66394	R2	11.8	0.01
66394	2Q1	273.1	0.02
66394	P1	295.1	0.44
66394	L2	339.5	0.11
66394	K2	13.5	0.34
66394	M8	139.5	0.02
66395	M2	282.5	6.55
66395	S2	315.5	2.23
66395	N2	258.2	1.33
66395	K1	265	1.71
66395	M4	8.9	0.12
66395	O1	250.2	1.02
66395	M6	239.8	0.02
66395	MK3	255.2	0.09
66395	S4	55.6	0.02
66395	MN4	335.8	0.05
66395	NU2	262.8	0.26
66395	MU2	251.7	0.15
66395	2N2	231.4	0.15
66395	OO1	294	0.06
66395	LDA2	285.7	0.04
66395	S1	55.6	0.03
66395	M1	281	0.06
66395	J1	277.7	0.1
66395	SA	255.6	0.26
66395	MF	176.1	0.08
66395	RHO1	241.4	0.03
66395	Q1	243.7	0.18
66395	T2	309.6	0.12
66395	R2	9.6	0.01
66395	2Q1	241.6	0.02
66395	P1	263.7	0.54
66395	2SM2	96.6	0.02
66395	M3	0.8	0.04
66395	L2	289.2	0.15
66395	2MK3	197.3	0.07
66395	K2	309	0.62
66395	MS4	47.7	0.07
66396	M2	281.6	6
66396	S2	315.5	1.94
66396	N2	258.2	1.22
66396	K1	266.1	1.64
66396	M4	27.6	0.13
66396	O1	249.4	1.02
66396	M6	16.7	0.01
66396	NU2	261.3	0.24
66396	S6	24	0.01
66396	MU2	338.1	0.14
66396	2N2	234.9	0.16
66396	OO1	282.9	0.04
66396	LDA2	297.3	0.04
66396	M1	257.9	0.07
66396	J1	274.4	0.08
66396	SA	255.6	0.26
66396	MF	176.1	0.08
66396	RHO1	242.2	0.04
66396	Q1	241.1	0.2
66396	T2	314.1	0.11
66396	R2	316.8	0.02
66396	2Q1	232.8	0.03
66396	P1	264.9	0.54
66396	L2	304.9	0.17
66396	K2	318.2	0.52
66396	M8	337.4	0.01
66397	M2	283.2	5.94
66397	S2	314.1	2.08
66397	N2	259.6	1.21
66397	K1	263.4	1.66
66397	M4	27.9	0.11
66397	O1	249.5	0.99
66397	M6	27.6	0.03
66397	S4	134	0.01
66397	NU2	262.7	0.24
66397	S6	208.9	0.01
66397	MU2	342.4	0.14
66397	2N2	236	0.16
66397	OO1	277.3	0.04
66397	LDA2	297.6	0.04
66397	M1	256.5	0.07
66397	J1	270.3	0.08
66397	RHO1	243.5	0.04
66397	Q1	242.6	0.19
66397	T2	312.9	0.12
66397	R2	315.4	0.02
66397	2Q1	235.7	0.03
66397	P1	262.4	0.55
66397	L2	306.8	0.17
66397	K2	316.7	0.57
66397	M8	113.3	0.01
66398	M2	284.1	6.66
66398	S2	317.9	2.3
66398	N2	260.3	1.35
66398	K1	265.6	1.74
66398	M4	26	0.13
66398	O1	250.5	1.04
66398	M6	69	0.06
66398	MK3	267.6	0.08
66398	S4	78.3	0.01
66398	MN4	358.1	0.05
66398	NU2	263	0.26
66398	MU2	255.9	0.16
66398	2N2	235.9	0.16
66398	OO1	295.1	0.06
66398	LDA2	273	0.05
66398	S1	50.5	0.02
66398	M1	276.3	0.06
66398	J1	280.8	0.1
66398	MM	143.5	0.05
66398	SSA	312.7	0.03
66398	SA	191.5	0.22
66398	MSF	20.1	0.03
66398	MF	197.1	0.1
66398	RHO1	240.9	0.04
66398	Q1	243.6	0.18
66398	T2	314.8	0.12
66398	R2	95.7	0.02
66398	2Q1	242.2	0.02
66398	P1	261.4	0.54
66398	2SM2	93.7	0.03
66398	M3	359.6	0.05
66398	L2	289.7	0.15
66398	2MK3	201.4	0.05
66398	K2	310.6	0.61
66398	M8	207.1	0.01
66398	MS4	64.2	0.08
66399	M2	282.8	6.48
66399	S2	316.6	2.19
66399	N2	257.6	1.27
66399	K1	267.4	1.63
66399	M4	27.8	0.1
66399	O1	249.5	1.01
66399	M6	72.9	0.06
66399	NU2	261	0.25
66399	S6	223.5	0.01
66399	MU2	338.3	0.15
66399	2N2	232.4	0.17
66399	OO1	285.3	0.04
66399	LDA2	298.5	0.05
66399	M1	258.5	0.07
66399	J1	276.3	0.08
66399	SA	190	0.19
66399	RHO1	241.8	0.04
66399	Q1	240.6	0.2
66399	T2	315.3	0.13
66399	R2	318	0.02
66399	2Q1	231.7	0.03
66399	P1	266.1	0.54
66399	L2	308.1	0.18
66399	K2	319.3	0.6
66400	M2	284.2	5.97
66400	S2	319.8	1.96
66400	N2	263.5	1.23
66400	K1	263.3	1.7
66400	M4	32.4	0.09
66400	O1	252.5	1.02
66400	M6	48.9	0.02
66400	S4	68.5	0.02
66400	NU2	266.3	0.24
66400	S6	45.9	0.01
66400	MU2	337.8	0.14
66400	2N2	242.8	0.16
66400	OO1	274.1	0.04
66400	LDA2	300.7	0.04
66400	M1	257.9	0.07
66400	J1	268.6	0.08
66400	RHO1	247.8	0.04
66400	Q1	247.1	0.2
66400	T2	318.4	0.11
66400	R2	321.2	0.02
66400	2Q1	241.8	0.03
66400	P1	262.5	0.56
66400	L2	304.9	0.17
66400	K2	322.7	0.53
66400	M8	263.1	0.01
66401	M2	298.7	6.61
66401	S2	335	2.13
66401	N2	277.1	1.21
66401	K1	273.5	1.75
66401	M4	147.4	0.14
66401	O1	258.1	1.02
66401	M6	223.7	0.07
66401	S4	181.7	0.02
66401	NU2	280	0.23
66401	MU2	350.2	0.16
66401	2N2	255.5	0.16
66401	OO1	288.8	0.04
66401	LDA2	315.5	0.05
66401	M1	265.8	0.07
66401	J1	281.1	0.08
66401	RHO1	251.5	0.04
66401	Q1	250.5	0.2
66401	T2	333.6	0.12
66401	R2	336.5	0.02
66401	2Q1	242.9	0.03
66401	P1	272.3	0.58
66401	L2	320.3	0.18
66401	K2	338	0.58
66401	M8	27.3	0.01
66402	M2	276.3	3.9
66402	S2	308	1.25
66402	N2	253.4	0.82
66402	K1	262.5	1.53
66402	M4	268.4	0.03
66402	O1	250.5	0.96
66402	M6	169.9	0.02
66402	S4	105.6	0.01
66402	NU2	256.4	0.16
66402	MU2	332.2	0.1
66402	2N2	230.5	0.11
66402	OO1	274.4	0.04
66402	LDA2	291	0.03
66402	M1	256.6	0.07
66402	J1	268.4	0.08
66402	RHO1	245.4	0.04
66402	Q1	244.6	0.19
66402	T2	306.7	0.08
66402	R2	309.2	0.01
66402	2Q1	238.7	0.03
66402	P1	261.6	0.51
66402	L2	299.2	0.11
66402	K2	310.5	0.34
66402	M8	147.2	0.01
66403	M2	275.5	4.07
66403	S2	306.8	1.34
66403	N2	250.6	0.83
66403	K1	264	1.56
66403	M4	189.2	0.03
66403	O1	248.8	0.96
66403	M6	144.6	0.01
66403	MK3	235.6	0.01
66403	S4	254.3	0.01
66403	MN4	158.5	0.01
66403	NU2	254.7	0.16
66403	MU2	226.1	0.09
66403	2N2	224	0.1
66403	OO1	295.6	0.05
66403	LDA2	296.2	0.03
66403	S1	49.9	0.05
66403	M1	277.3	0.05
66403	J1	273.6	0.09
66403	MM	0	0.03
66403	SA	272.4	0.36
66403	MF	192.7	0.11
66403	RHO1	240.9	0.03
66403	Q1	240.8	0.17
66403	T2	301.2	0.08
66403	2Q1	237.7	0.02
66403	P1	259.8	0.49
66403	2SM2	146.8	0.01
66403	M3	306.5	0.01
66403	L2	292.3	0.1
66403	2MK3	198.4	0.02
66403	K2	299.6	0.36
66403	MS4	228.7	0.02
66404	M2	299.5	6.67
66404	S2	335.6	2.21
66404	N2	280.1	1.31
66404	K1	273.2	1.8
66404	M4	141.1	0.16
66404	O1	258.1	1.06
66404	M6	230.7	0.08
66404	S4	199.2	0.02
66404	NU2	282.7	0.26
66404	S6	209.4	0.01
66404	MU2	349.6	0.16
66404	2N2	260.6	0.17
66404	OO1	288.3	0.05
66404	LDA2	316.3	0.05
66404	M1	265.7	0.08
66404	J1	280.7	0.09
66404	SA	255.6	0.26
66404	MF	176.1	0.08
66404	RHO1	251.6	0.04
66404	Q1	250.6	0.21
66404	T2	334.2	0.13
66404	R2	337.1	0.02
66404	2Q1	243	0.03
66404	P1	272	0.59
66404	L2	318.9	0.19
66404	K2	338.6	0.6
66404	M8	194.2	0.01
66405	M2	281.4	3.7
66405	S2	312.7	1.21
66405	N2	257.2	0.77
66405	K1	268	1.5
66405	O1	252.9	0.93
66405	M6	309.1	0.01
66405	S4	245.8	0.01
66405	NU2	260.7	0.15
66405	MU2	235.2	0.09
66405	2N2	232.3	0.09
66405	OO1	296	0.05
66405	LDA2	298.8	0.02
66405	S1	19.1	0.05
66405	M1	275.4	0.05
66405	J1	280.2	0.09
66405	MM	172.8	0.07
66405	SA	257.9	0.37
66405	MSF	346.3	0.05
66405	MF	203.2	0.11
66405	RHO1	245.7	0.03
66405	Q1	246.3	0.16
66405	T2	303.9	0.07
66405	2Q1	241.3	0.02
66405	P1	264.4	0.47
66405	2SM2	123.9	0.01
66405	M3	266.4	0.01
66405	L2	299.3	0.08
66405	K2	305.8	0.32
66405	M8	230.8	0.01
66405	MS4	35.4	0.01
66406	M2	290.2	4.77
66406	S2	322.2	1.63
66406	N2	265.9	0.98
66406	K1	273.7	1.64
66406	M4	13.8	0.18
66406	O1	256.8	1
66406	M6	115.4	0.04
66406	S4	5.3	0.05
66406	MN4	331.1	0.05
66406	NU2	269.5	0.19
66406	MU2	255.5	0.1
66406	2N2	239	0.11
66406	OO1	300.4	0.05
66406	LDA2	297.4	0.03
66406	S1	61.7	0.07
66406	M1	289.1	0.05
66406	J1	287.7	0.1
66406	SA	254.2	0.43
66406	MF	179.9	0.09
66406	RHO1	249.4	0.03
66406	Q1	250.3	0.17
66406	T2	313.8	0.09
66406	R2	323.5	0.01
66406	2Q1	250.9	0.02
66406	P1	271.2	0.51
66406	2SM2	132.8	0.01
66406	M3	277.8	0.02
66406	L2	299.4	0.11
66406	2MK3	174.1	0.01
66406	K2	316.2	0.45
66406	M8	186.7	0.01
66406	MS4	97.1	0.11
66407	M2	287.7	4.57
66407	S2	320.4	1.57
66407	N2	263.1	0.94
66407	K1	272	1.64
66407	M4	19.4	0.15
66407	O1	256	0.99
66407	M6	197.6	0.01
66407	S4	351.1	0.04
66407	MN4	338.4	0.04
66407	NU2	267.6	0.18
66407	MU2	244.4	0.11
66407	2N2	237.9	0.11
66407	OO1	298.1	0.05
66407	LDA2	303.5	0.03
66407	S1	359.1	0.02
66407	M1	286.8	0.05
66407	J1	282.2	0.1
66407	SA	243.1	0.37
66407	MF	176.5	0.09
66407	RHO1	251.8	0.03
66407	Q1	249.4	0.17
66407	T2	306.2	0.09
66407	R2	9.6	0.02
66407	2Q1	249.6	0.02
66407	P1	269.7	0.53
66407	2SM2	136.1	0.01
66407	M3	273.6	0.02
66407	L2	300.1	0.1
66407	K2	313.8	0.43
66407	MS4	103.4	0.11
66408	M2	286.9	4.37
66408	S2	317.4	1.5
66408	N2	261.8	0.87
66408	K1	271.6	1.62
66408	M4	19.7	0.14
66408	O1	255.5	0.99
66408	M6	202.5	0.01
66408	S4	353.4	0.04
66408	NU2	265.2	0.17
66408	MU2	321.5	0.1
66408	2N2	236.7	0.11
66408	OO1	287.8	0.04
66408	LDA2	301	0.03
66408	M1	263.6	0.07
66408	J1	279.7	0.08
66408	SA	254.2	0.43
66408	MF	179.9	0.09
66408	RHO1	248.6	0.04
66408	Q1	247.5	0.19
66408	T2	316.2	0.09
66408	R2	318.6	0.01
66408	2Q1	239.5	0.03
66408	P1	270.4	0.54
66408	L2	311.9	0.12
66408	K2	319.9	0.41
66408	M8	31.4	0.01
66409	M2	289.5	3.72
66409	S2	319.9	1.26
66409	N2	265.3	0.8
66409	K1	272.1	1.56
66409	M4	32.2	0.05
66409	O1	257.8	0.94
66409	M6	347.1	0.01
66409	S4	311.7	0.01
66409	NU2	268.5	0.15
66409	S6	241.8	0.01
66409	MU2	324.2	0.09
66409	2N2	241.1	0.11
66409	OO1	286.4	0.04
66409	LDA2	303.6	0.03
66409	M1	265	0.07
66409	J1	279.2	0.08
66409	RHO1	251.6	0.04
66409	Q1	250.6	0.18
66409	T2	318.7	0.08
66409	R2	321.2	0.01
66409	2Q1	243.5	0.03
66409	P1	271	0.52
66409	L2	313.7	0.1
66409	K2	322.4	0.34
66409	M8	214.3	0.01
66410	M2	288.8	4.42
66410	S2	319.6	1.49
66410	N2	264.4	0.92
66410	K1	273.2	1.6
66410	M4	33.9	0.12
66410	O1	258	0.96
66410	S4	359.2	0.03
66410	NU2	267.7	0.18
66410	MU2	323.3	0.1
66410	2N2	240	0.12
66410	OO1	288.4	0.04
66410	LDA2	303.1	0.03
66410	M1	265.6	0.07
66410	J1	280.7	0.08
66410	SA	243.1	0.37
66410	RHO1	251.4	0.04
66410	Q1	250.4	0.19
66410	T2	318.4	0.09
66410	R2	320.8	0.01
66410	2Q1	242.9	0.03
66410	P1	272	0.53
66410	L2	313.3	0.12
66410	K2	322.1	0.41
66410	M8	271.5	0.01
66411	M2	287.9	4.58
66411	S2	319	1.51
66411	N2	262.1	0.97
66411	K1	270.4	1.58
66411	M4	25.4	0.12
66411	O1	256.3	1.01
66411	M6	158.7	0.01
66411	S4	24.7	0.07
66411	NU2	265.5	0.19
66411	S6	158.8	0.01
66411	MU2	322	0.11
66411	2N2	236.3	0.13
66411	OO1	284.6	0.04
66411	LDA2	302.3	0.03
66411	M1	263.4	0.07
66411	J1	277.4	0.08
66411	RHO1	250.2	0.04
66411	Q1	249.3	0.2
66411	T2	317.7	0.09
66411	R2	320.2	0.01
66411	2Q1	242.3	0.03
66411	P1	269.4	0.52
66411	L2	313.7	0.13
66411	K2	321.5	0.41
66412	M2	288.9	4.29
66412	S2	318.9	1.46
66412	N2	267	0.87
66412	K1	272.3	1.54
66412	M4	22.8	0.11
66412	O1	258.2	0.97
66412	S4	13.9	0.02
66412	NU2	269.9	0.17
66412	MU2	323.8	0.1
66412	2N2	245.1	0.11
66412	OO1	286.4	0.04
66412	LDA2	302.8	0.03
66412	M1	265.3	0.07
66412	J1	279.3	0.08
66412	SA	254.2	0.43
66412	MF	179.9	0.09
66412	RHO1	252.1	0.04
66412	Q1	251.2	0.19
66412	T2	317.7	0.09
66412	R2	320.1	0.01
66412	2Q1	244.2	0.03
66412	P1	271.3	0.51
66412	L2	310.8	0.12
66412	K2	321.3	0.4
66413	M2	289.1	4.43
66413	S2	319.8	1.54
66413	N2	267.7	0.92
66413	K1	271.6	1.67
66413	M4	33.4	0.11
66413	O1	258.7	0.96
66413	S4	2.5	0.03
66413	NU2	270.6	0.18
66413	MU2	323	0.1
66413	2N2	246.2	0.12
66413	OO1	284.5	0.04
66413	LDA2	303.4	0.03
66413	M1	265.2	0.07
66413	J1	278	0.08
66413	SA	243.1	0.37
66413	RHO1	253.2	0.04
66413	Q1	252.3	0.19
66413	T2	318.6	0.09
66413	R2	321.1	0.01
66413	2Q1	245.9	0.03
66413	P1	270.6	0.55
66413	L2	310.6	0.12
66413	K2	322.3	0.42
66414	M2	288.8	4.32
66414	S2	319.3	1.5
66414	N2	262.5	0.84
66414	K1	272.7	1.55
66414	M4	21.4	0.13
66414	O1	258	0.94
66414	M6	195.1	0.01
66414	S4	17.8	0.04
66414	NU2	266	0.16
66414	MU2	322.9	0.1
66414	2N2	236.1	0.11
66414	OO1	287.5	0.04
66414	LDA2	302.9	0.03
66414	M1	265.4	0.07
66414	J1	280	0.08
66414	SA	254.2	0.43
66414	MF	179.9	0.09
66414	RHO1	251.7	0.04
66414	Q1	250.7	0.18
66414	T2	318.1	0.09
66414	R2	320.5	0.01
66414	2Q1	243.4	0.02
66414	P1	271.6	0.52
66414	L2	315.1	0.12
66414	K2	321.7	0.41
66415	M2	288.9	4.49
66415	S2	319	1.53
66415	N2	265	0.92
66415	K1	272.3	1.58
66415	M4	40.1	0.14
66415	O1	257.2	0.95
66415	S4	7.7	0.04
66415	NU2	268.2	0.18
66415	MU2	323.1	0.11
66415	2N2	241.1	0.12
66415	OO1	287.5	0.04
66415	LDA2	302.9	0.03
66415	M1	264.8	0.07
66415	J1	279.8	0.08
66415	SA	253.3	0.39
66415	RHO1	250.6	0.04
66415	Q1	249.6	0.18
66415	T2	317.8	0.09
66415	R2	320.3	0.01
66415	2Q1	242.1	0.03
66415	P1	271.2	0.52
66415	L2	312.8	0.12
66415	K2	321.5	0.42
66416	M2	288.6	4.51
66416	S2	318.9	1.55
66416	N2	265.3	0.93
66416	K1	273.1	1.63
66416	M4	29.1	0.12
66416	O1	258.9	0.96
66416	M6	207.5	0.01
66416	S4	1.3	0.04
66416	NU2	268.5	0.18
66416	MU2	322.5	0.11
66416	2N2	242	0.12
66416	OO1	287.3	0.04
66416	LDA2	302.7	0.03
66416	M1	266.1	0.07
66416	J1	280.2	0.08
66416	SA	243.1	0.37
66416	RHO1	252.8	0.04
66416	Q1	251.8	0.19
66416	T2	317.7	0.09
66416	R2	320.1	0.01
66416	2Q1	244.8	0.03
66416	P1	272	0.54
66416	L2	312	0.12
66416	K2	321.3	0.42
66416	M8	95.2	0.01
66417	M2	288	4.34
66417	S2	319.6	1.56
66417	N2	262.2	0.94
66417	K1	272.5	1.6
66417	M4	22.6	0.1
66417	O1	256.6	0.96
66417	M6	318.2	0.01
66417	S4	315.4	0.03
66417	NU2	265.7	0.18
66417	MU2	320.3	0.1
66417	2N2	236.5	0.12
66417	OO1	288.4	0.04
66417	LDA2	302.7	0.03
66417	M1	264.6	0.07
66417	J1	280.4	0.08
66417	SA	254.2	0.43
66417	MF	179.9	0.09
66417	RHO1	249.8	0.04
66417	Q1	248.7	0.19
66417	T2	318.4	0.09
66417	R2	320.9	0.01
66417	2Q1	240.8	0.03
66417	P1	271.3	0.53
66417	L2	313.7	0.12
66417	K2	322.2	0.42
66418	M2	286.2	3.89
66418	S2	318.6	1.31
66418	N2	263.8	0.75
66418	K1	273.8	1.38
66418	M4	31.8	0.07
66418	O1	256.4	0.99
66418	M6	354.3	0.01
66418	S4	344.7	0.03
66418	NU2	266.8	0.14
66418	S6	124.5	0.01
66418	MU2	317.4	0.09
66418	2N2	241.3	0.1
66418	OO1	291.3	0.04
66418	LDA2	301.3	0.03
66418	M1	265.2	0.07
66418	J1	282.5	0.08
66418	SA	253.3	0.39
66418	MF	163.9	0.08
66418	RHO1	248.9	0.04
66418	Q1	247.8	0.19
66418	T2	317.3	0.08
66418	R2	319.9	0.01
66418	2Q1	239.1	0.03
66418	P1	272.5	0.46
66418	L2	308.8	0.11
66418	K2	321.3	0.36
66418	M8	178.5	0.01
66419	M2	288.6	4.6
66419	S2	320.3	1.6
66419	N2	264.1	0.91
66419	K1	272.2	1.62
66419	M4	16.4	0.17
66419	O1	256.7	0.99
66419	M6	202.9	0.01
66419	S4	353.2	0.06
66419	MN4	334.4	0.05
66419	NU2	270.8	0.19
66419	MU2	245	0.11
66419	2N2	238.2	0.1
66419	OO1	309.4	0.05
66419	LDA2	305.6	0.03
66419	S1	35.8	0.05
66419	M1	279.5	0.06
66419	J1	286	0.1
66419	MM	256.5	0.16
66419	SSA	114.1	0.16
66419	SA	240.6	0.46
66419	MSF	144.2	0.08
66419	MF	162	0.14
66419	RHO1	255.8	0.02
66419	Q1	247.8	0.17
66419	T2	307.1	0.1
66419	R2	209.9	0.01
66419	2Q1	228	0.03
66419	P1	267.8	0.5
66419	2SM2	149.7	0.01
66419	M3	279.8	0.02
66419	L2	304.7	0.12
66419	2MK3	255.4	0.01
66419	K2	312.7	0.43
66419	MS4	102.7	0.1
66420	M2	288	3.93
66420	S2	319.5	1.35
66420	N2	264	0.8
66420	K1	272.9	1.52
66420	M4	22.3	0.03
66420	O1	257.7	0.95
66420	M6	28.6	0.02
66420	MK3	131.1	0.01
66420	S4	10	0.01
66420	MN4	343.6	0.01
66420	NU2	267.2	0.15
66420	MU2	238.8	0.1
66420	2N2	239.1	0.09
66420	OO1	295	0.05
66420	LDA2	307.1	0.02
66420	S1	51.4	0.03
66420	M1	278.5	0.06
66420	J1	286.4	0.09
66420	SA	242.9	0.46
66420	MF	181.9	0.09
66420	RHO1	253.4	0.03
66420	Q1	250.3	0.17
66420	T2	312.4	0.09
66420	2Q1	245.1	0.02
66420	P1	268.8	0.48
66420	M3	276	0.01
66420	L2	312.4	0.09
66420	K2	312.7	0.36
66420	MS4	95.2	0.02
66421	M2	288.6	3.93
66421	S2	318.5	1.39
66421	N2	263.9	0.76
66421	K1	271.4	1.57
66421	M4	37.8	0.04
66421	O1	257.6	0.92
66421	M6	30.7	0.01
66421	S4	327.7	0.01
66421	NU2	267.2	0.15
66421	S6	74.4	0.01
66421	MU2	319.6	0.1
66421	2N2	239.2	0.1
66421	OO1	285.2	0.04
66421	LDA2	302.5	0.03
66421	M1	264.6	0.07
66421	J1	278.2	0.07
66421	SA	253.3	0.39
66421	MF	163.9	0.08
66421	RHO1	251.7	0.04
66421	Q1	250.8	0.18
66421	T2	317.3	0.08
66421	R2	319.7	0.01
66421	2Q1	244	0.02
66421	P1	270.4	0.52
66421	L2	313.3	0.11
66421	K2	320.9	0.38
66421	M8	358.8	0.01
66422	M2	288.8	3.93
66422	S2	322.3	1.38
66422	N2	266.5	0.76
66422	K1	272.9	1.45
66422	M4	30.9	0.03
66422	O1	257.8	0.92
66422	M6	44.9	0.02
66422	S4	48.9	0.01
66422	NU2	269.5	0.15
66422	S6	168.6	0.01
66422	MU2	255.2	0.1
66422	2N2	244.2	0.1
66422	OO1	287.9	0.04
66422	LDA2	304.4	0.03
66422	M1	265.4	0.07
66422	J1	280.3	0.07
66422	SA	253.3	0.39
66422	MF	163.9	0.08
66422	RHO1	251.4	0.04
66422	Q1	250.3	0.18
66422	T2	321	0.08
66422	R2	323.7	0.01
66422	2Q1	242.9	0.02
66422	P1	271.7	0.48
66422	L2	311.2	0.11
66422	K2	325.1	0.38
66422	M8	331.8	0.01
66423	M2	288.9	3.94
66423	S2	320.7	1.36
66423	N2	264	0.8
66423	K1	273.4	1.48
66423	M4	24.7	0.03
66423	O1	258.5	0.93
66423	M6	40.9	0.02
66423	NU2	267.3	0.15
66423	MU2	257	0.1
66423	2N2	239.1	0.1
66423	OO1	288.4	0.04
66423	LDA2	303.6	0.03
66423	M1	266	0.07
66423	J1	280.9	0.07
66423	RHO1	252	0.04
66423	Q1	251	0.18
66423	T2	319.4	0.08
66423	R2	321.9	0.01
66423	2Q1	243.6	0.02
66423	P1	272.3	0.49
66423	L2	313.7	0.11
66423	K2	323.3	0.37
66423	M8	20.2	0.01
66424	M2	288.4	3.96
66424	S2	318.2	1.36
66424	N2	260.2	0.81
66424	K1	273.1	1.5
66424	M4	33.2	0.02
66424	O1	258.7	0.94
66424	M6	44.9	0.02
66424	NU2	264	0.16
66424	MU2	319	0.1
66424	2N2	232.1	0.11
66424	OO1	287.5	0.04
66424	LDA2	302.2	0.03
66424	M1	265.9	0.07
66424	J1	280.2	0.08
66424	SA	253.3	0.39
66424	MF	163.9	0.08
66424	RHO1	252.5	0.04
66424	Q1	251.6	0.18
66424	T2	317	0.08
66424	R2	319.4	0.01
66424	2Q1	244.4	0.02
66424	P1	272	0.5
66424	L2	316.5	0.11
66424	K2	320.6	0.37
66424	M8	25.3	0.01
66425	M2	289.2	4.01
66425	S2	320	1.39
66425	N2	264	0.81
66425	K1	273.2	1.5
66425	M4	28	0.03
66425	O1	257.6	0.93
66425	M6	28.4	0.03
66425	NU2	267.4	0.16
66425	MU2	318.9	0.1
66425	2N2	238.8	0.11
66425	OO1	288.9	0.04
66425	LDA2	303.5	0.03
66425	M1	265.5	0.07
66425	J1	281	0.07
66425	SA	253.3	0.39
66425	MF	163.9	0.08
66425	RHO1	250.9	0.04
66425	Q1	249.9	0.18
66425	T2	318.8	0.08
66425	R2	321.3	0.01
66425	2Q1	242.1	0.02
66425	P1	272.1	0.5
66425	L2	314.4	0.11
66425	K2	322.5	0.38
66426	M2	294.3	4.02
66426	S2	328.6	1.44
66426	N2	270.3	0.83
66426	K1	276	1.51
66426	M4	120.6	0.07
66426	O1	260.7	0.94
66426	M6	77	0.04
66426	S4	260.7	0.01
66426	NU2	273.5	0.16
66426	MU2	319.8	0.1
66426	2N2	246.3	0.11
66426	OO1	291.3	0.04
66426	LDA2	310.2	0.03
66426	M1	268.4	0.07
66426	J1	283.6	0.08
66426	SA	253.3	0.39
66426	MF	163.9	0.08
66426	RHO1	254.1	0.04
66426	Q1	253.1	0.18
66426	T2	327.3	0.09
66426	R2	330	0.01
66426	2Q1	245.5	0.02
66426	P1	274.8	0.5
66426	L2	318.2	0.11
66426	K2	331.4	0.39
66426	M8	303.2	0.01
66427	M2	324	7.29
66427	S2	358.3	2.72
66427	N2	298.4	1.5
66427	K1	279.8	1.85
66427	M4	71.2	0.1
66427	O1	263.6	1.13
66427	M6	194.7	0.05
66427	MK3	199.5	0.06
66427	S4	137	0.02
66427	MN4	42	0.04
66427	NU2	302.2	0.25
66427	MU2	275.8	0.3
66427	2N2	267.7	0.17
66427	OO1	314.4	0.06
66427	LDA2	304.2	0.03
66427	S1	52.5	0.05
66427	M1	297	0.07
66427	J1	295	0.1
66427	SA	250.2	0.41
66427	MF	171.7	0.08
66427	RHO1	250.4	0.04
66427	Q1	255.8	0.2
66427	T2	351.9	0.15
66427	R2	7.7	0.03
66427	2Q1	248.3	0.02
66427	P1	277.9	0.59
66427	2SM2	92.5	0.03
66427	M3	7.5	0.03
66427	L2	332.4	0.11
66427	2MK3	180.9	0.09
66427	K2	350.3	0.74
66427	M8	350.2	0.01
66427	MS4	117.5	0.09
66428	M2	324.8	7.3
66428	S2	357.3	2.86
66428	N2	300.7	1.61
66428	K1	277.9	1.86
66428	M4	76.1	0.11
66428	O1	263.5	1.11
66428	M6	180.7	0.06
66428	S4	181.5	0.03
66428	NU2	303.9	0.31
66428	S6	36.3	0.01
66428	MU2	349	0.17
66428	2N2	276.7	0.21
66428	OO1	292.4	0.05
66428	LDA2	339.9	0.05
66428	M1	270.8	0.08
66428	J1	285.1	0.09
66428	RHO1	257.2	0.04
66428	Q1	256.3	0.22
66428	T2	356	0.17
66428	R2	358.6	0.02
66428	2Q1	249.1	0.03
66428	P1	276.9	0.62
66428	L2	348.8	0.2
66428	K2	0	0.78
66428	M8	63.3	0.01
66429	M2	325.1	7.48
66429	S2	358.4	2.78
66429	N2	299.5	1.6
66429	K1	279.2	1.81
66429	M4	70.8	0.12
66429	O1	265.8	1.09
66429	M6	199.1	0.07
66429	S4	123.3	0.02
66429	NU2	302.9	0.31
66429	S6	171.9	0.01
66429	MU2	291.8	0.18
66429	2N2	274	0.21
66429	OO1	292.6	0.05
66429	LDA2	340.5	0.05
66429	M1	272.5	0.08
66429	J1	285.9	0.09
66429	SA	250.2	0.41
66429	MSF	171.7	0.08
66429	RHO1	260	0.04
66429	Q1	259.1	0.21
66429	T2	357.1	0.16
66429	R2	359.7	0.02
66429	2Q1	252.5	0.03
66429	P1	278.2	0.6
66429	L2	350.6	0.21
66429	K2	1.1	0.76
66429	M8	22.7	0.02
66430	M2	325.2	7.53
66430	S2	357.9	2.96
66430	N2	301.4	1.66
66430	K1	277.8	1.88
66430	M4	69.5	0.11
66430	O1	263.8	1.11
66430	M6	182.4	0.07
66430	S4	178.7	0.03
66430	NU2	304.6	0.32
66430	S6	31.7	0.01
66430	MU2	350.6	0.18
66430	2N2	277.5	0.22
66430	OO1	291.8	0.05
66430	LDA2	340.4	0.05
66430	M1	270.8	0.08
66430	J1	284.8	0.09
66430	RHO1	257.8	0.04
66430	Q1	256.8	0.22
66430	T2	356.6	0.17
66430	R2	359.2	0.02
66430	2Q1	249.9	0.03
66430	P1	276.8	0.62
66430	L2	349.1	0.21
66430	K2	0.5	0.8
66430	M8	49.6	0.01
66431	M2	335	7.49
66431	S2	6.9	2.66
66431	N2	307	1.49
66431	K1	284.6	1.88
66431	M4	51.9	0.19
66431	O1	269.9	1.13
66431	M6	205.8	0.04
66431	S4	123	0.03
66431	NU2	310.8	0.29
66431	MU2	359.4	0.18
66431	2N2	279	0.2
66431	OO1	299.3	0.05
66431	LDA2	349.8	0.05
66431	M1	277.3	0.08
66431	J1	291.9	0.09
66431	RHO1	263.6	0.04
66431	Q1	262.6	0.22
66431	T2	5.7	0.16
66431	R2	8.2	0.02
66431	2Q1	255.3	0.03
66431	P1	283.5	0.62
66431	L2	3.1	0.21
66431	K2	9.5	0.73
66431	M8	103.5	0.01
66432	M2	353.8	7.78
66432	S2	25	2.92
66432	N2	320.6	1.56
66432	K1	291.8	1.98
66432	M4	175.2	0.09
66432	O1	275.8	1.15
66432	M6	79	0.07
66432	S4	219.9	0.02
66432	NU2	325	0.31
66432	MU2	322.6	0.19
66432	2N2	287.4	0.21
66432	OO1	307.9	0.05
66432	LDA2	8.3	0.06
66432	M1	283.9	0.08
66432	J1	299.8	0.09
66432	SA	250.2	0.41
66432	MF	171.7	0.08
66432	RHO1	268.9	0.04
66432	Q1	267.8	0.22
66432	T2	23.8	0.17
66432	R2	26.3	0.02
66432	2Q1	259.8	0.03
66432	P1	290.6	0.66
66432	L2	27	0.22
66432	K2	27.5	0.79
66433	M2	8.9	8.15
66433	S2	40.6	3.14
66433	N2	339.9	1.79
66433	K1	297.2	1.9
66433	M4	260.8	0.28
66433	O1	280.8	1.25
66433	M6	108.6	0.15
66433	S4	345.6	0.03
66433	NU2	343.8	0.35
66433	S6	316.9	0.01
66433	MU2	337.1	0.2
66433	2N2	310.9	0.24
66433	OO1	313.6	0.05
66433	LDA2	23.6	0.06
66433	M1	289.1	0.09
66433	J1	305.3	0.1
66433	SA	243.7	0.39
66433	MF	163	0.09
66433	RHO1	273.8	0.05
66433	Q1	272.7	0.24
66433	T2	39.3	0.18
66433	R2	41.9	0.03
66433	2Q1	264.5	0.03
66433	P1	296	0.63
66433	L2	37.8	0.23
66433	K2	43.2	0.85
66433	M8	293.5	0.02
66434	M2	15.2	7.45
66434	S2	47.2	2.9
66434	N2	346.5	1.67
66434	K1	301.9	1.92
66434	M4	232.4	0.18
66434	O1	284.3	1.25
66434	M6	95.3	0.09
66434	S4	313.2	0.02
66434	NU2	350.3	0.32
66434	S6	244.9	0.01
66434	MU2	343.3	0.18
66434	2N2	317.7	0.22
66434	OO1	319.5	0.05
66434	LDA2	30.1	0.05
66434	M1	293.2	0.09
66434	J1	310.6	0.1
66434	SA	243.7	0.04
66434	RHO1	276.7	0.05
66434	Q1	275.6	0.24
66434	T2	45.9	0.17
66434	R2	48.5	0.02
66434	2Q1	266.8	0.03
66434	P1	300.6	0.64
66434	L2	44	0.21
66434	K2	49.8	0.79
66435	M2	16.6	8.21
66435	S2	52.4	3.02
66435	N2	351.6	1.69
66435	K1	301.7	1.89
66435	M4	277.3	0.4
66435	O1	288.4	1.23
66435	M6	117.3	0.23
66435	S4	64.2	0.01
66435	NU2	354.9	0.33
66435	S6	198.9	0.01
66435	MU2	340.9	0.2
66435	2N2	326.6	0.23
66435	OO1	315.2	0.05
66435	LDA2	33.2	0.06
66435	M1	295.1	0.09
66435	J1	308.4	0.1
66435	SA	243.7	0.39
66435	MF	163	0.09
66435	RHO1	282.7	0.05
66435	Q1	281.7	0.24
66435	T2	51	0.18
66435	R2	53.8	0.02
66435	2Q1	275.1	0.03
66435	P1	300.7	0.63
66435	L2	41.7	0.23
66435	K2	55.3	0.82
66435	M8	349.4	0.04
66436	M2	32.3	8.21
66436	S2	63.1	2.82
66436	N2	1.6	1.62
66436	K1	307.9	2.11
66436	M4	279.1	0.29
66436	O1	291.1	1.26
66436	M6	141.2	0.23
66436	MK3	253.3	0.14
66436	S4	17.8	0.03
66436	MN4	259.9	0.11
66436	NU2	22.7	0.29
66436	MU2	274.7	0.34
66436	2N2	332.3	0.18
66436	OO1	11.9	0.06
66436	LDA2	60.1	0.1
66436	S1	107.5	0.03
66436	M1	353.1	0.08
66436	J1	342.3	0.08
66436	SA	243.7	0.39
66436	MF	163	0.09
66436	RHO1	276.8	0.05
66436	Q1	290.2	0.21
66436	T2	59.5	0.16
66436	R2	97.4	0.05
66436	2Q1	288.4	0.02
66436	P1	308.2	0.61
66436	2SM2	282.7	0.05
66436	M3	103.9	0.03
66436	L2	79.9	0.24
66436	2MK3	244.9	0.15
66436	K2	55.8	0.8
66436	M8	14	0.03
66436	MS4	319.1	0.23
66437	M2	87.2	10.27
66437	S2	122.9	3.14
66437	N2	50.1	1.85
66437	K1	326.1	2.21
66437	M4	63.3	0.64
66437	O1	309.6	1.52
66437	M6	297.6	0.34
66437	S4	194.7	0.07
66437	NU2	55.1	0.36
66437	S6	235.3	0.03
66437	MU2	110.6	0.25
66437	2N2	13.1	0.25
66437	OO1	342.5	0.07
66437	LDA2	103.8	0.07
66437	M1	317.9	0.11
66437	J1	334.3	0.12
66437	RHO1	302.6	0.06
66437	Q1	301.5	0.3
66437	T2	121.5	0.18
66437	R2	124.3	0.03
66437	2Q1	293.3	0.04
66437	P1	324.9	0.73
66437	L2	124.2	0.29
66437	K2	125.8	0.85
66437	M8	295.4	0.05
66438	M2	75.1	8.14
66438	S2	108.9	2.43
66438	N2	39.7	1.47
66438	K1	327.3	1.94
66438	M4	15.7	0.26
66438	O1	313.4	1.19
66438	M6	229.5	0.21
66438	S4	132.4	0.03
66438	NU2	44.4	0.29
66438	MU2	98.9	0.19
66438	2N2	4.3	0.19
66438	OO1	340.7	0.05
66438	LDA2	90.8	0.06
66438	M1	320.3	0.09
66438	J1	333.8	0.1
66438	SA	243.7	0.39
66438	MF	163	0.09
66438	RHO1	307.5	0.05
66438	Q1	306.6	0.23
66438	T2	107.5	0.14
66438	R2	110.2	0.02
66438	2Q1	299.8	0.03
66438	P1	326.2	0.64
66438	L2	110.5	0.23
66438	K2	111.6	0.66
66438	M8	128.2	0.04
66439	M2	96.7	10.87
66439	S2	139.4	3.09
66439	N2	74	1.82
66439	K1	336.4	2.07
66439	M4	64.6	0.73
66439	O1	323.5	1.33
66439	M6	333.1	0.44
66439	S4	217.2	0.04
66439	NU2	77	0.35
66439	S6	304.2	0.01
66439	MU2	53.9	0.26
66439	2N2	51.3	0.24
66439	OO1	349.1	0.06
66439	LDA2	116.5	0.08
66439	M1	329.9	0.1
66439	J1	342.6	0.1
66439	SA	243.7	0.39
66439	MF	163	0.09
66439	RHO1	317.9	0.05
66439	Q1	317.1	0.26
66439	T2	137.7	0.18
66439	R2	141.1	0.03
66439	2Q1	310.9	0.03
66439	P1	335.5	0.69
66439	L2	119.4	0.31
66439	K2	142.9	0.84
66439	M8	293.8	0.08
66440	M2	105.2	11.5
66440	S2	147.4	3.21
66440	N2	79.2	1.96
66440	K1	342.1	2.2
66440	M4	80.7	0.89
66440	O1	325	1.22
66440	M6	18.2	0.51
66440	MK3	8.8	0.27
66440	S4	207	0.07
66440	MN4	60	0.31
66440	NU2	82.3	0.56
66440	S6	278.4	0.01
66440	MU2	234	0.7
66440	2N2	48.1	0.19
66440	OO1	79.3	0.06
66440	LDA2	111.1	0.31
66440	S1	74.2	0.01
66440	M1	40.2	0.1
66440	J1	65.2	0.08
66440	MM	36.1	0.17
66440	SSA	283	0.08
66440	SA	217.4	0.31
66440	MSF	39.6	0.44
66440	MF	94.7	0.08
66440	RHO1	296.2	0.05
66440	Q1	330.6	0.2
66440	T2	128.7	0.18
66440	R2	233.5	0.04
66440	2Q1	328.4	0.02
66440	P1	340.9	0.58
66440	2SM2	348.6	0.19
66440	M3	148	0.06
66440	L2	125.2	0.69
66440	2MK3	21.2	0.32
66440	K2	138.1	0.89
66440	M8	346.2	0.15
66440	MS4	128.2	0.57
66440	SIG1	24.4	0.15
66440	MP1	67.2	0.22
66440	CHI1	278.4	0.02
66440	2PO1	143	0.06
66440	SO1	151.1	0.24
66440	MSN2	335.1	0.16
66440	MNS2	201.8	0.19
66440	OP2	100.5	0.02
66440	MKS2	300.1	0.05
66440	2NS2	167.2	0.03
66440	MLN2S2	201.5	0.13
66440	2ML2S2	43.4	0.08
66440	SKM2	340.7	0.08
66440	2MS2K2	245	0.02
66440	MKL2S2	108.5	0.01
66440	M2(KS)2	126.9	0.02
66440	2KM(SN)2	167.5	0.01
66440	SO3	31.4	0.17
66440	SK3	67.6	0.14
66440	NO3	353.7	0.13
66440	MK4	122.2	0.14
66440	SN4	146.9	0.07
66440	2MLS4	220.8	0.09
66440	3MS4	161.2	0.12
66440	ML4	72.6	0.09
66440	N4	36.4	0.06
66440	SL4	117.4	0.07
66440	MNO5	249.7	0.06
66440	2MO5	268.3	0.11
66440	2MK5	256.3	0.2
66440	MSK5	324.6	0.1
66440	3KM5	305.5	0.03
66440	2MP5	285.1	0.09
66440	3MP5	357.4	0.07
66440	MNK5	239.1	0.07
66440	2SM6	114.6	0.09
66440	2MN6	352.7	0.27
66440	MSN6	48.1	0.09
66440	2MS6	59.4	0.47
66440	2NMLS6	297.7	0.08
66440	2NM6	325.4	0.07
66440	MSL6	70.2	0.11
66440	2ML6	34.3	0.08
66440	MSK6	91.8	0.06
66440	2MNLS6	325.1	0.1
66440	3MLS6	176.1	0.1
66440	2MK6	46.7	0.12
66440	2MNO7	245.7	0.05
66440	2NMK7	204.4	0.01
66440	2MSO7	293.2	0.08
66440	MSKO7	122.5	0.1
66440	2MSN8	14	0.08
66440	3MS8	26	0.21
66440	2(MS)8	80.3	0.08
66440	2(MN)8	292.9	0.04
66440	3MN8	319.3	0.11
66440	2MSL8	30.1	0.07
66440	4MLS8	128.4	0.05
66440	3ML8	350.6	0.03
66440	3MK8	16.8	0.05
66440	2MSK8	62.5	0.05
66440	2M2NK9	144.4	0.01
66440	3MNK9	171.4	0.02
66440	4MK9	201.2	0.03
66440	3MSK9	244.7	0.05
66440	4MN10	273.1	0.05
66440	M10	299.2	0.06
66440	3MNS10	315.2	0.07
66440	4MS10	336.3	0.11
66440	3MSL10	346.3	0.04
66440	3M2S10	22.5	0.06
66440	4MSK11	204	0.03
66440	4MNS12	276.2	0.05
66440	5MS12	298.3	0.06
66440	4MSL12	307	0.03
66440	4M2S12	343	0.05
66440	TK1	352.9	0.03
66440	PSI1	322.1	0.03
66440	KP1	324.7	0.01
66440	THE1	310.7	0.04
66440	KJ2-IHO	314.9	0.02
66440	OQ2-HORN	31	0.08
66441	M2	105.9	11.85
66441	S2	151.3	3.31
66441	N2	83.4	1.92
66441	K1	340.9	2.08
66441	M4	77.5	0.78
66441	O1	328.5	1.28
66441	M6	23.9	0.65
66441	S4	248.6	0.04
66441	NU2	86.4	0.37
66441	MU2	60.6	0.29
66441	2N2	60.9	0.26
66441	OO1	352.9	0.06
66441	LDA2	127	0.08
66441	M1	334.6	0.09
66441	J1	346.8	0.1
66441	RHO1	323.2	0.05
66441	Q1	322.4	0.25
66441	T2	149.4	0.19
66441	R2	153	0.03
66441	2Q1	316.1	0.03
66441	P1	340	0.69
66441	L2	128.5	0.33
66441	K2	154.9	0.9
66441	M8	350.9	0.17
66442	M2	116.4	12.22
66442	S2	161.3	3.65
66442	N2	93.1	2.22
66442	K1	345.3	2.05
66442	M4	114.5	1.12
66442	O1	336.9	1.49
66442	M6	73.6	0.8
66442	S4	306.8	0.08
66442	NU2	96.3	0.43
66442	S6	252.6	0.01
66442	MU2	71.5	0.29
66442	2N2	69.9	0.3
66442	OO1	353.7	0.07
66442	LDA2	137.3	0.09
66442	M1	341.2	0.1
66442	J1	349.5	0.12
66442	MM	39.7	0.2
66442	SSA	45.6	0.24
66442	SA	230.2	0.18
66442	MSF	50.4	0.47
66442	RHO1	333.3	0.06
66442	Q1	332.8	0.29
66442	T2	159.5	0.22
66442	R2	163.1	0.03
66442	2Q1	328.6	0.04
66442	P1	344.7	0.68
66442	L2	139.7	0.34
66442	K2	165	0.99
66442	M8	73.9	0.26
66443	M2	323.5	5.32
66443	S2	1.9	1.9
66443	N2	293.9	1.1
66443	K1	288.1	1.57
66443	M4	194.9	0.03
66443	O1	268.6	1.07
66443	M6	7.7	0.03
66443	S4	319.4	0.02
66443	NU2	297.9	0.21
66443	MU2	337.3	0.13
66443	2N2	264.3	0.15
66443	OO1	307.6	0.05
66443	LDA2	341.3	0.04
66443	M1	278.4	0.08
66443	J1	297.8	0.09
66443	SSA	151.7	0.05
66443	SA	262.1	0.26
66443	RHO1	260.2	0.04
66443	Q1	258.9	0.21
66443	T2	0.3	0.11
66443	R2	3.4	0.02
66443	2Q1	249.3	0.03
66443	P1	286.6	0.52
66443	L2	353.2	0.15
66443	K2	5	0.52
66443	M8	89.7	0.01
66444	M2	322.7	5.33
66444	S2	358.7	1.91
66444	N2	298.1	1.16
66444	K1	287.2	1.56
66444	M4	213.2	0.05
66444	O1	269.3	1.06
66444	M6	35.8	0.02
66444	S4	312.7	0.02
66444	NU2	301.4	0.23
66444	S6	218.2	0.01
66444	MU2	338.1	0.13
66444	2N2	273.5	0.15
66444	OO1	305.2	0.05
66444	LDA2	339.4	0.04
66444	M1	278.3	0.08
66444	J1	296.1	0.09
66444	SSA	151.7	0.05
66444	SA	262.1	0.26
66444	RHO1	261.6	0.04
66444	Q1	260.4	0.21
66444	T2	357.2	0.11
66444	R2	0.1	0.02
66444	2Q1	251.5	0.03
66444	P1	285.9	0.52
66444	L2	347.3	0.15
66444	K2	1.6	0.52
66445	M2	308.3	3.17
66445	S2	341.6	1.15
66445	N2	283.6	0.62
66445	K1	284.6	1.32
66445	M4	54.9	0.06
66445	O1	273.8	0.8
66445	M6	83.3	0.04
66445	S4	141.1	0.02
66445	NU2	286.9	0.12
66445	S6	198.7	0.02
66445	MU2	330.1	0.08
66445	2N2	258.8	0.08
66445	OO1	295.3	0.04
66445	LDA2	323.8	0.02
66445	M1	279.2	0.06
66445	J1	289.9	0.06
66445	SA	151.7	0.05
66445	MSF	262.1	0.26
66445	RHO1	269.2	0.03
66445	Q1	268.5	0.15
66445	T2	340.3	0.07
66445	R2	343	0.01
66445	2Q1	263.2	0.02
66445	P1	283.8	0.44
66445	L2	333.1	0.09
66445	K2	344.3	0.31
66445	M8	202.7	0.01
66446	M2	307.4	3.17
66446	S2	340.9	1.06
66446	N2	283.4	0.66
66446	K1	288.5	1.3
66446	M4	24.7	0.03
66446	O1	272.7	0.84
66446	M6	85.9	0.03
66446	MK3	259.6	0.01
66446	MN4	357.6	0.01
66446	NU2	285.1	0.13
66446	MU2	277.8	0.08
66446	2N2	258.1	0.08
66446	OO1	311	0.04
66446	LDA2	306.3	0.02
66446	S1	49.9	0.04
66446	M1	292.9	0.05
66446	J1	297.2	0.08
66446	SA	246.1	0.26
66446	MSF	25.2	0.03
66446	MF	193.3	0.11
66446	RHO1	266.6	0.03
66446	Q1	264.6	0.15
66446	T2	331	0.07
66446	2Q1	266.6	0.02
66446	P1	284.2	0.41
66446	2SM2	130.9	0.01
66446	M3	286.8	0.01
66446	L2	314.9	0.08
66446	2MK3	240.8	0.01
66446	K2	332.1	0.29
66446	M8	211.5	0.01
66446	MS4	69.9	0.02
66447	M2	317.5	4.05
66447	S2	355.5	1.44
66447	N2	297.5	0.86
66447	K1	287.4	1.44
66447	M4	184.1	0.31
66447	O1	267.7	1.05
66447	M6	37.8	0.09
66447	S4	217.7	0.01
66447	NU2	300.2	0.17
66447	S6	206.7	0.02
66447	MU2	279.5	0.1
66447	2N2	277.6	0.11
66447	OO1	307.2	0.05
66447	LDA2	335.1	0.03
66447	M1	277.6	0.08
66447	J1	297.3	0.08
66447	SSA	151.7	0.05
66447	SA	262.1	0.26
66447	RHO1	259.2	0.04
66447	Q1	257.9	0.2
66447	T2	353.9	0.09
66447	R2	357	0.01
66447	2Q1	248	0.03
66447	P1	286	0.48
66447	L2	337.4	0.11
66447	K2	358.5	0.39
66447	M8	81.4	0.03
66448	M2	308.4	3.4
66448	S2	342.2	1.27
66448	N2	285.6	0.68
66448	K1	286.6	1.3
66448	M4	15.8	0.03
66448	O1	273.4	0.86
66448	M6	102.5	0.04
66448	S4	176.7	0.01
66448	NU2	288.6	0.13
66448	S6	225	0.01
66448	MU2	328.9	0.08
66448	2N2	262.7	0.09
66448	OO1	299.8	0.04
66448	LDA2	324.1	0.02
66448	M1	280.1	0.06
66448	J1	293.2	0.07
66448	SSA	151.7	0.05
66448	SA	262.1	0.26
66448	RHO1	267.8	0.03
66448	Q1	266.9	0.17
66448	T2	340.8	0.08
66448	R2	343.5	0.01
66448	2Q1	260.3	0.02
66448	P1	285.6	0.43
66448	L2	331.2	0.1
66448	K2	344.9	0.34
66448	M8	236.6	0.01
66449	M2	308.8	3.47
66449	S2	340.3	1.15
66449	N2	284.6	0.77
66449	K1	288.7	1.38
66449	M4	21.1	0.03
66449	O1	273.7	0.87
66449	M6	86.7	0.05
66449	S4	265.4	0.01
66449	NU2	287.9	0.15
66449	S6	123.5	0.02
66449	MU2	277.3	0.08
66449	2N2	260.5	0.1
66449	OO1	303.7	0.04
66449	LDA2	323.4	0.02
66449	M1	281.3	0.06
66449	J1	296.2	0.07
66449	MM	191.7	0.06
66449	SSA	151.7	0.05
66449	SA	262.1	0.26
66449	MSF	51.5	0.05
66449	MF	165.2	0.07
66449	RHO1	267.3	0.03
66449	Q1	266.3	0.17
66449	T2	339	0.07
66449	R2	341.6	0.01
66449	2Q1	258.9	0.02
66449	P1	287.6	0.46
66449	L2	332.9	0.1
66449	K2	342.9	0.31
66449	M8	260.8	0.01
66450	M2	323.9	5.2
66450	S2	2.4	1.93
66450	N2	303.6	1.13
66450	K1	286.6	1.59
66450	M4	191.4	0.06
66450	O1	267.8	1.07
66450	M6	16.2	0.1
66450	S4	317.8	0.02
66450	NU2	306.3	0.22
66450	MU2	285.3	0.12
66450	2N2	283.4	0.15
66450	OO1	305.4	0.05
66450	LDA2	341.8	0.04
66450	M1	277.3	0.08
66450	J1	295.9	0.09
66450	SSA	151.7	0.05
66450	SA	262.1	0.26
66450	RHO1	259.8	0.04
66450	Q1	258.5	0.21
66450	T2	0.9	0.11
66450	R2	4	0.02
66450	2Q1	249.2	0.03
66450	P1	285.2	0.53
66450	L2	344.1	0.14
66450	K2	5.6	0.52
66451	M2	323.4	5.5
66451	S2	357.6	2.01
66451	N2	302	1.1
66451	K1	285.8	1.73
66451	M4	225.7	0.06
66451	O1	269.4	1.01
66451	M6	15.9	0.03
66451	S4	337.5	0.01
66451	NU2	304.9	0.21
66451	S6	184.9	0.01
66451	MU2	289.2	0.13
66451	2N2	280.7	0.15
66451	OO1	302.1	0.04
66451	LDA2	339.3	0.04
66451	M1	277.6	0.07
66451	J1	293.9	0.08
66451	SA	250.2	0.41
66451	MF	171.7	0.08
66451	RHO1	262.3	0.04
66451	Q1	261.2	0.2
66451	T2	356.3	0.12
66451	R2	359	0.02
66451	2Q1	253.1	0.03
66451	P1	284.5	0.57
66451	L2	344.8	0.15
66451	K2	0.4	0.55
66452	M2	298.7	2.98
66452	S2	329.2	1.08
66452	N2	274.6	0.59
66452	K1	272.2	1.1
66452	M4	45.2	0.01
66452	O1	258.1	0.74
66452	M6	155.6	0.01
66452	S4	211.5	0.03
66452	NU2	277.8	0.11
66452	S6	352.2	0.01
66452	MU2	268.1	0.07
66452	2N2	250.5	0.08
66452	OO1	286.4	0.03
66452	LDA2	312.9	0.02
66452	M1	265.2	0.05
66452	J1	279.2	0.06
66452	RHO1	252.1	0.03
66452	Q1	251.1	0.14
66452	T2	328	0.06
66452	R2	330.5	0.01
66452	2Q1	244.1	0.02
66452	P1	271.2	0.36
66452	L2	322.8	0.08
66452	K2	331.7	0.29
66453	M2	298.9	3
66453	S2	327	1.02
66453	N2	276	0.66
66453	K1	270.9	1.2
66453	M4	169.1	0.01
66453	O1	262	0.72
66453	M6	158.5	0.02
66453	S4	214.6	0.01
66453	NU2	279.1	0.13
66453	MU2	324.2	0.07
66453	2N2	253.1	0.09
66453	OO1	279.7	0.03
66453	LDA2	311.9	0.02
66453	M1	266.5	0.05
66453	J1	275.3	0.06
66453	SSA	151.7	0.05
66453	SA	262.1	0.26
66453	RHO1	258.2	0.03
66453	Q1	257.6	0.14
66453	T2	325.8	0.06
66453	R2	328.1	0.01
66453	2Q1	253.2	0.02
66453	P1	270.2	0.4
66453	L2	321.8	0.09
66453	K2	329.2	0.28
66453	M8	91.7	0.01
66454	M2	322.7	5.44
66454	S2	359.3	2
66454	N2	300.6	1.15
66454	K1	286.1	1.63
66454	M4	217.7	0.05
66454	O1	268.3	1.06
66454	M6	20	0.03
66454	S4	315.5	0.01
66454	NU2	303.6	0.22
66454	MU2	286	0.13
66454	2N2	278.5	0.15
66454	OO1	304	0.05
66454	LDA2	339.7	0.04
66454	M1	277.3	0.08
66454	J1	295	0.08
66454	SA	250.2	0.41
66454	MF	171.7	0.08
66454	RHO1	260.7	0.04
66454	Q1	259.5	0.2
66454	T2	357.8	0.12
66454	R2	0.8	0.02
66454	2Q1	250.7	0.03
66454	P1	284.8	0.54
66454	L2	344.8	0.15
66454	K2	2.3	0.54
66455	M2	299.4	2.99
66455	S2	330.7	1
66455	N2	278	0.64
66455	K1	268.9	1.12
66455	M4	149.4	0.01
66455	O1	256.3	0.74
66455	M6	151.8	0.01
66455	S4	193.3	0.01
66455	NU2	280.9	0.12
66455	S6	224.2	0.01
66455	MU2	268.1	0.07
66455	2N2	256.7	0.09
66455	OO1	281.5	0.03
66455	LDA2	314	0.02
66455	M1	262.7	0.05
66455	J1	275.2	0.06
66455	MM	191.7	0.06
66455	SSA	151.7	0.05
66455	SA	262.1	0.26
66455	MSF	51.5	0.05
66455	MF	165.2	0.07
66455	RHO1	251	0.03
66455	Q1	250.1	0.14
66455	T2	329.5	0.06
66455	R2	332	0.01
66455	2Q1	243.9	0.02
66455	P1	268	0.37
66455	L2	320.8	0.08
66455	K2	333.3	0.27
66456	M2	322.6	5.32
66456	S2	355.6	1.95
66456	N2	303.1	1.07
66456	K1	285.1	1.77
66456	M4	221.8	0.1
66456	O1	268.9	1.02
66456	M6	169.4	0.02
66456	S4	318	0.03
66456	NU2	305.7	0.21
66456	MU2	341.6	0.13
66456	2N2	283.6	0.14
66456	OO1	301.4	0.04
66456	LDA2	337.9	0.04
66456	M1	277.1	0.07
66456	J1	293.2	0.08
66456	SSA	151.7	0.05
66456	SA	262.1	0.26
66456	RHO1	261.9	0.04
66456	Q1	260.8	0.2
66456	T2	354.2	0.11
66456	R2	356.9	0.02
66456	2Q1	252.7	0.03
66456	P1	283.9	0.58
66456	L2	342	0.15
66456	K2	358.2	0.53
66457	M2	302.1	3.17
66457	S2	332.3	1.14
66457	N2	277.2	0.66
66457	K1	269.8	1.17
66457	M4	201.7	0.06
66457	O1	255.5	0.75
66457	M6	175.6	0.03
66457	S4	218	0.02
66457	NU2	280.5	0.13
66457	MU2	271.8	0.08
66457	2N2	252.4	0.09
66457	OO1	284.2	0.03
66457	LDA2	316.1	0.02
66457	M1	262.7	0.05
66457	J1	276.9	0.06
66457	RHO1	249.4	0.03
66457	Q1	248.4	0.14
66457	T2	331.1	0.07
66457	R2	333.5	0.01
66457	2Q1	241.3	0.02
66457	P1	268.8	0.39
66457	L2	326.9	0.09
66457	K2	334.7	0.31
66457	M8	38.7	0.01
66458	M2	319.3	5.27
66458	S2	357.2	1.9
66458	N2	293.9	1.06
66458	K1	284.8	1.63
66458	M4	219.3	0.08
66458	O1	267.7	1.07
66458	M6	51.4	0.01
66458	S4	319.3	0.02
66458	NU2	297.3	0.21
66458	MU2	333.4	0.13
66458	2N2	268.5	0.14
66458	OO1	301.9	0.05
66458	LDA2	336.8	0.04
66458	M1	276.3	0.08
66458	J1	293.3	0.09
66458	SSA	151.7	0.05
66458	SA	262.1	0.26
66458	RHO1	260.3	0.04
66458	Q1	259.2	0.21
66458	T2	355.6	0.11
66458	R2	358.7	0.02
66458	2Q1	250.7	0.03
66458	P1	283.5	0.54
66458	L2	344.6	0.15
66458	K2	0.2	0.52
66459	M2	314.2	4.43
66459	S2	348.5	1.59
66459	N2	291.3	0.93
66459	K1	280.4	1.62
66459	M4	209.6	0.11
66459	O1	265.3	1.01
66459	M6	89.8	0.04
66459	MK3	103.4	0.06
66459	S4	299.7	0.01
66459	MN4	177.8	0.04
66459	NU2	291.3	0.17
66459	MU2	296	0.16
66459	2N2	266.4	0.11
66459	OO1	313.3	0.06
66459	LDA2	265.1	0.03
66459	S1	55.2	0.05
66459	M1	293.2	0.06
66459	J1	298.2	0.1
66459	SSA	328.3	0.02
66459	SA	243.6	0.23
66459	MF	184.1	0.11
66459	RHO1	254.2	0.03
66459	Q1	258.1	0.18
66459	T2	338.5	0.1
66459	2Q1	257.7	0.02
66459	P1	277.4	0.51
66459	2SM2	101	0.03
66459	L2	299.7	0.09
66459	2MK3	71.9	0.05
66459	K2	339.3	0.42
66459	M8	325	0.01
66459	MS4	258.7	0.07
66460	M2	321.8	4.68
66460	S2	357.6	1.6
66460	N2	297.7	1.04
66460	K1	286.4	1.53
66460	M4	215.3	0.1
66460	O1	268.1	1.05
66460	M6	154.1	0.02
66460	S4	303.2	0.02
66460	NU2	301	0.2
66460	MU2	286.1	0.11
66460	2N2	273.6	0.14
66460	OO1	304.6	0.05
66460	LDA2	338.4	0.03
66460	M1	277.3	0.08
66460	J1	295.4	0.08
66460	SSA	151.7	0.05
66460	SA	262.1	0.26
66460	RHO1	260.3	0.04
66460	Q1	259.1	0.2
66460	T2	356.1	0.1
66460	R2	359	0.01
66460	2Q1	250	0.03
66460	P1	285	0.51
66460	L2	345.9	0.13
66460	K2	0.5	0.44
66460	M8	91.9	0.01
66461	M2	302.9	2.96
66461	S2	335.4	1.02
66461	N2	280.5	0.59
66461	K1	277.2	1.44
66461	M4	246	0.07
66461	O1	260.4	0.98
66461	M6	254.2	0.01
66461	S4	258.2	0.01
66461	NU2	283.5	0.11
66461	MU2	318.9	0.07
66461	2N2	258.2	0.08
66461	OO1	294	0.04
66461	LDA2	318	0.02
66461	M1	268.9	0.07
66461	J1	285.5	0.08
66461	RHO1	253.2	0.04
66461	Q1	252.1	0.19
66461	T2	334.1	0.06
66461	R2	336.7	0.01
66461	2Q1	243.8	0.03
66461	P1	275.9	0.48
66461	L2	325.2	0.08
66461	K2	338	0.28
66462	M2	315.7	3.15
66462	S2	352.3	1.06
66462	N2	292.1	0.65
66462	K1	282	1.42
66462	M4	254.8	0.06
66462	O1	265.7	0.95
66462	M6	244.1	0.02
66462	S4	311.6	0.01
66462	NU2	295.2	0.12
66462	MU2	279.3	0.08
66462	2N2	268.4	0.09
66462	OO1	298.4	0.04
66462	LDA2	332.8	0.02
66462	M1	274	0.07
66462	J1	290.1	0.08
66462	SSA	54.2	0.05
66462	SA	267.8	0.18
66462	RHO1	258.7	0.04
66462	Q1	257.6	0.18
66462	T2	350.8	0.06
66462	R2	353.8	0.01
66462	2Q1	249.5	0.02
66462	P1	280.7	0.47
66462	L2	339.5	0.09
66462	K2	355.2	0.29
66463	M2	9	3.323
66463	S2	45.3	1.171
66463	N2	344.2	0.738
66463	K1	311	1.427
66463	M4	334	0.079
66463	O1	292.9	0.965
66463	M6	22.5	0.03
66463	S4	19.5	0.016
66463	NU2	347.5	0.144
66463	MU2	332.7	0.079
66463	2N2	319.5	0.098
66463	OO1	328.9	0.043
66463	LDA2	25.8	0.023
66463	M1	302	0.069
66463	J1	319.9	0.075
66463	RHO1	285.2	0.036
66463	Q1	284.1	0.187
66463	T2	43.7	0.069
66463	R2	46.7	0.01
66463	2Q1	275.2	0.026
66463	P1	309.6	0.472
66463	L2	33.7	0.105
66463	K2	48.1	0.318
66464	M2	324.5	3.04
66464	S2	356.2	0.98
66464	N2	301.3	0.65
66464	K1	289.5	1.48
66464	M4	259.7	0.06
66464	O1	271.9	0.94
66464	M6	266.1	0.04
66464	NU2	304.4	0.13
66464	S6	205.1	0.01
66464	MU2	292.8	0.07
66464	2N2	278	0.09
66464	OO1	307	0.04
66464	LDA2	339.2	0.02
66464	M1	280.8	0.07
66464	J1	298.2	0.08
66464	SA	272.3	0.4
66464	RHO1	264.4	0.04
66464	Q1	263.2	0.18
66464	T2	354.9	0.06
66464	R2	357.5	0.01
66464	2Q1	254.5	0.02
66464	P1	288.1	0.49
66464	L2	347.7	0.09
66464	K2	358.8	0.27
66465	M2	323.1	2.67
66465	S2	355.7	0.94
66465	N2	298.7	0.59
66465	K1	288.2	1.36
66465	M4	249.8	0.03
66465	O1	273	0.91
66465	M6	286.5	0.04
66465	NU2	302	0.11
66465	S6	238.8	0.01
66465	MU2	333.3	0.07
66465	2N2	274.2	0.08
66465	OO1	303.4	0.04
66465	LDA2	338.3	0.02
66465	M1	280.7	0.07
66465	J1	295.7	0.07
66465	SA	272.3	0.4
66465	RHO1	266.5	0.04
66465	Q1	265.5	0.18
66465	T2	354.4	0.06
66465	R2	357	0.01
66465	2Q1	257.9	0.02
66465	P1	287.1	0.45
66465	L2	347.6	0.08
66465	K2	358.4	0.26
66466	M2	322.2	2.59
66466	S2	351.2	0.9
66466	N2	300.2	0.58
66466	K1	286.2	1.41
66466	M4	271.7	0.03
66466	O1	271.4	0.88
66466	M6	290.6	0.04
66466	NU2	303.1	0.11
66466	S6	252.5	0.01
66466	MU2	335.6	0.06
66466	2N2	278.1	0.08
66466	OO1	301.1	0.04
66466	LDA2	335.7	0.02
66466	M1	278.9	0.06
66466	J1	293.6	0.07
66466	RHO1	265	0.03
66466	Q1	264	0.17
66466	T2	350	0.05
66466	R2	352.4	0.01
66466	2Q1	256.7	0.02
66466	P1	285.1	0.47
66466	L2	344.2	0.07
66466	K2	353.5	0.25
66467	M2	322.5	2.39
66467	S2	353	0.81
66467	N2	297.4	0.51
66467	K1	286.6	1.37
66467	M4	308.4	0.02
66467	O1	270.3	0.92
66467	M6	332.8	0.02
66467	S4	212.1	0.01
66467	NU2	300.7	0.1
66467	S6	250.4	0.01
66467	MU2	333.2	0.06
66467	2N2	272.2	0.07
66467	OO1	302.9	0.04
66467	LDA2	336.7	0.02
66467	M1	278.5	0.07
66467	J1	294.7	0.07
66467	SA	272.3	0.4
66467	RHO1	263.3	0.04
66467	Q1	262.2	0.18
66467	T2	351.8	0.05
66467	R2	354.3	0.01
66467	2Q1	254.1	0.02
66467	P1	285.4	0.45
66467	L2	347.7	0.07
66467	K2	355.5	0.22
66468	M2	318.4	2.26
66468	S2	344.7	0.77
66468	N2	295.9	0.49
66468	K1	282.2	1.35
66468	O1	266	0.9
66468	M6	353.8	0.01
66468	S4	227	0.01
66468	NU2	298.9	0.1
66468	MU2	292.2	0.06
66468	2N2	273.4	0.07
66468	OO1	298.3	0.04
66468	LDA2	330.6	0.02
66468	M1	274.2	0.06
66468	J1	290.2	0.07
66468	SA	272.3	0.4
66468	RHO1	259.1	0.03
66468	Q1	258	0.17
66468	T2	343.6	0.05
66468	R2	345.7	0.01
66468	2Q1	250	0.02
66468	P1	281	0.45
66468	L2	340.9	0.06
66468	K2	346.8	0.21
66469	M2	322.2	2.4
66469	S2	349.4	0.8
66469	N2	299.3	0.52
66469	K1	285.1	1.36
66469	M4	276.1	0.01
66469	O1	270.3	0.87
66469	M6	26.4	0.03
66469	S4	200.8	0.01
66469	NU2	303	0.1
66469	S6	282.8	0.01
66469	MU2	276.2	0.06
66469	2N2	273.8	0.06
66469	OO1	315.6	0.05
66469	LDA2	335.6	0.02
66469	S1	65	0.03
66469	M1	293.7	0.05
66469	J1	297.6	0.08
66469	SA	266.4	0.47
66469	RHO1	262.2	0.03
66469	Q1	263.3	0.16
66469	T2	340.2	0.05
66469	2Q1	269	0.02
66469	P1	281.7	0.43
66469	2SM2	173.9	0.01
66469	M3	226.1	0.01
66469	L2	343.7	0.05
66469	K2	343.1	0.22
66469	MS4	301.8	0.01
66470	M2	324.1	2.49
66470	S2	351.6	0.84
66470	N2	301.5	0.53
66470	K1	286.3	1.34
66470	M4	267.8	0.01
66470	O1	270.6	0.87
66470	M6	15.7	0.04
66470	NU2	304.5	0.1
66470	MU2	296.7	0.06
66470	2N2	279	0.07
66470	OO1	302	0.04
66470	LDA2	336.8	0.02
66470	M1	278.5	0.06
66470	J1	294.1	0.07
66470	SA	266.4	0.47
66470	RHO1	263.9	0.03
66470	Q1	262.8	0.17
66470	T2	350.4	0.05
66470	R2	352.7	0.01
66470	2Q1	255	0.02
66470	P1	285.1	0.44
66470	L2	346.7	0.07
66470	K2	353.8	0.23
66471	M2	326.3	2.24
66471	S2	356.2	0.72
66471	N2	300.4	0.51
66471	K1	285	1.28
66471	M4	87.1	0.01
66471	O1	270.1	0.84
66471	M6	109.5	0.06
66471	S4	187.1	0.01
66471	NU2	303.9	0.1
66471	S6	96.1	0.01
66471	MU2	332.8	0.05
66471	2N2	274.5	0.07
66471	OO1	299.9	0.04
66471	LDA2	340.2	0.02
66471	M1	277.6	0.06
66471	J1	292.4	0.07
66471	RHO1	263.7	0.03
66471	Q1	262.7	0.16
66471	T2	355	0.04
66471	R2	357.4	0.01
66471	2Q1	255.3	0.02
66471	P1	283.9	0.42
66471	L2	352.2	0.06
66471	K2	358.6	0.2
66472	M2	328.2	2.21
66472	S2	353.6	0.73
66472	N2	303.9	0.49
66472	K1	284.3	1.36
66472	M4	45.6	0.01
66472	O1	269.9	0.87
66472	M6	133.9	0.05
66472	MK3	47.7	0.01
66472	S4	207.2	0.01
66472	NU2	308.7	0.1
66472	MU2	277.3	0.06
66472	2N2	276.4	0.06
66472	OO1	311	0.04
66472	LDA2	343	0.01
66472	S1	69	0.04
66472	M1	300.5	0.05
66472	J1	294.7	0.08
66472	SA	258.6	0.35
66472	MF	170	0.1
66472	RHO1	256.6	0.03
66472	Q1	264.9	0.16
66472	T2	343.7	0.05
66472	R2	295.9	0.01
66472	2Q1	270.9	0.02
66472	P1	279.8	0.42
66472	M3	229	0.01
66472	L2	337.5	0.05
66472	2MK3	0.9	0.01
66472	K2	346.1	0.2
66473	M2	335.2	2.34
66473	S2	359.5	0.76
66473	N2	313.6	0.55
66473	K1	288.8	1.4
66473	M4	167.5	0.02
66473	O1	277.6	0.85
66473	M6	196.4	0.1
66473	S4	183.6	0.01
66473	NU2	316.5	0.11
66473	S6	217.2	0.02
66473	MU2	310.8	0.06
66473	2N2	291.9	0.07
66473	OO1	300.1	0.04
66473	LDA2	346.5	0.02
66473	M1	283.2	0.06
66473	J1	294.4	0.07
66473	SA	272.3	0.4
66473	RHO1	272.8	0.03
66473	Q1	272	0.16
66473	T2	358.6	0.05
66473	R2	0.5	0.01
66473	2Q1	266.4	0.02
66473	P1	288	0.47
66473	L2	356.8	0.07
66473	K2	1.5	0.21
66473	M8	195.7	0.01
66474	M2	178.3	0.74
66474	S2	252.4	0.11
66474	N2	134.4	0.2
66474	K1	3.9	1.12
66474	O1	12.8	0.78
66474	NU2	140.3	0.04
66474	2N2	90.4	0.03
66474	OO1	354.9	0.03
66474	S1	161.5	0.05
66474	M1	5.5	0.04
66474	J1	359.5	0.06
66474	SSA	197.3	0.26
66474	SA	264.5	0.3
66474	RHO1	16.7	0.03
66474	Q1	16.3	0.15
66474	2Q1	21.6	0.02
66474	P1	5.7	0.38
66474	L2	222.2	0.02
66474	K2	235.7	0.03
66475	M2	81.4	0.64
66475	S2	262.6	0.06
66475	N2	32.4	0.23
66475	K1	332.8	1.37
66475	O1	310.3	0.94
66475	NU2	43.9	0.04
66475	MU2	328.4	0.03
66475	2N2	352.1	0.04
66475	OO1	9.7	0.04
66475	LDA2	137.7	0.01
66475	S1	101.9	0.04
66475	M1	335.1	0.05
66475	J1	346.1	0.07
66475	SSA	227.3	0.1
66475	SA	273.3	0.23
66475	RHO1	298.7	0.03
66475	Q1	299.8	0.17
66475	T2	321	0.01
66475	2Q1	306.2	0.02
66475	P1	326.7	0.43
66475	M3	150.1	0.01
66475	L2	125.3	0.01
66475	K2	319.2	0.01
66476	M2	90.8	0.56
66476	S2	281.5	0.1
66476	N2	36	0.22
66476	K1	336	1.25
66476	M4	297.6	0.01
66476	O1	315.6	0.89
66476	MK3	123.4	0.01
66476	NU2	50.2	0.04
66476	MU2	335	0.04
66476	2N2	351.7	0.04
66476	OO1	7	0.03
66476	S1	113.6	0.05
66476	M1	344.5	0.04
66476	J1	351.4	0.07
66476	SSA	235.8	0.09
66476	SA	254.7	0.19
66476	RHO1	302.5	0.03
66476	Q1	305.5	0.16
66476	T2	313.4	0.01
66476	2Q1	306.7	0.02
66476	P1	331.1	0.4
66476	M3	155.2	0.01
66476	2MK3	69.9	0.01
66476	K2	306.5	0.03
66477	M2	66.4	0.86
66477	S2	327	0.05
66477	N2	21.9	0.31
66477	K1	318.1	1.32
66477	M4	341	0.01
66477	O1	302.6	0.88
66477	MK3	92	0.03
66477	NU2	32.6	0.06
66477	MU2	326.7	0.05
66477	2N2	339.9	0.05
66477	OO1	358.5	0.04
66477	LDA2	136.3	0.01
66477	S1	138.6	0.04
66477	M1	324.1	0.04
66477	J1	327.1	0.07
66477	SSA	202.1	0.07
66477	SA	265.5	0.27
66477	MF	176.2	0.13
66477	RHO1	294.1	0.03
66477	Q1	296.7	0.16
66477	T2	334.5	0.01
66477	R2	216.3	0.01
66477	2Q1	294.5	0.02
66477	P1	313.9	0.42
66477	M3	157	0.01
66477	2MK3	50.5	0.02
66477	K2	23.9	0.03
66478	M2	80.2	0.89
66478	S2	310	0.08
66478	N2	30.3	0.34
66478	K1	318.7	1.11
66478	O1	306.8	0.75
66478	NU2	42.5	0.07
66478	MU2	332.5	0.06
66478	2N2	346.5	0.06
66478	OO1	334.6	0.04
66478	LDA2	19.9	0.01
66478	S1	96.6	0.03
66478	M1	337.3	0.04
66478	J1	339.7	0.07
66478	SSA	216.2	0.13
66478	SA	277.7	0.31
66478	MF	208.4	0.08
66478	RHO1	292.3	0.03
66478	Q1	301	0.14
66478	T2	337.5	0.01
66478	2Q1	295.9	0.02
66478	P1	318.4	0.35
66478	M3	167.8	0.01
66478	L2	130.1	0.05
66478	K2	341	0.03
66479	M2	344.9	1.39
66479	S2	359.4	0.49
66479	N2	325	0.33
66479	K1	287.6	1.22
66479	M4	95.3	0.04
66479	O1	273.4	0.82
66479	M6	289	0.05
66479	NU2	327.7	0.07
66479	MU2	358	0.03
66479	2N2	305	0.05
66479	OO1	301.8	0.04
66479	LDA2	351.6	0.01
66479	M1	280.6	0.06
66479	J1	294.7	0.07
66479	RHO1	267.3	0.03
66479	Q1	266.4	0.16
66479	T2	358.8	0.03
66479	2Q1	259.3	0.02
66479	P1	286.6	0.4
66479	L2	4.9	0.04
66479	K2	0.6	0.13
66479	M8	286.5	0.02
66480	M2	69.7	0.85
66480	S2	318.5	0.07
66480	N2	30.1	0.31
66480	K1	311.6	1.11
66480	M4	182.4	0.04
66480	O1	300.2	0.79
66480	M6	86.9	0.02
66480	S4	19.9	0.01
66480	NU2	35.4	0.06
66480	MU2	208.6	0.02
66480	2N2	350.5	0.04
66480	OO1	323.1	0.03
66480	LDA2	18.1	0.01
66480	M1	305.9	0.06
66480	J1	317.3	0.06
66480	RHO1	295.2	0.03
66480	Q1	294.5	0.15
66480	2Q1	288.8	0.02
66480	P1	310.8	0.37
66480	L2	109.3	0.02
66480	K2	309.5	0.02
66480	M8	86.7	0.02
66481	M2	345.5	1.545
66481	S2	359.9	0.499
66481	N2	324.4	0.381
66481	K1	285.7	1.263
66481	M4	106.4	0.039
66481	O1	269.7	0.85
66481	M6	290.2	0.043
66481	S4	235.1	0.01
66481	NU2	327.2	0.072
66481	S6	192.7	0.003
66481	MU2	331	0.036
66481	2N2	303.3	0.049
66481	OO1	301.9	0.036
66481	LDA2	352.2	0.01
66481	M1	277.8	0.059
66481	J1	293.7	0.066
66481	SSA	216.2	0.128
66481	SA	277.7	0.308
66481	MF	208.4	0.075
66481	RHO1	262.7	0.033
66481	Q1	261.7	0.164
66481	T2	359.4	0.03
66481	R2	0.5	0.003
66481	2Q1	253.7	0.023
66481	P1	284.5	0.417
66481	L2	6.6	0.043
66481	K2	1.1	0.135
66481	M8	270.8	0.007
66482	M2	81.3	0.91
66482	S2	320	0.1
66482	N2	31	0.32
66482	K1	321.4	1.22
66482	M4	156.7	0.01
66482	O1	302.6	0.81
66482	NU2	37.8	0.06
66482	MU2	231	0.02
66482	2N2	340.7	0.04
66482	OO1	340.3	0.04
66482	LDA2	25	0.01
66482	M1	312.1	0.06
66482	J1	330.8	0.07
66482	RHO1	294.5	0.03
66482	Q1	293.2	0.16
66482	T2	324.9	0.01
66482	2Q1	283.9	0.02
66482	P1	320	0.4
66482	L2	131.5	0.03
66482	K2	310.2	0.03
66483	M2	344.4	1.33
66483	S2	356.6	0.52
66483	N2	328	0.35
66483	K1	289.3	1.21
66483	M4	209.6	0.02
66483	O1	272.3	0.84
66483	S4	211.9	0.01
66483	NU2	330.2	0.07
66483	MU2	332.1	0.03
66483	2N2	311.7	0.05
66483	OO1	306.3	0.04
66483	LDA2	350	0.01
66483	M1	280.9	0.06
66483	J1	297.7	0.07
66483	SSA	216.2	0.13
66483	SA	277.7	0.31
66483	MF	208.4	0.08
66483	RHO1	265	0.03
66483	Q1	263.8	0.16
66483	T2	356.2	0.03
66483	2Q1	255.4	0.02
66483	P1	288	0.4
66483	L2	0.7	0.04
66483	K2	357.6	0.14
66484	M2	83.8	0.87
66484	S2	300.8	0.1
66484	N2	32.1	0.35
66484	K1	318.3	1.21
66484	M4	130	0.01
66484	O1	301.6	0.79
66484	M6	348.2	0.01
66484	S4	266.1	0.01
66484	NU2	39	0.07
66484	MU2	226.7	0.02
66484	2N2	340.3	0.05
66484	OO1	334.9	0.03
66484	LDA2	17.5	0.01
66484	M1	310	0.06
66484	J1	326.5	0.06
66484	SSA	216.2	0.13
66484	SA	277.7	0.31
66484	MF	208.4	0.08
66484	RHO1	294.4	0.03
66484	Q1	293.3	0.15
66484	T2	306.7	0.01
66484	2Q1	285.1	0.02
66484	P1	317	0.4
66484	L2	135.5	0.02
66484	K2	289.4	0.03
66485	M2	69	0.51
66485	S2	325.1	0.21
66485	N2	26.7	0.26
66485	K1	316.2	1.03
66485	M4	248.7	0.03
66485	O1	301.4	0.74
66485	M6	180	0.01
66485	MK3	131.3	0.02
66485	MN4	185.4	0.01
66485	NU2	46.5	0.05
66485	MU2	338.1	0.04
66485	2N2	331.6	0.07
66485	OO1	318.9	0.03
66485	S1	318.3	0.05
66485	M1	327.1	0.05
66485	J1	324.4	0.07
66485	SSA	216.2	0.13
66485	SA	277.7	0.31
66485	RHO1	292.6	0.03
66485	Q1	293.5	0.15
66485	T2	7.8	0.01
66485	R2	308.5	0.02
66485	2Q1	301.5	0.03
66485	P1	316	0.29
66485	2SM2	270.6	0.01
66485	M3	163.4	0.01
66485	L2	38.6	0.03
66485	2MK3	192.8	0.01
66485	K2	325.1	0.06
66485	MS4	303.1	0.02
66486	M2	340.4	0.83
66486	S2	336.4	0.4
66486	N2	335.4	0.25
66486	K1	300.1	1.07
66486	M4	224.5	0.13
66486	O1	285.5	0.78
66486	M6	321.7	0.02
66486	NU2	336.2	0.05
66486	S6	260.2	0.01
66486	MU2	344.5	0.02
66486	2N2	330.1	0.03
66486	OO1	314.7	0.03
66486	LDA2	338.6	0.01
66486	M1	292.8	0.06
66486	J1	307.3	0.06
66486	SSA	216.2	0.13
66486	SA	277.7	0.31
66486	MF	208.4	0.08
66486	RHO1	279.3	0.03
66486	Q1	278.2	0.15
66486	T2	336.6	0.02
66486	2Q1	271.1	0.02
66486	P1	299	0.35
66486	L2	345.6	0.02
66486	K2	336.1	0.11
66487	M2	340.6	1.39
66487	S2	353.3	0.48
66487	N2	322.4	0.38
66487	K1	287.6	1.17
66487	M4	218.2	0.03
66487	O1	272.1	0.81
66487	M6	243	0.03
66487	S4	326.6	0.01
66487	NU2	324.9	0.08
66487	MU2	327.9	0.03
66487	2N2	304.3	0.05
66487	OO1	303.1	0.04
66487	LDA2	346.5	0.01
66487	M1	279.9	0.06
66487	J1	295.3	0.07
66487	SSA	216.2	0.13
66487	SA	277.7	0.31
66487	MF	208.4	0.08
66487	RHO1	265.4	0.03
66487	Q1	264.4	0.16
66487	T2	352.8	0.03
66487	2Q1	256.7	0.02
66487	P1	286.4	0.39
66487	L2	358.8	0.04
66487	K2	354.3	0.13
66487	M8	229.8	0.01
66488	M2	25.6	0.4
66488	S2	323.8	0.28
66488	N2	12.3	0.26
66488	K1	310.7	1.03
66488	M4	203.9	0.04
66488	O1	296.5	0.73
66488	M6	151.2	0.02
66488	NU2	14.2	0.05
66488	MU2	87.4	0.01
66488	2N2	359	0.04
66488	OO1	325.1	0.03
66488	M1	303.7	0.05
66488	J1	317.8	0.06
66488	SSA	216.2	0.13
66488	SA	277.7	0.31
66488	MF	208.4	0.08
66488	RHO1	290.4	0.03
66488	Q1	289.4	0.14
66488	T2	326.3	0.02
66488	2Q1	282.3	0.02
66488	P1	309.7	0.34
66488	L2	39	0.01
66488	K2	318.8	0.08
66488	M8	96	0.01
66489	M2	334.4	1.47
66489	S2	355	0.54
66489	N2	319	0.35
66489	K1	288.2	1.2
66489	M4	193.5	0.02
66489	O1	272.1	0.84
66489	M6	334.9	0.01
66489	S4	246.8	0.01
66489	NU2	321.1	0.07
66489	MU2	313.7	0.04
66489	2N2	303.6	0.05
66489	OO1	304.2	0.04
66489	LDA2	344	0.01
66489	M1	280.2	0.06
66489	J1	296.1	0.07
66489	SSA	216.2	0.13
66489	SA	277.7	0.31
66489	MF	208.4	0.08
66489	RHO1	265.2	0.03
66489	Q1	264.1	0.16
66489	T2	354.3	0.03
66489	2Q1	256.1	0.02
66489	P1	287	0.4
66489	L2	349.9	0.04
66489	K2	356.8	0.15
66490	M2	65.2	1.35
66490	S2	5.1	0.09
66490	N2	24.5	0.44
66490	K1	308.7	1.31
66490	M4	200.2	0.03
66490	O1	296.1	0.93
66490	M6	168.5	0.01
66490	NU2	30	0.09
66490	MU2	155.4	0.03
66490	2N2	343.9	0.06
66490	OO1	321.3	0.04
66490	LDA2	37.3	0.01
66490	M1	302.5	0.07
66490	J1	315	0.07
66490	RHO1	290.7	0.04
66490	Q1	289.8	0.18
66490	T2	7.5	0.01
66490	2Q1	283.6	0.02
66490	P1	307.8	0.43
66490	L2	105.8	0.04
66490	K2	0.2	0.02
66490	M8	102	0.01
66491	M2	356.3	1.67
66491	S2	6.3	0.52
66491	N2	329.4	0.43
66491	K1	292.5	1.48
66491	M4	208.6	0.08
66491	O1	274.9	1.01
66491	NU2	333	0.08
66491	MU2	16.8	0.04
66491	2N2	302.6	0.06
66491	OO1	310.2	0.04
66491	LDA2	0.9	0.01
66491	M1	283.8	0.07
66491	J1	301.3	0.08
66491	SSA	216.2	0.13
66491	SA	277.7	0.31
66491	MF	208.4	0.08
66491	RHO1	267.3	0.04
66491	Q1	266.1	0.2
66491	T2	5.9	0.03
66491	2Q1	257.3	0.03
66491	P1	291.2	0.49
66491	L2	23.1	0.05
66491	K2	7.1	0.14
66492	M2	117.2	2.32
66492	S2	294.3	0.07
66492	N2	67.9	0.82
66492	K1	321.9	1.59
66492	M4	106.2	0.06
66492	O1	305.7	1.08
66492	M6	71.8	0.03
66492	S4	76.7	0.01
66492	NU2	74.5	0.16
66492	S6	7.2	0.01
66492	MU2	300.2	0.06
66492	2N2	18.5	0.11
66492	OO1	338.1	0.05
66492	LDA2	199.4	0.02
66492	M1	313.9	0.08
66492	J1	329.9	0.09
66492	SSA	241.9	0.02
66492	SA	243.7	0.23
66492	RHO1	298.8	0.04
66492	Q1	297.7	0.21
66492	2Q1	289.6	0.03
66492	P1	320.7	0.52
66492	L2	166.6	0.07
66492	K2	308.6	0.02
66493	M2	51.8	0.77
66493	S2	18.5	0.42
66493	N2	46.2	0.35
66493	K1	312.4	1.34
66493	M4	276.7	0.07
66493	O1	292.3	0.85
66493	M6	238.6	0.04
66493	S4	230.9	0.01
66493	NU2	47	0.07
66493	MU2	85.1	0.02
66493	2N2	40.7	0.05
66493	OO1	332.6	0.04
66493	LDA2	36.4	0.01
66493	M1	302.5	0.06
66493	J1	322.4	0.07
66493	SSA	216.2	0.13
66493	SA	277.7	0.31
66493	RHO1	283.6	0.03
66493	Q1	282.3	0.16
66493	T2	19.9	0.03
66493	2Q1	272.3	0.02
66493	P1	310.9	0.45
66493	L2	57.3	0.02
66493	K2	15.8	0.11
66494	M2	17.3	0.76
66494	S2	12.8	0.47
66494	N2	29.7	0.27
66494	K1	307.7	1.3
66494	M4	299.7	0.1
66494	O1	287.2	0.8
66494	M6	173.5	0.01
66494	S4	236.8	0.01
66494	NU2	28.1	0.05
66494	MU2	21.6	0.02
66494	2N2	42.2	0.03
66494	OO1	328.2	0.04
66494	LDA2	15.2	0.01
66494	M1	297.5	0.06
66494	J1	317.8	0.06
66494	SSA	216.2	0.13
66494	SA	277.7	0.31
66494	RHO1	278.3	0.03
66494	Q1	277	0.15
66494	T2	13	0.03
66494	2Q1	266.8	0.02
66494	P1	306.1	0.43
66494	L2	4.8	0.02
66494	K2	12.5	0.13
66495	M2	334	2.07
66495	S2	357.4	0.7
66495	N2	311.8	0.48
66495	K1	285.1	1.32
66495	M4	86.2	0.02
66495	O1	269.8	0.87
66495	M6	173.3	0.04
66495	S4	208.8	0.01
66495	NU2	314.8	0.09
66495	MU2	310.5	0.05
66495	2N2	289.6	0.06
66495	OO1	300.5	0.04
66495	LDA2	344.8	0.01
66495	M1	277.5	0.06
66495	J1	292.7	0.07
66495	SA	258.6	0.35
66495	MF	170	0.1
66495	RHO1	263.2	0.03
66495	Q1	262.1	0.17
66495	T2	356.5	0.04
66495	R2	358.3	0.01
66495	2Q1	254.5	0.02
66495	P1	283.9	0.44
66495	L2	356.1	0.06
66495	K2	359.3	0.19
66496	M2	206.5	3.39
66496	S2	5.9	0.04
66496	N2	154.9	1.06
66496	K1	3.8	2.13
66496	M4	229.5	0.09
66496	O1	343.5	1.33
66496	M6	316.3	0.05
66496	MK3	174.6	0.03
66496	S4	217.3	0.01
66496	MN4	182.5	0.04
66496	NU2	167.5	0.21
66496	MU2	75.6	0.16
66496	2N2	108.2	0.14
66496	OO1	34.9	0.07
66496	LDA2	246.5	0.05
66496	S1	163.2	0.06
66496	M1	45	0.09
66496	J1	9.9	0.07
66496	SSA	241.9	0.02
66496	SA	243.7	0.23
66496	RHO1	341.4	0.05
66496	Q1	340.8	0.24
66496	T2	118	0.03
66496	R2	197.5	0.01
66496	2Q1	342.8	0.03
66496	P1	358.5	0.67
66496	2SM2	88.6	0.01
66496	M3	52.5	0.03
66496	L2	230.5	0.13
66496	2MK3	236.1	0.06
66496	K2	242.9	0.04
66496	M8	19.9	0.01
66496	MS4	253.9	0.02
66497	M2	117.6	0.74
66497	S2	4.4	0.03
66497	N2	64.7	0.24
66497	K1	339.9	1.04
66497	O1	326.1	0.69
66497	NU2	71.8	0.05
66497	S6	103.5	0.02
66497	MU2	230.9	0.02
66497	2N2	11.8	0.03
66497	OO1	353.7	0.03
66497	LDA2	65.1	0.01
66497	M1	333.1	0.05
66497	J1	346.8	0.06
66497	SSA	222.3	0.08
66497	SA	235.6	0.19
66497	MF	175.7	0.09
66497	RHO1	320.2	0.03
66497	Q1	319.3	0.13
66497	2Q1	312.4	0.02
66497	P1	338.9	0.34
66497	L2	170.5	0.02
66497	K2	355.2	0.01
66498	M2	262.7	3.82
66498	S2	321.3	0.07
66498	N2	208.9	1.22
66498	K1	26.8	2.43
66498	M4	53	0.21
66498	O1	3.6	1.41
66498	M6	149.2	0.1
66498	S4	266	0.02
66498	NU2	216.1	0.24
66498	S6	232.3	0.01
66498	MU2	204.1	0.09
66498	2N2	155.1	0.16
66498	OO1	50.1	0.06
66498	LDA2	289.9	0.03
66498	M1	15.3	0.1
66498	J1	38.4	0.11
66498	RHO1	353.6	0.05
66498	Q1	352.1	0.27
66498	2Q1	340.6	0.04
66498	P1	25.1	0.81
66498	L2	316.5	0.11
66498	K2	326.1	0.02
66498	M8	250.2	0.03
66499	M2	95	0.82
66499	S2	195.8	0.01
66499	N2	49.2	0.28
66499	K1	326.7	0.95
66499	M4	13	0.01
66499	O1	312.8	0.64
66499	MK3	300.9	0.01
66499	NU2	58.6	0.05
66499	MU2	350.1	0.04
66499	2N2	5.7	0.05
66499	OO1	353	0.03
66499	S1	97.9	0.03
66499	M1	329	0.04
66499	J1	342.7	0.06
66499	SSA	222.3	0.08
66499	SA	235.6	0.19
66499	MF	175.7	0.09
66499	RHO1	306.4	0.02
66499	Q1	303.1	0.12
66499	T2	344.4	0.01
66499	2Q1	300.5	0.02
66499	P1	323	0.3
66499	M3	171.7	0.01
66499	2MK3	325.9	0.01
66499	K2	48.1	0.01
66500	M2	228.2	3.15
66500	S2	21.2	0.1
66500	N2	158.7	1.18
66500	K1	182.3	2.54
66500	M4	258.8	0.05
66500	O1	148.5	1.61
66500	M6	288.3	0.03
66500	S4	310.7	0.02
66500	NU2	168	0.23
66500	S6	230.6	0.01
66500	MU2	70.5	0.07
66500	2N2	89.2	0.16
66500	OO1	216.1	0.07
66500	LDA2	301.4	0.02
66500	M1	165.5	0.11
66500	J1	199.1	0.13
66500	RHO1	134	0.06
66500	Q1	131.7	0.31
66500	T2	12.7	0.01
66500	2Q1	115	0.04
66500	P1	179.7	0.84
66500	L2	297.7	0.09
66500	K2	33.5	0.03
66500	M8	125.5	0.01
66501	M2	336.9	5.97
66501	S2	90.4	0.24
66501	N2	279.4	1.85
66501	K1	53.1	2.75
66501	M4	174.2	0.12
66501	O1	30.4	1.73
66501	M6	56.1	0.02
66501	NU2	287.1	0.36
66501	MU2	224.7	0.14
66501	2N2	221.9	0.25
66501	OO1	75.7	0.07
66501	LDA2	29	0.04
66501	M1	41.8	0.12
66501	J1	64.3	0.13
66501	RHO1	20.7	0.07
66501	Q1	19.2	0.33
66501	T2	85.9	0.01
66501	2Q1	7.9	0.05
66501	P1	51.4	0.91
66501	L2	34.4	0.17
66501	K2	99.7	0.07
66501	M8	119.6	0.01
66502	M2	315.5	1.25
66502	S2	125.9	0.05
66502	N2	221	0.27
66502	K1	201.3	2.12
66502	M4	129	0.19
66502	O1	166.5	1.37
66502	M6	45.1	0.04
66502	S4	330.1	0.02
66502	NU2	233.6	0.05
66502	S6	132.5	0.01
66502	MU2	145.2	0.03
66502	2N2	126.4	0.04
66502	OO1	236.2	0.06
66502	LDA2	34.6	0.01
66502	M1	184	0.1
66502	J1	218.6	0.11
66502	RHO1	151.5	0.05
66502	Q1	149.2	0.27
66502	2Q1	131.9	0.04
66502	P1	198.7	0.7
66502	L2	50.1	0.04
66502	K2	139.7	0.01
66502	M8	127.6	0.01
66503	M2	254.3	2.39
66503	S2	45.3	0.07
66503	N2	183.3	0.85
66503	K1	192.7	2.43
66503	M4	89.3	0.11
66503	O1	159.8	1.57
66503	M6	245.3	0.02
66503	S4	2.4	0.02
66503	NU2	192.8	0.16
66503	MU2	106.3	0.04
66503	2N2	112.2	0.11
66503	OO1	225.5	0.07
66503	LDA2	294.9	0.01
66503	M1	176.4	0.11
66503	J1	208.9	0.12
66503	RHO1	145.7	0.06
66503	Q1	143.5	0.31
66503	2Q1	127.2	0.04
66503	P1	190.2	0.8
66503	L2	325.3	0.07
66503	K2	49.2	0.02
66503	M8	178.1	0.01
66504	M2	269.6	2.34
66504	S2	41.1	0.07
66504	N2	194.6	0.87
66504	K1	198.3	2.63
66504	M4	113.3	0.2
66504	O1	163.2	1.6
66504	M6	241.2	0.04
66504	S4	245.4	0.01
66504	NU2	204.6	0.17
66504	S6	106.4	0.01
66504	MU2	176.5	0.06
66504	2N2	119.5	0.11
66504	OO1	233.4	0.07
66504	LDA2	330.6	0.02
66504	M1	180.9	0.11
66504	J1	215.7	0.13
66504	RHO1	148.1	0.06
66504	Q1	145.8	0.31
66504	2Q1	128.4	0.04
66504	P1	195.6	0.87
66504	L2	344.6	0.07
66504	K2	51.7	0.02
66504	M8	164.5	0.01
66505	M2	282.4	2
66505	S2	14.7	0.03
66505	N2	208.1	0.54
66505	K1	199.6	2.37
66505	M4	115.4	0.26
66505	O1	163.9	1.56
66505	M6	254.6	0.02
66505	S4	322.7	0.02
66505	NU2	218	0.1
66505	S6	146	0.01
66505	MU2	227.8	0.05
66505	2N2	133.8	0.07
66505	OO1	235.3	0.07
66505	LDA2	325.2	0.01
66505	M1	181.9	0.11
66505	J1	217.3	0.12
66505	RHO1	148.6	0.06
66505	Q1	146.2	0.31
66505	2Q1	128.5	0.04
66505	P1	196.9	0.78
66505	L2	356.6	0.06
66505	K2	22.2	0.01
66505	M8	161.4	0.01
66506	M2	346.6	7.129
66506	S2	96.5	0.236
66506	N2	292.8	2.031
66506	K1	59.1	2.743
66506	M4	218.4	0.407
66506	O1	34.4	1.657
66506	M6	357.8	0.115
66506	S4	200.1	0.013
66506	NU2	300	0.394
66506	S6	93.7	0.003
66506	MU2	239	0.171
66506	2N2	239	0.269
66506	OO1	83.7	0.069
66506	LDA2	36.5	0.049
66506	M1	46.8	0.115
66506	J1	71.3	0.128
66506	RHO1	23.8	0.062
66506	Q1	22.2	0.322
66506	T2	92.5	0.013
66506	R2	109.5	0.003
66506	2Q1	9.9	0.043
66506	P1	57.3	0.906
66506	L2	40.3	0.2
66506	K2	105.3	0.066
66506	M8	187.1	0.056
66507	M2	239.5	3.06
66507	S2	25.3	0.11
66507	N2	166.5	1.15
66507	K1	186.9	2.6
66507	M4	92.6	0.02
66507	O1	152.6	1.64
66507	M6	314.9	0.03
66507	S4	310.8	0.01
66507	NU2	176.3	0.22
66507	S6	252.4	0.01
66507	MU2	96.6	0.07
66507	2N2	93.4	0.15
66507	OO1	221.2	0.07
66507	LDA2	306	0.02
66507	M1	169.8	0.11
66507	J1	203.9	0.13
66507	RHO1	137.8	0.06
66507	Q1	135.5	0.32
66507	T2	19.5	0.01
66507	2Q1	118.5	0.04
66507	P1	184.3	0.86
66507	L2	312.7	0.09
66507	K2	37.2	0.03
66507	M8	80.1	0.01
66508	M2	251.4	2.87
66508	S2	43	0.09
66508	N2	181.1	1.06
66508	K1	190.7	2.63
66508	M4	94.1	0.07
66508	O1	156.2	1.66
66508	M6	271.5	0.02
66508	S4	329	0.01
66508	NU2	190.5	0.21
66508	MU2	103.2	0.07
66508	2N2	110.7	0.14
66508	OO1	225.2	0.07
66508	LDA2	320.3	0.02
66508	M1	173.6	0.12
66508	J1	207.8	0.13
66508	RHO1	141.4	0.06
66508	Q1	139.1	0.32
66508	T2	34.7	0.01
66508	2Q1	122	0.04
66508	P1	188.1	0.87
66508	L2	321.7	0.08
66508	K2	54.8	0.02
66508	M8	228.6	0.01
66509	M2	7	7.16
66509	S2	105.7	0.26
66509	N2	314.3	1.89
66509	K1	69.4	2.6
66509	M4	278.2	0.62
66509	O1	41.1	1.51
66509	M6	94.4	0.21
66509	S4	334.5	0.01
66509	NU2	321.3	0.37
66509	S6	100	0.01
66509	MU2	272.6	0.17
66509	2N2	261.4	0.25
66509	OO1	97.7	0.07
66509	LDA2	50.9	0.05
66509	M1	55.4	0.11
66509	J1	83.5	0.12
66509	RHO1	29	0.06
66509	Q1	27.1	0.3
66509	T2	100.8	0.02
66509	2Q1	13	0.04
66509	P1	67.4	0.86
66509	L2	60	0.2
66509	K2	113.6	0.07
66509	M8	321.7	0.07
66510	M2	164.8	2.72
66510	S2	301.8	0.2
66510	N2	101	0.61
66510	K1	98.6	1.88
66510	M4	16.6	0.12
66510	O1	67.5	1.29
66510	M6	170.7	0.06
66510	S4	97.6	0.01
66510	NU2	109.5	0.12
66510	MU2	62.9	0.06
66510	2N2	37.3	0.08
66510	OO1	129.7	0.06
66510	LDA2	229	0.02
66510	M1	83.2	0.09
66510	J1	114	0.1
66510	RHO1	54.1	0.05
66510	Q1	52.1	0.25
66510	T2	296.4	0.01
66510	2Q1	36.6	0.03
66510	P1	96.3	0.62
66510	L2	228.6	0.08
66510	K2	312.8	0.05
66510	M8	13.5	0.01
66511	M2	182.6	3.61
66511	S2	8.2	0.34
66511	N2	110.8	0.83
66511	K1	107.8	2.14
66511	M4	125.1	0.12
66511	O1	72.7	1.35
66511	M6	226.2	0.06
66511	MK3	156.7	0.07
66511	S4	128.4	0.01
66511	MN4	67.6	0.07
66511	NU2	146.5	0.18
66511	MU2	343.4	0.11
66511	2N2	124.2	0.1
66511	OO1	150.5	0.06
66511	LDA2	258.2	0.1
66511	S1	287.7	0.18
66511	M1	150.7	0.08
66511	J1	69.8	0.05
66511	RHO1	60.9	0.1
66511	Q1	62.5	0.26
66511	T2	13.3	0.13
66511	R2	218.9	0.36
66511	2Q1	154	0.03
66511	P1	96.6	0.72
66511	2SM2	90.1	0.02
66511	M3	87.1	0.04
66511	L2	248.9	0.35
66511	2MK3	103.8	0.03
66511	K2	242.4	0.21
66511	M8	142.4	0.01
66511	MS4	307.5	0.01
66512	M2	211	4.16
66512	S2	88	0.32
66512	N2	140.6	0.87
66512	K1	121	2.18
66512	M4	284	0.08
66512	O1	85.2	1.43
66512	M6	323.3	0.1
66512	MK3	220	0.21
66512	S4	192.3	0.01
66512	MN4	191.3	0.05
66512	NU2	172.3	0.23
66512	MU2	1.3	0.1
66512	2N2	115.3	0.17
66512	OO1	181.2	0.06
66512	LDA2	277.1	0.11
66512	S1	255.3	0.09
66512	M1	159.4	0.09
66512	J1	57.1	0.05
66512	RHO1	76.7	0.07
66512	Q1	82.7	0.27
66512	T2	78.9	0.2
66512	R2	298.9	0.33
66512	2Q1	119.6	0.06
66512	P1	110.4	0.67
66512	2SM2	108.5	0.02
66512	M3	109.7	0.09
66512	L2	275.8	0.42
66512	2MK3	154.5	0.16
66512	K2	292.2	0.13
66512	M8	333.2	0.01
66512	MS4	76	0.03
66513	M2	242.4	3.39
66513	S2	44	0.14
66513	N2	177.3	0.66
66513	K1	143.5	1.95
66513	M4	33	0.33
66513	O1	107.5	1.42
66513	M6	97.9	0.06
66513	S4	271.6	0.01
66513	NU2	186	0.13
66513	MU2	85.2	0.08
66513	2N2	112.3	0.09
66513	OO1	179.6	0.06
66513	LDA2	315.5	0.02
66513	M1	125.7	0.1
66513	J1	161.4	0.11
66513	RHO1	92	0.05
66513	Q1	89.6	0.27
66513	T2	37.1	0.01
66513	2Q1	71.7	0.04
66513	P1	140.8	0.64
66513	L2	307.6	0.1
66513	K2	56.7	0.04
66513	M8	218.3	0.02
66514	M2	232	2.94
66514	S2	323.7	0.14
66514	N2	174.3	0.79
66514	K1	164.5	1.57
66514	M4	322.2	0.11
66514	O1	125.3	0.97
66514	M6	333.7	0.09
66514	S4	146.6	0.01
66514	NU2	182	0.15
66514	S6	70.2	0.01
66514	MU2	141.9	0.07
66514	2N2	116.7	0.1
66514	OO1	204	0.04
66514	LDA2	273.8	0.02
66514	M1	145.1	0.07
66514	J1	184.1	0.08
66514	RHO1	108.4	0.04
66514	Q1	105.8	0.19
66514	T2	320.5	0.01
66514	2Q1	86.3	0.03
66514	P1	161.6	0.52
66514	L2	289.5	0.08
66514	K2	331	0.04
66515	M2	241.9	2.89
66515	S2	336.1	0.22
66515	N2	188.6	0.76
66515	K1	189.9	0.7
66515	M4	323	0.05
66515	O1	149.8	0.45
66515	M6	106.2	0.02
66515	S4	24.5	0.01
66515	NU2	195.8	0.15
66515	MU2	148.4	0.07
66515	2N2	135.4	0.1
66515	OO1	230	0.02
66515	LDA2	285.4	0.02
66515	M1	170	0.03
66515	J1	209.8	0.03
66515	RHO1	132.6	0.02
66515	Q1	129.9	0.09
66515	T2	331.8	0.01
66515	2Q1	109.5	0.01
66515	P1	186.9	0.23
66515	L2	295.2	0.08
66515	K2	343.7	0.06
66516	M2	260.3	3.62
66516	S2	18	0.21
66516	N2	192	0.71
66516	K1	148.3	1.96
66516	M4	71.1	0.26
66516	O1	110.9	1.44
66516	M6	112.1	0.11
66516	S4	293.4	0.01
66516	NU2	201.2	0.14
66516	MU2	144.3	0.08
66516	2N2	123.8	0.09
66516	OO1	185.6	0.06
66516	LDA2	314.3	0.03
66516	M1	129.8	0.1
66516	J1	166.8	0.11
66516	RHO1	94.9	0.06
66516	Q1	92.4	0.28
66516	T2	12.9	0.01
66516	2Q1	73.9	0.04
66516	P1	145.4	0.65
66516	L2	328.5	0.1
66516	K2	27.5	0.06
66516	M8	285	0.03
66517	M2	283.9	3.33
66517	S2	46.4	0.15
66517	N2	217	0.6
66517	K1	163	1.87
66517	M4	115.8	0.28
66517	O1	124.2	1.38
66517	M6	191.3	0.1
66517	S4	328.8	0.02
66517	NU2	225.9	0.12
66517	MU2	149.2	0.06
66517	2N2	150	0.08
66517	OO1	201.7	0.06
66517	LDA2	306.1	0.01
66517	M1	143.7	0.1
66517	J1	182.1	0.11
66517	RHO1	107.5	0.05
66517	Q1	105	0.27
66517	T2	47.3	0.01
66517	2Q1	85.6	0.04
66517	P1	160.1	0.62
66517	L2	350.8	0.1
66517	K2	52.6	0.04
66517	M8	14	0.02
66518	M2	233.6	3.07
66518	S2	315.3	0.32
66518	N2	181.7	0.79
66518	K1	262.5	0.9
66518	M4	25.4	0.04
66518	O1	221.3	0.46
66518	M6	314.5	0.05
66518	NU2	188.7	0.15
66518	S6	74.5	0.01
66518	MU2	180.4	0.07
66518	2N2	129.9	0.1
66518	OO1	303.2	0.02
66518	LDA2	271.2	0.02
66518	M1	241.9	0.03
66518	J1	282.6	0.04
66518	RHO1	203.7	0.02
66518	Q1	200.9	0.09
66518	T2	312	0.02
66518	2Q1	180.6	0.01
66518	P1	259.4	0.3
66518	L2	285.4	0.09
66518	K2	321.9	0.09
66518	M8	59.5	0.01
66519	M2	251.6	3.74
66519	S2	337.6	0.33
66519	N2	200.1	0.95
66519	K1	215.4	1.03
66519	M4	13.6	0.09
66519	O1	170	0.62
66519	M6	45	0.06
66519	S4	77.3	0.01
66519	NU2	207	0.18
66519	MU2	184.6	0.09
66519	2N2	148.6	0.13
66519	OO1	260.8	0.03
66519	LDA2	291.1	0.03
66519	M1	192.9	0.04
66519	J1	237.8	0.05
66519	RHO1	150.7	0.02
66519	Q1	147.6	0.12
66519	T2	334.3	0.02
66519	2Q1	125.4	0.02
66519	P1	212	0.34
66519	L2	303.3	0.1
66519	K2	344.5	0.09
66519	M8	271.3	0.01
66520	M2	348.4	2.31
66520	S2	173.4	0.07
66520	N2	277.5	0.42
66520	K1	201.2	1.54
66520	M4	238.8	0.25
66520	O1	161	1.25
66520	M6	343	0.05
66520	S4	33.7	0.01
66520	NU2	287	0.08
66520	MU2	176.6	0.02
66520	2N2	206.6	0.06
66520	OO1	241.1	0.06
66520	LDA2	21.2	0.01
66520	M1	181.2	0.09
66520	J1	220.9	0.1
66520	RHO1	143.9	0.05
66520	Q1	141.2	0.24
66520	2Q1	121.4	0.03
66520	P1	198.1	0.51
66520	L2	59.2	0.07
66520	K2	179.9	0.02
66520	M8	237.1	0.02
66521	M2	62.7	0.9
66521	S2	21.2	0.12
66521	N2	0.3	0.2
66521	K1	248.6	0.79
66521	M4	38.4	0.17
66521	O1	205.2	0.72
66521	M6	97.3	0.01
66521	MK3	217	0.21
66521	S4	273.4	0.01
66521	MN4	328.1	0.07
66521	NU2	81.3	0.04
66521	MU2	196.1	0.04
66521	2N2	7.3	0.09
66521	OO1	281.5	0.02
66521	LDA2	159.3	0.06
66521	S1	185.5	0.11
66521	M1	271.7	0.06
66521	J1	206.5	0.08
66521	RHO1	222.7	0.02
66521	Q1	187.3	0.13
66521	2Q1	169.4	0.03
66521	P1	258.1	0.31
66521	2SM2	279.1	0.02
66521	M3	97.9	0.07
66521	L2	149.6	0.11
66521	2MK3	162.2	0.15
66521	K2	181	0.04
66521	M8	163.2	0.01
66521	MS4	241.2	0.02
66522	M2	285.1	1.65
66522	S2	46.8	0.2
66522	N2	228.5	0.47
66522	K1	285.7	0.82
66522	M4	196.3	0.22
66522	O1	265.4	0.45
66522	M6	66.7	0.02
66522	S4	64.9	0.03
66522	NU2	236.1	0.09
66522	S6	99.9	0.01
66522	MU2	168.4	0.03
66522	2N2	172	0.06
66522	OO1	305.3	0.02
66522	LDA2	298.8	0.01
66522	M1	275.5	0.03
66522	J1	295.4	0.04
66522	RHO1	256.8	0.02
66522	Q1	255.5	0.09
66522	T2	43.8	0.01
66522	2Q1	245.5	0.01
66522	P1	284.2	0.27
66522	L2	341.3	0.05
66522	K2	52.2	0.06
66522	M8	335.6	0.01
66523	M2	54.1	0.65
66523	S2	182.5	0.12
66523	N2	8.4	0.24
66523	K1	23.9	0.62
66523	M4	37.4	0.11
66523	O1	0.7	0.46
66523	M6	113	0.01
66523	S4	278	0.01
66523	NU2	14.5	0.05
66523	MU2	283.7	0.02
66523	2N2	322.8	0.03
66523	OO1	47	0.02
66523	M1	12.3	0.03
66523	J1	35.1	0.04
66523	RHO1	351	0.02
66523	Q1	349.2	0.09
66523	T2	176.8	0.01
66523	2Q1	338.6	0.01
66523	P1	22.1	0.2
66523	L2	99.6	0.02
66523	K2	193	0.03
66524	M2	284.5	0.96
66524	S2	22.1	0.22
66524	N2	235.4	0.17
66524	K1	6.6	0.3
66524	M4	30.8	0.03
66524	O1	341.3	0.19
66524	M6	223.9	0.02
66524	NU2	242.1	0.03
66524	MU2	186.9	0.02
66524	2N2	186.4	0.02
66524	OO1	32	0.01
66524	LDA2	329.8	0.01
66524	M1	354	0.01
66524	J1	19.3	0.01
66524	RHO1	330.3	0.01
66524	Q1	328.7	0.04
66524	T2	18.1	0.01
66524	P1	4.8	0.1
66524	L2	331.8	0.03
66524	K2	30	0.06
66525	M2	257.4	0.55
66525	S2	2.2	0.12
66525	N2	199.3	0.18
66525	K1	129.4	1.35
66525	M4	194.3	0.04
66525	O1	77.1	0.76
66525	NU2	207.1	0.04
66525	2N2	141.2	0.02
66525	OO1	181.7	0.03
66525	M1	103.2	0.05
66525	J1	155.6	0.06
66525	SSA	195.3	0.02
66525	RHO1	54.6	0.03
66525	Q1	50.9	0.15
66525	R2	164.8	0.02
66525	2Q1	24.8	0.02
66525	P1	129.2	0.45
66525	L2	315.5	0.02
66525	K2	2.3	0.03
66526	M2	222.5	0.98
66526	S2	324.4	0.2
66526	N2	167.2	0.17
66526	K1	345.3	0.34
66526	M4	22.6	0.02
66526	O1	317.4	0.2
66526	M6	68.2	0.01
66526	NU2	174.7	0.03
66526	MU2	120.8	0.02
66526	2N2	111.8	0.02
66526	OO1	13.3	0.01
66526	LDA2	269.8	0.01
66526	M1	331.5	0.01
66526	J1	359.2	0.02
66526	RHO1	305.2	0.01
66526	Q1	303.4	0.04
66526	T2	320.4	0.01
66526	2Q1	289.5	0.01
66526	P1	343.2	0.11
66526	L2	277.3	0.03
66526	K2	332.7	0.05
66526	M8	57.5	0.01
66527	M2	65.4	1.04
66527	S2	175.9	0.19
66527	N2	9	0.26
66527	K1	95.4	0.37
66527	M4	150.5	0.04
66527	O1	53.6	0.2
66527	M6	0.9	0.01
66527	NU2	16.5	0.05
66527	MU2	314.9	0.03
66527	2N2	312.6	0.03
66527	OO1	136.8	0.01
66527	LDA2	116.7	0.01
66527	M1	74.8	0.01
66527	J1	116.2	0.02
66527	RHO1	35.8	0.01
66527	Q1	32.8	0.04
66527	T2	171.5	0.01
66527	P1	92.3	0.12
66527	L2	121.8	0.03
66527	K2	184.9	0.05
66528	M2	196.4	1.05
66528	S2	294.3	0.21
66528	N2	142.5	0.2
66528	K1	335.9	0.37
66528	M4	339.5	0.02
66528	O1	303	0.23
66528	M6	26.7	0.02
66528	NU2	149.7	0.04
66528	MU2	98.6	0.03
66528	2N2	88.8	0.03
66528	OO1	8.9	0.01
66528	LDA2	241.9	0.01
66528	M1	319.5	0.02
66528	J1	352	0.02
66528	RHO1	288.8	0.01
66528	Q1	286.8	0.04
66528	T2	290.4	0.01
66528	2Q1	270.2	0.01
66528	P1	333.4	0.12
66528	L2	250.4	0.03
66528	K2	302.2	0.06
66529	M2	219.9	0.51
66529	S2	287	0.05
66529	N2	172.4	0.16
66529	K1	112.3	1.15
66529	M4	98.9	0.02
66529	O1	65	0.69
66529	MK3	295.5	0.05
66529	MN4	13.5	0.01
66529	NU2	146.8	0.04
66529	MU2	23.4	0.02
66529	2N2	39.9	0.03
66529	OO1	121.9	0.08
66529	LDA2	175.5	0.03
66529	S1	62.9	0.12
66529	M1	204.3	0.11
66529	J1	7.7	0.06
66529	SSA	194.3	0.06
66529	SA	126	0.24
66529	RHO1	330.9	0.06
66529	Q1	44.4	0.1
66529	T2	54.7	0.01
66529	R2	77.3	0.01
66529	2Q1	9.4	0.05
66529	P1	108.4	0.39
66529	2SM2	144.4	0.01
66529	M3	215.9	0.01
66529	2MK3	223.6	0.03
66529	K2	307.8	0.07
66529	MS4	162.1	0.01
66530	M2	232.5	0.59
66530	S2	348.5	0.12
66530	N2	177.2	0.18
66530	K1	112.2	1.46
66530	M4	158.3	0.01
66530	O1	58.6	0.86
66530	M6	324.4	0.01
66530	NU2	184.6	0.04
66530	MU2	116.5	0.01
66530	2N2	121.8	0.02
66530	OO1	165.8	0.04
66530	M1	85.6	0.06
66530	J1	138.8	0.07
66530	RHO1	35.7	0.03
66530	Q1	32.1	0.17
66530	T2	343.9	0.01
66530	2Q1	5.5	0.02
66530	P1	108.2	0.48
66530	L2	287.8	0.02
66530	K2	357.9	0.03
66531	M2	37.7	0.36
66531	S2	106.9	0.05
66531	N2	340.2	0.12
66531	K1	146.9	0.29
66531	M4	181.2	0.02
66531	O1	79	0.2
66531	M6	64.4	0.01
66531	MK3	66.5	0.03
66531	MN4	145.5	0.01
66531	NU2	343.8	0.02
66531	MU2	245.2	0.02
66531	2N2	283.4	0.02
66531	OO1	239.6	0.02
66531	S1	130.3	0.08
66531	SSA	245.7	0.39
66531	SA	128.7	0.18
66531	Q1	67.5	0.04
66531	T2	166.8	0.01
66531	P1	137.6	0.08
66531	2MK3	33.4	0.01
66531	K2	88.8	0.06
66531	MS4	238.7	0.01
66532	M2	270.2	0.48
66532	S2	6.3	0.13
66532	N2	211.7	0.17
66532	K1	128.8	1.42
66532	M4	272.5	0.02
66532	O1	72.4	0.76
66532	M6	359.7	0.01
66532	S4	39.3	0.01
66532	NU2	219.5	0.03
66532	MU2	171.4	0.01
66532	2N2	153.4	0.02
66532	OO1	185.8	0.03
66532	M1	101.1	0.05
66532	J1	157.4	0.06
66532	SSA	245.7	0.39
66532	SA	128.7	0.18
66532	RHO1	47.8	0.03
66532	Q1	44.1	0.15
66532	T2	2.6	0.01
66532	2Q1	15.9	0.02
66532	P1	124.5	0.47
66532	L2	328.8	0.01
66532	K2	13.9	0.03
66533	M2	186.9	0.43
66533	S2	293.9	0.09
66533	N2	116.3	0.11
66533	K1	254.6	0.14
66533	M4	219.1	0.08
66533	O1	121.8	0.06
66533	S4	235.5	0.01
66533	NU2	125.7	0.02
66533	MU2	81	0.01
66533	2N2	46.2	0.01
66533	Q1	55.8	0.01
66533	P1	244.6	0.05
66533	L2	258.4	0.01
66533	K2	302.8	0.02
66534	M2	206	0.36
66534	S2	321.7	0.11
66534	N2	130.1	0.1
66534	K1	262.9	0.11
66534	M4	270.3	0.09
66534	O1	118.5	0.03
66534	S4	318.1	0.01
66534	NU2	140.2	0.02
66534	MU2	117.5	0.01
66534	2N2	54.2	0.01
66534	Q1	47	0.01
66534	T2	317.1	0.01
66534	P1	252.1	0.04
66534	L2	281.9	0.01
66534	K2	331.1	0.03
66535	M2	188.5	0.36
66535	S2	313.2	0.09
66535	N2	123.9	0.12
66535	K1	265.2	0.14
66535	M4	213.8	0.03
66535	O1	130.3	0.06
66535	M6	194.5	0.01
66535	S4	74.6	0.01
66535	NU2	132.5	0.02
66535	S6	38.3	0.01
66535	MU2	89.5	0.01
66535	2N2	59.2	0.02
66535	Q1	63.3	0.01
66535	T2	308.2	0.01
66535	P1	255.1	0.05
66535	L2	253.2	0.01
66535	K2	323.3	0.02
66536	M2	199.4	0.41
66536	S2	296.9	0.1
66536	N2	124.4	0.1
66536	K1	266.3	0.12
66536	M4	182.8	0.01
66536	O1	108.2	0.06
66536	NU2	134.5	0.02
66536	MU2	125.9	0.01
66536	2N2	49.5	0.01
66536	Q1	29.8	0.01
66536	T2	293	0.01
66536	P1	254.5	0.04
66536	L2	274.4	0.01
66536	K2	304.8	0.03
66537	M2	213.6	0.45
66537	S2	317.4	0.12
66537	N2	140.4	0.09
66537	K1	284.1	0.1
66537	M4	150.4	0.01
66537	O1	92.2	0.03
66537	M6	283.6	0.01
66537	S4	219.2	0.01
66537	NU2	150.2	0.02
66537	MU2	109.7	0.01
66537	2N2	67.2	0.01
66537	T2	313.3	0.01
66537	P1	296.7	0.03
66537	L2	286.7	0.01
66537	K2	325.9	0.03
66538	M2	64.2	0.7
66538	S2	132.8	0.17
66538	N2	355.9	0.15
66538	K1	4.5	0.23
66538	M4	309.6	0.01
66538	O1	159.7	0.11
66538	S4	239.8	0.01
66538	NU2	5.1	0.03
66538	MU2	354.1	0.02
66538	2N2	287.9	0.02
66538	Q1	192	0.02
66538	T2	129.9	0.01
66538	P1	5.4	0.08
66538	L2	132.6	0.02
66538	K2	138.3	0.05
66539	M2	62.5	0.71
66539	S2	135.3	0.15
66539	N2	3.4	0.19
66539	K1	1.7	0.17
66539	M4	20.8	0.03
66539	O1	33.2	0.02
66539	M6	224.1	0.02
66539	NU2	11.4	0.04
66539	MU2	349.6	0.02
66539	2N2	304	0.02
66539	LDA2	96.4	0.01
66539	Q1	93.7	0.01
66539	T2	132.6	0.01
66539	P1	359.2	0.06
66539	L2	121.6	0.02
66539	K2	141.2	0.04
66540	M2	265.3	0.4
66540	S2	332.3	0.12
66540	N2	208.4	0.11
66540	K1	334	0.13
66540	M4	294.1	0.02
66540	O1	66.4	0.05
66540	M6	113.5	0.01
66540	NU2	216	0.02
66540	MU2	226.2	0.01
66540	2N2	151.5	0.02
66540	Q1	112.3	0.01
66540	T2	329.6	0.01
66540	P1	340.9	0.04
66540	L2	322.2	0.01
66540	K2	337.8	0.03
66540	M8	231	0.01
66541	M2	312	0.37
66541	S2	22	0.09
66541	N2	252	0.1
66541	K1	335.4	0.13
66541	M4	111.6	0.02
66541	O1	182.2	0.04
66541	M6	278.2	0.01
66541	NU2	260	0.02
66541	MU2	241.9	0.01
66541	2N2	192	0.01
66541	Q1	106.2	0.01
66541	T2	19.2	0.01
66541	P1	323.9	0.04
66541	L2	11.9	0.01
66541	K2	27.7	0.02
66542	M2	133.3	0.19
66542	S2	210.9	0.05
66542	N2	66.6	0.05
66542	K1	56.8	0.16
66542	M4	184.1	0.02
66542	O1	33.9	0.04
66542	M6	103.8	0.01
66542	S4	352.9	0.01
66542	NU2	76.3	0.01
66542	2N2	1.6	0.01
66542	Q1	38.9	0.01
66542	P1	52.4	0.05
66542	L2	195.6	0.01
66542	K2	216.6	0.01
66543	M2	194.4	0.12
66543	S2	280.7	0.03
66543	N2	110.2	0.02
66543	K1	25.3	0.17
66543	M4	139.3	0.01
66543	O1	196.1	0.06
66543	M6	11.3	0.01
66543	Q1	198.9	0.01
66543	P1	21.2	0.06
66543	K2	287	0.01
66544	M2	280.8	0.24
66544	S2	335	0.05
66544	N2	225.9	0.06
66544	K1	84.6	0.07
66544	O1	127.3	0.03
66544	MK3	75.2	0.01
66544	NU2	236.2	0.01
66544	MU2	77.7	0.01
66544	2N2	143.1	0.01
66544	OO1	108.5	0.01
66544	S1	297.8	0.04
66544	SSA	239.6	0.29
66544	SA	144.5	0.53
66544	Q1	132	0.01
66544	T2	46.2	0.02
66544	R2	9.4	0.03
66544	P1	95.4	0.02
66544	L2	324.9	0.01
66544	2MK3	335.9	0.01
66544	K2	314.6	0.03
66545	M2	268.7	0.34
66545	S2	334.8	0.12
66545	N2	210.8	0.1
66545	K1	30.4	0.12
66545	M4	79.3	0.01
66545	O1	129.3	0.04
66545	NU2	218.6	0.02
66545	MU2	233.4	0.01
66545	2N2	152.9	0.01
66545	Q1	178.3	0.01
66545	T2	332.1	0.01
66545	P1	37.9	0.04
66545	L2	326.6	0.01
66545	K2	340.1	0.03
66546	M2	298.8	0.25
66546	S2	3	0.03
66546	N2	245.2	0.08
66546	K1	50.6	0.06
66546	O1	162.4	0.03
66546	NU2	252.4	0.02
66546	MU2	234.5	0.01
66546	2N2	191.6	0.01
66546	SSA	239.6	0.29
66546	SA	144.5	0.53
66546	P1	59	0.02
66546	L2	352.3	0.01
66546	K2	8.3	0.01
66547	M2	270	0.18
66547	S2	320	0.08
66547	N2	248.3	0.02
66547	K1	150.3	0.07
66547	O1	153.2	0.06
66547	S1	91.8	0.01
66547	J1	141.3	0.01
66547	SSA	252.4	0.22
66547	SA	155.5	0.39
66547	RHO1	109.6	0.01
66547	Q1	130.9	0.01
66547	T2	7.3	0.01
66547	R2	353.6	0.01
66547	2Q1	127.1	0.01
66547	P1	147	0.03
66547	K2	306	0.02
66548	M2	275.7	0.21
66548	S2	314.9	0.1
66548	N2	258.2	0.03
66548	K1	158.4	0.08
66548	O1	186.8	0.11
66548	NU2	234.3	0.007
66548	MU2	273.3	0.007
66548	2N2	241.1	0.003
66548	OO1	173.9	0.003
66548	LDA2	252.7	0.003
66548	S1	290.6	0.01
66548	M1	207.1	0.003
66548	J1	159.7	0.01
66548	SSA	249	0.203
66548	SA	145.3	0.384
66548	RHO1	169.2	0.007
66548	Q1	173.6	0.036
66548	T2	337.8	0.01
66548	R2	343.4	0.01
66548	2Q1	94.1	0.007
66548	P1	177.2	0.03
66548	L2	299	0.007
66548	K2	318.4	0.03
66549	M2	287.7	0.23
66549	S2	334.6	0.11
66549	N2	268.5	0.03
66549	K1	156.3	0.05
66549	O1	195.9	0.15
66549	NU2	271.2	0.01
66549	2N2	249.3	0.01
66549	OO1	116.8	0.01
66549	M1	176.1	0.01
66549	J1	136.5	0.01
66549	RHO1	213	0.01
66549	Q1	215.7	0.03
66549	T2	334.6	0.01
66549	P1	156.4	0.02
66549	L2	306.9	0.01
66549	K2	334.6	0.03
66550	M2	308.2	0.213
66550	S2	349.5	0.095
66550	N2	289.2	0.036
66550	K1	172	0.075
66550	O1	198	0.098
66550	NU2	291.9	0.007
66550	2N2	270.3	0.007
66550	OO1	145.9	0.003
66550	M1	185	0.007
66550	J1	158.9	0.007
66550	RHO1	209.2	0.003
66550	Q1	190	0.033
66550	T2	349.4	0.007
66550	2Q1	224	0.003
66550	P1	171.8	0.026
66550	L2	327.1	0.007
66550	K2	349.6	0.026
66551	M2	281	0.1936
66551	S2	328.3	0.082
66551	N2	253.5	0.0164
66551	K1	144.4	0.0853
66551	M4	180.6	0.0033
66551	O1	189.9	0.0591
66551	S4	179	0.0033
66551	NU2	257.2	0.0033
66551	S6	59	0.0033
66551	MU2	306.5	0.0033
66551	2N2	226.1	0.0033
66551	OO1	98.9	0.0033
66551	M1	166.9	0.0033
66551	J1	121.8	0.0066
66551	RHO1	209.4	0.0033
66551	Q1	212.5	0.0131
66551	T2	326.4	0.0066
66551	2Q1	235	0.0033
66551	P1	147.8	0.0295
66551	L2	308.4	0.0066
66551	K2	332.1	0.023
66551	M8	266.5	0.0033
66552	M2	15.3	0.33
66552	S2	42.5	0.06
66552	N2	356.3	0.07
66552	K1	217.1	0.26
66552	M4	278	0.01
66552	O1	215.2	0.19
66552	NU2	359	0.01
66552	MU2	348.2	0.01
66552	2N2	336.1	0.01
66552	OO1	219.6	0.01
66552	M1	216.2	0.01
66552	J1	218.2	0.01
66552	SSA	47.2	0.06
66552	SA	181.8	0.2
66552	RHO1	214.4	0.01
66552	Q1	214.3	0.04
66552	P1	216.9	0.09
66552	L2	35	0.01
66552	K2	44.6	0.02
66553	M2	344.6	0.1
66553	S2	19.7	0.03
66553	N2	310.6	0.01
66553	K1	228.5	0.27
66553	M4	263.1	0.01
66553	O1	222.2	0.2
66553	OO1	234.1	0.01
66553	S1	242.5	0.01
66553	M1	239.5	0.01
66553	J1	229.9	0.02
66553	MM	322.1	0.02
66553	SA	179.8	0.18
66553	MF	0.1	0.05
66553	RHO1	219.7	0.01
66553	Q1	209.3	0.03
66553	P1	229	0.08
66553	L2	359.8	0.01
66553	K2	16	0.01
66554	M2	16	0.18
66554	S2	26.4	0.03
66554	N2	2	0.03
66554	K1	226.2	0.28
66554	M4	298.4	0.01
66554	O1	222.7	0.19
66554	S4	225.5	0.01
66554	NU2	3.9	0.01
66554	OO1	229.8	0.01
66554	M1	224.5	0.01
66554	J1	228	0.02
66554	MM	333.6	0.02
66554	SSA	47.2	0.06
66554	SA	181.8	0.2
66554	MF	352.4	0.04
66554	RHO1	221.2	0.01
66554	Q1	220.9	0.04
66554	2Q1	219.2	0.01
66554	P1	226	0.09
66554	K2	27.3	0.01
66555	M2	23.8	0.15
66555	S2	22.8	0.03
66555	N2	11.4	0.03
66555	K1	228.9	0.27
66555	O1	222	0.19
66555	NU2	5.2	0.01
66555	2N2	4.5	0.01
66555	OO1	235.5	0.01
66555	S1	165.5	0.01
66555	M1	242.1	0.01
66555	J1	230.4	0.02
66555	MM	324.3	0.02
66555	SSA	53.2	0.05
66555	SA	191.6	0.2
66555	MSF	266.2	0.01
66555	MF	358.6	0.05
66555	RHO1	216.6	0.01
66555	Q1	210.4	0.03
66555	P1	230.8	0.09
66555	L2	38.3	0.01
66555	K2	16.7	0.01
66556	M2	328.9	0.05
66556	S2	11.7	0.03
66556	N2	232.2	0.01
66556	K1	237	0.28
66556	M4	290.7	0.01
66556	O1	228.6	0.21
66556	OO1	248.4	0.01
66556	S1	240.7	0.02
66556	M1	273.5	0.01
66556	J1	234.3	0.02
66556	MM	349	0.03
66556	SA	173.7	0.21
66556	MF	356.9	0.05
66556	RHO1	213.6	0.01
66556	Q1	210.6	0.03
66556	T2	192.5	0.01
66556	P1	236.1	0.09
66556	K2	355.4	0.01
66556	MS4	355.2	0.01
66557	M2	11.3	0.3
66557	S2	70.5	0.06
66557	N2	354.9	0.06
66557	K1	224.5	0.23
66557	M4	308.6	0.02
66557	O1	215.9	0.19
66557	M6	325.6	0.01
66557	MK3	57.9	0.01
66557	MN4	257.8	0.01
66557	NU2	353.9	0.02
66557	MU2	53.6	0.01
66557	2N2	26.6	0.01
66557	OO1	231.4	0.01
66557	LDA2	319.1	0.01
66557	S1	191.3	0.04
66557	M1	207.7	0.01
66557	J1	226.2	0.02
66557	Q1	192.1	0.03
66557	T2	111.3	0.01
66557	R2	318	0.04
66557	P1	231.6	0.06
66557	2SM2	154.4	0.01
66557	L2	342.3	0.01
66557	2MK3	73.5	0.01
66557	K2	21.4	0.03
66557	MS4	17.3	0.01
66558	M2	23.8	0.15
66558	S2	136.3	0.02
66558	N2	22.9	0.03
66558	K1	230.9	0.25
66558	M4	283.8	0.01
66558	O1	221.7	0.2
66558	MN4	205.2	0.01
66558	NU2	30.2	0.01
66558	MU2	99	0.01
66558	OO1	224.9	0.01
66558	S1	197.3	0.03
66558	M1	215.2	0.01
66558	J1	225.7	0.02
66558	SSA	47.2	0.06
66558	SA	181.8	0.2
66558	RHO1	245.2	0.01
66558	Q1	196.8	0.03
66558	T2	172.2	0.02
66558	R2	344	0.05
66558	2Q1	168	0.01
66558	P1	233.9	0.06
66558	L2	32.3	0.01
66558	K2	26	0.03
66559	M2	28.1	0.14
66559	S2	18.8	0.02
66559	N2	6.2	0.03
66559	K1	228.4	0.27
66559	O1	222.9	0.2
66559	NU2	9.1	0.01
66559	OO1	233.9	0.01
66559	M1	225.6	0.01
66559	J1	231.1	0.02
66559	RHO1	220.5	0.01
66559	Q1	220.2	0.04
66559	2Q1	217.5	0.01
66559	P1	228	0.09
66559	K2	18	0.01
66560	M2	12.8	0.35
66560	S2	38	0.06
66560	N2	351.6	0.08
66560	K1	218.2	0.25
66560	O1	217.1	0.19
66560	M6	319	0.01
66560	NU2	354.3	0.02
66560	MU2	347.6	0.01
66560	2N2	330.4	0.01
66560	OO1	220.2	0.01
66560	M1	217.6	0.01
66560	J1	218.9	0.02
66560	SSA	47.2	0.06
66560	SA	181.8	0.2
66560	RHO1	216.5	0.01
66560	Q1	216.5	0.04
66560	2Q1	215.8	0.01
66560	P1	218.1	0.08
66560	L2	34.3	0.01
66560	K2	39.9	0.02
66561	M2	43.9	0.07
66561	S2	51.9	0.05
66561	N2	44	0.02
66561	K1	237.3	0.24
66561	M4	282.4	0.01
66561	O1	229	0.2
66561	S4	191.2	0.01
66561	MU2	136.9	0.01
66561	OO1	247.4	0.01
66561	LDA2	227.4	0.01
66561	S1	199.2	0.06
66561	M1	219.5	0.01
66561	J1	226.4	0.02
66561	SSA	60	0.05
66561	SA	184.9	0.19
66561	Q1	208.3	0.03
66561	R2	263.4	0.04
66561	P1	248	0.06
66561	2SM2	175	0.01
66561	M3	51.1	0.01
66561	L2	150.4	0.01
66561	K2	325.5	0.02
66562	M2	23.1	0.13
66562	S2	9.9	0.03
66562	N2	13.7	0.03
66562	K1	229.5	0.26
66562	M4	302	0.01
66562	O1	221.6	0.2
66562	NU2	6.6	0.01
66562	MU2	80.8	0.01
66562	OO1	236.2	0.01
66562	S1	201.1	0.01
66562	M1	240.8	0.01
66562	J1	235.1	0.02
66562	SSA	46	0.05
66562	SA	181.2	0.21
66562	MF	358.7	0.05
66562	RHO1	214.8	0.01
66562	Q1	208.8	0.04
66562	P1	231.2	0.08
66562	L2	41.6	0.01
66562	K2	5	0.01
66563	M2	16.1	0.42
66563	S2	44.2	0.07
66563	N2	354	0.1
66563	K1	210.2	0.22
66563	O1	213.2	0.17
66563	NU2	356.9	0.02
66563	MU2	348	0.01
66563	2N2	331.4	0.01
66563	OO1	207.3	0.01
66563	M1	211.7	0.01
66563	J1	208.8	0.01
66563	SSA	47.2	0.06
66563	SA	181.9	0.2
66563	RHO1	214.5	0.01
66563	Q1	214.7	0.03
66563	P1	210.4	0.08
66563	L2	38.2	0.01
66563	K2	46.6	0.02
66564	M2	15.9	0.413
66564	S2	73.2	0.151
66564	N2	359.7	0.098
66564	K1	216.1	0.22
66564	M4	358.9	0.007
66564	O1	216	0.187
66564	MK3	65.9	0.003
66564	NU2	5.9	0.023
66564	MU2	35.5	0.01
66564	2N2	3.8	0.007
66564	OO1	234.4	0.013
66564	LDA2	333.5	0.01
66564	S1	207.5	0.043
66564	M1	212.7	0.01
66564	J1	218	0.02
66564	SSA	47.2	0.062
66564	SA	181.8	0.2
66564	RHO1	186.2	0.007
66564	Q1	198.5	0.033
66564	T2	96.8	0.049
66564	R2	256.4	0.079
66564	2Q1	128.3	0.003
66564	P1	220.2	0.056
66564	2SM2	139	0.003
66564	L2	328.7	0.023
66564	K2	329.6	0.023
66565	M2	12.9	0.32
66565	S2	32.5	0.06
66565	N2	347.3	0.07
66565	K1	224.4	0.25
66565	M4	335.5	0.01
66565	O1	222.7	0.19
66565	NU2	345.4	0.01
66565	MU2	23.6	0.01
66565	2N2	337.7	0.01
66565	OO1	231.5	0.01
66565	LDA2	31.6	0.01
66565	S1	218.5	0.02
66565	M1	236.7	0.01
66565	J1	227.1	0.02
66565	SSA	60.7	0.07
66565	SA	191	0.19
66565	MF	0.1	0.05
66565	RHO1	207.7	0.01
66565	Q1	209.3	0.04
66565	T2	13.8	0.01
66565	P1	225	0.07
66565	L2	38.5	0.01
66565	K2	29.9	0.01
66566	M2	17.8	0.37
66566	S2	37.1	0.06
66566	N2	353.2	0.08
66566	K1	222.5	0.25
66566	O1	223.3	0.2
66566	NU2	353.6	0.01
66566	MU2	26.7	0.01
66566	2N2	346.5	0.01
66566	OO1	234.5	0.01
66566	S1	250.7	0.02
66566	M1	248.4	0.01
66566	J1	220.2	0.02
66566	MM	332.1	0.03
66566	SA	197.7	0.14
66566	MF	350.5	0.06
66566	RHO1	215.1	0.01
66566	Q1	208.6	0.04
66566	T2	11.7	0.01
66566	P1	223.6	0.08
66566	L2	33.3	0.01
66566	K2	33.6	0.02
66567	M2	343	0.09
66567	S2	9.2	0.03
66567	N2	307.6	0.01
66567	K1	232.8	0.27
66567	M4	250	0.01
66567	O1	226.1	0.21
66567	MN4	151.1	0.01
66567	OO1	244.5	0.01
66567	S1	234.9	0.02
66567	M1	255.1	0.01
66567	J1	233.6	0.02
66567	MM	340.2	0.02
66567	SA	179	0.18
66567	MF	0.2	0.05
66567	RHO1	221.6	0.01
66567	Q1	212.1	0.04
66567	2Q1	203	0.01
66567	P1	232.6	0.08
66567	L2	5.9	0.01
66567	K2	5.7	0.01
66568	M2	14.7	0.5
66568	S2	359.3	0.12
66568	N2	350.1	0.12
66568	K1	220.6	0.23
66568	O1	224.2	0.19
66568	NU2	356.2	0.02
66568	MU2	11.6	0.01
66568	2N2	322.4	0.01
66568	OO1	221.1	0.01
66568	LDA2	44.5	0.01
66568	S1	205.6	0.03
66568	M1	213.6	0.01
66568	J1	230.2	0.02
66568	SSA	37.1	0.07
66568	SA	186.9	0.18
66568	Q1	205.5	0.03
66568	T2	337.5	0.04
66568	R2	140.8	0.1
66568	P1	223.3	0.08
66568	L2	6.4	0.03
66568	K2	156.2	0.03
66569	M2	12.5	0.52
66569	S2	41.2	0.08
66569	N2	345.2	0.12
66569	K1	219.2	0.24
66569	O1	222.8	0.19
66569	NU2	342.6	0.02
66569	MU2	10.9	0.02
66569	2N2	338	0.02
66569	OO1	223.5	0.01
66569	LDA2	46.9	0.01
66569	S1	224.4	0.02
66569	M1	230.8	0.01
66569	J1	226.1	0.02
66569	MM	318.4	0.03
66569	SSA	258.8	0.01
66569	SA	197.4	0.11
66569	MSF	298.4	0.01
66569	MF	357.2	0.06
66569	RHO1	208.4	0.01
66569	Q1	212.9	0.04
66569	T2	18.3	0.01
66569	P1	220.1	0.08
66569	L2	38.5	0.02
66569	K2	39.4	0.02
66570	M2	29.6	0.14
66570	S2	307.1	0.03
66570	N2	16.2	0.03
66570	K1	230.4	0.25
66570	M4	298.3	0.01
66570	O1	230	0.2
66570	NU2	14.1	0.02
66570	MU2	148.3	0.02
66570	2N2	168.5	0.01
66570	OO1	238.3	0.02
66570	LDA2	57	0.01
66570	S1	227.8	0.03
66570	M1	231.9	0.01
66570	J1	236.5	0.02
66570	SSA	37.1	0.07
66570	SA	186.9	0.18
66570	RHO1	149.3	0.01
66570	Q1	205	0.04
66570	R2	85.9	0.03
66570	P1	229	0.07
66570	M3	38.4	0.01
66570	L2	51.9	0.02
66570	K2	93.9	0.01
66571	M2	18.1	0.05
66571	S2	0.5	0.02
66571	N2	85	0.01
66571	K1	231.8	0.27
66571	M4	281.3	0.01
66571	O1	227.8	0.2
66571	NU2	51.7	0.01
66571	MU2	132.7	0.01
66571	OO1	240.3	0.01
66571	S1	215.8	0.01
66571	M1	257	0.01
66571	J1	230.5	0.02
66571	MM	318	0.02
66571	SA	184.5	0.18
66571	MF	352.9	0.05
66571	RHO1	216.4	0.01
66571	Q1	211.7	0.04
66571	2Q1	204	0.01
66571	P1	231.3	0.09
66571	K2	336.6	0.01
66572	M2	20.3	0.51
66572	S2	49.4	0.07
66572	N2	358.3	0.12
66572	K1	227.7	0.29
66572	M4	250.9	0.01
66572	O1	226.4	0.25
66572	MK3	35.4	0.01
66572	NU2	1.5	0.02
66572	MU2	18.8	0.02
66572	2N2	337.3	0.02
66572	OO1	252.2	0.01
66572	LDA2	41.8	0.01
66572	S1	153	0.02
66572	M1	266.1	0.01
66572	J1	214	0.02
66572	MM	354.5	0.02
66572	SSA	38.3	0.05
66572	SA	181.4	0.18
66572	RHO1	214.9	0.01
66572	Q1	211.2	0.05
66572	T2	24.9	0.01
66572	2Q1	218.6	0.01
66572	P1	228.9	0.09
66572	L2	21.3	0.01
66572	2MK3	24.5	0.01
66572	K2	49.6	0.02
66573	M2	65.9	0.04
66573	S2	5	0.04
66573	N2	137.7	0.02
66573	K1	231.1	0.27
66573	M4	266.8	0.01
66573	O1	229.7	0.19
66573	OO1	231.5	0.01
66573	M1	229.9	0.01
66573	J1	231.3	0.02
66573	RHO1	229.8	0.01
66573	Q1	229.5	0.04
66573	2Q1	228.4	0.01
66573	P1	230.8	0.09
66573	K2	0.3	0.01
66574	M2	11.2	0.03
66574	S2	280.5	0.08
66574	N2	82.9	0.02
66574	K1	238	0.25
66574	M4	282.9	0.01
66574	O1	231.2	0.19
66574	MN4	164.9	0.01
66574	NU2	5	0.02
66574	MU2	97.5	0.01
66574	OO1	235.8	0.02
66574	LDA2	197.6	0.01
66574	S1	184.5	0.06
66574	M1	228.9	0.01
66574	J1	249.6	0.02
66574	SSA	42.6	0.05
66574	SA	184.2	0.2
66574	RHO1	239.6	0.01
66574	Q1	217.1	0.03
66574	R2	87.9	0.09
66574	P1	250.4	0.07
66574	L2	227.2	0.01
66574	K2	124.1	0.04
66575	M2	3.3	0.57
66575	S2	39.2	0.09
66575	N2	337.5	0.13
66575	K1	209.3	0.32
66575	O1	211.2	0.26
66575	MK3	77.8	0.01
66575	NU2	341.8	0.03
66575	MU2	356.5	0.02
66575	2N2	318.9	0.02
66575	OO1	215.3	0.01
66575	S1	230.3	0.02
66575	M1	233.1	0.01
66575	J1	212.7	0.02
66575	MM	319.4	0.02
66575	SA	187.7	0.16
66575	MF	350.5	0.05
66575	RHO1	200	0.01
66575	Q1	199.4	0.05
66575	T2	24.2	0.01
66575	P1	208.8	0.1
66575	L2	10.3	0.02
66575	K2	42	0.03
66576	M2	39.1	0.03
66576	S2	7.1	0.03
66576	N2	102.9	0.02
66576	K1	233.8	0.27
66576	M4	312.2	0.01
66576	O1	232.8	0.17
66576	MN4	209.2	0.01
66576	MU2	205.6	0.01
66576	2N2	123.9	0.01
66576	OO1	241.1	0.02
66576	S1	133.5	0.02
66576	M1	250.5	0.01
66576	J1	232.7	0.02
66576	MM	344.2	0.02
66576	SSA	42.6	0.05
66576	SA	184.2	0.2
66576	MF	353	0.05
66576	RHO1	250	0.01
66576	Q1	224.4	0.03
66576	T2	50	0.01
66576	R2	104	0.01
66576	P1	240.3	0.08
66576	L2	276.7	0.01
66576	K2	40.4	0.02
66577	M2	9.9	0.02
66577	S2	9.8	0.03
66577	K1	233.4	0.26
66577	M4	295.2	0.01
66577	O1	227.8	0.18
66577	OO1	251.2	0.01
66577	S1	203.7	0.02
66577	M1	280.1	0.01
66577	J1	233	0.02
66577	MM	341.3	0.02
66577	SA	179.9	0.18
66577	MF	357.4	0.05
66577	RHO1	204	0.01
66577	Q1	215.3	0.03
66577	P1	233.6	0.08
66577	L2	340.2	0.01
66577	K2	2.8	0.01
66578	M2	7.3	0.2
66578	S2	332.1	0.01
66578	N2	3.2	0.04
66578	K1	231.5	0.2
66578	M4	276.4	0.02
66578	O1	224.9	0.16
66578	M6	351.9	0.01
66578	MN4	229.6	0.01
66578	MU2	110.3	0.01
66578	OO1	237.3	0.01
66578	LDA2	230	0.01
66578	S1	192.1	0.05
66578	M1	212.1	0.01
66578	J1	231.7	0.02
66578	SSA	42.6	0.05
66578	SA	184.2	0.2
66578	RHO1	189.7	0.01
66578	Q1	199.2	0.03
66578	T2	241.3	0.02
66578	R2	38.1	0.04
66578	P1	239.9	0.06
66578	M3	93.9	0.01
66578	L2	145.2	0.01
66578	K2	51.4	0.03
66578	MS4	345.8	0.01
66579	M2	55	0.03
66579	S2	311.1	0.06
66579	N2	50.6	0.03
66579	K1	231.8	0.22
66579	M4	304.3	0.01
66579	O1	226.8	0.18
66579	NU2	185.7	0.01
66579	MU2	98.3	0.02
66579	OO1	241.9	0.01
66579	LDA2	201.5	0.02
66579	S1	205.3	0.06
66579	M1	221.6	0.01
66579	J1	223.2	0.02
66579	SSA	42.6	0.05
66579	SA	184.2	0.2
66579	RHO1	207.6	0.01
66579	Q1	206.1	0.03
66579	T2	280.7	0.04
66579	R2	98.3	0.03
66579	P1	242.2	0.06
66579	M3	84.5	0.01
66579	L2	143.9	0.02
66579	K2	19	0.01
66580	M2	14.5	0.48
66580	S2	41	0.07
66580	N2	350.7	0.11
66580	K1	213.8	0.19
66580	M4	321.3	0.01
66580	O1	210.8	0.15
66580	MK3	331.9	0.01
66580	NU2	350.3	0.02
66580	MU2	11.4	0.01
66580	2N2	334.9	0.02
66580	OO1	223	0.01
66580	LDA2	35.5	0.01
66580	S1	209.6	0.02
66580	M1	219	0.01
66580	J1	218.2	0.02
66580	MM	317	0.03
66580	SSA	99.8	0.02
66580	SA	187.7	0.16
66580	MSF	351.2	0.01
66580	MF	356.7	0.05
66580	RHO1	200.1	0.01
66580	Q1	194.3	0.03
66580	T2	17.7	0.01
66580	P1	217.6	0.06
66580	L2	46.7	0.02
66580	2MK3	351.8	0.01
66580	K2	39.5	0.02
66581	M2	0.6	0.48
66581	S2	29.9	0.1
66581	N2	340.1	0.11
66581	K1	208.5	0.24
66581	M4	278	0.01
66581	O1	205.4	0.19
66581	M6	358.5	0.01
66581	NU2	334.1	0.02
66581	MU2	349.6	0.02
66581	2N2	323.5	0.02
66581	OO1	221.5	0.01
66581	LDA2	6.8	0.01
66581	S1	317.9	0.01
66581	M1	220.8	0.01
66581	J1	217.6	0.01
66581	MM	330.3	0.02
66581	SA	180	0.28
66581	MF	355.4	0.05
66581	RHO1	206.2	0.01
66581	Q1	193.3	0.04
66581	T2	12.2	0.01
66581	P1	211	0.07
66581	L2	20.8	0.02
66581	K2	26.4	0.02
66582	M2	5.6	0.35
66582	S2	34.8	0.06
66582	N2	341.9	0.07
66582	K1	220.5	0.19
66582	M4	315.7	0.02
66582	O1	218.5	0.16
66582	M6	321.4	0.01
66582	NU2	345.1	0.01
66582	MU2	201.9	0.01
66582	2N2	318	0.01
66582	OO1	222.3	0.01
66582	M1	219.5	0.01
66582	J1	221.3	0.01
66582	SSA	42.6	0.05
66582	SA	184.2	0.2
66582	RHO1	217.7	0.01
66582	Q1	217.6	0.03
66582	P1	220.4	0.07
66582	L2	29.4	0.01
66582	K2	37.2	0.02
66583	M2	7.6	0.08
66583	S2	17.2	0.04
66583	N2	27.1	0.01
66583	K1	233.1	0.27
66583	M4	0.6	0.04
66583	O1	231.5	0.2
66583	MK3	355.6	0.01
66583	MN4	322.6	0.01
66583	OO1	235	0.01
66583	S1	204.6	0.01
66583	M1	264.9	0.01
66583	J1	229.2	0.02
66583	MM	348	0.02
66583	SA	180.9	0.14
66583	MF	359.3	0.07
66583	RHO1	226	0.01
66583	Q1	219.9	0.04
66583	P1	232.5	0.08
66583	2MK3	11.3	0.01
66583	K2	12.9	0.01
66583	MS4	54.5	0.01
64580	M2	42.3	1.801
64580	S2	67.1	0.388
64580	N2	35.5	0.362
64580	K1	68.7	0.595
64580	M4	62	0.169
64580	O1	47.9	0.321
64580	M6	308.5	0.172
64580	MK3	107.1	0.112
64580	S4	286.9	0.005
64580	MN4	52.2	0.083
64580	S6	46.5	0.005
64580	2N2	285.6	0.056
64580	OO1	134.1	0.097
64580	M1	60.2	0.017
64580	J1	92.3	0.034
64580	Q1	65.3	0.057
64580	2Q1	166.3	0.019
64580	P1	68.3	0.169
64580	2SM2	263.7	0.02
64580	M3	186.6	0.036
64580	L2	38.4	0.125
64580	2MK3	103.8	0.093
64580	K2	23.3	0.118
64580	M8	341.2	0.045
64580	MS4	107.5	0.068
64581	M2	42.4	1.977
64581	S2	67.6	0.423
64581	N2	35.8	0.395
64581	K1	69	0.649
64581	M4	59.8	0.181
64581	O1	49	0.348
64581	M6	308.3	0.19
64581	MK3	106.3	0.118
64581	S4	290.6	0.005
64581	MN4	50.2	0.09
64581	S6	46.3	0.006
64581	2N2	284.5	0.063
64581	OO1	135.6	0.109
64581	M1	63.5	0.019
64581	J1	94.6	0.036
64581	Q1	65.9	0.065
64581	2Q1	164	0.02
64581	P1	68.6	0.185
64581	2SM2	261.5	0.022
64581	M3	186	0.037
64581	L2	38.3	0.139
64581	2MK3	105.2	0.099
64581	K2	22.4	0.129
64581	M8	338.8	0.05
64581	MS4	105.3	0.074
64582	M2	42.5	2.089
64582	S2	67.9	0.444
64582	N2	36	0.416
64582	K1	69.2	0.686
64582	M4	59.4	0.194
64582	O1	49.1	0.367
64582	M6	308.1	0.201
64582	MK3	106.3	0.125
64582	S4	294	0.003
64582	MN4	49.4	0.095
64582	S6	44.6	0.006
64582	2N2	281.7	0.067
64582	OO1	136.2	0.114
64582	M1	64.6	0.02
64582	J1	96.2	0.036
64582	Q1	65.7	0.07
64582	2Q1	166.6	0.023
64582	P1	68.9	0.196
64582	2SM2	261	0.024
64582	M3	187.8	0.038
64582	L2	38.6	0.149
64582	2MK3	106.6	0.104
64582	K2	21	0.136
64582	M8	337.9	0.055
64582	MS4	104.8	0.08
64583	M2	42.6	2.177
64583	S2	68.3	0.458
64583	N2	36.2	0.431
64583	K1	69.3	0.712
64583	M4	60	0.207
64583	O1	48.9	0.383
64583	M6	308.2	0.209
64583	MK3	107	0.131
64583	S4	297.5	0.003
64583	MN4	49.4	0.1
64583	S6	42.5	0.006
64583	2N2	279	0.071
64583	OO1	136.5	0.12
64583	M1	64.1	0.02
64583	J1	96.8	0.035
64583	Q1	65.1	0.073
64583	2Q1	170	0.027
64583	P1	68.8	0.205
64583	2SM2	262.8	0.025
64583	M3	191.4	0.04
64583	L2	39.4	0.158
64583	2MK3	108.5	0.108
64583	K2	19.5	0.143
64583	M8	337.4	0.06
64583	MS4	105.2	0.086
64584	M2	42.6	2.25
64584	S2	68.7	0.47
64584	N2	36.5	0.444
64584	K1	69.4	0.732
64584	M4	61.2	0.22
64584	O1	48.6	0.397
64584	M6	308.4	0.215
64584	MK3	108.4	0.136
64584	S4	305.9	0.003
64584	MN4	50.2	0.104
64584	S6	49.6	0.004
64584	2N2	277.1	0.075
64584	OO1	136.3	0.127
64584	M1	63	0.021
64584	J1	96.3	0.035
64584	Q1	65	0.075
64584	2Q1	173.7	0.031
64584	P1	68.5	0.21
64584	2SM2	266.7	0.025
64584	M3	195.9	0.041
64584	L2	40.4	0.166
64584	2MK3	110.6	0.113
64584	K2	18.9	0.151
64584	M8	336.6	0.064
64584	MS4	105.7	0.091
64585	M2	42.8	2.313
64585	S2	69	0.481
64585	N2	36.8	0.454
64585	K1	69.4	0.754
64585	M4	62.5	0.233
64585	O1	48.3	0.408
64585	M6	308.8	0.218
64585	MK3	110	0.14
64585	S4	313.6	0.004
64585	MN4	51.4	0.108
64585	S6	61.3	0.004
64585	2N2	276.5	0.079
64585	OO1	135.9	0.132
64585	M1	61.7	0.022
64585	J1	96.3	0.035
64585	Q1	65.2	0.076
64585	2Q1	175.5	0.034
64585	P1	68.8	0.215
64585	2SM2	270.2	0.026
64585	M3	200.3	0.043
64585	L2	40.9	0.173
64585	2MK3	112	0.119
64585	K2	18.4	0.158
64585	M8	335.8	0.069
64585	MS4	106	0.096
64586	M2	42.8	2.363
64586	S2	68.2	0.492
64586	N2	36.9	0.463
64586	K1	68.8	0.764
64586	M4	64.2	0.243
64586	O1	47.6	0.416
64586	M6	308.5	0.217
64586	MK3	111.6	0.141
64586	S4	303.6	0.003
64586	MN4	52	0.11
64586	S6	58.2	0.004
64586	2N2	278.6	0.08
64586	OO1	137.3	0.135
64586	M1	60.2	0.024
64586	J1	96.3	0.034
64586	Q1	63.7	0.078
64586	2Q1	173.7	0.036
64586	P1	66.4	0.222
64586	2SM2	273.8	0.026
64586	M3	200.5	0.043
64586	L2	41.4	0.181
64586	2MK3	114.8	0.124
64586	K2	23.3	0.163
64586	M8	336.4	0.07
64586	MS4	108.4	0.102
64587	M2	42.5	2.356
64587	S2	64	0.527
64587	N2	37	0.459
64587	K1	61.6	0.697
64587	M4	77	0.223
64587	O1	44.6	0.401
64587	M6	306.1	0.178
64587	MK3	132.5	0.131
64587	S4	80.7	0.005
64587	MN4	63.6	0.106
64587	S6	86.3	0.01
64587	2N2	281.9	0.066
64587	OO1	139	0.156
64587	M1	47.1	0.019
64587	J1	114.8	0.035
64587	Q1	54.1	0.079
64587	2Q1	171.6	0.051
64587	P1	47.7	0.276
64587	2SM2	252.8	0.019
64587	M3	225.1	0.049
64587	L2	39.4	0.184
64587	2MK3	138.3	0.128
64587	K2	49.9	0.173
64587	M8	349.1	0.072
64587	MS4	108.3	0.114
64588	M2	79.4	0.414
64588	S2	105.1	0.102
64588	N2	52.7	0.1
64588	K1	82.4	0.149
64588	M4	156.6	0.006
64588	O1	71	0.044
64588	M6	267.2	0.007
64588	MK3	10.5	0.014
64588	S4	155	0.004
64588	MN4	13.1	0.006
64588	NU2	98.2	0.023
64588	S6	208.9	0.001
64588	MU2	297	0.013
64588	2N2	47.8	0.023
64588	OO1	69.4	0.013
64588	LDA2	113.9	0.008
64588	M1	82.2	0.007
64588	J1	104.4	0.019
64588	RHO1	129.8	0.013
64588	Q1	45.6	0.018
64588	2Q1	338.5	0.006
64588	P1	69.3	0.055
64588	2SM2	67.5	0.003
64588	M3	126.2	0.005
64588	L2	102.6	0.021
64588	2MK3	341.2	0.01
64588	K2	101.2	0.024
64588	M8	142.7	0.003
64588	MS4	129	0.016
64589	M2	79.8	0.422
64589	S2	103.9	0.106
64589	N2	53.4	0.1
64589	K1	82.2	0.152
64589	M4	181.2	0.006
64589	O1	66	0.045
64589	M6	254.9	0.006
64589	MK3	10.4	0.013
64589	S4	152.8	0.005
64589	MN4	359.4	0.004
64589	NU2	91.9	0.022
64589	S6	231	0.001
64589	MU2	289.5	0.009
64589	2N2	49.1	0.025
64589	OO1	58.8	0.013
64589	LDA2	120.8	0.008
64589	M1	72.6	0.008
64589	J1	106.9	0.019
64589	RHO1	129.2	0.011
64589	Q1	45.6	0.017
64589	2Q1	336.1	0.006
64589	P1	70.8	0.05
64589	2SM2	52.1	0.003
64589	M3	127.5	0.004
64589	L2	105	0.025
64589	2MK3	3	0.01
64589	K2	104.9	0.025
64589	M8	128	0.002
64589	MS4	129.7	0.015
64590	M2	79.8	0.428
64590	S2	103.7	0.109
64590	N2	54.5	0.1
64590	K1	80.8	0.152
64590	M4	195.4	0.007
64590	O1	62.1	0.047
64590	M6	246.9	0.007
64590	MK3	16.4	0.011
64590	S4	144.7	0.005
64590	MN4	338	0.004
64590	NU2	86.2	0.02
64590	S6	245.5	0.002
64590	MU2	278.2	0.007
64590	2N2	52.2	0.026
64590	OO1	47.3	0.013
64590	LDA2	127.9	0.01
64590	M1	72.8	0.009
64590	J1	106.6	0.016
64590	RHO1	134.4	0.006
64590	Q1	45.2	0.016
64590	2Q1	331.4	0.008
64590	P1	72	0.049
64590	2SM2	58.9	0.003
64590	M3	108.9	0.003
64590	L2	108.5	0.026
64590	2MK3	5.3	0.009
64590	K2	107.3	0.026
64590	M8	90	0.002
64590	MS4	124.4	0.013
64591	M2	79.6	0.431
64591	S2	103.4	0.112
64591	N2	54.7	0.1
64591	K1	79.9	0.151
64591	M4	205.1	0.006
64591	O1	60.4	0.05
64591	M6	234.7	0.007
64591	MK3	27.2	0.011
64591	S4	151.1	0.005
64591	MN4	327	0.005
64591	NU2	81.2	0.021
64591	MU2	261.1	0.004
64591	2N2	54.8	0.027
64591	OO1	49.8	0.014
64591	LDA2	128.7	0.009
64591	M1	74.4	0.008
64591	J1	109.7	0.016
64591	RHO1	154.3	0.006
64591	Q1	56.8	0.015
64591	2Q1	339.2	0.008
64591	P1	72.1	0.048
64591	2SM2	63.6	0.004
64591	M3	100.7	0.002
64591	L2	106.7	0.026
64591	2MK3	10.2	0.008
64591	K2	113.3	0.027
64591	M8	70.3	0.003
64591	MS4	119	0.011
64592	M2	79	0.432
64592	S2	103.4	0.113
64592	N2	54.3	0.101
64592	K1	79.2	0.151
64592	M4	231.7	0.006
64592	O1	59.9	0.052
64592	M6	214	0.006
64592	MK3	36.4	0.01
64592	S4	138.2	0.004
64592	MN4	308.7	0.004
64592	NU2	74.5	0.02
64592	MU2	228.3	0.002
64592	2N2	54	0.029
64592	OO1	49	0.016
64592	LDA2	132.7	0.009
64592	M1	76.3	0.009
64592	J1	110.8	0.015
64592	RHO1	173.4	0.005
64592	Q1	58.5	0.014
64592	2Q1	348.6	0.008
64592	P1	73.3	0.044
64592	2SM2	68.9	0.004
64592	M3	103.8	0.001
64592	L2	103.7	0.025
64592	2MK3	1.5	0.006
64592	K2	115.4	0.03
64592	M8	75.5	0.004
64592	MS4	106.9	0.009
64593	M2	78.4	0.431
64593	S2	103	0.114
64593	N2	54.9	0.1
64593	K1	78.5	0.149
64593	M4	229.6	0.006
64593	O1	59.9	0.055
64593	M6	202.9	0.006
64593	MK3	41.1	0.011
64593	S4	114.5	0.003
64593	MN4	314.2	0.004
64593	NU2	73.1	0.021
64593	S6	128.9	0.001
64593	2N2	56.6	0.028
64593	OO1	50.1	0.017
64593	LDA2	131.1	0.008
64593	M1	73.5	0.009
64593	J1	111.3	0.015
64593	RHO1	199.6	0.005
64593	Q1	63.8	0.013
64593	2Q1	348.8	0.01
64593	P1	75.2	0.044
64593	2SM2	75.3	0.004
64593	M3	89.6	0.002
64593	L2	99.7	0.025
64593	2MK3	351.8	0.005
64593	K2	119.2	0.029
64593	M8	73.5	0.004
64593	MS4	96.3	0.009
64594	M2	77.8	0.429
64594	S2	103.1	0.113
64594	N2	55.1	0.099
64594	K1	78.6	0.148
64594	M4	232.5	0.005
64594	O1	61.5	0.056
64594	M6	181.9	0.005
64594	MK3	51.6	0.01
64594	S4	93.9	0.002
64594	MN4	295.7	0.004
64594	NU2	70.8	0.019
64594	S6	127.1	0.001
64594	MU2	119.6	0.002
64594	2N2	58.2	0.029
64594	OO1	46.3	0.017
64594	LDA2	121.3	0.009
64594	M1	74.5	0.01
64594	J1	112.4	0.017
64594	RHO1	199.8	0.008
64594	Q1	76.3	0.015
64594	2Q1	350	0.011
64594	P1	78.6	0.04
64594	2SM2	83.2	0.004
64594	M3	118.8	0.001
64594	L2	96.5	0.024
64594	2MK3	317.3	0.005
64594	K2	117.6	0.029
64594	M8	83.2	0.005
64594	MS4	81.8	0.008
64595	M2	77	0.427
64595	S2	102.5	0.113
64595	N2	55.7	0.099
64595	K1	78.8	0.147
64595	M4	216.6	0.004
64595	O1	62.9	0.057
64595	M6	169.7	0.007
64595	MK3	67	0.01
64595	S4	75.4	0.002
64595	MN4	313.8	0.004
64595	NU2	73.6	0.02
64595	S6	119.9	0.002
64595	MU2	135.3	0.002
64595	2N2	60.1	0.029
64595	OO1	50.9	0.017
64595	LDA2	111.7	0.01
64595	M1	72.6	0.01
64595	J1	114.2	0.016
64595	RHO1	188.8	0.009
64595	Q1	79.9	0.016
64595	2Q1	350.5	0.012
64595	P1	78.4	0.04
64595	2SM2	87.9	0.004
64595	M3	103.1	0.002
64595	L2	95.3	0.024
64595	2MK3	303.8	0.004
64595	K2	118.2	0.03
64595	M8	81.6	0.005
64595	MS4	71.7	0.009
64596	M2	76.6	0.424
64596	S2	102.5	0.112
64596	N2	55.4	0.098
64596	K1	78.4	0.146
64596	M4	212.6	0.003
64596	O1	65.2	0.057
64596	M6	152.3	0.007
64596	MK3	64.1	0.011
64596	S4	58.7	0.004
64596	MN4	309.5	0.004
64596	NU2	71.2	0.02
64596	S6	149.7	0.002
64596	MU2	149.4	0.001
64596	2N2	63.5	0.027
64596	OO1	56.8	0.016
64596	LDA2	109.6	0.012
64596	M1	74.3	0.01
64596	J1	116.7	0.017
64596	RHO1	178	0.012
64596	Q1	81.6	0.018
64596	2Q1	339.8	0.012
64596	P1	80.9	0.039
64596	2SM2	90.7	0.004
64596	M3	110.1	0.003
64596	L2	94.5	0.023
64596	2MK3	300.7	0.007
64596	K2	118.7	0.03
64596	M8	79.3	0.007
64596	MS4	64	0.009
64597	M2	76.1	0.419
64597	S2	101.6	0.111
64597	N2	55.8	0.097
64597	K1	77.8	0.144
64597	M4	129.2	0.003
64597	O1	65.9	0.059
64597	M6	136	0.007
64597	MK3	67.6	0.014
64597	S4	29.9	0.004
64597	MN4	317.8	0.002
64597	NU2	74.3	0.022
64597	S6	131.9	0.002
64597	MU2	263.5	0.001
64597	2N2	67.2	0.022
64597	OO1	53.8	0.015
64597	LDA2	106.1	0.013
64597	M1	67.1	0.009
64597	J1	122.2	0.018
64597	RHO1	185.7	0.014
64597	Q1	88.3	0.02
64597	2Q1	338	0.012
64597	P1	82.7	0.04
64597	2SM2	87	0.004
64597	M3	120.1	0.004
64597	L2	96.9	0.024
64597	2MK3	283.8	0.008
64597	K2	119.8	0.031
64597	M8	83.4	0.005
64597	MS4	59	0.008
64598	M2	75.7	0.417
64598	S2	100.9	0.109
64598	N2	55.5	0.094
64598	K1	78.3	0.143
64598	M4	110.9	0.005
64598	O1	67.7	0.06
64598	M6	130.3	0.009
64598	MK3	70.1	0.014
64598	S4	34.8	0.005
64598	MN4	317.1	0.002
64598	NU2	72.3	0.022
64598	S6	165.8	0.002
64598	MU2	272.2	0.003
64598	2N2	66.3	0.02
64598	OO1	62.6	0.014
64598	LDA2	107.5	0.014
64598	M1	67.5	0.009
64598	J1	127.3	0.018
64598	RHO1	180.7	0.016
64598	Q1	89.4	0.021
64598	2Q1	337.7	0.012
64598	P1	84.2	0.039
64598	2SM2	59.9	0.003
64598	M3	119.8	0.006
64598	L2	97.4	0.022
64598	2MK3	279.7	0.01
64598	K2	119	0.031
64598	M8	82.3	0.005
64598	MS4	51.6	0.008
64599	M2	75.4	0.413
64599	S2	100.4	0.107
64599	N2	55.8	0.089
64599	K1	78.2	0.141
64599	M4	97.5	0.009
64599	O1	69.9	0.059
64599	M6	123.1	0.009
64599	MK3	64.4	0.015
64599	S4	12.7	0.005
64599	MN4	346.7	0.002
64599	NU2	73.7	0.021
64599	S6	186	0.002
64599	MU2	274.3	0.003
64599	2N2	65	0.018
64599	OO1	64.3	0.017
64599	LDA2	102.1	0.014
64599	M1	66.6	0.01
64599	J1	126.8	0.018
64599	RHO1	180.6	0.016
64599	Q1	87.6	0.02
64599	2Q1	335.7	0.011
64599	P1	83.7	0.039
64599	2SM2	46.3	0.003
64599	M3	139.6	0.006
64599	L2	101.9	0.021
64599	2MK3	277.2	0.011
64599	K2	120.7	0.029
64599	M8	93.2	0.004
64599	MS4	48	0.008
64600	M2	75.1	0.407
64600	S2	98.9	0.105
64600	N2	54.8	0.087
64600	K1	78.4	0.14
64600	M4	94.1	0.013
64600	O1	70.1	0.058
64600	M6	120.7	0.01
64600	MK3	59.6	0.015
64600	S4	4.5	0.006
64600	MN4	325.9	0.002
64600	NU2	73.7	0.022
64600	S6	210	0.002
64600	MU2	273.5	0.004
64600	2N2	63.9	0.016
64600	OO1	62.5	0.016
64600	LDA2	98.3	0.015
64600	M1	62.1	0.01
64600	J1	131	0.019
64600	RHO1	173.6	0.015
64600	Q1	87.6	0.019
64600	2Q1	332.4	0.01
64600	P1	83.7	0.038
64600	2SM2	29.4	0.002
64600	M3	142.6	0.008
64600	L2	107.7	0.022
64600	2MK3	281.2	0.011
64600	K2	120.4	0.029
64600	M8	100.9	0.003
64600	MS4	43.8	0.008
64601	M2	74.8	0.402
64601	S2	98.6	0.102
64601	N2	56.3	0.084
64601	K1	78.5	0.137
64601	M4	96.7	0.016
64601	O1	70.7	0.058
64601	M6	113.5	0.011
64601	MK3	59.1	0.015
64601	S4	3.2	0.008
64601	MN4	15.2	0.002
64601	NU2	78.2	0.02
64601	S6	261.6	0.001
64601	MU2	278.8	0.005
64601	2N2	60.7	0.013
64601	OO1	67.1	0.017
64601	LDA2	99.5	0.015
64601	M1	64.1	0.011
64601	J1	130.8	0.02
64601	RHO1	165	0.014
64601	Q1	81.1	0.017
64601	2Q1	326.2	0.011
64601	P1	85.7	0.04
64601	2SM2	349.9	0.003
64601	M3	149.6	0.009
64601	L2	111.8	0.021
64601	2MK3	279.7	0.011
64601	K2	118.5	0.029
64601	M8	120.8	0.003
64601	MS4	32.6	0.008
64602	M2	74.7	0.397
64602	S2	98.1	0.1
64602	N2	56.1	0.082
64602	K1	78.3	0.136
64602	M4	93.2	0.019
64602	O1	72.7	0.055
64602	M6	108.3	0.011
64602	MK3	56.8	0.017
64602	S4	3.1	0.009
64602	MN4	30.1	0.002
64602	NU2	84.3	0.019
64602	S6	259.3	0.001
64602	MU2	308.6	0.006
64602	2N2	51.8	0.011
64602	OO1	59.1	0.016
64602	LDA2	96.7	0.014
64602	M1	65.9	0.011
64602	J1	129.8	0.018
64602	RHO1	158	0.015
64602	Q1	77.5	0.018
64602	2Q1	320.9	0.009
64602	P1	88.8	0.039
64602	2SM2	343.9	0.005
64602	M3	155	0.011
64602	L2	116.7	0.021
64602	2MK3	288.4	0.01
64602	K2	116.8	0.027
64602	M8	134.8	0.003
64602	MS4	37.7	0.009
64603	M2	74.5	0.392
64603	S2	96.5	0.098
64603	N2	56.1	0.081
64603	K1	78.4	0.134
64603	M4	96	0.022
64603	O1	74.7	0.053
64603	M6	114.6	0.011
64603	MK3	58.5	0.018
64603	S4	12.7	0.01
64603	MN4	47.8	0.004
64603	NU2	88.2	0.02
64603	S6	305.5	0.001
64603	MU2	303.3	0.008
64603	2N2	42.3	0.007
64603	OO1	62.2	0.018
64603	LDA2	95.8	0.013
64603	M1	66.3	0.011
64603	J1	126	0.018
64603	RHO1	160	0.016
64603	Q1	77.5	0.015
64603	2Q1	308.2	0.009
64603	P1	87.7	0.04
64603	2SM2	343.1	0.006
64603	M3	156.5	0.011
64603	L2	115.7	0.02
64603	2MK3	291.7	0.009
64603	K2	115.3	0.025
64603	M8	137.4	0.002
64603	MS4	42.9	0.009
64604	M2	74.2	0.387
64604	S2	94.5	0.096
64604	N2	57.4	0.081
64604	K1	78.4	0.134
64604	M4	98.6	0.022
64604	O1	77.6	0.051
64604	M6	118.8	0.011
64604	MK3	59	0.018
64604	S4	9.2	0.009
64604	MN4	52.3	0.006
64604	NU2	93.4	0.02
64604	S6	306	0.002
64604	MU2	312.7	0.007
64604	2N2	22.1	0.007
64604	OO1	61.6	0.017
64604	LDA2	91	0.011
64604	M1	65.2	0.011
64604	J1	121.3	0.018
64604	RHO1	150.6	0.016
64604	Q1	73	0.015
64604	2Q1	290.1	0.009
64604	P1	86.1	0.04
64604	2SM2	343.5	0.009
64604	M3	159.9	0.012
64604	L2	117.6	0.019
64604	2MK3	298.7	0.007
64604	K2	108.9	0.026
64604	M8	144.8	0.003
64604	MS4	48.2	0.008
64605	M2	74.1	0.384
64605	S2	92.9	0.094
64605	N2	57.3	0.08
64605	K1	78.4	0.133
64605	M4	97.7	0.025
64605	O1	81.6	0.049
64605	M6	120.6	0.01
64605	MK3	60.2	0.02
64605	S4	15.5	0.01
64605	MN4	54.7	0.007
64605	NU2	99.7	0.02
64605	S6	12.6	0.002
64605	MU2	315.7	0.007
64605	2N2	13.3	0.006
64605	OO1	67.8	0.02
64605	LDA2	97.4	0.009
64605	M1	67.6	0.01
64605	J1	117.4	0.016
64605	RHO1	149.6	0.016
64605	Q1	69.2	0.014
64605	2Q1	280.8	0.009
64605	P1	85.7	0.041
64605	2SM2	343.5	0.01
64605	M3	163.5	0.013
64605	L2	124.7	0.017
64605	2MK3	317.5	0.005
64605	K2	104.1	0.026
64605	M8	158.5	0.003
64605	MS4	56.8	0.01
64606	M2	74	0.381
64606	S2	90.9	0.092
64606	N2	57.4	0.08
64606	K1	78.1	0.131
64606	M4	99.3	0.025
64606	O1	87.5	0.046
64606	M6	119.1	0.009
64606	MK3	58.2	0.021
64606	S4	18.8	0.008
64606	MN4	55.3	0.009
64606	NU2	100.4	0.02
64606	S6	32.8	0.002
64606	MU2	315.3	0.008
64606	2N2	347.6	0.006
64606	OO1	71	0.021
64606	LDA2	102	0.009
64606	M1	69.7	0.009
64606	J1	107.5	0.015
64606	RHO1	144.2	0.016
64606	Q1	65.6	0.013
64606	2Q1	277.7	0.009
64606	P1	83.8	0.043
64606	2SM2	356.5	0.011
64606	M3	173.4	0.013
64606	L2	131.7	0.016
64606	2MK3	341.1	0.005
64606	K2	97.6	0.027
64606	M8	149.5	0.002
64606	MS4	62.8	0.009
64607	M2	73.8	0.379
64607	S2	88.6	0.091
64607	N2	57.5	0.08
64607	K1	78.2	0.127
64607	M4	100.8	0.027
64607	O1	92.8	0.045
64607	M6	123.1	0.01
64607	MK3	60.8	0.022
64607	S4	24.4	0.007
64607	MN4	54.1	0.011
64607	NU2	106.7	0.019
64607	S6	30.9	0.003
64607	MU2	307.1	0.008
64607	2N2	333.6	0.005
64607	OO1	74.3	0.02
64607	LDA2	87.9	0.008
64607	M1	65.1	0.008
64607	J1	96.3	0.015
64607	RHO1	130.9	0.016
64607	Q1	52.6	0.012
64607	2Q1	281.1	0.008
64607	P1	79.4	0.046
64607	2SM2	355.1	0.01
64607	M3	171.6	0.012
64607	L2	130.5	0.016
64607	2MK3	12.9	0.005
64607	K2	89	0.029
64607	M8	149	0.002
64607	MS4	63.2	0.007
64608	M2	73.8	0.375
64608	S2	88.2	0.089
64608	N2	56.8	0.08
64608	K1	78.4	0.125
64608	M4	98.5	0.029
64608	O1	95.8	0.044
64608	M6	123.4	0.009
64608	MK3	61.4	0.023
64608	S4	33.2	0.006
64608	MN4	55.6	0.012
64608	NU2	110	0.018
64608	S6	39.7	0.002
64608	MU2	309.8	0.009
64608	2N2	320.3	0.006
64608	OO1	77.4	0.018
64608	LDA2	79.6	0.007
64608	M1	67.1	0.006
64608	J1	87.4	0.014
64608	RHO1	128.6	0.018
64608	Q1	52	0.013
64608	2Q1	272.9	0.007
64608	P1	76.8	0.048
64608	2SM2	7.9	0.011
64608	M3	171.8	0.011
64608	L2	129.4	0.017
64608	2MK3	37	0.006
64608	K2	86.5	0.03
64608	M8	174.4	0.002
64608	MS4	73.3	0.007
64609	M2	73.8	0.374
64609	S2	86.7	0.088
64609	N2	56.1	0.078
64609	K1	79.2	0.121
64609	M4	97.8	0.029
64609	O1	101.8	0.044
64609	M6	131.2	0.008
64609	MK3	64.1	0.024
64609	S4	45	0.005
64609	MN4	56.6	0.012
64609	NU2	110.8	0.016
64609	S6	40.4	0.003
64609	MU2	307.2	0.011
64609	2N2	306.2	0.008
64609	OO1	75.7	0.015
64609	LDA2	69	0.007
64609	M1	71.1	0.005
64609	J1	80.4	0.015
64609	RHO1	121.7	0.017
64609	Q1	35.2	0.013
64609	2Q1	297.6	0.005
64609	P1	73.9	0.049
64609	2SM2	11.2	0.012
64609	M3	171.9	0.01
64609	L2	133.2	0.017
64609	2MK3	44.1	0.007
64609	K2	82	0.03
64609	M8	179.1	0.003
64609	MS4	75.4	0.007
64610	M2	73.6	0.371
64610	S2	85.9	0.087
64610	N2	55.5	0.079
64610	K1	78.7	0.118
64610	M4	95.6	0.031
64610	O1	104.3	0.046
64610	M6	128.1	0.009
64610	MK3	64.2	0.024
64610	S4	59.8	0.004
64610	MN4	60.2	0.014
64610	NU2	112.4	0.014
64610	S6	36.3	0.003
64610	MU2	312.3	0.011
64610	2N2	298.5	0.009
64610	OO1	81.8	0.013
64610	LDA2	60.3	0.008
64610	M1	69.6	0.004
64610	J1	69.4	0.016
64610	RHO1	110	0.019
64610	Q1	24.5	0.014
64610	2Q1	301.1	0.005
64610	P1	73.3	0.052
64610	2SM2	17.3	0.013
64610	M3	179.9	0.008
64610	L2	129.1	0.018
64610	2MK3	54.5	0.01
64610	K2	79.3	0.031
64610	M8	178.8	0.003
64610	MS4	84.7	0.009
64611	M2	73.6	0.368
64611	S2	84.7	0.086
64611	N2	55.5	0.078
64611	K1	77.9	0.116
64611	M4	94.9	0.032
64611	O1	107.4	0.048
64611	M6	125.3	0.008
64611	MK3	66.4	0.024
64611	S4	66.3	0.004
64611	MN4	66	0.014
64611	NU2	115.8	0.014
64611	S6	27.4	0.002
64611	MU2	307.4	0.012
64611	2N2	296.3	0.009
64611	OO1	82.7	0.01
64611	LDA2	52.2	0.008
64611	M1	75	0.003
64611	J1	62.9	0.018
64611	RHO1	113.4	0.018
64611	Q1	20.8	0.015
64611	2Q1	312.8	0.005
64611	P1	74.8	0.054
64611	2SM2	21	0.013
64611	M3	175.1	0.008
64611	L2	131.9	0.019
64611	2MK3	59.8	0.01
64611	K2	73.3	0.029
64611	M8	191.9	0.004
64611	MS4	84.1	0.01
64612	M2	73.6	0.367
64612	S2	82.8	0.086
64612	N2	55.1	0.076
64612	K1	79.3	0.115
64612	M4	92.5	0.033
64612	O1	110.8	0.049
64612	M6	129.3	0.008
64612	MK3	69.3	0.024
64612	S4	87.6	0.004
64612	MN4	68.3	0.013
64612	NU2	112.4	0.011
64612	S6	2.9	0.002
64612	MU2	309.5	0.011
64612	2N2	297	0.011
64612	OO1	91.9	0.009
64612	LDA2	43.7	0.009
64612	M1	50.1	0.002
64612	J1	58.5	0.02
64612	RHO1	113.2	0.018
64612	Q1	20	0.013
64612	2Q1	314.2	0.006
64612	P1	74.6	0.056
64612	2SM2	27.8	0.012
64612	M3	173.4	0.007
64612	L2	134.3	0.02
64612	2MK3	67.7	0.013
64612	K2	71.7	0.029
64612	M8	192.5	0.004
64612	MS4	89.1	0.011
64613	M2	73.5	0.365
64613	S2	81.8	0.086
64613	N2	54.8	0.074
64613	K1	80.6	0.112
64613	M4	92.2	0.034
64613	O1	113.5	0.054
64613	M6	130.6	0.009
64613	MK3	72.6	0.024
64613	S4	88.9	0.003
64613	MN4	72.4	0.013
64613	NU2	105.3	0.009
64613	S6	357.4	0.003
64613	MU2	302.2	0.01
64613	2N2	298.2	0.012
64613	OO1	81.8	0.008
64613	LDA2	38.7	0.009
64613	M1	279.2	0.001
64613	J1	55.3	0.02
64613	RHO1	116.7	0.019
64613	Q1	20.5	0.014
64613	2Q1	309.4	0.006
64613	P1	75	0.058
64613	2SM2	31.7	0.011
64613	M3	164.9	0.007
64613	L2	133.6	0.021
64613	2MK3	74.8	0.013
64613	K2	63.5	0.029
64613	M8	192.3	0.004
64613	MS4	92.8	0.014
64614	M2	73.5	0.363
64614	S2	81.2	0.085
64614	N2	55.4	0.072
64614	K1	81.6	0.112
64614	M4	89.6	0.034
64614	O1	114.7	0.058
64614	M6	125.4	0.009
64614	MK3	76.1	0.022
64614	S4	108.8	0.003
64614	MN4	69.3	0.013
64614	NU2	101.4	0.007
64614	S6	7.3	0.003
64614	MU2	297.9	0.009
64614	2N2	297.3	0.011
64614	OO1	67.6	0.005
64614	LDA2	42	0.012
64614	M1	268.2	0.002
64614	J1	51.5	0.021
64614	RHO1	117.1	0.019
64614	Q1	29.1	0.015
64614	2Q1	339.3	0.006
64614	P1	74.8	0.057
64614	2SM2	40.4	0.011
64614	M3	181.7	0.006
64614	L2	134.7	0.026
64614	2MK3	79.1	0.014
64614	K2	60.5	0.027
64614	M8	194.5	0.004
64614	MS4	99.1	0.015
64615	M2	73.5	0.362
64615	S2	80.7	0.084
64615	N2	56.6	0.07
64615	K1	82.6	0.113
64615	M4	88.1	0.033
64615	O1	114.4	0.062
64615	M6	129.4	0.008
64615	MK3	82	0.022
64615	S4	134.1	0.003
64615	MN4	79.6	0.012
64615	NU2	87.7	0.007
64615	S6	344.9	0.003
64615	MU2	295.9	0.009
64615	2N2	299.7	0.011
64615	OO1	22.1	0.005
64615	LDA2	43.5	0.013
64615	M1	261.2	0.004
64615	J1	56.8	0.021
64615	RHO1	114.8	0.018
64615	Q1	31.6	0.014
64615	2Q1	347.3	0.008
64615	P1	75.4	0.055
64615	2SM2	43.1	0.01
64615	M3	174.6	0.005
64615	L2	134.8	0.031
64615	2MK3	83.7	0.014
64615	K2	56.3	0.028
64615	M8	212.5	0.004
64615	MS4	105.5	0.017
64616	M2	73.7	0.358
64616	S2	81.7	0.085
64616	N2	57.2	0.068
64616	K1	84.9	0.114
64616	M4	87.8	0.032
64616	O1	113.9	0.067
64616	M6	118.7	0.007
64616	MK3	86.3	0.021
64616	S4	127.7	0.003
64616	MN4	91	0.012
64616	NU2	71.2	0.007
64616	S6	344	0.002
64616	MU2	277.7	0.009
64616	2N2	300	0.011
64616	OO1	8.6	0.006
64616	LDA2	43.5	0.016
64616	M1	264.5	0.005
64616	J1	55.9	0.022
64616	RHO1	111.9	0.016
64616	Q1	26.4	0.014
64616	2Q1	335.7	0.008
64616	P1	74.9	0.053
64616	2SM2	50.5	0.008
64616	M3	188.6	0.005
64616	L2	134.5	0.037
64616	2MK3	84.4	0.014
64616	K2	50.3	0.024
64616	M8	231	0.004
64616	MS4	109.9	0.018
64617	M2	74.2	0.358
64617	S2	82	0.087
64617	N2	58.5	0.066
64617	K1	87.3	0.117
64617	M4	87.6	0.031
64617	O1	112.1	0.071
64617	M6	119.7	0.007
64617	MK3	95.6	0.021
64617	S4	161	0.003
64617	MN4	87.8	0.012
64617	NU2	59.4	0.008
64617	S6	283.3	0.001
64617	MU2	267.9	0.009
64617	2N2	297.9	0.011
64617	OO1	359	0.008
64617	LDA2	45.3	0.016
64617	M1	272.5	0.006
64617	J1	58.1	0.025
64617	RHO1	113.9	0.014
64617	Q1	28.2	0.012
64617	2Q1	327.1	0.009
64617	P1	72.3	0.05
64617	2SM2	65.8	0.008
64617	M3	205.8	0.003
64617	L2	134.5	0.041
64617	2MK3	88.1	0.013
64617	K2	49.3	0.026
64617	M8	240.4	0.004
64617	MS4	112.4	0.019
64618	M2	75	0.357
64618	S2	85.1	0.09
64618	N2	60.3	0.066
64618	K1	89.7	0.118
64618	M4	87.8	0.03
64618	O1	110.6	0.076
64618	M6	107.8	0.006
64618	MK3	102.5	0.022
64618	S4	184.9	0.003
64618	MN4	86.8	0.012
64618	NU2	52.6	0.01
64618	S6	359.7	0.001
64618	MU2	257.8	0.01
64618	2N2	292.4	0.01
64618	OO1	346.1	0.008
64618	LDA2	48.5	0.017
64618	M1	277.1	0.007
64618	J1	58.8	0.026
64618	RHO1	118	0.015
64618	Q1	25.9	0.013
64618	2Q1	304.5	0.011
64618	P1	69.8	0.051
64618	2SM2	87.7	0.009
64618	M3	212.4	0.003
64618	L2	133	0.043
64618	2MK3	94	0.013
64618	K2	54.6	0.024
64618	M8	269.8	0.003
64618	MS4	113.8	0.02
64619	M2	76.2	0.357
64619	S2	87.6	0.094
64619	N2	60.9	0.063
64619	K1	91.8	0.119
64619	M4	85.6	0.03
64619	O1	108.2	0.08
64619	M6	107.5	0.007
64619	MK3	112.3	0.023
64619	S4	193	0.004
64619	MN4	82	0.013
64619	NU2	43.4	0.01
64619	S6	38.9	0.002
64619	MU2	256	0.011
64619	2N2	285.5	0.011
64619	OO1	14.9	0.008
64619	LDA2	56.9	0.015
64619	M1	286.8	0.007
64619	J1	66.5	0.027
64619	RHO1	128.1	0.016
64619	Q1	40.7	0.013
64619	2Q1	285.6	0.015
64619	P1	66.4	0.052
64619	2SM2	113.7	0.009
64619	M3	218.7	0.005
64619	L2	134.8	0.042
64619	2MK3	100.8	0.012
64619	K2	62.3	0.023
64619	M8	267.6	0.003
64619	MS4	119.4	0.021
64620	M2	77.4	0.359
64620	S2	90.5	0.097
64620	N2	61.2	0.064
64620	K1	94	0.12
64620	M4	88.9	0.03
64620	O1	106.5	0.085
64620	M6	103.1	0.008
64620	MK3	118.8	0.026
64620	S4	188.1	0.004
64620	MN4	69.7	0.014
64620	NU2	40.9	0.012
64620	S6	75.6	0.002
64620	MU2	261.8	0.012
64620	2N2	274.8	0.01
64620	OO1	61.1	0.005
64620	LDA2	71.5	0.011
64620	M1	295	0.007
64620	J1	76.7	0.027
64620	RHO1	137.3	0.015
64620	Q1	40.7	0.012
64620	2Q1	278.6	0.017
64620	P1	62.6	0.052
64620	2SM2	127.3	0.009
64620	M3	207.3	0.005
64620	L2	133.5	0.036
64620	2MK3	118.4	0.011
64620	K2	71.2	0.022
64620	M8	253.3	0.003
64620	MS4	120.7	0.019
64621	M2	78.6	0.359
64621	S2	92.2	0.096
64621	N2	62	0.068
64621	K1	95.6	0.122
64621	M4	93.6	0.03
64621	O1	104.6	0.085
64621	M6	106.4	0.008
64621	MK3	117.8	0.026
64621	S4	176.6	0.004
64621	MN4	61.5	0.015
64621	NU2	50.4	0.015
64621	S6	122.6	0.004
64621	MU2	279.3	0.013
64621	2N2	270.7	0.012
64621	OO1	96.3	0.004
64621	LDA2	87.9	0.01
64621	M1	298.3	0.005
64621	J1	87.8	0.026
64621	RHO1	141.8	0.014
64621	Q1	46.2	0.011
64621	2Q1	268.4	0.018
64621	P1	62.1	0.051
64621	2SM2	146	0.01
64621	M3	196.5	0.005
64621	L2	134.1	0.033
64621	2MK3	132.4	0.01
64621	K2	81.6	0.024
64621	M8	226.9	0.003
64621	MS4	126.7	0.017
64622	M2	80.3	0.362
64622	S2	95	0.094
64622	N2	63	0.072
64622	K1	96.5	0.128
64622	M4	95	0.03
64622	O1	104.1	0.085
64622	M6	112.1	0.008
64622	MK3	111.2	0.028
64622	S4	157.2	0.002
64622	MN4	51.2	0.016
64622	NU2	52.9	0.015
64622	S6	129.3	0.005
64622	MU2	296	0.012
64622	2N2	270.9	0.009
64622	OO1	131	0.005
64622	LDA2	105.4	0.011
64622	M1	322.6	0.005
64622	J1	97.3	0.023
64622	RHO1	149.6	0.009
64622	Q1	48.2	0.01
64622	2Q1	265.7	0.018
64622	P1	66.2	0.049
64622	2SM2	153.2	0.009
64622	M3	185.5	0.005
64622	L2	132.2	0.029
64622	2MK3	146.1	0.008
64622	K2	92.3	0.027
64622	M8	235.2	0.004
64622	MS4	133.7	0.015
64623	M2	81.9	0.368
64623	S2	98	0.091
64623	N2	65	0.075
64623	K1	98.9	0.134
64623	M4	98.7	0.029
64623	O1	104.5	0.082
64623	M6	128.5	0.007
64623	MK3	106.1	0.029
64623	S4	163.7	0.002
64623	MN4	43.5	0.017
64623	NU2	57.2	0.016
64623	S6	131.6	0.006
64623	MU2	316.2	0.013
64623	2N2	274.2	0.008
64623	OO1	139.9	0.012
64623	LDA2	117.4	0.01
64623	M1	336.6	0.005
64623	J1	100.7	0.018
64623	RHO1	129.4	0.005
64623	Q1	56.6	0.011
64623	2Q1	253.8	0.015
64623	P1	72.9	0.046
64623	2SM2	170.3	0.009
64623	M3	193.8	0.005
64623	L2	130.5	0.028
64623	2MK3	151.9	0.005
64623	K2	91.8	0.032
64623	M8	245.3	0.005
64623	MS4	151	0.014
64624	M2	83.2	0.373
64624	S2	101.4	0.088
64624	N2	65.6	0.077
64624	K1	101	0.141
64624	M4	102.4	0.025
64624	O1	103.5	0.081
64624	M6	136	0.008
64624	MK3	103.1	0.031
64624	S4	18.9	0.001
64624	MN4	41.8	0.016
64624	NU2	60.4	0.012
64624	S6	151.4	0.007
64624	MU2	345.5	0.015
64624	2N2	287.4	0.006
64624	OO1	137.5	0.013
64624	LDA2	123.8	0.011
64624	M1	356.9	0.005
64624	J1	105.5	0.014
64624	RHO1	75.7	0.002
64624	Q1	56.6	0.011
64624	2Q1	238.1	0.014
64624	P1	82.3	0.044
64624	2SM2	176.5	0.008
64624	M3	178.5	0.007
64624	L2	130.2	0.026
64624	2MK3	154.4	0.001
64624	K2	94.2	0.036
64624	M8	261.1	0.007
64624	MS4	165.9	0.013
64625	M2	83.4	0.377
64625	S2	104.6	0.087
64625	N2	65.4	0.077
64625	K1	103.3	0.147
64625	M4	115	0.02
64625	O1	101	0.081
64625	M6	143.8	0.009
64625	MK3	101.6	0.029
64625	S4	10.5	0.002
64625	MN4	41.4	0.013
64625	NU2	63.8	0.009
64625	S6	172.9	0.006
64625	MU2	357.2	0.021
64625	2N2	315.6	0.004
64625	OO1	144.6	0.015
64625	LDA2	114.9	0.012
64625	M1	21.2	0.005
64625	J1	118.2	0.01
64625	RHO1	340.8	0.006
64625	Q1	69.6	0.01
64625	2Q1	229.9	0.015
64625	P1	96.1	0.041
64625	2SM2	179	0.005
64625	M3	179.3	0.008
64625	L2	125.2	0.025
64625	2MK3	348.4	0.004
64625	K2	96.3	0.04
64625	M8	275.6	0.007
64625	MS4	186	0.013
64626	M2	83	0.379
64626	S2	107.7	0.087
64626	N2	64.4	0.076
64626	K1	106	0.155
64626	M4	135.4	0.015
64626	O1	95	0.085
64626	M6	133.3	0.008
64626	MK3	102.3	0.024
64626	S4	11.7	0.003
64626	MN4	52.8	0.012
64626	NU2	40	0.004
64626	S6	191.7	0.004
64626	MU2	2.3	0.024
64626	2N2	19.7	0.006
64626	OO1	145.1	0.017
64626	LDA2	102.3	0.015
64626	M1	42.9	0.005
64626	J1	157.5	0.005
64626	RHO1	354	0.011
64626	Q1	67.4	0.011
64626	2Q1	225.4	0.015
64626	P1	109.8	0.039
64626	2SM2	178.5	0.002
64626	M3	174.6	0.012
64626	L2	120	0.026
64626	2MK3	354.7	0.01
64626	K2	94.9	0.045
64626	M8	271.8	0.007
64626	MS4	197.4	0.013
64627	M2	81.2	0.378
64627	S2	108	0.084
64627	N2	62.7	0.078
64627	K1	108.4	0.16
64627	M4	161.6	0.015
64627	O1	89.5	0.087
64627	M6	105.9	0.008
64627	MK3	98.4	0.018
64627	S4	42.2	0.004
64627	MN4	65.4	0.009
64627	NU2	27.2	0.003
64627	S6	226.9	0.002
64627	MU2	1	0.026
64627	2N2	47.6	0.009
64627	OO1	148.1	0.019
64627	LDA2	95	0.016
64627	M1	70.1	0.004
64627	J1	211.9	0.005
64627	RHO1	1.3	0.016
64627	Q1	72.9	0.009
64627	2Q1	226.2	0.016
64627	P1	119.6	0.038
64627	2SM2	22	0.003
64627	M3	167.8	0.015
64627	L2	117.2	0.025
64627	2MK3	356.3	0.014
64627	K2	91.5	0.048
64627	M8	284.5	0.005
64627	MS4	202.1	0.012
64628	M2	78.8	0.372
64628	S2	107.6	0.082
64628	N2	61.1	0.077
64628	K1	110.6	0.16
64628	M4	174.4	0.018
64628	O1	85.2	0.089
64628	M6	83.4	0.007
64628	MK3	78.2	0.012
64628	S4	52.5	0.005
64628	MN4	82.9	0.006
64628	NU2	351	0.003
64628	S6	225	0.001
64628	MU2	2.9	0.025
64628	2N2	55.4	0.013
64628	OO1	149.1	0.027
64628	LDA2	93.1	0.017
64628	M1	104.4	0.004
64628	J1	231.2	0.006
64628	RHO1	2.8	0.015
64628	Q1	77.2	0.009
64628	2Q1	226.1	0.015
64628	P1	125.4	0.034
64628	2SM2	28.1	0.006
64628	M3	160.8	0.014
64628	L2	110.4	0.022
64628	2MK3	356.4	0.016
64628	K2	90	0.048
64628	M8	315.5	0.003
64628	MS4	199	0.011
64629	M2	76.1	0.364
64629	S2	105.8	0.08
64629	N2	56.6	0.078
64629	K1	111.7	0.156
64629	M4	167.2	0.018
64629	O1	83.4	0.089
64629	M6	61.7	0.006
64629	MK3	39	0.009
64629	S4	49.2	0.003
64629	MN4	93	0.007
64629	NU2	14.6	0.004
64629	MU2	357.5	0.019
64629	2N2	64.3	0.014
64629	OO1	143.3	0.034
64629	LDA2	91.5	0.015
64629	M1	126.1	0.007
64629	J1	233.2	0.01
64629	RHO1	5.7	0.019
64629	Q1	72.9	0.006
64629	2Q1	220	0.016
64629	P1	129.7	0.03
64629	2SM2	25	0.01
64629	M3	148.1	0.013
64629	L2	104.7	0.023
64629	2MK3	353.1	0.014
64629	K2	87.4	0.044
64629	M8	349.9	0.005
64629	MS4	185.1	0.011
64630	M2	73.9	0.355
64630	S2	101.6	0.079
64630	N2	50.9	0.076
64630	K1	111.5	0.147
64630	M4	154.2	0.017
64630	O1	82.4	0.091
64630	M6	64.2	0.004
64630	MK3	18.1	0.013
64630	S4	61.1	0.004
64630	MN4	91.7	0.01
64630	NU2	46.5	0.007
64630	S6	96.4	0.001
64630	MU2	351.3	0.018
64630	2N2	61.8	0.012
64630	OO1	143.6	0.04
64630	LDA2	93.7	0.013
64630	M1	137.1	0.008
64630	J1	241	0.012
64630	RHO1	7.5	0.021
64630	Q1	69.4	0.007
64630	2Q1	216.7	0.012
64630	P1	131.4	0.026
64630	2SM2	31.5	0.01
64630	M3	128.9	0.012
64630	L2	95.4	0.026
64630	2MK3	347.5	0.016
64630	K2	83.1	0.042
64630	M8	5.4	0.005
64630	MS4	164.4	0.008
64631	M2	72	0.348
64631	S2	99.1	0.077
64631	N2	45.4	0.072
64631	K1	110.1	0.136
64631	M4	141	0.016
64631	O1	82.7	0.091
64631	M6	118.4	0.004
64631	MK3	14.7	0.018
64631	S4	66.8	0.004
64631	MN4	88.3	0.012
64631	NU2	42.3	0.009
64631	S6	177.5	0.001
64631	MU2	356.3	0.015
64631	2N2	61.2	0.012
64631	OO1	139.8	0.043
64631	LDA2	99.5	0.013
64631	M1	138.4	0.01
64631	J1	247.6	0.015
64631	RHO1	7.8	0.021
64631	Q1	90	0.007
64631	2Q1	203.2	0.009
64631	P1	134	0.027
64631	2SM2	32	0.012
64631	M3	116.4	0.013
64631	L2	96.7	0.031
64631	2MK3	340.1	0.018
64631	K2	78	0.042
64631	M8	8.2	0.006
64631	MS4	130.3	0.007
64632	M2	70.8	0.342
64632	S2	95.7	0.076
64632	N2	41.1	0.068
64632	K1	108.8	0.126
64632	M4	131.3	0.016
64632	O1	81.7	0.099
64632	M6	136.2	0.006
64632	MK3	21.6	0.021
64632	S4	56.9	0.004
64632	MN4	87.6	0.011
64632	NU2	53.6	0.009
64632	S6	206	0.002
64632	MU2	353.7	0.014
64632	2N2	60.8	0.008
64632	OO1	135.1	0.042
64632	LDA2	102.8	0.013
64632	M1	137	0.013
64632	J1	247.5	0.016
64632	RHO1	359.4	0.023
64632	Q1	107.1	0.008
64632	2Q1	186.6	0.009
64632	P1	132.5	0.027
64632	2SM2	38.6	0.014
64632	M3	116.4	0.017
64632	L2	97.5	0.036
64632	2MK3	332.6	0.025
64632	K2	71.8	0.044
64632	M8	0.9	0.006
64632	MS4	110.6	0.007
64633	M2	69.6	0.332
64633	S2	94	0.073
64633	N2	38.5	0.065
64633	K1	107.2	0.117
64633	M4	133.3	0.017
64633	O1	80.2	0.107
64633	M6	144.8	0.009
64633	MK3	27.9	0.023
64633	S4	47.9	0.004
64633	MN4	100.1	0.011
64633	NU2	51.2	0.005
64633	S6	213	0.002
64633	MU2	343.3	0.011
64633	2N2	77.6	0.006
64633	OO1	121.4	0.031
64633	LDA2	108.7	0.013
64633	M1	133.9	0.014
64633	J1	240.8	0.015
64633	RHO1	358.4	0.022
64633	Q1	109.9	0.008
64633	2Q1	189	0.011
64633	P1	132.3	0.029
64633	2SM2	43.5	0.014
64633	M3	117.9	0.022
64633	L2	100.8	0.038
64633	2MK3	332.2	0.029
64633	K2	65.1	0.044
64633	M8	353.9	0.008
64633	MS4	116.8	0.006
64634	M2	75.1	0.443
64634	S2	85.1	0.099
64634	N2	51.5	0.083
64634	K1	58.1	0.155
64634	M4	232	0.004
64634	O1	33.6	0.08
64634	M6	332.1	0.013
64634	MK3	14.6	0.013
64634	S4	113.6	0.002
64634	MN4	290.2	0.011
64634	NU2	57.5	0.034
64634	MU2	240.1	0.018
64634	2N2	345.2	0.014
64634	OO1	1.4	0.007
64634	LDA2	61.7	0.015
64634	M1	64.3	0.008
64634	J1	65.5	0.01
64634	RHO1	197.2	0.006
64634	Q1	40.6	0.016
64634	2Q1	150.1	0.008
64634	P1	55.8	0.054
64634	2SM2	258.1	0.006
64634	M3	117.2	0.006
64634	L2	116.7	0.046
64634	2MK3	52.4	0.01
64634	K2	113.4	0.037
64634	M8	47	0.005
64634	MS4	46	0.012
64635	M2	73.5	0.437
64635	S2	87.1	0.101
64635	N2	51.9	0.086
64635	K1	61.1	0.145
64635	M4	131	0.001
64635	O1	35.2	0.076
64635	M6	325.8	0.012
64635	MK3	12.7	0.015
64635	S4	133.2	0.002
64635	MN4	291.6	0.009
64635	NU2	51	0.03
64635	S6	77.6	0.001
64635	MU2	221.5	0.011
64635	2N2	349.6	0.015
64635	OO1	352.1	0.009
64635	LDA2	61.3	0.016
64635	M1	56.4	0.007
64635	J1	59.8	0.011
64635	RHO1	191.1	0.007
64635	Q1	41.1	0.015
64635	2Q1	156.2	0.006
64635	P1	55.5	0.056
64635	2SM2	280.6	0.006
64635	M3	119.9	0.005
64635	L2	108.3	0.041
64635	2MK3	43.7	0.009
64635	K2	106.4	0.04
64635	M8	55.2	0.005
64635	MS4	47.3	0.011
64636	M2	71.8	0.433
64636	S2	88.9	0.102
64636	N2	51.4	0.089
64636	K1	64.5	0.136
64636	M4	96.6	0.005
64636	O1	37.5	0.071
64636	M6	325.8	0.012
64636	MK3	10.5	0.019
64636	S4	138.2	0.002
64636	MN4	294.5	0.006
64636	NU2	45.4	0.027
64636	S6	67.5	0.001
64636	MU2	195.6	0.008
64636	2N2	350.5	0.015
64636	OO1	341.4	0.01
64636	LDA2	58.6	0.016
64636	M1	44.1	0.007
64636	J1	59.9	0.012
64636	RHO1	187.2	0.008
64636	Q1	42.8	0.016
64636	2Q1	169.9	0.004
64636	P1	56	0.057
64636	2SM2	293	0.006
64636	M3	134.8	0.005
64636	L2	98.2	0.037
64636	2MK3	32.5	0.008
64636	K2	101.5	0.042
64636	M8	56.9	0.005
64636	MS4	50.3	0.012
64637	M2	70.1	0.43
64637	S2	90.7	0.102
64637	N2	50.8	0.091
64637	K1	68.1	0.128
64637	M4	92.3	0.009
64637	O1	40.5	0.067
64637	M6	324.5	0.011
64637	MK3	11.1	0.023
64637	S4	149.2	0.002
64637	MN4	303.8	0.004
64637	NU2	38.3	0.024
64637	S6	55.6	0.001
64637	MU2	152.5	0.007
64637	2N2	358.8	0.016
64637	OO1	343	0.011
64637	LDA2	56.6	0.016
64637	M1	34.1	0.006
64637	J1	60.7	0.014
64637	RHO1	178.1	0.01
64637	Q1	40.4	0.016
64637	2Q1	199	0.002
64637	P1	55.3	0.056
64637	2SM2	312.1	0.006
64637	M3	147.5	0.005
64637	L2	87.4	0.035
64637	2MK3	13.5	0.007
64637	K2	98.6	0.044
64637	M8	59.2	0.004
64637	MS4	59.2	0.012
64638	M2	68.4	0.429
64638	S2	92.5	0.101
64638	N2	50.2	0.092
64638	K1	71.8	0.121
64638	M4	87.8	0.012
64638	O1	43.3	0.062
64638	M6	323.8	0.01
64638	MK3	13.1	0.027
64638	S4	124.6	0.003
64638	MN4	339.6	0.002
64638	NU2	32.6	0.022
64638	MU2	125.7	0.009
64638	2N2	6.9	0.018
64638	OO1	350.6	0.013
64638	LDA2	56.8	0.015
64638	M1	19.7	0.005
64638	J1	61.2	0.016
64638	RHO1	164.4	0.009
64638	Q1	37.6	0.018
64638	2Q1	229.2	0.002
64638	P1	54.6	0.056
64638	2SM2	326.5	0.005
64638	M3	158.8	0.005
64638	L2	78.3	0.035
64638	2MK3	355.8	0.006
64638	K2	95.9	0.046
64638	M8	58	0.004
64638	MS4	68.3	0.013
64639	M2	66.9	0.428
64639	S2	93.4	0.099
64639	N2	49.7	0.092
64639	K1	74.6	0.114
64639	M4	81.6	0.015
64639	O1	46.2	0.058
64639	M6	319.1	0.008
64639	MK3	15.5	0.03
64639	S4	113.7	0.003
64639	MN4	26.8	0.003
64639	NU2	25.9	0.019
64639	S6	239.9	0.001
64639	MU2	113.9	0.013
64639	2N2	15.6	0.02
64639	OO1	351	0.015
64639	LDA2	53.1	0.015
64639	M1	3.8	0.004
64639	J1	63.8	0.018
64639	RHO1	147.3	0.01
64639	Q1	33.6	0.018
64639	2Q1	284	0.002
64639	P1	55.1	0.055
64639	2SM2	336.2	0.005
64639	M3	163.7	0.006
64639	L2	70.3	0.038
64639	2MK3	350.1	0.007
64639	K2	93.3	0.047
64639	M8	53.2	0.003
64639	MS4	76.1	0.014
64640	M2	65.6	0.43
64640	S2	94.1	0.097
64640	N2	48.9	0.093
64640	K1	76.9	0.109
64640	M4	79.5	0.018
64640	O1	50	0.054
64640	M6	306.5	0.005
64640	MK3	17.3	0.031
64640	S4	92.8	0.004
64640	MN4	43.8	0.004
64640	NU2	27.4	0.018
64640	S6	247.5	0.003
64640	MU2	115.5	0.014
64640	2N2	21.9	0.021
64640	OO1	346.2	0.016
64640	LDA2	50.6	0.016
64640	M1	338	0.003
64640	J1	67.6	0.02
64640	RHO1	140	0.012
64640	Q1	31.6	0.018
64640	2Q1	318.6	0.003
64640	P1	56.4	0.054
64640	2SM2	350.9	0.004
64640	M3	161.7	0.008
64640	L2	66.2	0.041
64640	2MK3	342.6	0.009
64640	K2	91	0.049
64640	M8	53.2	0.002
64640	MS4	86.1	0.015
64641	M2	64.6	0.434
64641	S2	94	0.095
64641	N2	48.1	0.094
64641	K1	79.1	0.106
64641	M4	77.1	0.022
64641	O1	57.1	0.05
64641	M6	269.7	0.003
64641	MK3	16.6	0.031
64641	S4	72.6	0.005
64641	MN4	52.6	0.004
64641	NU2	32.8	0.017
64641	S6	242.8	0.002
64641	MU2	119	0.014
64641	2N2	23.8	0.023
64641	OO1	348.4	0.016
64641	LDA2	49.5	0.017
64641	M1	313	0.004
64641	J1	69.3	0.023
64641	RHO1	131.4	0.016
64641	Q1	30.4	0.02
64641	2Q1	328.6	0.006
64641	P1	58.2	0.053
64641	2SM2	17.4	0.004
64641	M3	154.2	0.008
64641	L2	63.9	0.043
64641	2MK3	339.7	0.01
64641	K2	90.1	0.05
64641	M8	45.3	0.002
64641	MS4	93	0.017
64642	M2	63.9	0.438
64642	S2	93.4	0.091
64642	N2	47.9	0.095
64642	K1	80.3	0.104
64642	M4	76.7	0.024
64642	O1	66.5	0.046
64642	M6	219	0.004
64642	MK3	19.3	0.029
64642	S4	60.4	0.006
64642	MN4	55.2	0.005
64642	NU2	43	0.016
64642	S6	242.4	0.001
64642	MU2	123.5	0.013
64642	2N2	24.9	0.026
64642	OO1	347.6	0.018
64642	LDA2	49.4	0.017
64642	M1	292.5	0.005
64642	J1	72.1	0.024
64642	RHO1	131	0.018
64642	Q1	28.2	0.02
64642	2Q1	335.6	0.007
64642	P1	61.4	0.052
64642	2SM2	37.1	0.004
64642	M3	142.8	0.008
64642	L2	64.5	0.043
64642	2MK3	337.5	0.011
64642	K2	87.2	0.049
64642	M8	25	0.002
64642	MS4	97.6	0.019
64643	M2	63.7	0.441
64643	S2	92.7	0.088
64643	N2	47.5	0.095
64643	K1	81.6	0.104
64643	M4	77.6	0.025
64643	O1	75.7	0.046
64643	M6	215.2	0.007
64643	MK3	23.9	0.027
64643	S4	55.8	0.006
64643	MN4	56.7	0.005
64643	NU2	53.6	0.015
64643	MU2	127.8	0.011
64643	2N2	24.6	0.028
64643	OO1	354.4	0.02
64643	LDA2	50.5	0.017
64643	M1	273.7	0.005
64643	J1	75.1	0.023
64643	RHO1	132.1	0.02
64643	Q1	25.8	0.02
64643	2Q1	339.7	0.008
64643	P1	64.3	0.05
64643	2SM2	57.9	0.005
64643	M3	129.4	0.007
64643	L2	67.4	0.044
64643	2MK3	328.4	0.012
64643	K2	84.5	0.048
64643	M8	8.9	0.002
64643	MS4	101.1	0.022
64644	M2	63.6	0.444
64644	S2	91.7	0.085
64644	N2	47	0.095
64644	K1	82.9	0.104
64644	M4	80.2	0.027
64644	O1	84.4	0.048
64644	M6	213.7	0.009
64644	MK3	27.8	0.026
64644	S4	60.5	0.006
64644	MN4	52.9	0.004
64644	NU2	62.8	0.016
64644	MU2	129.7	0.009
64644	2N2	23.2	0.031
64644	OO1	358.4	0.021
64644	LDA2	53.4	0.019
64644	M1	261.8	0.006
64644	J1	79	0.022
64644	RHO1	137.2	0.022
64644	Q1	29.6	0.019
64644	2Q1	338.6	0.009
64644	P1	67	0.048
64644	2SM2	73.4	0.006
64644	M3	112.2	0.007
64644	L2	73.1	0.044
64644	2MK3	322.8	0.012
64644	K2	80.5	0.047
64644	M8	344.2	0.003
64644	MS4	105.6	0.024
64645	M2	63.7	0.447
64645	S2	90.1	0.082
64645	N2	46	0.095
64645	K1	85	0.105
64645	M4	83.3	0.026
64645	O1	91.7	0.051
64645	M6	211.9	0.01
64645	MK3	28.6	0.025
64645	S4	63.4	0.006
64645	MN4	45.6	0.003
64645	NU2	69.7	0.018
64645	S6	19.6	0.001
64645	MU2	139.5	0.006
64645	2N2	24.6	0.032
64645	OO1	4.2	0.019
64645	LDA2	53.1	0.02
64645	M1	252.4	0.007
64645	J1	83.4	0.02
64645	RHO1	138.1	0.023
64645	Q1	28.3	0.019
64645	2Q1	332.5	0.009
64645	P1	69.8	0.046
64645	2SM2	83.3	0.006
64645	M3	103.6	0.008
64645	L2	76.7	0.045
64645	2MK3	317.8	0.011
64645	K2	77.6	0.046
64645	M8	330.2	0.005
64645	MS4	109.5	0.026
64646	M2	63.9	0.448
64646	S2	88.2	0.081
64646	N2	45.7	0.093
64646	K1	88.4	0.106
64646	M4	89	0.026
64646	O1	97.1	0.054
64646	M6	211.5	0.011
64646	MK3	28.6	0.024
64646	S4	79.1	0.007
64646	MN4	49	0.003
64646	NU2	72	0.018
64646	S6	8.2	0.001
64646	MU2	181.1	0.004
64646	2N2	26.1	0.032
64646	OO1	3.9	0.017
64646	LDA2	54.4	0.019
64646	M1	247.6	0.007
64646	J1	89.5	0.019
64646	RHO1	141.2	0.023
64646	Q1	31.5	0.018
64646	2Q1	320.4	0.01
64646	P1	72.1	0.045
64646	2SM2	86.6	0.007
64646	M3	96.5	0.008
64646	L2	81	0.045
64646	2MK3	306.5	0.011
64646	K2	74.4	0.045
64646	M8	326.8	0.006
64646	MS4	112.1	0.027
64647	M2	64.3	0.447
64647	S2	86	0.081
64647	N2	45.7	0.09
64647	K1	91.5	0.109
64647	M4	94.8	0.025
64647	O1	101	0.058
64647	M6	210.4	0.011
64647	MK3	26.3	0.021
64647	S4	89.3	0.008
64647	MN4	61.4	0.003
64647	NU2	77.3	0.017
64647	S6	36	0.002
64647	MU2	209.4	0.004
64647	2N2	30.5	0.031
64647	OO1	7.4	0.016
64647	LDA2	57.6	0.018
64647	M1	250.1	0.007
64647	J1	96.8	0.018
64647	RHO1	142	0.023
64647	Q1	37	0.017
64647	2Q1	308	0.011
64647	P1	75	0.043
64647	2SM2	86.6	0.008
64647	M3	91.7	0.007
64647	L2	84.5	0.045
64647	2MK3	293.2	0.011
64647	K2	71.5	0.045
64647	M8	325.7	0.007
64647	MS4	114.7	0.027
64648	M2	64.6	0.444
64648	S2	84.4	0.081
64648	N2	46.4	0.088
64648	K1	94.6	0.113
64648	M4	103.1	0.023
64648	O1	103.8	0.061
64648	M6	208.8	0.011
64648	MK3	21.4	0.02
64648	S4	96.6	0.009
64648	MN4	68.7	0.003
64648	NU2	84.9	0.015
64648	S6	39.7	0.002
64648	MU2	227.5	0.005
64648	2N2	37.4	0.029
64648	OO1	9.4	0.013
64648	LDA2	62.4	0.017
64648	M1	257	0.007
64648	J1	107.7	0.018
64648	RHO1	140.4	0.02
64648	Q1	40.2	0.016
64648	2Q1	299.1	0.009
64648	P1	77.8	0.041
64648	2SM2	85.1	0.009
64648	M3	79.7	0.007
64648	L2	88.2	0.045
64648	2MK3	285.8	0.012
64648	K2	69.3	0.044
64648	M8	321.3	0.007
64648	MS4	114.2	0.027
64649	M2	65.1	0.439
64649	S2	83.5	0.083
64649	N2	47.6	0.087
64649	K1	97.7	0.117
64649	M4	111.2	0.02
64649	O1	105.4	0.064
64649	M6	208	0.01
64649	MK3	18.7	0.019
64649	S4	98.9	0.009
64649	MN4	79.8	0.003
64649	NU2	96.8	0.014
64649	S6	45.2	0.002
64649	MU2	248.4	0.005
64649	2N2	44.6	0.028
64649	OO1	22.2	0.012
64649	LDA2	65.5	0.016
64649	M1	261.7	0.006
64649	J1	119.7	0.019
64649	RHO1	138.3	0.017
64649	Q1	41.7	0.016
64649	2Q1	298.8	0.008
64649	P1	80.8	0.039
64649	2SM2	84.3	0.008
64649	M3	72.5	0.007
64649	L2	92.1	0.044
64649	2MK3	278.1	0.012
64649	K2	67.6	0.044
64649	M8	324	0.007
64649	MS4	112	0.026
64650	M2	65.5	0.432
64650	S2	82.5	0.085
64650	N2	48.9	0.087
64650	K1	100.8	0.12
64650	M4	119.9	0.018
64650	O1	105	0.067
64650	M6	205	0.008
64650	MK3	17.4	0.019
64650	S4	105.5	0.009
64650	MN4	124.8	0.003
64650	NU2	104.7	0.014
64650	S6	0.5	0.002
64650	MU2	272.5	0.004
64650	2N2	49.2	0.027
64650	OO1	58	0.009
64650	LDA2	72.3	0.017
64650	M1	266	0.005
64650	J1	127.5	0.021
64650	RHO1	139.1	0.015
64650	Q1	46.9	0.016
64650	2Q1	301	0.006
64650	P1	83.6	0.038
64650	2SM2	85.3	0.008
64650	M3	68.7	0.006
64650	L2	96.8	0.043
64650	2MK3	276.1	0.012
64650	K2	65	0.045
64650	M8	320.4	0.007
64650	MS4	108	0.025
64651	M2	66	0.426
64651	S2	82.3	0.089
64651	N2	48.9	0.088
64651	K1	103.3	0.125
64651	M4	131.5	0.016
64651	O1	104.2	0.07
64651	M6	201	0.007
64651	MK3	15.9	0.018
64651	S4	108.3	0.009
64651	MN4	163.8	0.005
64651	NU2	102	0.014
64651	S6	322.5	0.001
64651	MU2	274.6	0.005
64651	2N2	54.4	0.024
64651	OO1	98	0.009
64651	LDA2	80.1	0.017
64651	M1	262.3	0.005
64651	J1	132.8	0.021
64651	RHO1	149	0.011
64651	Q1	53.8	0.013
64651	2Q1	303.6	0.004
64651	P1	86.2	0.039
64651	2SM2	83.2	0.005
64651	M3	75.1	0.005
64651	L2	101.8	0.041
64651	2MK3	278.5	0.014
64651	K2	65	0.046
64651	M8	317.6	0.006
64651	MS4	102.9	0.023
64652	M2	66.4	0.418
64652	S2	83.4	0.093
64652	N2	47.8	0.087
64652	K1	104.9	0.131
64652	M4	145.8	0.016
64652	O1	102.7	0.073
64652	M6	191.3	0.004
64652	MK3	16.6	0.017
64652	S4	115.8	0.008
64652	MN4	167.2	0.009
64652	NU2	98.1	0.013
64652	S6	299.9	0.003
64652	MU2	290.7	0.003
64652	2N2	55.5	0.021
64652	OO1	116.1	0.01
64652	LDA2	92	0.015
64652	M1	238.3	0.005
64652	J1	138.5	0.021
64652	RHO1	156.2	0.007
64652	Q1	60.4	0.011
64652	2Q1	303.7	0.002
64652	P1	87.9	0.04
64652	2SM2	64.5	0.001
64652	M3	71.6	0.004
64652	L2	106.9	0.037
64652	2MK3	282.6	0.013
64652	K2	66.9	0.048
64652	M8	304.4	0.004
64652	MS4	95.1	0.022
64653	M2	66.8	0.413
64653	S2	84.6	0.098
64653	N2	46.1	0.086
64653	K1	105.2	0.137
64653	M4	160.5	0.017
64653	O1	101.2	0.076
64653	M6	171.5	0.003
64653	MK3	22.5	0.016
64653	S4	115	0.005
64653	MN4	169.4	0.012
64653	NU2	85.8	0.014
64653	S6	292.5	0.003
64653	MU2	317.2	0.001
64653	2N2	51	0.016
64653	OO1	131.8	0.013
64653	LDA2	94.2	0.014
64653	M1	215.7	0.006
64653	J1	145.7	0.017
64653	RHO1	118.6	0.003
64653	Q1	57.8	0.01
64653	2Q1	241.2	0.004
64653	P1	88.7	0.04
64653	2SM2	298.5	0.001
64653	M3	66.1	0.002
64653	L2	107.8	0.034
64653	2MK3	283	0.012
64653	K2	65.4	0.049
64653	M8	269.3	0.003
64653	MS4	85.4	0.019
64654	M2	67.1	0.405
64654	S2	86.1	0.103
64654	N2	43.4	0.084
64654	K1	105	0.142
64654	M4	168	0.019
64654	O1	100.1	0.079
64654	M6	142.6	0.003
64654	MK3	23.9	0.013
64654	S4	104.3	0.004
64654	MN4	168.6	0.014
64654	NU2	67.7	0.016
64654	S6	288.1	0.003
64654	MU2	165.3	0.002
64654	2N2	49.4	0.011
64654	OO1	144	0.016
64654	LDA2	97.2	0.012
64654	M1	197.7	0.007
64654	J1	158	0.012
64654	RHO1	47.6	0.007
64654	Q1	50	0.008
64654	2Q1	223.5	0.007
64654	P1	85.4	0.038
64654	2SM2	273.8	0.001
64654	M3	273.9	0.002
64654	L2	110.6	0.03
64654	2MK3	275.3	0.011
64654	K2	62.1	0.049
64654	M8	262.9	0.003
64654	MS4	72	0.015
64655	M2	67.2	0.396
64655	S2	87.5	0.109
64655	N2	41.2	0.081
64655	K1	103.8	0.146
64655	M4	172.7	0.023
64655	O1	99	0.083
64655	M6	94	0.002
64655	MK3	24.7	0.011
64655	S4	28.8	0.002
64655	MN4	166.9	0.016
64655	NU2	62	0.017
64655	S6	298.6	0.003
64655	MU2	147	0.007
64655	2N2	50.9	0.01
64655	OO1	157.3	0.016
64655	LDA2	97.7	0.011
64655	M1	177.6	0.009
64655	J1	190	0.007
64655	RHO1	42.9	0.015
64655	Q1	38.2	0.007
64655	2Q1	231.3	0.009
64655	P1	83.6	0.037
64655	2SM2	300.7	0.003
64655	M3	263.2	0.004
64655	L2	114.3	0.024
64655	2MK3	268.6	0.008
64655	K2	60.7	0.049
64655	M8	276.3	0.003
64655	MS4	54.1	0.011
64656	M2	66.9	0.387
64656	S2	89.6	0.112
64656	N2	41.3	0.078
64656	K1	102.2	0.149
64656	M4	173.6	0.027
64656	O1	99	0.085
64656	M6	56	0.005
64656	MK3	27.2	0.012
64656	S4	350.3	0.004
64656	MN4	167.9	0.018
64656	NU2	56.4	0.017
64656	S6	321.2	0.002
64656	MU2	138.4	0.008
64656	2N2	50.1	0.008
64656	OO1	165.1	0.018
64656	LDA2	103.9	0.011
64656	M1	160.9	0.01
64656	J1	235.3	0.008
64656	RHO1	36.8	0.021
64656	Q1	17.4	0.008
64656	2Q1	234.5	0.01
64656	P1	84.6	0.037
64656	2SM2	313.5	0.002
64656	M3	253.1	0.005
64656	L2	121.9	0.019
64656	2MK3	251.9	0.005
64656	K2	59.5	0.047
64656	M8	283.7	0.003
64656	MS4	32.6	0.01
64657	M2	66.9	0.377
64657	S2	90.8	0.113
64657	N2	44.1	0.074
64657	K1	100.7	0.154
64657	M4	168.7	0.03
64657	O1	99	0.089
64657	M6	37	0.008
64657	MK3	27.3	0.013
64657	S4	334.8	0.006
64657	MN4	167.6	0.019
64657	NU2	61.3	0.013
64657	S6	10.7	0.001
64657	MU2	118.1	0.007
64657	2N2	42.7	0.005
64657	OO1	159.2	0.019
64657	LDA2	111.8	0.011
64657	M1	147	0.012
64657	J1	248.8	0.012
64657	RHO1	38.3	0.028
64657	Q1	9.1	0.008
64657	2Q1	239.6	0.008
64657	P1	86.9	0.037
64657	2SM2	24	0.002
64657	M3	223.3	0.006
64657	L2	137.1	0.015
64657	2MK3	319.8	0.001
64657	K2	59.2	0.043
64657	M8	278.8	0.002
64657	MS4	6.7	0.009
64658	M2	66.7	0.368
64658	S2	90.6	0.114
64658	N2	47.5	0.073
64658	K1	99.6	0.16
64658	M4	164.4	0.031
64658	O1	99.4	0.094
64658	M6	28.6	0.009
64658	MK3	26.8	0.014
64658	S4	333.7	0.006
64658	MN4	156.8	0.02
64658	NU2	68.2	0.011
64658	S6	101.9	0.001
64658	MU2	91.2	0.005
64658	2N2	221.2	0.002
64658	OO1	150	0.019
64658	LDA2	122.7	0.012
64658	M1	140.2	0.013
64658	J1	252.9	0.016
64658	RHO1	37	0.033
64658	Q1	3	0.009
64658	2Q1	237.8	0.005
64658	P1	85.1	0.036
64658	2SM2	70	0.004
64658	M3	199.9	0.007
64658	L2	163.1	0.012
64658	2MK3	31.5	0.004
64658	K2	57.5	0.04
64658	M8	284.4	0.001
64658	MS4	342.9	0.01
64659	M2	63.5	0.36
64659	S2	87.8	0.111
64659	N2	48.6	0.073
64659	K1	97	0.168
64659	M4	154.5	0.033
64659	O1	97.8	0.099
64659	M6	12.4	0.01
64659	MK3	21.9	0.016
64659	S4	351.9	0.005
64659	MN4	138.2	0.021
64659	NU2	76.3	0.009
64659	S6	155.6	0.002
64659	MU2	34	0.004
64659	2N2	216.8	0.009
64659	OO1	141.7	0.02
64659	LDA2	135.1	0.011
64659	M1	130.8	0.012
64659	J1	255.1	0.017
64659	RHO1	30.7	0.033
64659	Q1	352.2	0.008
64659	P1	84	0.035
64659	2SM2	61.5	0.006
64659	M3	178.4	0.007
64659	L2	178.9	0.011
64659	2MK3	20.9	0.006
64659	K2	48.5	0.034
64659	M8	289.6	0.001
64659	MS4	314.3	0.011
64660	M2	66.1	0.354
64660	S2	90.9	0.106
64660	N2	53.9	0.075
64660	K1	97.7	0.177
64660	M4	151.6	0.032
64660	O1	96.5	0.106
64660	M6	11.9	0.008
64660	MK3	31.6	0.016
64660	S4	16.1	0.006
64660	MN4	128.9	0.021
64660	NU2	98.5	0.008
64660	S6	189.4	0.003
64660	MU2	5.1	0.007
64660	2N2	219.3	0.015
64660	OO1	138.1	0.022
64660	LDA2	145.1	0.012
64660	M1	122.4	0.011
64660	J1	261.7	0.015
64660	RHO1	24.9	0.03
64660	Q1	336.9	0.006
64660	2Q1	64.7	0.006
64660	P1	88.1	0.03
64660	2SM2	73	0.007
64660	M3	165.8	0.007
64660	L2	185.1	0.01
64660	2MK3	9.1	0.009
64660	K2	41.8	0.031
64660	M8	274.6	0.001
64660	MS4	303.7	0.011
64661	M2	65.6	0.351
64661	S2	89.5	0.098
64661	N2	55.1	0.078
64661	K1	97.1	0.186
64661	M4	141.2	0.031
64661	O1	92.7	0.114
64661	M6	355.2	0.007
64661	MK3	28.9	0.017
64661	S4	29.5	0.008
64661	MN4	119.5	0.021
64661	NU2	107.8	0.01
64661	S6	150.9	0.002
64661	MU2	350.7	0.01
64661	2N2	219.2	0.021
64661	OO1	133.6	0.021
64661	LDA2	149.5	0.01
64661	M1	110.6	0.01
64661	J1	263	0.009
64661	RHO1	11.2	0.025
64661	Q1	279	0.003
64661	2Q1	56.4	0.01
64661	P1	92.2	0.026
64661	2SM2	75.7	0.008
64661	M3	151.9	0.009
64661	L2	155.8	0.008
64661	2MK3	359.2	0.013
64661	K2	32.1	0.029
64661	M8	150.8	0.001
64661	MS4	284.6	0.01
64662	M2	64.5	0.35
64662	S2	87.9	0.091
64662	N2	56.4	0.081
64662	K1	96.5	0.197
64662	M4	128.5	0.029
64662	O1	89.2	0.12
64662	M6	342.8	0.007
64662	MK3	22.9	0.015
64662	S4	35.5	0.008
64662	MN4	112.3	0.019
64662	NU2	119	0.011
64662	S6	111.4	0.003
64662	MU2	348.5	0.01
64662	2N2	217.2	0.022
64662	OO1	126.7	0.022
64662	LDA2	144.6	0.01
64662	M1	92.8	0.011
64662	J1	234	0.002
64662	RHO1	351.8	0.019
64662	Q1	206.6	0.004
64662	2Q1	56.5	0.011
64662	P1	98.2	0.025
64662	2SM2	76	0.009
64662	M3	145.9	0.011
64662	L2	116.7	0.009
64662	2MK3	352.9	0.018
64662	K2	22.9	0.031
64662	M8	152.4	0.002
64662	MS4	246.3	0.008
64663	M2	62.8	0.349
64663	S2	89.8	0.087
64663	N2	57.2	0.083
64663	K1	96.1	0.205
64663	M4	116.9	0.026
64663	O1	86.6	0.128
64663	M6	317	0.006
64663	MK3	17.3	0.014
64663	S4	32.7	0.008
64663	MN4	103	0.015
64663	NU2	128.2	0.012
64663	S6	105.1	0.003
64663	MU2	359.4	0.009
64663	2N2	215.8	0.019
64663	OO1	120.9	0.027
64663	LDA2	130.5	0.01
64663	M1	81	0.011
64663	J1	117.8	0.006
64663	RHO1	311.1	0.014
64663	Q1	167.8	0.009
64663	2Q1	39.2	0.01
64663	P1	100.2	0.028
64663	2SM2	67.9	0.009
64663	M3	132.4	0.014
64663	L2	81.3	0.011
64663	2MK3	343.8	0.023
64663	K2	18.4	0.03
64663	M8	154.2	0.003
64663	MS4	197.3	0.008
64664	M2	60.8	0.347
64664	S2	94.2	0.089
64664	N2	53.1	0.085
64664	K1	96.8	0.212
64664	M4	105.2	0.02
64664	O1	83.4	0.134
64664	M6	281.5	0.007
64664	MK3	4.3	0.01
64664	S4	27.6	0.01
64664	MN4	86.6	0.009
64664	NU2	121	0.013
64664	S6	98.4	0.003
64664	MU2	3.3	0.007
64664	2N2	211.3	0.013
64664	OO1	118.3	0.033
64664	LDA2	115.4	0.011
64664	M1	73.4	0.011
64664	J1	120.2	0.013
64664	RHO1	272.7	0.016
64664	Q1	160.5	0.012
64664	2Q1	7.8	0.01
64664	P1	102.4	0.034
64664	2SM2	69.1	0.007
64664	M3	117.7	0.018
64664	L2	54.8	0.014
64664	2MK3	328	0.03
64664	K2	18.5	0.026
64664	M8	150.4	0.005
64664	MS4	169.8	0.008
64665	M2	58.7	0.34
64665	S2	98.1	0.098
64665	N2	46.9	0.086
64665	K1	99.1	0.218
64665	M4	95.4	0.015
64665	O1	80.3	0.138
64665	M6	238.2	0.008
64665	MK3	347	0.009
64665	S4	16.1	0.011
64665	MN4	59.1	0.005
64665	NU2	107.3	0.017
64665	S6	114.2	0.001
64665	MU2	356.1	0.005
64665	2N2	207.7	0.007
64665	OO1	118.8	0.042
64665	LDA2	113.1	0.012
64665	M1	71	0.01
64665	J1	137.5	0.018
64665	RHO1	267.8	0.016
64665	Q1	148.7	0.008
64665	2Q1	338.1	0.013
64665	P1	100.7	0.037
64665	2SM2	36.9	0.005
64665	M3	98.4	0.021
64665	L2	26.9	0.018
64665	2MK3	310.9	0.033
64665	K2	34.9	0.018
64665	M8	129.2	0.005
64665	MS4	143.4	0.007
64666	M2	56.3	0.323
64666	S2	100.3	0.105
64666	N2	38.6	0.083
64666	K1	101.4	0.222
64666	M4	68.7	0.01
64666	O1	79.1	0.14
64666	M6	213.5	0.012
64666	MK3	313	0.014
64666	S4	7	0.012
64666	MN4	27.7	0.002
64666	NU2	90.3	0.018
64666	S6	301	0.001
64666	MU2	310	0.004
64666	2N2	203.1	0.003
64666	OO1	125.8	0.047
64666	LDA2	129.1	0.01
64666	M1	69	0.01
64666	J1	146.7	0.022
64666	RHO1	270.2	0.011
64666	Q1	75.9	0.006
64666	2Q1	322.8	0.017
64666	P1	99.8	0.04
64666	2SM2	359.1	0.005
64666	M3	81.1	0.024
64666	L2	2.9	0.024
64666	2MK3	292.2	0.037
64666	K2	63	0.013
64666	M8	97.2	0.007
64666	MS4	113.3	0.004
64667	M2	54.4	0.3
64667	S2	98.6	0.109
64667	N2	28.1	0.076
64667	K1	102.6	0.222
64667	M4	41.8	0.012
64667	O1	78.6	0.138
64667	M6	200.5	0.015
64667	MK3	299.6	0.023
64667	S4	8.6	0.013
64667	MN4	117.8	0.001
64667	NU2	68.6	0.018
64667	S6	292.3	0.003
64667	MU2	312	0.005
64667	2N2	318.8	0.002
64667	OO1	130	0.039
64667	LDA2	172.6	0.006
64667	M1	72.1	0.009
64667	J1	153.6	0.026
64667	RHO1	294.5	0.007
64667	Q1	46.2	0.008
64667	2Q1	328.3	0.019
64667	P1	96.6	0.04
64667	2SM2	357.5	0.006
64667	M3	65.2	0.025
64667	L2	349.8	0.032
64667	2MK3	276.5	0.039
64667	K2	93.4	0.018
64667	M8	89.3	0.008
64667	MS4	39.1	0.003
64668	M2	53.3	0.273
64668	S2	95	0.099
64668	N2	19.7	0.067
64668	K1	101.7	0.22
64668	M4	25.5	0.015
64668	O1	80.1	0.135
64668	M6	186.5	0.017
64668	MK3	294.4	0.036
64668	S4	9	0.014
64668	MN4	134.2	0.004
64668	NU2	47.4	0.018
64668	S6	268.2	0.006
64668	MU2	327.5	0.009
64668	2N2	289.2	0.008
64668	OO1	115.7	0.023
64668	LDA2	222.4	0.007
64668	M1	91.5	0.008
64668	J1	162.1	0.028
64668	RHO1	349.4	0.007
64668	Q1	78.1	0.007
64668	2Q1	335	0.019
64668	P1	93.6	0.035
64668	2SM2	5.4	0.008
64668	M3	47.6	0.021
64668	L2	336.5	0.032
64668	2MK3	265.6	0.039
64668	K2	95.2	0.023
64668	M8	79.9	0.008
64668	MS4	334.8	0.008
64669	M2	43.6	0.061
64669	S2	30.2	0.014
64669	N2	28	0.006
64669	K1	330.7	0.011
64669	M4	33.3	0.007
64669	O1	132.2	0.028
64669	M6	151.2	0.002
64669	MK3	333.7	0.014
64669	S4	56.1	0.001
64669	MN4	7.5	0.005
64669	S6	48.7	0.002
64669	2N2	297.7	0.008
64669	OO1	79.9	0.031
64669	M1	322.2	0.003
64669	J1	160.3	0.011
64669	Q1	168	0.008
64669	2Q1	5.2	0.01
64669	2SM2	317.7	0.012
64669	M3	41.7	0.004
64669	L2	78	0.018
64669	2MK3	184.6	0.01
64669	MS4	67.6	0.006
64670	M2	46	0.071
64670	S2	38.1	0.018
64670	N2	43.4	0.008
64670	K1	15.7	0.009
64670	M4	27.6	0.009
64670	O1	138.8	0.024
64670	M6	165.9	0.001
64670	MK3	343.6	0.011
64670	S4	18.2	0.001
64670	MN4	18.2	0.004
64670	S6	79.3	0.001
64670	2N2	282.8	0.01
64670	OO1	82.5	0.028
64670	M1	327.1	0.003
64670	J1	158.2	0.008
64670	Q1	163.8	0.006
64670	2Q1	14.7	0.008
64670	2SM2	311.4	0.012
64670	M3	46.2	0.003
64670	L2	86.3	0.02
64670	2MK3	205.3	0.011
64670	M8	340.7	0.001
64670	MS4	51.7	0.008
64671	M2	47.6	0.078
64671	S2	42.5	0.021
64671	N2	50.4	0.011
64671	K1	57.5	0.014
64671	M4	23.2	0.011
64671	O1	148.2	0.018
64671	M6	280.1	0.001
64671	MK3	359.5	0.007
64671	MN4	39.8	0.004
64671	S6	166.4	0.001
64671	2N2	263.5	0.01
64671	OO1	85.4	0.021
64671	M1	333.7	0.004
64671	J1	149.7	0.005
64671	Q1	154.8	0.004
64671	2Q1	31	0.007
64671	2SM2	297.2	0.011
64671	M3	51.5	0.004
64671	L2	89.3	0.02
64671	2MK3	222.2	0.012
64671	M8	348.3	0.001
64671	MS4	40.9	0.009
64672	M2	48.2	0.078
64672	S2	45.1	0.023
64672	N2	55.8	0.013
64672	K1	78.7	0.021
64672	M4	15.6	0.011
64672	O1	155.6	0.009
64672	M6	296.8	0.001
64672	MK3	42.8	0.005
64672	MN4	35.2	0.004
64672	S6	187.9	0.002
64672	2N2	248.2	0.01
64672	OO1	89.8	0.011
64672	M1	328.5	0.003
64672	J1	141.1	0.003
64672	Q1	117.9	0.002
64672	2Q1	50.8	0.007
64672	2SM2	279.4	0.008
64672	M3	67.4	0.002
64672	L2	84.4	0.018
64672	2MK3	232.7	0.012
64672	M8	268.8	0.001
64672	MS4	39.3	0.008
64673	M2	48.7	0.072
64673	S2	50.8	0.021
64673	N2	56.8	0.015
64673	K1	94.2	0.03
64673	M4	10.7	0.008
64673	O1	111.9	0.002
64673	M6	226.6	0.001
64673	MK3	95.4	0.008
64673	S4	192.9	0.002
64673	MN4	14.9	0.002
64673	S6	191.4	0.002
64673	2N2	236.1	0.009
64673	OO1	146.9	0.003
64673	M1	333.7	0.001
64673	J1	15.4	0.001
64673	Q1	82.7	0.004
64673	2Q1	76.8	0.007
64673	2SM2	240.2	0.005
64673	M3	120.4	0.001
64673	L2	73.7	0.012
64673	2MK3	245.5	0.01
64673	MS4	54.8	0.005
64674	M2	52.8	0.062
64674	S2	67.6	0.018
64674	N2	56.8	0.016
64674	K1	109.2	0.039
64674	M4	45.3	0.003
64674	O1	47.5	0.008
64674	M6	134.8	0.001
64674	MK3	115	0.014
64674	S4	177.9	0.004
64674	S6	207.8	0.001
64674	2N2	209.9	0.004
64674	OO1	213.2	0.005
64674	M1	124.4	0.001
64674	J1	5.3	0.004
64674	Q1	73	0.006
64674	2Q1	106.9	0.008
64674	2SM2	173.7	0.004
64674	M3	177.2	0.003
64674	L2	43.2	0.006
64674	2MK3	269.9	0.004
64674	MS4	107.6	0.004
64675	M2	76.6	0.051
64675	S2	102.3	0.019
64675	N2	58.6	0.015
64675	K1	129.8	0.05
64675	M4	123.2	0.01
64675	O1	72.5	0.018
64675	M6	76.6	0.003
64675	MK3	131.2	0.023
64675	S4	147.7	0.004
64675	MN4	150.3	0.002
64675	S6	288.7	0.001
64675	2N2	126.6	0.003
64675	OO1	188.1	0.006
64675	M1	140.7	0.003
64675	J1	51.3	0.005
64675	Q1	76.5	0.006
64675	2Q1	157.7	0.01
64675	2SM2	126.3	0.008
64675	M3	214.1	0.005
64675	L2	265.6	0.005
64675	2MK3	46.1	0.008
64675	MS4	125	0.008
64676	M2	118.6	0.081
64676	S2	128.6	0.029
64676	N2	61.3	0.014
64676	K1	153.2	0.074
64676	M4	127.5	0.02
64676	O1	100.1	0.043
64676	M6	188	0.002
64676	MK3	147.5	0.036
64676	S4	164.5	0.005
64676	MN4	106.1	0.006
64676	S6	20.9	0.001
64676	2N2	72.1	0.011
64676	OO1	218.8	0.016
64676	M1	130.2	0.008
64676	J1	53.1	0.012
64676	Q1	79.9	0.002
64676	2Q1	157.4	0.011
64676	2SM2	115.1	0.009
64676	M3	202.5	0.007
64676	L2	216.1	0.015
64676	2MK3	65	0.017
64676	M8	167.9	0.002
64676	MS4	145.2	0.014
64677	M2	65.9	0.064
64677	S2	86.2	0.025
64677	N2	32.4	0.022
64677	K1	115	0.019
64677	M4	318.5	0.008
64677	O1	69.2	0.037
64677	M6	236.5	0.01
64677	MK3	38.9	0.01
64677	S4	233.5	0.001
64677	MN4	303.5	0.002
64677	S6	142.2	0.003
64677	2N2	73.7	0.008
64677	OO1	309.5	0.005
64677	M1	190.6	0.003
64677	J1	123.1	0.005
64677	Q1	80.3	0.011
64677	2Q1	210.2	0.012
64677	P1	18.5	0.009
64677	2SM2	230.8	0.002
64677	M3	201.1	0.002
64677	L2	357.4	0.008
64677	2MK3	346.6	0.012
64677	K2	129.9	0.011
64677	M8	242.5	0.003
64677	MS4	21	0.004
64678	M2	72.8	0.165
64678	S2	88.2	0.038
64678	N2	60.4	0.029
64678	K1	83.9	0.066
64678	M4	350.7	0.017
64678	O1	105.5	0.031
64678	M6	262.3	0.003
64678	MK3	41.7	0.019
64678	S4	328.7	0.002
64678	MN4	352.2	0.005
64678	S6	284.7	0.002
64678	2N2	9.5	0.014
64678	OO1	219.3	0.02
64678	M1	117.6	0.002
64678	J1	29.1	0.002
64678	Q1	159.3	0.005
64678	2Q1	52.7	0.002
64678	P1	90.9	0.02
64678	2SM2	56	0.005
64678	M3	109.5	0.006
64678	L2	86.5	0.015
64678	2MK3	311	0.013
64678	K2	85	0.017
64678	M8	340	0.002
64678	MS4	21.3	0.009
64679	M2	53.1	0.039
64679	S2	82.5	0.017
64679	N2	25.3	0.02
64679	K1	87.2	0.011
64679	M4	179	0.024
64679	O1	3.1	0.033
64679	M6	189.6	0.002
64679	MK3	16.1	0.015
64679	S4	39.9	0.003
64679	MN4	174.1	0.015
64679	S6	0.4	0.001
64679	2N2	205	0.004
64679	OO1	4.1	0.01
64679	M1	29.5	0.011
64679	J1	32	0.006
64679	Q1	342.8	0.002
64679	2Q1	65.2	0.011
64679	2SM2	97.7	0.007
64679	M3	163	0.003
64679	L2	226.2	0.022
64679	2MK3	104.2	0.006
64679	M8	50.9	0.002
64679	MS4	186.8	0.009
64680	M2	58.4	0.086
64680	S2	66.4	0.034
64680	N2	29.7	0.017
64680	K1	80.3	0.015
64680	M4	116.2	0.01
64680	O1	30.8	0.012
64680	M6	142.8	0.002
64680	MK3	332.2	0.014
64680	S4	39.6	0.002
64680	MN4	138	0.004
64680	S6	16.7	0.003
64680	2N2	355.1	0.004
64680	OO1	44.6	0.004
64680	M1	340.3	0.003
64680	J1	176.9	0.008
64680	Q1	205.3	0.005
64680	2Q1	25.2	0.008
64680	2SM2	45	0.002
64680	M3	170.3	0.006
64680	L2	142.9	0.011
64680	2MK3	229.3	0.005
64680	M8	18	0.001
64680	MS4	108.7	0.009
64681	M2	65.4	0.13
64681	S2	75	0.024
64681	N2	63.1	0.023
64681	K1	126.4	0.042
64681	M4	25.5	0.021
64681	O1	136.5	0.042
64681	M6	283.9	0.009
64681	MK3	183.7	0.018
64681	S4	208	0.01
64681	MN4	23.9	0.015
64681	S6	359.2	0.001
64681	2N2	60	0.01
64681	OO1	160.2	0.024
64681	M1	220.2	0.004
64681	J1	264.7	0.004
64681	Q1	125.1	0.012
64681	2Q1	249.5	0.01
64681	2SM2	256.6	0.012
64681	M3	180	0.007
64681	L2	63.3	0.039
64681	2MK3	153.4	0.008
64681	M8	215.6	0.003
64681	MS4	93	0.006
64682	M2	28.7	0.136
64682	S2	48.2	0.032
64682	N2	2.4	0.031
64682	K1	39.5	0.044
64682	M4	191.7	0.027
64682	O1	7.3	0.066
64682	M6	147.6	0.004
64682	MK3	311.5	0.024
64682	S4	28.1	0.003
64682	MN4	174.7	0.014
64682	S6	14.7	0.002
64682	2N2	345.4	0.012
64682	OO1	156	0.006
64682	M1	45.2	0.009
64682	J1	343.9	0.008
64682	Q1	10.9	0.012
64682	2Q1	346.5	0.002
64682	P1	312.8	0.017
64682	2SM2	350.1	0.005
64682	M3	26.1	0.013
64682	L2	145.5	0.011
64682	2MK3	271.2	0.018
64682	K2	348.5	0.021
64682	M8	345.6	0.002
64682	MS4	239.6	0.005
64683	M2	32.6	0.142
64683	S2	52	0.035
64683	N2	5	0.031
64683	K1	41.1	0.045
64683	M4	192.2	0.023
64683	O1	8.2	0.064
64683	M6	142.5	0.004
64683	MK3	309.9	0.026
64683	S4	14.5	0.005
64683	MN4	174.8	0.013
64683	S6	12.5	0.002
64683	2N2	348.2	0.012
64683	OO1	150.8	0.008
64683	M1	49.2	0.009
64683	J1	349.9	0.008
64683	Q1	14.9	0.013
64683	2Q1	31.4	0.001
64683	P1	315.1	0.018
64683	2SM2	329.2	0.006
64683	M3	23.8	0.012
64683	L2	138.8	0.013
64683	2MK3	273.1	0.019
64683	K2	349.5	0.019
64683	M8	340.3	0.002
64683	MS4	268.9	0.003
64684	M2	35.9	0.146
64684	S2	53	0.038
64684	N2	7.7	0.03
64684	K1	40.8	0.047
64684	M4	191	0.019
64684	O1	10.2	0.059
64684	M6	139.8	0.004
64684	MK3	308.4	0.026
64684	S4	10.2	0.006
64684	MN4	176.7	0.012
64684	S6	12.6	0.002
64684	2N2	345.9	0.012
64684	OO1	142.3	0.01
64684	M1	49.7	0.008
64684	J1	357.6	0.007
64684	Q1	13.5	0.013
64684	2Q1	114.7	0.003
64684	P1	323.4	0.018
64684	2SM2	314.1	0.007
64684	M3	18	0.012
64684	L2	135.4	0.012
64684	2MK3	272.5	0.02
64684	K2	355.1	0.017
64684	M8	339.8	0.002
64684	MS4	314.9	0.003
64685	M2	39.2	0.15
64685	S2	54.6	0.039
64685	N2	11.9	0.029
64685	K1	43.7	0.048
64685	M4	180.9	0.014
64685	O1	12.4	0.053
64685	M6	128	0.002
64685	MK3	309	0.024
64685	S4	0.2	0.007
64685	MN4	177.3	0.01
64685	S6	0.6	0.001
64685	2N2	336.1	0.012
64685	OO1	133.3	0.014
64685	M1	44.9	0.006
64685	J1	12.7	0.007
64685	Q1	13.1	0.012
64685	2Q1	122.3	0.005
64685	P1	330.2	0.018
64685	2SM2	310.2	0.007
64685	M3	12.6	0.011
64685	L2	139.1	0.012
64685	2MK3	270.7	0.019
64685	K2	358.6	0.018
64685	M8	323	0.002
64685	MS4	345.1	0.004
64686	M2	43	0.155
64686	S2	59.5	0.039
64686	N2	17.2	0.03
64686	K1	49.8	0.051
64686	M4	152.1	0.01
64686	O1	16.6	0.045
64686	M6	47.4	0.001
64686	MK3	314.8	0.021
64686	S4	357.1	0.007
64686	MN4	175.3	0.008
64686	S6	274.9	0.001
64686	2N2	328.9	0.01
64686	OO1	124.9	0.017
64686	M1	37.9	0.005
64686	J1	31.8	0.006
64686	Q1	13.9	0.011
64686	2Q1	126.9	0.007
64686	P1	339.7	0.016
64686	2SM2	305	0.007
64686	M3	10	0.011
64686	L2	144.3	0.012
64686	2MK3	267.5	0.016
64686	K2	356.8	0.018
64686	M8	322.6	0.002
64686	MS4	351.8	0.005
64687	M2	47.5	0.161
64687	S2	63.8	0.04
64687	N2	25.2	0.031
64687	K1	57	0.055
64687	M4	111.7	0.01
64687	O1	25.5	0.039
64687	M6	316.1	0.001
64687	MK3	326.6	0.015
64687	S4	356.4	0.007
64687	MN4	167.2	0.005
64687	S6	255.9	0.001
64687	2N2	319.4	0.009
64687	OO1	114.9	0.021
64687	M1	37.6	0.004
64687	J1	54.7	0.004
64687	Q1	13	0.009
64687	2Q1	124.7	0.009
64687	P1	358.1	0.012
64687	2SM2	308.9	0.008
64687	M3	15	0.009
64687	L2	148.3	0.013
64687	2MK3	267.4	0.013
64687	K2	357.2	0.018
64687	M8	335	0.002
64687	MS4	356.4	0.006
64688	M2	52.2	0.168
64688	S2	65.9	0.042
64688	N2	34	0.034
64688	K1	65.7	0.06
64688	M4	88.1	0.014
64688	O1	38.5	0.035
64688	M6	296.2	0.003
64688	MK3	349	0.011
64688	S4	0.1	0.005
64688	MN4	117.7	0.003
64688	S6	262.4	0.001
64688	2N2	308.3	0.006
64688	OO1	111.8	0.024
64688	M1	46.8	0.004
64688	J1	75.6	0.004
64688	Q1	10	0.007
64688	2Q1	114.7	0.01
64688	P1	28.8	0.01
64688	2SM2	313.6	0.007
64688	M3	28.2	0.006
64688	L2	148.5	0.013
64688	2MK3	267.9	0.009
64688	K2	8.2	0.016
64688	M8	3.5	0.001
64688	MS4	12.9	0.006
64689	M2	56.8	0.177
64689	S2	70.4	0.043
64689	N2	42.7	0.037
64689	K1	74.2	0.068
64689	M4	72.9	0.017
64689	O1	54.7	0.034
64689	M6	281	0.005
64689	MK3	20.5	0.009
64689	S4	12	0.003
64689	MN4	71.2	0.006
64689	2N2	297.6	0.004
64689	OO1	111.7	0.026
64689	M1	65.1	0.004
64689	J1	88.5	0.005
64689	Q1	14.5	0.006
64689	2Q1	111.3	0.012
64689	P1	84	0.012
64689	2SM2	315.5	0.006
64689	M3	59	0.003
64689	L2	143.8	0.012
64689	2MK3	274.4	0.006
64689	K2	16.2	0.013
64689	M8	8	0.001
64689	MS4	34.3	0.007
64690	M2	60.8	0.186
64690	S2	75	0.046
64690	N2	50.5	0.041
64690	K1	80.5	0.077
64690	M4	59	0.019
64690	O1	72.8	0.035
64690	M6	274	0.01
64690	MK3	59.4	0.007
64690	S4	101.1	0.001
64690	MN4	53.7	0.009
64690	S6	291	0.001
64690	2N2	272.1	0.001
64690	OO1	106.7	0.027
64690	M1	84.8	0.004
64690	J1	121.4	0.004
64690	Q1	38.7	0.004
64690	2Q1	109.9	0.012
64690	P1	108.1	0.02
64690	2SM2	312.1	0.005
64690	M3	134.9	0.002
64690	L2	129.2	0.011
64690	2MK3	299.9	0.001
64690	K2	38.3	0.01
64690	M8	248.2	0.001
64690	MS4	53.6	0.009
64691	M2	64.1	0.197
64691	S2	80.7	0.052
64691	N2	58.6	0.045
64691	K1	88.3	0.087
64691	M4	43.3	0.023
64691	O1	89.2	0.042
64691	M6	275.4	0.015
64691	MK3	93	0.01
64691	S4	170.1	0.002
64691	MN4	43.5	0.011
64691	S6	341.7	0.001
64691	2N2	93	0.002
64691	OO1	102.7	0.026
64691	M1	112.6	0.005
64691	J1	147.6	0.007
64691	Q1	101	0.004
64691	2Q1	102.6	0.011
64691	P1	123.1	0.029
64691	2SM2	281	0.004
64691	M3	174.8	0.005
64691	L2	105.5	0.008
64691	2MK3	61.9	0.006
64691	K2	88.2	0.008
64691	M8	224.5	0.002
64691	MS4	57.3	0.013
64692	M2	67.1	0.209
64692	S2	86.5	0.058
64692	N2	66.1	0.048
64692	K1	95.1	0.1
64692	M4	27.7	0.031
64692	O1	103.4	0.052
64692	M6	281.1	0.02
64692	MK3	104.1	0.018
64692	S4	196.2	0.003
64692	MN4	37.8	0.013
64692	S6	212.2	0.002
64692	2N2	77.9	0.004
64692	OO1	106.5	0.027
64692	M1	134.2	0.006
64692	J1	158.1	0.011
64692	Q1	126.9	0.008
64692	2Q1	89.9	0.01
64692	P1	128.3	0.039
64692	2SM2	245.5	0.003
64692	M3	187.3	0.009
64692	L2	60.4	0.009
64692	2MK3	66	0.015
64692	K2	129.3	0.012
64692	M8	235.9	0.004
64692	MS4	51.5	0.017
64693	M2	70.9	0.223
64693	S2	90.9	0.07
64693	N2	72.8	0.051
64693	K1	100.9	0.112
64693	M4	20.8	0.043
64693	O1	114.4	0.07
64693	M6	283	0.023
64693	MK3	104.6	0.031
64693	S4	197.7	0.002
64693	MN4	33.1	0.016
64693	S6	171.1	0.003
64693	2N2	56.5	0.005
64693	OO1	125.4	0.028
64693	M1	150	0.007
64693	J1	149.1	0.015
64693	Q1	129.4	0.011
64693	2Q1	83.2	0.01
64693	P1	126.5	0.05
64693	2SM2	214.9	0.004
64693	M3	186.2	0.013
64693	L2	32.7	0.016
64693	2MK3	60.6	0.026
64693	K2	155.2	0.02
64693	M8	239.1	0.004
64693	MS4	45.9	0.019
64694	M2	75.9	0.243
64694	S2	89.9	0.079
64694	N2	74.4	0.055
64694	K1	107.4	0.11
64694	M4	19.2	0.05
64694	O1	119.8	0.09
64694	M6	277.8	0.022
64694	MK3	103.3	0.042
64694	S4	192.9	0.004
64694	MN4	17.8	0.02
64694	S6	160.7	0.005
64694	2N2	42.2	0.01
64694	OO1	167.1	0.02
64694	M1	132.9	0.01
64694	J1	121.2	0.015
64694	Q1	121.1	0.01
64694	2Q1	59.3	0.014
64694	P1	113.2	0.049
64694	2SM2	233.9	0.005
64694	M3	163.8	0.019
64694	L2	39	0.027
64694	2MK3	53.9	0.035
64694	K2	159	0.036
64694	M8	173.8	0.003
64694	MS4	42.9	0.018
64695	M2	59.8	0.652
64695	S2	72.1	0.154
64695	N2	45.7	0.135
64695	K1	74.7	0.256
64695	M4	37.5	0.056
64695	O1	54.5	0.136
64695	M6	326.1	0.029
64695	MK3	71	0.044
64695	S4	39.1	0.005
64695	MN4	33.8	0.025
64695	S6	50.3	0.001
64695	2N2	340.4	0.026
64695	OO1	107.8	0.02
64695	M1	49	0.003
64695	J1	72.1	0.018
64695	Q1	42.2	0.023
64695	2Q1	48.6	0.008
64695	P1	67.4	0.076
64695	2SM2	332.3	0.008
64695	M3	128	0.015
64695	L2	88.7	0.046
64695	2MK3	5.3	0.029
64695	K2	73	0.04
64695	M8	327.6	0.014
64695	MS4	64.6	0.034
64696	M2	59.8	0.675
64696	S2	72.1	0.158
64696	N2	45.9	0.141
64696	K1	74.2	0.268
64696	M4	38.7	0.059
64696	O1	53.2	0.143
64696	M6	324.3	0.028
64696	MK3	74	0.048
64696	S4	38.3	0.005
64696	MN4	38	0.027
64696	S6	76.3	0.001
64696	2N2	343.9	0.028
64696	OO1	102.6	0.018
64696	M1	36.3	0.004
64696	J1	71.6	0.018
64696	Q1	40.2	0.026
64696	2Q1	50.5	0.008
64696	P1	67.4	0.08
64696	2SM2	335.9	0.007
64696	M3	130.6	0.017
64696	L2	87.9	0.047
64696	2MK3	9.6	0.032
64696	K2	71.3	0.044
64696	M8	324.2	0.014
64696	MS4	65.1	0.036
64697	M2	59.7	0.687
64697	S2	72.1	0.161
64697	N2	46.1	0.142
64697	K1	73.9	0.273
64697	M4	40	0.061
64697	O1	51.3	0.147
64697	M6	322	0.027
64697	MK3	75.6	0.049
64697	S4	38.8	0.006
64697	MN4	40.4	0.027
64697	S6	33.1	0.001
64697	2N2	345.5	0.03
64697	OO1	103.9	0.016
64697	M1	34.3	0.005
64697	J1	71.6	0.019
64697	Q1	40.8	0.026
64697	2Q1	61.4	0.007
64697	P1	67.5	0.08
64697	2SM2	335.8	0.007
64697	M3	135.1	0.019
64697	L2	87.6	0.047
64697	2MK3	13.5	0.033
64697	K2	69.7	0.046
64697	M8	322	0.013
64697	MS4	66.6	0.036
64698	M2	59.4	0.694
64698	S2	71.9	0.162
64698	N2	46.3	0.143
64698	K1	73.3	0.275
64698	M4	42	0.061
64698	O1	49.5	0.149
64698	M6	320.4	0.026
64698	MK3	76.3	0.051
64698	S4	42.2	0.006
64698	MN4	41.7	0.028
64698	S6	356.5	0.001
64698	2N2	347	0.032
64698	OO1	107.7	0.017
64698	M1	42.2	0.005
64698	J1	72.9	0.018
64698	Q1	43.6	0.027
64698	2Q1	88.5	0.006
64698	P1	67.6	0.079
64698	2SM2	343.6	0.007
64698	M3	139.5	0.019
64698	L2	86.5	0.048
64698	2MK3	17.9	0.031
64698	K2	67.6	0.05
64698	M8	321.3	0.012
64698	MS4	69.7	0.035
64699	M2	59	0.7
64699	S2	72.1	0.162
64699	N2	46.7	0.143
64699	K1	72.7	0.276
64699	M4	44.8	0.06
64699	O1	48.2	0.15
64699	M6	317.6	0.027
64699	MK3	75.6	0.052
64699	S4	39.5	0.007
64699	MN4	42.7	0.028
64699	S6	336.7	0.001
64699	2N2	347.5	0.031
64699	OO1	115.5	0.02
64699	M1	56.5	0.006
64699	J1	75	0.017
64699	Q1	48.9	0.028
64699	2Q1	115.9	0.005
64699	P1	67.9	0.079
64699	2SM2	343.7	0.006
64699	M3	144.9	0.019
64699	L2	84.2	0.047
64699	2MK3	24.4	0.03
64699	K2	64.4	0.053
64699	M8	322.4	0.012
64699	MS4	72.8	0.035
64700	M2	58.6	0.705
64700	S2	72	0.164
64700	N2	46.8	0.144
64700	K1	72.2	0.275
64700	M4	48.4	0.059
64700	O1	47	0.15
64700	M6	314.6	0.029
64700	MK3	75	0.053
64700	S4	39	0.008
64700	MN4	43.8	0.028
64700	S6	280.3	0.001
64700	2N2	347.9	0.03
64700	OO1	116.9	0.023
64700	M1	61.1	0.007
64700	J1	78.1	0.016
64700	Q1	52.5	0.029
64700	2Q1	144.3	0.005
64700	P1	68.9	0.079
64700	2SM2	340.8	0.006
64700	M3	150.7	0.019
64700	L2	82	0.047
64700	2MK3	31.6	0.029
64700	K2	63.2	0.055
64700	M8	320.6	0.012
64700	MS4	76.2	0.035
64701	M2	58.2	0.71
64701	S2	72.1	0.165
64701	N2	46.9	0.144
64701	K1	72	0.274
64701	M4	53	0.059
64701	O1	46.4	0.149
64701	M6	311.8	0.031
64701	MK3	75.4	0.054
64701	S4	37.1	0.007
64701	MN4	44.9	0.028
64701	S6	292.7	0.001
64701	2N2	346.9	0.029
64701	OO1	121	0.025
64701	M1	61.4	0.009
64701	J1	79.7	0.016
64701	Q1	56	0.03
64701	2Q1	159.1	0.006
64701	P1	69.9	0.079
64701	2SM2	345.6	0.006
64701	M3	154	0.02
64701	L2	80.7	0.047
64701	2MK3	37.6	0.03
64701	K2	62.7	0.057
64701	M8	320.3	0.012
64701	MS4	78.4	0.037
64702	M2	58.1	0.713
64702	S2	72.6	0.166
64702	N2	46.7	0.145
64702	K1	72.6	0.273
64702	M4	57.6	0.06
64702	O1	46.9	0.148
64702	M6	309.5	0.033
64702	MK3	77.2	0.055
64702	S4	32.8	0.007
64702	MN4	45	0.029
64702	S6	300.2	0.002
64702	2N2	347.5	0.028
64702	OO1	125.5	0.025
64702	M1	62.3	0.01
64702	J1	75.5	0.016
64702	Q1	55.7	0.03
64702	2Q1	163.9	0.006
64702	P1	71.3	0.078
64702	2SM2	350.3	0.006
64702	M3	155.4	0.022
64702	L2	79.5	0.047
64702	2MK3	41.5	0.032
64702	K2	63.1	0.055
64702	M8	322.7	0.011
64702	MS4	79.5	0.037
64703	M2	58.2	0.716
64703	S2	73.9	0.166
64703	N2	46.3	0.145
64703	K1	73.2	0.274
64703	M4	61	0.062
64703	O1	48.5	0.148
64703	M6	308.3	0.033
64703	MK3	81.3	0.056
64703	S4	34.7	0.006
64703	MN4	46.7	0.03
64703	S6	273.1	0.002
64703	2N2	348.3	0.028
64703	OO1	125.5	0.028
64703	M1	67.3	0.011
64703	J1	74.5	0.017
64703	Q1	56.9	0.029
64703	2Q1	173	0.005
64703	P1	72.5	0.078
64703	2SM2	351.1	0.007
64703	M3	158	0.022
64703	L2	79.2	0.047
64703	2MK3	46.1	0.034
64703	K2	61	0.054
64703	M8	330.7	0.011
64703	MS4	81.4	0.037
64704	M2	58.3	0.715
64704	S2	75.1	0.163
64704	N2	45.7	0.146
64704	K1	73.6	0.275
64704	M4	65.3	0.062
64704	O1	50.2	0.149
64704	M6	304.4	0.031
64704	MK3	86.3	0.056
64704	S4	44	0.006
64704	MN4	46.5	0.029
64704	S6	253.9	0.002
64704	2N2	350.5	0.028
64704	OO1	130	0.03
64704	M1	72.5	0.012
64704	J1	75.1	0.016
64704	Q1	57.5	0.029
64704	2Q1	187.4	0.005
64704	P1	73.4	0.079
64704	2SM2	347.9	0.007
64704	M3	156.9	0.021
64704	L2	78.4	0.047
64704	2MK3	52	0.035
64704	K2	56.4	0.055
64704	M8	341	0.01
64704	MS4	86.7	0.035
64705	M2	43.8	0.781
64705	S2	56.4	0.227
64705	N2	21.5	0.173
64705	K1	92.7	0.137
64705	M4	76.6	0.059
64705	O1	60.4	0.085
64705	M6	4.6	0.024
64705	MK3	58.1	0.029
64705	S4	30.2	0.01
64705	MN4	80.3	0.023
64705	S6	298.1	0.004
64705	2N2	296.5	0.03
64705	OO1	264.6	0.063
64705	M1	63.5	0.006
64705	J1	25	0.034
64705	Q1	104	0.027
64705	2Q1	265.9	0.042
64705	P1	269.4	0.007
64705	2SM2	287	0.005
64705	M3	301.7	0.034
64705	L2	37.5	0.108
64705	2MK3	181.1	0.066
64705	K2	150.4	0.121
64705	M8	28.4	0.015
64705	MS4	123.2	0.031
64706	M2	45.4	0.791
64706	S2	59.3	0.22
64706	N2	20.3	0.172
64706	K1	102	0.136
64706	M4	64.4	0.073
64706	O1	54.2	0.085
64706	M6	9.7	0.022
64706	MK3	65.3	0.039
64706	S4	4.2	0.009
64706	MN4	62.2	0.026
64706	S6	262.2	0.004
64706	2N2	308.8	0.033
64706	OO1	267.1	0.068
64706	M1	56.2	0.008
64706	J1	23.7	0.036
64706	Q1	97.6	0.033
64706	2Q1	255	0.05
64706	P1	245.8	0.019
64706	2SM2	294.7	0.012
64706	M3	293.7	0.037
64706	L2	40.6	0.106
64706	2MK3	172.9	0.074
64706	K2	158.3	0.1
64706	M8	25.1	0.013
64706	MS4	133.9	0.029
64707	M2	46	0.8
64707	S2	62.4	0.207
64707	N2	19.4	0.171
64707	K1	108.8	0.145
64707	M4	58.6	0.081
64707	O1	57	0.086
64707	M6	22.3	0.02
64707	MK3	70.1	0.038
64707	S4	346.7	0.01
64707	MN4	47.2	0.03
64707	S6	253.3	0.006
64707	2N2	310.6	0.039
64707	OO1	266.2	0.069
64707	M1	60.2	0.007
64707	J1	18.9	0.037
64707	Q1	98.4	0.038
64707	2Q1	250.1	0.055
64707	P1	237.1	0.032
64707	2SM2	292.8	0.018
64707	M3	288	0.039
64707	L2	42.6	0.108
64707	2MK3	166.9	0.077
64707	K2	163.1	0.083
64707	M8	25.1	0.011
64707	MS4	137.7	0.025
64708	M2	46.2	0.805
64708	S2	65	0.19
64708	N2	18.5	0.17
64708	K1	112.1	0.154
64708	M4	54.6	0.083
64708	O1	61.4	0.088
64708	M6	46.3	0.019
64708	MK3	74.5	0.033
64708	S4	332.5	0.011
64708	MN4	37.4	0.034
64708	S6	247.4	0.008
64708	2N2	309.7	0.041
64708	OO1	264.1	0.069
64708	M1	56.9	0.007
64708	J1	17.3	0.038
64708	Q1	98.7	0.045
64708	2Q1	247.3	0.059
64708	P1	234.6	0.038
64708	2SM2	287.5	0.024
64708	M3	285.5	0.042
64708	L2	43.3	0.108
64708	2MK3	162.6	0.077
64708	K2	164.8	0.067
64708	M8	29.4	0.01
64708	MS4	134	0.022
64709	M2	46.4	0.807
64709	S2	69.5	0.174
64709	N2	18.3	0.169
64709	K1	114.1	0.166
64709	M4	51.3	0.083
64709	O1	66.4	0.091
64709	M6	70.6	0.022
64709	MK3	77.9	0.027
64709	S4	323	0.012
64709	MN4	31.1	0.039
64709	S6	246.2	0.008
64709	2N2	306.7	0.042
64709	OO1	261.4	0.07
64709	M1	61.6	0.005
64709	J1	12.8	0.039
64709	Q1	98.8	0.049
64709	2Q1	244.9	0.064
64709	P1	229.4	0.044
64709	2SM2	282.7	0.029
64709	M3	284.6	0.043
64709	L2	44.1	0.109
64709	2MK3	159.9	0.075
64709	K2	174	0.052
64709	M8	39.1	0.009
64709	MS4	126.8	0.02
64710	M2	46.4	0.811
64710	S2	74.6	0.161
64710	N2	18.6	0.166
64710	K1	114	0.179
64710	M4	50.8	0.081
64710	O1	73.9	0.099
64710	M6	81.1	0.027
64710	MK3	82.4	0.019
64710	S4	311.8	0.014
64710	MN4	23.4	0.045
64710	S6	241.5	0.008
64710	2N2	302	0.042
64710	OO1	252.4	0.071
64710	M1	138.7	0.002
64710	J1	1	0.041
64710	Q1	98.8	0.047
64710	2Q1	243.4	0.067
64710	P1	226.2	0.048
64710	2SM2	283.8	0.032
64710	M3	282.4	0.04
64710	L2	46.5	0.117
64710	2MK3	158.2	0.07
64710	K2	183.4	0.045
64710	M8	63.8	0.006
64710	MS4	109	0.019
64711	M2	46.3	0.815
64711	S2	81.9	0.15
64711	N2	20	0.16
64711	K1	113.7	0.192
64711	M4	51.1	0.078
64711	O1	82	0.109
64711	M6	82.1	0.033
64711	MK3	89	0.01
64711	S4	300.6	0.018
64711	MN4	19.1	0.051
64711	S6	241.3	0.007
64711	2N2	295.8	0.042
64711	OO1	242.1	0.071
64711	M1	209.1	0.007
64711	J1	350.4	0.043
64711	Q1	104.1	0.039
64711	2Q1	242.4	0.071
64711	P1	224.3	0.051
64711	2SM2	287.5	0.034
64711	M3	278.2	0.037
64711	L2	48.2	0.126
64711	2MK3	155.9	0.063
64711	K2	207.8	0.039
64711	M8	102.5	0.006
64711	MS4	87.5	0.02
64712	M2	46.3	0.818
64712	S2	91	0.141
64712	N2	22.1	0.154
64712	K1	113.4	0.199
64712	M4	52.8	0.079
64712	O1	87.7	0.117
64712	M6	80.5	0.038
64712	MK3	105.6	0.005
64712	S4	299.7	0.021
64712	MN4	16.9	0.053
64712	S6	231	0.004
64712	2N2	288.5	0.044
64712	OO1	235.8	0.07
64712	M1	216.4	0.012
64712	J1	343.8	0.043
64712	Q1	118.8	0.032
64712	2Q1	241.5	0.075
64712	P1	223.8	0.05
64712	2SM2	287.1	0.037
64712	M3	274	0.035
64712	L2	49.5	0.131
64712	2MK3	152.8	0.058
64712	K2	247.1	0.044
64712	M8	141	0.008
64712	MS4	69.1	0.021
64713	M2	46.3	0.815
64713	S2	99.4	0.131
64713	N2	23.1	0.15
64713	K1	113.6	0.192
64713	M4	54.1	0.082
64713	O1	89.8	0.121
64713	M6	82.5	0.042
64713	MK3	231.8	0.002
64713	S4	297.7	0.025
64713	MN4	18	0.051
64713	S6	241.1	0.003
64713	2N2	283.3	0.043
64713	OO1	233.6	0.074
64713	M1	223.9	0.014
64713	J1	342.1	0.041
64713	Q1	132	0.032
64713	2Q1	241.2	0.081
64713	P1	231.7	0.043
64713	2SM2	283.3	0.04
64713	M3	271.5	0.036
64713	L2	51	0.129
64713	2MK3	150.6	0.056
64713	K2	269.8	0.062
64713	M8	148	0.011
64713	MS4	61.6	0.022
64714	M2	73.1	1.882
64714	S2	99.7	0.4
64714	N2	64.8	0.37
64714	K1	90.8	0.762
64714	M4	95.4	0.205
64714	O1	76.2	0.451
64714	M6	15.6	0.185
64714	MK3	133.3	0.14
64714	S4	59.3	0.002
64714	MN4	90.4	0.093
64714	S6	155.7	0.01
64714	2N2	332.8	0.048
64714	OO1	153.3	0.119
64714	M1	112.4	0.021
64714	J1	101.9	0.038
64714	Q1	88.2	0.082
64714	2Q1	194.7	0.012
64714	P1	94.4	0.212
64714	2SM2	284.6	0.016
64714	M3	212.9	0.04
64714	L2	72	0.13
64714	2MK3	116.2	0.136
64714	K2	48.7	0.16
64714	M8	65.5	0.063
64714	MS4	135.2	0.096
64715	M2	72.1	2.31
64715	S2	99.2	0.47
64715	N2	63.5	0.445
64715	K1	88.8	0.912
64715	M4	97	0.196
64715	O1	72.2	0.53
64715	M6	11.3	0.204
64715	MK3	136.4	0.118
64715	S4	139.7	0.011
64715	MN4	91.6	0.091
64715	S6	155.1	0.011
64715	2N2	345.9	0.068
64715	OO1	152	0.147
64715	M1	98.7	0.024
64715	J1	102.2	0.044
64715	Q1	83.5	0.094
64715	2Q1	179	0.012
64715	P1	91	0.239
64715	2SM2	272	0.022
64715	M3	213.6	0.032
64715	L2	70.6	0.16
64715	2MK3	128	0.132
64715	K2	51.9	0.212
64715	M8	78.6	0.056
64715	MS4	145.2	0.123
64716	M2	70.9	0.405
64716	S2	84	0.102
64716	N2	47.4	0.08
64716	K1	84.9	0.139
64716	M4	70.4	0.043
64716	O1	59.6	0.053
64716	M6	148.3	0.01
64716	MK3	52.3	0.036
64716	S4	336.3	0.004
64716	MN4	98.8	0.019
64716	NU2	84.1	0.031
64716	S6	142.3	0.004
64716	MU2	248.4	0.012
64716	2N2	356.1	0.012
64716	OO1	346.2	0.004
64716	LDA2	48.5	0.019
64716	M1	348.3	0.002
64716	J1	114.1	0.013
64716	RHO1	209.2	0.009
64716	Q1	23.6	0.005
64716	2Q1	18.3	0.017
64716	P1	73.9	0.044
64716	2SM2	330.5	0.004
64716	M3	141.4	0.015
64716	L2	124.7	0.045
64716	2MK3	355.4	0.009
64716	K2	65.1	0.028
64716	M8	153.5	0.008
64716	MS4	111	0.004
64717	M2	74.2	0.415
64717	S2	90.1	0.092
64717	N2	62.4	0.079
64717	K1	88.6	0.154
64717	M4	51.2	0.004
64717	O1	77.3	0.048
64717	M6	121.3	0.014
64717	MK3	47.3	0.034
64717	S4	305.1	0.002
64717	MN4	83.1	0.005
64717	NU2	29.5	0.015
64717	S6	201.4	0.003
64717	MU2	266.3	0.014
64717	2N2	151.3	0.009
64717	OO1	7.7	0.027
64717	LDA2	120.7	0.015
64717	M1	344.1	0.007
64717	J1	75	0.01
64717	RHO1	124.3	0.023
64717	Q1	34.7	0.026
64717	2Q1	21.6	0.009
64717	P1	65	0.047
64717	2SM2	280.9	0.003
64717	M3	103.3	0.011
64717	L2	117.1	0.033
64717	2MK3	284.5	0.019
64717	K2	120.8	0.032
64717	M8	24.1	0.003
64717	MS4	98.2	0.008
64718	M2	57.2	0.326
64718	S2	82.3	0.087
64718	N2	40.9	0.066
64718	K1	93.9	0.165
64718	M4	160.4	0.035
64718	O1	106.5	0.073
64718	M6	359.4	0.015
64718	MK3	86.7	0.018
64718	S4	44.8	0.008
64718	MN4	158.3	0.012
64718	NU2	55.6	0.012
64718	S6	234.1	0.003
64718	MU2	185.4	0.012
64718	2N2	7.3	0.018
64718	OO1	153.6	0.013
64718	LDA2	112	0.007
64718	M1	213.3	0.006
64718	J1	81.4	0.009
64718	RHO1	93.2	0.01
64718	Q1	353.1	0.009
64718	2Q1	318.5	0.02
64718	P1	15.3	0.033
64718	2SM2	277.1	0.008
64718	M3	338	0.006
64718	L2	355.4	0.019
64718	2MK3	116.9	0.008
64718	K2	98.1	0.045
64718	M8	66.8	0.004
64718	MS4	119.7	0.008
64719	M2	46.8	0.484
64719	S2	59.6	0.09
64719	N2	22.7	0.093
64719	K1	76.3	0.194
64719	M4	87.5	0.067
64719	O1	33.3	0.104
64719	M6	177	0.02
64719	MK3	44.8	0.021
64719	S4	147.8	0.009
64719	MN4	58.3	0.026
64719	S6	71.2	0.005
64719	2N2	337.7	0.027
64719	OO1	190	0.043
64719	M1	47.9	0.008
64719	J1	264.3	0.022
64719	Q1	68.5	0.026
64719	2Q1	194.3	0.029
64719	P1	129.3	0.05
64719	2SM2	55.2	0.011
64719	M3	314.6	0.009
64719	L2	32.7	0.038
64719	2MK3	155.2	0.015
64719	K2	45.6	0.09
64719	M8	300.8	0.019
64719	MS4	118.3	0.027
64720	M2	45.8	0.501
64720	S2	92.5	0.087
64720	N2	36.6	0.101
64720	K1	84.8	0.234
64720	M4	37	0.015
64720	O1	42.9	0.077
64720	M6	118	0.021
64720	MK3	294.1	0.031
64720	S4	123.5	0.006
64720	MN4	166.6	0.007
64720	S6	252.8	0.003
64720	2N2	310.3	0.03
64720	OO1	168.4	0.045
64720	M1	60	0.014
64720	J1	238.7	0.022
64720	Q1	76.4	0.03
64720	2Q1	177.6	0.042
64720	P1	127.2	0.116
64720	2SM2	290.1	0.015
64720	M3	359.4	0.001
64720	L2	54.6	0.045
64720	2MK3	279.2	0.035
64720	K2	4.5	0.078
64720	M8	179.1	0.019
64720	MS4	235.8	0.005
64721	M2	53.8	0.467
64721	S2	120.2	0.112
64721	N2	55	0.101
64721	K1	90.6	0.264
64721	M4	322.6	0.052
64721	O1	81	0.131
64721	M6	51.6	0.018
64721	MK3	289.6	0.047
64721	S4	95.4	0.015
64721	MN4	98.3	0.015
64721	2N2	292.6	0.029
64721	OO1	171.3	0.079
64721	M1	113.9	0.022
64721	J1	220.7	0.038
64721	Q1	89.9	0.053
64721	2Q1	160.6	0.07
64721	P1	116.8	0.157
64721	2SM2	302.5	0.033
64721	M3	56.8	0.01
64721	L2	45.4	0.04
64721	2MK3	256.4	0.043
64721	K2	342.7	0.111
64721	M8	126.7	0.005
64721	MS4	324.6	0.023
64722	M2	63	0.608
64722	S2	82.6	0.125
64722	N2	55.1	0.127
64722	K1	66.9	0.224
64722	M4	246.4	0.055
64722	O1	42	0.176
64722	M6	124.5	0.016
64722	MK3	270.4	0.033
64722	S4	29.4	0.015
64722	MN4	248.9	0.022
64722	S6	333.7	0.002
64722	2N2	334	0.028
64722	OO1	141.4	0.034
64722	M1	99.2	0.013
64722	J1	177.4	0.015
64722	Q1	61.7	0.043
64722	2Q1	199.9	0.03
64722	P1	54.8	0.058
64722	2SM2	309.9	0.001
64722	M3	34.5	0.019
64722	L2	77.4	0.054
64722	2MK3	277.6	0.049
64722	K2	48.5	0.065
64722	M8	73	0.02
64722	MS4	305.7	0.015
64723	M2	63.3	0.616
64723	S2	83.5	0.127
64723	N2	54.6	0.128
64723	K1	67.1	0.225
64723	M4	240.5	0.056
64723	O1	42.9	0.174
64723	M6	126.7	0.02
64723	MK3	268.4	0.033
64723	S4	32.5	0.015
64723	MN4	247.2	0.022
64723	S6	333.8	0.002
64723	2N2	336.7	0.029
64723	OO1	142.9	0.033
64723	M1	101.8	0.013
64723	J1	173.3	0.015
64723	Q1	61.1	0.041
64723	2Q1	200.7	0.028
64723	P1	53.9	0.061
64723	2SM2	314.1	0.001
64723	M3	37.3	0.018
64723	L2	75.1	0.053
64723	2MK3	276.4	0.047
64723	K2	48.5	0.064
64723	M8	78.3	0.021
64723	MS4	298.2	0.012
64724	M2	63.5	0.623
64724	S2	83.4	0.13
64724	N2	54	0.129
64724	K1	67.8	0.224
64724	M4	234.7	0.061
64724	O1	43.7	0.171
64724	M6	131.3	0.022
64724	MK3	266.2	0.033
64724	S4	39	0.015
64724	MN4	243	0.023
64724	S6	342.5	0.002
64724	2N2	341	0.028
64724	OO1	145.4	0.032
64724	M1	103.6	0.012
64724	J1	167.6	0.013
64724	Q1	60.4	0.04
64724	2Q1	201.5	0.027
64724	P1	51.7	0.062
64724	2SM2	342.2	0.001
64724	M3	38.9	0.015
64724	L2	74.1	0.053
64724	2MK3	274.8	0.045
64724	K2	51.3	0.067
64724	M8	80.2	0.022
64724	MS4	285.6	0.01
64725	M2	63.9	0.63
64725	S2	83.6	0.134
64725	N2	53.2	0.131
64725	K1	68.3	0.224
64725	M4	230.8	0.067
64725	O1	44.2	0.168
64725	M6	136.6	0.023
64725	MK3	263.9	0.033
64725	S4	45.2	0.015
64725	MN4	238.6	0.023
64725	S6	332.5	0.002
64725	2N2	345.2	0.028
64725	OO1	152.3	0.03
64725	M1	103.7	0.011
64725	J1	160.3	0.012
64725	Q1	60.7	0.038
64725	2Q1	200	0.026
64725	P1	49.3	0.064
64725	2SM2	7.1	0.002
64725	M3	36	0.013
64725	L2	73.2	0.053
64725	2MK3	272	0.043
64725	K2	54.7	0.066
64725	M8	79.5	0.021
64725	MS4	265	0.011
64726	M2	64.3	0.634
64726	S2	83.1	0.139
64726	N2	52.2	0.132
64726	K1	69.5	0.224
64726	M4	227.6	0.076
64726	O1	44.6	0.166
64726	M6	142.1	0.024
64726	MK3	261.2	0.035
64726	S4	53.1	0.016
64726	MN4	233.9	0.024
64726	S6	350.8	0.002
64726	2N2	350	0.028
64726	OO1	157.4	0.029
64726	M1	101.6	0.01
64726	J1	151.3	0.011
64726	Q1	62.3	0.037
64726	2Q1	202.3	0.023
64726	P1	48.3	0.064
64726	2SM2	21.5	0.003
64726	M3	29.3	0.01
64726	L2	72.8	0.054
64726	2MK3	268	0.041
64726	K2	59.4	0.067
64726	M8	78.2	0.019
64726	MS4	247.2	0.013
64727	M2	64.6	0.636
64727	S2	82.7	0.144
64727	N2	51.5	0.133
64727	K1	70.4	0.224
64727	M4	225.3	0.086
64727	O1	44.8	0.162
64727	M6	146.7	0.025
64727	MK3	258.4	0.038
64727	S4	58.7	0.016
64727	MN4	228.8	0.026
64727	S6	357.1	0.003
64727	2N2	352	0.027
64727	OO1	164.9	0.029
64727	M1	94.6	0.009
64727	J1	141.1	0.011
64727	Q1	63.8	0.034
64727	2Q1	202.9	0.021
64727	P1	46.9	0.065
64727	2SM2	34.4	0.003
64727	M3	15.9	0.005
64727	L2	72.7	0.053
64727	2MK3	262.6	0.038
64727	K2	63.7	0.067
64727	M8	74	0.018
64727	MS4	236	0.016
64728	M2	64.8	0.637
64728	S2	82.6	0.146
64728	N2	51.1	0.134
64728	K1	71.2	0.223
64728	M4	223.6	0.095
64728	O1	44.4	0.159
64728	M6	150.5	0.025
64728	MK3	256.5	0.043
64728	S4	62.1	0.016
64728	MN4	225.6	0.027
64728	S6	335.5	0.002
64728	2N2	356.2	0.026
64728	OO1	170	0.028
64728	M1	83.7	0.008
64728	J1	136.7	0.01
64728	Q1	63.5	0.03
64728	2Q1	206.1	0.019
64728	P1	45.3	0.064
64728	2SM2	44.2	0.004
64728	M3	344.6	0.002
64728	L2	72.2	0.052
64728	2MK3	257.3	0.036
64728	K2	65.9	0.068
64728	M8	66.4	0.017
64728	MS4	230.5	0.018
64729	M2	64.9	0.635
64729	S2	82.1	0.15
64729	N2	51.2	0.135
64729	K1	71.6	0.221
64729	M4	222.2	0.104
64729	O1	43.7	0.157
64729	M6	154.8	0.026
64729	MK3	256.5	0.05
64729	S4	67.7	0.017
64729	MN4	223.1	0.029
64729	S6	329.4	0.002
64729	2N2	0	0.026
64729	OO1	181.1	0.027
64729	M1	70.1	0.009
64729	J1	128.5	0.011
64729	Q1	61	0.027
64729	2Q1	214.9	0.017
64729	P1	42.4	0.064
64729	2SM2	63.1	0.006
64729	M3	241.3	0.002
64729	L2	72	0.051
64729	2MK3	252.8	0.035
64729	K2	70	0.068
64729	M8	55.7	0.017
64729	MS4	226.7	0.021
64730	M2	65.2	0.631
64730	S2	82.4	0.151
64730	N2	51.4	0.135
64730	K1	71.7	0.217
64730	M4	220.6	0.113
64730	O1	42.8	0.152
64730	M6	157.5	0.027
64730	MK3	257.3	0.059
64730	S4	69.9	0.018
64730	MN4	221.1	0.031
64730	S6	324.2	0.003
64730	2N2	3.8	0.028
64730	OO1	191.2	0.026
64730	M1	58	0.009
64730	J1	123	0.01
64730	Q1	59.3	0.024
64730	2Q1	222.5	0.014
64730	P1	38.5	0.064
64730	2SM2	66.2	0.007
64730	M3	210.8	0.004
64730	L2	73.2	0.051
64730	2MK3	248.8	0.035
64730	K2	72.1	0.067
64730	M8	43.8	0.019
64730	MS4	225.7	0.023
64731	M2	65.5	0.624
64731	S2	84.1	0.149
64731	N2	51.6	0.131
64731	K1	71.8	0.219
64731	M4	218.1	0.119
64731	O1	41.8	0.146
64731	M6	158.3	0.029
64731	MK3	257.7	0.07
64731	S4	71.5	0.018
64731	MN4	217.1	0.036
64731	S6	318.8	0.002
64731	2N2	1.5	0.031
64731	OO1	214.7	0.02
64731	M1	47.5	0.011
64731	J1	108.9	0.009
64731	Q1	55.7	0.019
64731	2Q1	241.5	0.013
64731	P1	39.7	0.062
64731	2SM2	57.8	0.007
64731	M3	218.3	0.005
64731	L2	75.8	0.052
64731	2MK3	243.4	0.035
64731	K2	66.8	0.065
64731	M8	34.8	0.022
64731	MS4	227.1	0.024
64732	M2	66.4	2.072
64732	S2	88.2	0.447
64732	N2	52.4	0.408
64732	K1	82.6	0.856
64732	M4	17.5	0.14
64732	O1	70.9	0.486
64732	M6	333.7	0.102
64732	MK3	40.8	0.11
64732	S4	17.6	0.011
64732	MN4	28.4	0.044
64732	S6	96.8	0.01
64732	2N2	4.5	0.091
64732	OO1	162.5	0.098
64732	M1	108.4	0.025
64732	J1	90.5	0.042
64732	Q1	84.1	0.075
64732	2Q1	333.7	0.01
64732	P1	86.2	0.238
64732	2SM2	312.7	0.025
64732	M3	137.1	0.034
64732	L2	81.2	0.143
64732	2MK3	21.3	0.083
64732	K2	39.2	0.168
64732	M8	285	0.023
64732	MS4	27.6	0.048
64733	M2	66.5	2.131
64733	S2	88.8	0.462
64733	N2	53.1	0.42
64733	K1	82.6	0.881
64733	M4	17.7	0.144
64733	O1	70.4	0.499
64733	M6	334.4	0.102
64733	MK3	42.6	0.115
64733	S4	31.3	0.012
64733	MN4	28.4	0.05
64733	S6	102.9	0.01
64733	2N2	4.2	0.093
64733	OO1	158.6	0.099
64733	M1	109.5	0.027
64733	J1	93.8	0.045
64733	Q1	84.9	0.081
64733	2Q1	305.5	0.007
64733	P1	86.7	0.245
64733	2SM2	306.2	0.026
64733	M3	134.7	0.035
64733	L2	82.6	0.145
64733	2MK3	19.7	0.085
64733	K2	38.6	0.168
64733	M8	284.9	0.023
64733	MS4	33.6	0.052
64734	M2	66.6	2.165
64734	S2	88.9	0.47
64734	N2	53.8	0.428
64734	K1	83	0.89
64734	M4	17.6	0.147
64734	O1	70.4	0.508
64734	M6	335.8	0.101
64734	MK3	43	0.12
64734	S4	36	0.013
64734	MN4	26.2	0.056
64734	S6	108.4	0.009
64734	2N2	4	0.093
64734	OO1	156.3	0.102
64734	M1	111.8	0.028
64734	J1	94.7	0.046
64734	Q1	85.2	0.085
64734	2Q1	264.1	0.006
64734	P1	86.7	0.245
64734	2SM2	305.9	0.025
64734	M3	130	0.036
64734	L2	83.7	0.147
64734	2MK3	16.5	0.086
64734	K2	40.2	0.17
64734	M8	287.2	0.024
64734	MS4	36.7	0.057
64735	M2	66.8	2.188
64735	S2	88.6	0.474
64735	N2	54.2	0.432
64735	K1	83.4	0.894
64735	M4	17.3	0.149
64735	O1	70.9	0.514
64735	M6	337.5	0.099
64735	MK3	42.8	0.124
64735	S4	37.2	0.014
64735	MN4	23.3	0.06
64735	S6	114.7	0.008
64735	2N2	3.9	0.094
64735	OO1	154.6	0.105
64735	M1	114.2	0.03
64735	J1	94.5	0.046
64735	Q1	84.9	0.087
64735	2Q1	229.7	0.007
64735	P1	86.3	0.244
64735	2SM2	308.9	0.025
64735	M3	124.7	0.037
64735	L2	84.5	0.149
64735	2MK3	13	0.086
64735	K2	43.2	0.175
64735	M8	289.8	0.023
64735	MS4	38.1	0.063
64736	M2	67	2.203
64736	S2	88.1	0.478
64736	N2	54.5	0.435
64736	K1	83.8	0.892
64736	M4	17.1	0.15
64736	O1	71.6	0.519
64736	M6	339.1	0.097
64736	MK3	42.1	0.128
64736	S4	35.9	0.015
64736	MN4	20.6	0.064
64736	S6	120.2	0.006
64736	2N2	3.4	0.095
64736	OO1	153.5	0.11
64736	M1	116.3	0.031
64736	J1	94.4	0.046
64736	Q1	83.9	0.089
64736	2Q1	204.1	0.009
64736	P1	85.6	0.241
64736	2SM2	314	0.024
64736	M3	118.9	0.038
64736	L2	85.3	0.152
64736	2MK3	9.6	0.087
64736	K2	47	0.179
64736	M8	292.6	0.021
64736	MS4	38.5	0.068
64737	M2	67.1	2.211
64737	S2	87.4	0.48
64737	N2	54.7	0.435
64737	K1	84.2	0.889
64737	M4	17.5	0.149
64737	O1	72.4	0.521
64737	M6	340.5	0.094
64737	MK3	41.3	0.134
64737	S4	33.1	0.016
64737	MN4	18.7	0.066
64737	S6	123.7	0.005
64737	2N2	2.2	0.096
64737	OO1	153	0.113
64737	M1	116.8	0.032
64737	J1	95	0.046
64737	Q1	83.2	0.089
64737	2Q1	190.6	0.011
64737	P1	84.9	0.24
64737	2SM2	320.1	0.023
64737	M3	113.9	0.039
64737	L2	85.7	0.155
64737	2MK3	6.6	0.087
64737	K2	50.8	0.184
64737	M8	295.9	0.018
64737	MS4	38.9	0.072
64738	M2	67.2	2.211
64738	S2	87	0.48
64738	N2	54.9	0.432
64738	K1	84.6	0.886
64738	M4	19.1	0.145
64738	O1	73	0.521
64738	M6	342	0.092
64738	MK3	40.6	0.139
64738	S4	29.2	0.018
64738	MN4	18	0.067
64738	S6	126.8	0.004
64738	2N2	0.8	0.098
64738	OO1	152.2	0.114
64738	M1	116.5	0.032
64738	J1	95.3	0.045
64738	Q1	82.7	0.09
64738	2Q1	182.8	0.012
64738	P1	84.7	0.239
64738	2SM2	324.9	0.022
64738	M3	110.5	0.04
64738	L2	86.1	0.157
64738	2MK3	3.9	0.086
64738	K2	53.4	0.187
64738	M8	300.5	0.015
64738	MS4	40.2	0.075
64739	M2	67.1	2.186
64739	S2	86.6	0.463
64739	N2	54.8	0.419
64739	K1	84.3	0.873
64739	M4	20.6	0.121
64739	O1	72.1	0.509
64739	M6	343.4	0.08
64739	MK3	34	0.129
64739	S4	28.4	0.017
64739	MN4	17.5	0.058
64739	S6	116.6	0.005
64739	2N2	0.6	0.102
64739	OO1	154	0.115
64739	M1	117.2	0.029
64739	J1	94.4	0.04
64739	Q1	80	0.087
64739	2Q1	182.9	0.011
64739	P1	84.9	0.232
64739	2SM2	325	0.021
64739	M3	102.3	0.035
64739	L2	86.8	0.16
64739	2MK3	352.1	0.074
64739	K2	55.9	0.205
64739	M8	305.6	0.011
64739	MS4	44.1	0.068
64740	M2	21.5	0.436
64740	S2	34.3	0.088
64740	N2	30.2	0.061
64740	K1	22.7	0.117
64740	M4	113.8	0.142
64740	O1	347.5	0.084
64740	M6	336.1	0.035
64740	MK3	119	0.047
64740	S4	172.1	0.014
64740	MN4	94	0.065
64740	S6	320.5	0.015
64740	2N2	235.7	0.034
64740	OO1	199.6	0.033
64740	M1	30.6	0.011
64740	J1	285.2	0.011
64740	Q1	326.1	0.005
64740	2Q1	233.1	0.029
64740	P1	354.4	0.012
64740	2SM2	294.1	0.02
64740	M3	73.9	0.01
64740	L2	32.1	0.06
64740	2MK3	145.4	0.003
64740	M8	93.7	0.009
64740	MS4	139	0.073
64741	M2	22	0.453
64741	S2	34.9	0.091
64741	N2	31.1	0.063
64741	K1	22.5	0.125
64741	M4	112.8	0.145
64741	O1	346.5	0.092
64741	M6	335	0.033
64741	MK3	121.2	0.044
64741	S4	173.4	0.013
64741	MN4	93.6	0.065
64741	S6	317.3	0.014
64741	2N2	239.6	0.036
64741	OO1	196.6	0.035
64741	M1	33.4	0.01
64741	J1	284.6	0.012
64741	Q1	333.9	0.004
64741	2Q1	232.5	0.031
64741	P1	4.5	0.013
64741	2SM2	297.1	0.02
64741	M3	69.1	0.009
64741	L2	31.7	0.059
64741	2MK3	180.5	0.01
64741	M8	92.9	0.01
64741	MS4	139.2	0.077
64742	M2	22.5	0.465
64742	S2	36	0.093
64742	N2	32.2	0.066
64742	K1	22.4	0.133
64742	M4	111.2	0.147
64742	O1	345.9	0.099
64742	M6	332.8	0.031
64742	MK3	121.9	0.041
64742	S4	175.9	0.011
64742	MN4	93.3	0.065
64742	S6	311.7	0.012
64742	2N2	244.1	0.037
64742	OO1	194	0.036
64742	M1	31.3	0.01
64742	J1	288.9	0.012
64742	Q1	335.9	0.005
64742	2Q1	231.3	0.032
64742	P1	12.9	0.014
64742	2SM2	298.6	0.019
64742	M3	66.3	0.009
64742	L2	30.2	0.059
64742	2MK3	183.9	0.017
64742	M8	89.1	0.01
64742	MS4	138.4	0.079
64743	M2	23.2	0.477
64743	S2	37.3	0.094
64743	N2	32.8	0.068
64743	K1	21.6	0.141
64743	M4	109.6	0.15
64743	O1	345.6	0.106
64743	M6	330.7	0.029
64743	MK3	121.1	0.039
64743	S4	181.3	0.008
64743	MN4	91.9	0.066
64743	S6	306.1	0.009
64743	2N2	247.2	0.038
64743	OO1	190.8	0.036
64743	M1	31.6	0.01
64743	J1	289.3	0.012
64743	Q1	342.3	0.005
64743	2Q1	228.5	0.034
64743	P1	19.6	0.018
64743	2SM2	300.7	0.019
64743	M3	63.6	0.009
64743	L2	29.3	0.058
64743	2MK3	187.2	0.022
64743	M8	79.7	0.009
64743	MS4	137.1	0.079
64744	M2	24	0.487
64744	S2	38.2	0.095
64744	N2	33.7	0.07
64744	K1	21.4	0.151
64744	M4	107.3	0.153
64744	O1	345.4	0.112
64744	M6	327.3	0.025
64744	MK3	117.5	0.037
64744	S4	188.6	0.007
64744	MN4	90.7	0.066
64744	S6	296.9	0.008
64744	2N2	250.1	0.038
64744	OO1	187.4	0.038
64744	M1	29.4	0.01
64744	J1	285.6	0.012
64744	Q1	352.8	0.006
64744	2Q1	227	0.033
64744	P1	29	0.022
64744	2SM2	302.7	0.018
64744	M3	61	0.009
64744	L2	29.4	0.057
64744	2MK3	189.4	0.025
64744	M8	68.8	0.008
64744	MS4	135.8	0.08
64745	M2	24.9	0.498
64745	S2	39.5	0.097
64745	N2	34.8	0.073
64745	K1	20.7	0.159
64745	M4	105.3	0.157
64745	O1	345.6	0.119
64745	M6	322.9	0.021
64745	MK3	112.8	0.035
64745	S4	204.7	0.005
64745	MN4	90.1	0.066
64745	S6	285.3	0.007
64745	2N2	252.8	0.037
64745	OO1	184.8	0.041
64745	M1	29.1	0.011
64745	J1	277.3	0.013
64745	Q1	11.8	0.008
64745	2Q1	221.6	0.034
64745	P1	33.4	0.028
64745	2SM2	303.8	0.016
64745	M3	61.6	0.009
64745	L2	29.9	0.056
64745	2MK3	189.3	0.027
64745	M8	47.8	0.007
64745	MS4	133.6	0.079
64746	M2	25.8	0.506
64746	S2	40.7	0.099
64746	N2	35.4	0.076
64746	K1	19.4	0.165
64746	M4	102.8	0.16
64746	O1	345.8	0.124
64746	M6	316.5	0.017
64746	MK3	107.3	0.033
64746	S4	227.2	0.004
64746	MN4	89.2	0.065
64746	S6	275	0.008
64746	2N2	256	0.035
64746	OO1	181	0.043
64746	M1	29.4	0.012
64746	J1	270.4	0.013
64746	Q1	25.3	0.011
64746	2Q1	218.6	0.032
64746	P1	32.7	0.034
64746	2SM2	307.2	0.015
64746	M3	58.7	0.008
64746	L2	32.9	0.054
64746	2MK3	193.3	0.026
64746	M8	30	0.007
64746	MS4	130.5	0.078
64747	M2	26.8	0.513
64747	S2	41.8	0.101
64747	N2	36.4	0.079
64747	K1	18.5	0.167
64747	M4	100	0.163
64747	O1	346.7	0.129
64747	M6	307.3	0.014
64747	MK3	100.6	0.034
64747	S4	250.1	0.005
64747	MN4	88.2	0.065
64747	S6	259.5	0.009
64747	2N2	259.7	0.033
64747	OO1	180.6	0.043
64747	M1	31.5	0.013
64747	J1	262.4	0.015
64747	Q1	35.3	0.014
64747	2Q1	213.5	0.03
64747	P1	30.3	0.039
64747	2SM2	307.2	0.014
64747	M3	54.8	0.008
64747	L2	35.6	0.054
64747	2MK3	196.1	0.023
64747	M8	21.2	0.007
64747	MS4	126.5	0.076
64748	M2	27.6	0.518
64748	S2	42.9	0.101
64748	N2	36.8	0.08
64748	K1	17.2	0.169
64748	M4	97.2	0.166
64748	O1	348.6	0.131
64748	M6	294.2	0.011
64748	MK3	96.9	0.035
64748	S4	261.3	0.005
64748	MN4	87.2	0.064
64748	S6	245.2	0.011
64748	2N2	262.9	0.03
64748	OO1	178	0.046
64748	M1	33.8	0.015
64748	J1	258.1	0.017
64748	Q1	41.9	0.015
64748	2Q1	206.6	0.03
64748	P1	27.9	0.045
64748	2SM2	306.7	0.013
64748	M3	58.1	0.007
64748	L2	38.6	0.054
64748	2MK3	200	0.02
64748	M8	18.4	0.008
64748	MS4	123.1	0.073
64749	M2	28.2	0.522
64749	S2	43.2	0.101
64749	N2	37.2	0.08
64749	K1	15.2	0.168
64749	M4	94.9	0.168
64749	O1	351.6	0.134
64749	M6	275	0.008
64749	MK3	94.7	0.036
64749	S4	284.1	0.006
64749	MN4	87.2	0.063
64749	S6	237.4	0.012
64749	2N2	266.6	0.028
64749	OO1	177.6	0.049
64749	M1	36.1	0.017
64749	J1	253.8	0.02
64749	Q1	49.7	0.015
64749	2Q1	202.1	0.029
64749	P1	23.6	0.053
64749	2SM2	300.8	0.011
64749	M3	60.4	0.008
64749	L2	41	0.055
64749	2MK3	205.7	0.016
64749	M8	16.8	0.008
64749	MS4	120.6	0.07
64750	M2	29	0.523
64750	S2	44.1	0.1
64750	N2	38.2	0.079
64750	K1	13.7	0.169
64750	M4	92.7	0.171
64750	O1	355.1	0.136
64750	M6	252.8	0.007
64750	MK3	94.6	0.037
64750	S4	290.2	0.007
64750	MN4	87.9	0.063
64750	S6	234.4	0.013
64750	2N2	269.8	0.028
64750	OO1	179.2	0.053
64750	M1	37.3	0.019
64750	J1	245.1	0.022
64750	Q1	58.8	0.016
64750	2Q1	200	0.029
64750	P1	22.2	0.062
64750	2SM2	292.9	0.009
64750	M3	72.6	0.008
64750	L2	41.9	0.056
64750	2MK3	221.2	0.012
64750	M8	19.3	0.007
64750	MS4	118.3	0.067
64751	M2	29.6	0.523
64751	S2	44.9	0.099
64751	N2	39.2	0.078
64751	K1	11.1	0.169
64751	M4	90.9	0.173
64751	O1	359.2	0.139
64751	M6	237.6	0.005
64751	MK3	98.1	0.039
64751	S4	295.1	0.007
64751	MN4	88.4	0.065
64751	S6	231.7	0.012
64751	2N2	271.5	0.027
64751	OO1	183.4	0.053
64751	M1	39.8	0.021
64751	J1	237.1	0.025
64751	Q1	75.2	0.016
64751	2Q1	203.2	0.029
64751	P1	20.9	0.073
64751	2SM2	274.1	0.008
64751	M3	80.9	0.01
64751	L2	41.1	0.055
64751	2MK3	257.4	0.008
64751	M8	17.3	0.006
64751	MS4	117.7	0.066
64752	M2	30.2	0.521
64752	S2	45.9	0.099
64752	N2	40	0.078
64752	K1	9	0.17
64752	M4	90.2	0.174
64752	O1	1.9	0.141
64752	M6	192.3	0.002
64752	MK3	103.7	0.04
64752	S4	289.5	0.007
64752	MN4	88.3	0.067
64752	S6	229.3	0.01
64752	2N2	270.5	0.026
64752	OO1	189.1	0.056
64752	M1	37.5	0.023
64752	J1	230.9	0.026
64752	Q1	89.2	0.019
64752	2Q1	209.2	0.03
64752	P1	21.8	0.084
64752	2SM2	254.1	0.009
64752	M3	89.6	0.011
64752	L2	38.5	0.054
64752	2MK3	301.3	0.008
64752	M8	9	0.006
64752	MS4	118.5	0.065
64753	M2	31	0.52
64753	S2	47.3	0.098
64753	N2	40.7	0.078
64753	K1	8	0.171
64753	M4	90.2	0.174
64753	O1	4.7	0.144
64753	M6	118.9	0.005
64753	MK3	109.1	0.042
64753	S4	281.2	0.009
64753	MN4	87.4	0.069
64753	S6	222.6	0.008
64753	2N2	265.7	0.024
64753	OO1	193.9	0.057
64753	M1	35	0.024
64753	J1	225.7	0.029
64753	Q1	97.6	0.023
64753	2Q1	215.8	0.031
64753	P1	23.2	0.091
64753	2SM2	246.8	0.013
64753	M3	98.3	0.012
64753	L2	34.9	0.053
64753	2MK3	331.3	0.012
64753	M8	9.7	0.008
64753	MS4	120.4	0.064
64754	M2	31.6	0.517
64754	S2	48.5	0.097
64754	N2	42	0.08
64754	K1	10.6	0.165
64754	M4	91.4	0.169
64754	O1	7.8	0.145
64754	M6	111.6	0.01
64754	MK3	114.1	0.043
64754	S4	273.3	0.012
64754	MN4	87.3	0.069
64754	S6	209.7	0.006
64754	2N2	258.8	0.025
64754	OO1	197.4	0.063
64754	M1	30.2	0.023
64754	J1	226	0.031
64754	Q1	104.9	0.025
64754	2Q1	223.8	0.031
64754	P1	26.7	0.09
64754	2SM2	243.4	0.018
64754	M3	103.2	0.012
64754	L2	31.2	0.053
64754	2MK3	347.4	0.014
64754	M8	19.4	0.009
64754	MS4	122.8	0.062
64755	M2	43.6	0.614
64755	S2	68.6	0.161
64755	N2	58.5	0.091
64755	K1	67.2	0.155
64755	M4	119.4	0.047
64755	O1	50.3	0.085
64755	M6	245	0.029
64755	MK3	264.9	0.012
64755	S4	259	0.01
64755	MN4	89	0.009
64755	S6	8.4	0.003
64755	2N2	224.5	0.059
64755	OO1	182.9	0.05
64755	M1	152.5	0.006
64755	J1	244.8	0.003
64755	Q1	100	0.033
64755	2Q1	153.9	0.027
64755	P1	49.8	0.024
64755	2SM2	342.7	0.005
64755	M3	116.2	0.011
64755	L2	5.7	0.052
64755	2MK3	171.7	0.016
64755	M8	53.4	0.002
64755	MS4	160.9	0.027
64756	M2	45	0.597
64756	S2	68.6	0.156
64756	N2	62.6	0.093
64756	K1	68.9	0.16
64756	M4	115.9	0.055
64756	O1	53.7	0.083
64756	M6	237.4	0.027
64756	MK3	235.8	0.01
64756	S4	258	0.007
64756	MN4	93.2	0.011
64756	S6	277.7	0.001
64756	2N2	218.4	0.058
64756	OO1	181.8	0.049
64756	M1	169.1	0.005
64756	J1	212.2	0.006
64756	Q1	105.4	0.033
64756	2Q1	154.7	0.033
64756	P1	61.2	0.027
64756	2SM2	308.9	0.003
64756	M3	113.5	0.011
64756	L2	0.2	0.052
64756	2MK3	173	0.018
64756	M8	357.2	0.005
64756	MS4	152.5	0.031
64757	M2	46.5	0.576
64757	S2	69	0.15
64757	N2	64.9	0.095
64757	K1	68.3	0.165
64757	M4	112.4	0.06
64757	O1	56.7	0.08
64757	M6	230.3	0.024
64757	MK3	208	0.008
64757	S4	266	0.004
64757	MN4	95.6	0.014
64757	S6	233.8	0.002
64757	2N2	212.8	0.054
64757	OO1	177.4	0.046
64757	M1	197.6	0.004
64757	J1	176.9	0.011
64757	Q1	108.2	0.028
64757	2Q1	151.5	0.034
64757	P1	70.3	0.034
64757	2SM2	236	0.003
64757	M3	105.2	0.012
64757	L2	352.1	0.05
64757	2MK3	178.6	0.019
64757	M8	357.7	0.009
64757	MS4	148.1	0.035
64758	M2	48	0.554
64758	S2	69.9	0.143
64758	N2	66.2	0.096
64758	K1	66.9	0.166
64758	M4	110.7	0.064
64758	O1	58.6	0.078
64758	M6	219.6	0.021
64758	MK3	168.6	0.007
64758	S4	282.3	0.002
64758	MN4	97.7	0.018
64758	S6	328.6	0.001
64758	2N2	208.3	0.044
64758	OO1	168	0.042
64758	M1	246.3	0.004
64758	J1	160.6	0.017
64758	Q1	109	0.022
64758	2Q1	148	0.033
64758	P1	75.1	0.04
64758	2SM2	202.4	0.006
64758	M3	99.4	0.016
64758	L2	341.8	0.049
64758	2MK3	184.6	0.018
64758	M8	3.2	0.013
64758	MS4	143.7	0.039
64759	M2	49.6	0.535
64759	S2	71.9	0.138
64759	N2	67.8	0.094
64759	K1	66	0.162
64759	M4	110	0.072
64759	O1	58.9	0.073
64759	M6	202.7	0.019
64759	MK3	123.4	0.01
64759	MN4	102.4	0.021
64759	S6	17.1	0.004
64759	2N2	204.3	0.031
64759	OO1	161.6	0.04
64759	M1	286	0.007
64759	J1	148.9	0.021
64759	Q1	102.5	0.022
64759	2Q1	147.9	0.03
64759	P1	76	0.043
64759	2SM2	192.3	0.01
64759	M3	95.5	0.019
64759	L2	333.9	0.05
64759	2MK3	190.5	0.017
64759	M8	6.2	0.015
64759	MS4	140.8	0.043
64760	M2	51	0.522
64760	S2	74.7	0.136
64760	N2	67.9	0.091
64760	K1	67.2	0.16
64760	M4	110.5	0.081
64760	O1	57.6	0.067
64760	M6	185.2	0.019
64760	MK3	100.3	0.019
64760	S4	152.3	0.002
64760	MN4	104.3	0.025
64760	S6	22.2	0.006
64760	2N2	199.6	0.017
64760	OO1	161.8	0.039
64760	M1	295.8	0.01
64760	J1	133.7	0.02
64760	Q1	94.1	0.022
64760	2Q1	149.2	0.026
64760	P1	80	0.04
64760	2SM2	187.6	0.013
64760	M3	90.1	0.018
64760	L2	330	0.051
64760	2MK3	189.1	0.015
64760	M8	8.9	0.016
64760	MS4	140.2	0.045
64761	M2	52.1	0.512
64761	S2	77.5	0.137
64761	N2	65.2	0.09
64761	K1	69.8	0.165
64761	M4	112.1	0.09
64761	O1	54.4	0.063
64761	M6	170.4	0.018
64761	MK3	90.6	0.029
64761	S4	138.2	0.003
64761	MN4	104.7	0.03
64761	S6	15.6	0.005
64761	2N2	189.1	0.004
64761	OO1	165.3	0.039
64761	M1	298.3	0.012
64761	J1	117.3	0.017
64761	Q1	89.6	0.022
64761	2Q1	146.8	0.025
64761	P1	92.8	0.036
64761	2SM2	190	0.015
64761	M3	83.9	0.014
64761	L2	330.3	0.053
64761	2MK3	174.7	0.015
64761	M8	13.4	0.015
64761	MS4	140.6	0.046
64762	M2	52.9	0.506
64762	S2	79.4	0.139
64762	N2	61.3	0.089
64762	K1	71.8	0.175
64762	M4	113.8	0.096
64762	O1	51.3	0.058
64762	M6	160.5	0.017
64762	MK3	87.6	0.037
64762	S4	113.7	0.004
64762	MN4	106.8	0.034
64762	S6	8.2	0.003
64762	2N2	28.2	0.005
64762	OO1	164.2	0.038
64762	M1	296.5	0.012
64762	J1	108.4	0.014
64762	Q1	87.9	0.021
64762	2Q1	140.1	0.026
64762	P1	107.7	0.037
64762	2SM2	199.5	0.015
64762	M3	72	0.011
64762	L2	332	0.053
64762	2MK3	162.4	0.017
64762	M8	16.6	0.014
64762	MS4	140.9	0.049
64763	M2	53.4	0.505
64763	S2	80.6	0.14
64763	N2	57.8	0.09
64763	K1	72.6	0.184
64763	M4	115.7	0.1
64763	O1	46.5	0.055
64763	M6	152.8	0.014
64763	MK3	89.5	0.043
64763	S4	97.5	0.006
64763	MN4	109.6	0.038
64763	S6	15.3	0.002
64763	2N2	25.8	0.012
64763	OO1	163.2	0.037
64763	M1	297.6	0.013
64763	J1	107.5	0.012
64763	Q1	87.2	0.019
64763	2Q1	135.4	0.027
64763	P1	116.2	0.042
64763	2SM2	208.6	0.015
64763	M3	54.8	0.009
64763	L2	333.9	0.049
64763	2MK3	155.2	0.021
64763	M8	22.3	0.012
64763	MS4	140.9	0.051
64764	M2	53.8	0.506
64764	S2	80.9	0.142
64764	N2	54.9	0.091
64764	K1	72.3	0.19
64764	M4	117.7	0.102
64764	O1	41.1	0.051
64764	M6	144.7	0.012
64764	MK3	91.6	0.047
64764	S4	92.1	0.008
64764	MN4	113.2	0.04
64764	S6	101.2	0.001
64764	2N2	21.9	0.017
64764	OO1	162.5	0.036
64764	M1	300.4	0.013
64764	J1	107.1	0.011
64764	Q1	86.9	0.017
64764	2Q1	130.3	0.029
64764	P1	117.2	0.046
64764	2SM2	213.7	0.014
64764	M3	40.1	0.008
64764	L2	336.7	0.043
64764	2MK3	151.5	0.024
64764	M8	32.1	0.011
64764	MS4	140.4	0.052
64765	M2	54.2	0.506
64765	S2	80.9	0.143
64765	N2	52.1	0.091
64765	K1	71.1	0.196
64765	M4	119.5	0.1
64765	O1	35.4	0.048
64765	M6	130.7	0.009
64765	MK3	91.3	0.047
64765	S4	102.1	0.008
64765	MN4	116.1	0.041
64765	S6	175.3	0.002
64765	2N2	19.9	0.022
64765	OO1	160.7	0.033
64765	M1	306.9	0.015
64765	J1	105.8	0.009
64765	Q1	88.3	0.014
64765	2Q1	125.5	0.03
64765	P1	113.2	0.052
64765	2SM2	214.6	0.013
64765	M3	27.9	0.008
64765	L2	337.7	0.037
64765	2MK3	151.2	0.026
64765	M8	38.1	0.01
64765	MS4	139.7	0.052
64766	M2	54.6	0.504
64766	S2	80.6	0.144
64766	N2	49.5	0.091
64766	K1	69.6	0.2
64766	M4	120.9	0.095
64766	O1	29.6	0.045
64766	M6	109.7	0.008
64766	MK3	91.8	0.044
64766	S4	112	0.01
64766	MN4	117.7	0.042
64766	S6	209.4	0.004
64766	2N2	17.7	0.026
64766	OO1	154.6	0.031
64766	M1	314.5	0.016
64766	J1	104.7	0.007
64766	Q1	89.8	0.012
64766	2Q1	122.3	0.031
64766	P1	109.5	0.058
64766	2SM2	214.8	0.01
64766	M3	26.8	0.007
64766	L2	337.9	0.031
64766	2MK3	152.6	0.027
64766	M8	38.8	0.009
64766	MS4	139.9	0.05
64767	M2	54.9	0.5
64767	S2	80.8	0.145
64767	N2	47	0.091
64767	K1	68.1	0.205
64767	M4	121.5	0.089
64767	O1	26.3	0.045
64767	M6	90.2	0.01
64767	MK3	92.5	0.04
64767	S4	123.4	0.011
64767	MN4	119.8	0.043
64767	S6	216.7	0.007
64767	2N2	16.8	0.029
64767	OO1	148.8	0.03
64767	M1	321.2	0.016
64767	J1	109.5	0.004
64767	Q1	91.7	0.01
64767	2Q1	120	0.031
64767	P1	106.1	0.062
64767	2SM2	208.7	0.007
64767	M3	35	0.006
64767	L2	340.4	0.027
64767	2MK3	156.1	0.027
64767	M8	43	0.008
64767	MS4	140.7	0.047
64768	M2	55.2	0.492
64768	S2	80.8	0.145
64768	N2	45	0.091
64768	K1	66.3	0.208
64768	M4	121.8	0.083
64768	O1	25.7	0.048
64768	M6	78.1	0.012
64768	MK3	90.9	0.034
64768	S4	130.6	0.012
64768	MN4	120.4	0.042
64768	S6	221.4	0.009
64768	2N2	16.3	0.03
64768	OO1	143.7	0.029
64768	M1	325.5	0.017
64768	J1	146.8	0.002
64768	Q1	87.9	0.008
64768	2Q1	117.6	0.031
64768	P1	99.9	0.065
64768	2SM2	199.5	0.005
64768	M3	37.5	0.006
64768	L2	341.1	0.024
64768	2MK3	158	0.03
64768	M8	40	0.006
64768	MS4	141.3	0.044
64769	M2	55.6	0.483
64769	S2	80.8	0.145
64769	N2	43.8	0.09
64769	K1	64.3	0.211
64769	M4	122.1	0.075
64769	O1	26.8	0.053
64769	M6	75.2	0.015
64769	MK3	87.6	0.028
64769	S4	130.2	0.012
64769	MN4	119.5	0.04
64769	S6	228.2	0.011
64769	2N2	15.4	0.031
64769	OO1	139.3	0.029
64769	M1	329.2	0.017
64769	J1	245.5	0.002
64769	Q1	65.5	0.007
64769	2Q1	117.1	0.031
64769	P1	93.5	0.068
64769	2SM2	209.7	0.003
64769	M3	31.1	0.006
64769	L2	339.6	0.022
64769	2MK3	159.1	0.033
64769	M8	35.2	0.005
64769	MS4	142.2	0.039
64770	M2	56.1	0.471
64770	S2	81.2	0.146
64770	N2	43.3	0.088
64770	K1	63.3	0.217
64770	M4	121.4	0.067
64770	O1	30.1	0.059
64770	M6	78.9	0.018
64770	MK3	77.4	0.023
64770	S4	124.2	0.012
64770	MN4	117.9	0.038
64770	S6	235.9	0.011
64770	2N2	12.7	0.031
64770	OO1	133.2	0.028
64770	M1	334.2	0.016
64770	J1	274.6	0.006
64770	Q1	50.7	0.006
64770	2Q1	118.8	0.031
64770	P1	90.2	0.072
64770	2SM2	242.6	0.003
64770	M3	22.5	0.007
64770	L2	333.1	0.021
64770	2MK3	159.8	0.034
64770	M8	26.2	0.003
64770	MS4	142.6	0.035
64771	M2	56.5	0.458
64771	S2	82.2	0.146
64771	N2	42.8	0.084
64771	K1	62.2	0.219
64771	M4	119.6	0.059
64771	O1	35.5	0.067
64771	M6	80.4	0.021
64771	MK3	55.7	0.021
64771	S4	121.2	0.012
64771	MN4	113.8	0.034
64771	S6	235.4	0.011
64771	2N2	8.9	0.033
64771	OO1	120.8	0.027
64771	M1	337.2	0.014
64771	J1	277.7	0.007
64771	Q1	46.4	0.006
64771	2Q1	121.2	0.027
64771	P1	86.4	0.072
64771	2SM2	268.7	0.003
64771	M3	13.5	0.009
64771	L2	320.4	0.021
64771	2MK3	160.1	0.034
64771	M8	350.4	0.002
64771	MS4	140.9	0.03
64772	M2	51.9	0.396
64772	S2	83.1	0.135
64772	N2	36.5	0.078
64772	K1	43.7	0.201
64772	M4	156	0.057
64772	O1	15.9	0.071
64772	M6	100.3	0.018
64772	MK3	299	0.032
64772	S4	142.9	0.013
64772	MN4	129.3	0.03
64772	S6	211.6	0.009
64772	2N2	16.4	0.034
64772	OO1	114.4	0.015
64772	M1	348.8	0.013
64772	J1	271.6	0.018
64772	Q1	10.8	0.015
64772	2Q1	117.7	0.02
64772	P1	57.5	0.078
64772	2SM2	254.4	0.004
64772	M3	9.5	0.016
64772	L2	325.3	0.022
64772	2MK3	192.9	0.047
64772	M8	260.6	0.004
64772	MS4	168.5	0.028
64773	M2	88.6	0.506
64773	S2	123.6	0.12
64773	N2	88.4	0.127
64773	K1	136.7	0.258
64773	M4	28.5	0.047
64773	O1	170.7	0.204
64773	M6	6.9	0.013
64773	MK3	89.4	0.074
64773	S4	49.5	0.005
64773	MN4	32.4	0.015
64773	S6	39.5	0.003
64773	2N2	45	0.004
64773	OO1	123.6	0.078
64773	M1	244.5	0.019
64773	J1	103	0.036
64773	Q1	132	0.044
64773	2Q1	107.6	0.014
64773	P1	127.8	0.129
64773	2SM2	207.1	0.018
64773	M3	147.3	0.034
64773	L2	40.2	0.034
64773	2MK3	71.1	0.07
64773	K2	44.3	0.038
64773	M8	148.6	0.015
64773	MS4	78.6	0.029
64774	M2	88.2	0.531
64774	S2	125.6	0.124
64774	N2	87.2	0.132
64774	K1	135.6	0.27
64774	M4	24.5	0.044
64774	O1	169.9	0.205
64774	M6	8.4	0.015
64774	MK3	88.7	0.073
64774	S4	34	0.006
64774	MN4	25.5	0.013
64774	S6	40.5	0.003
64774	2N2	79.4	0.004
64774	OO1	119.9	0.081
64774	M1	246.5	0.02
64774	J1	108.6	0.035
64774	Q1	133.2	0.045
64774	2Q1	96.6	0.011
64774	P1	128.6	0.131
64774	2SM2	203.9	0.018
64774	M3	154.2	0.034
64774	L2	41.7	0.038
64774	2MK3	74.2	0.068
64774	K2	43.9	0.045
64774	M8	146.6	0.014
64774	MS4	78.9	0.028
64775	M2	88.2	0.549
64775	S2	125.1	0.128
64775	N2	86.1	0.135
64775	K1	134.1	0.278
64775	M4	20.5	0.043
64775	O1	169	0.206
64775	M6	10.8	0.017
64775	MK3	87.6	0.072
64775	S4	27.2	0.006
64775	MN4	16.1	0.012
64775	S6	51.9	0.003
64775	2N2	100.1	0.006
64775	OO1	116	0.081
64775	M1	248.6	0.02
64775	J1	114.7	0.034
64775	Q1	136	0.045
64775	2Q1	77.2	0.009
64775	P1	129.2	0.134
64775	2SM2	202	0.019
64775	M3	160.2	0.034
64775	L2	43.9	0.04
64775	2MK3	76.8	0.067
64775	K2	47.6	0.045
64775	M8	145.7	0.014
64775	MS4	76.8	0.026
64776	M2	88.3	0.564
64776	S2	124.5	0.132
64776	N2	85	0.137
64776	K1	132.3	0.282
64776	M4	18.1	0.042
64776	O1	167.9	0.205
64776	M6	10.1	0.017
64776	MK3	86.4	0.072
64776	S4	22.6	0.006
64776	MN4	3.7	0.011
64776	S6	65.9	0.003
64776	2N2	106	0.009
64776	OO1	112.5	0.08
64776	M1	250.7	0.019
64776	J1	120.7	0.034
64776	Q1	136.9	0.045
64776	2Q1	56.6	0.01
64776	P1	128.9	0.137
64776	2SM2	201.8	0.018
64776	M3	166.1	0.034
64776	L2	45.7	0.041
64776	2MK3	80.1	0.066
64776	K2	51	0.045
64776	M8	142.3	0.013
64776	MS4	73	0.024
64777	M2	88.5	0.575
64777	S2	123.9	0.136
64777	N2	83.8	0.137
64777	K1	130	0.285
64777	M4	16.9	0.042
64777	O1	166.2	0.203
64777	M6	9.9	0.016
64777	MK3	86.1	0.072
64777	S4	359.4	0.004
64777	MN4	351.9	0.011
64777	S6	76	0.003
64777	2N2	105.6	0.011
64777	OO1	109.1	0.076
64777	M1	253.1	0.019
64777	J1	126.5	0.035
64777	Q1	137.2	0.043
64777	2Q1	43.4	0.011
64777	P1	128.2	0.14
64777	2SM2	202.5	0.017
64777	M3	171	0.034
64777	L2	46.9	0.042
64777	2MK3	83.8	0.065
64777	K2	54.6	0.044
64777	M8	137.6	0.011
64777	MS4	67.9	0.023
64778	M2	89	0.583
64778	S2	122.8	0.14
64778	N2	82.5	0.136
64778	K1	128.2	0.286
64778	M4	16.7	0.042
64778	O1	164.2	0.199
64778	M6	4.7	0.015
64778	MK3	86.5	0.074
64778	S4	315.8	0.003
64778	MN4	346	0.012
64778	S6	80.8	0.003
64778	2N2	95.7	0.013
64778	OO1	107.2	0.073
64778	M1	254.8	0.018
64778	J1	129.5	0.036
64778	Q1	135.3	0.041
64778	2Q1	41.7	0.012
64778	P1	127.1	0.14
64778	2SM2	204.5	0.014
64778	M3	176.1	0.032
64778	L2	48.5	0.04
64778	2MK3	87.1	0.062
64778	K2	60.7	0.04
64778	M8	129	0.01
64778	MS4	62.3	0.021
64779	M2	89.6	0.591
64779	S2	121	0.145
64779	N2	81.1	0.135
64779	K1	126.8	0.287
64779	M4	15.5	0.043
64779	O1	162.2	0.193
64779	M6	359.3	0.014
64779	MK3	86.7	0.076
64779	S4	277.2	0.005
64779	MN4	346.8	0.013
64779	S6	85.3	0.002
64779	2N2	85.2	0.015
64779	OO1	106.7	0.068
64779	M1	256.4	0.017
64779	J1	128.9	0.036
64779	Q1	133.1	0.039
64779	2Q1	41.4	0.012
64779	P1	126.8	0.138
64779	2SM2	207.1	0.011
64779	M3	181.2	0.031
64779	L2	51	0.038
64779	2MK3	90.3	0.061
64779	K2	72	0.036
64779	M8	122.6	0.01
64779	MS4	55.8	0.019
64780	M2	90.2	0.597
64780	S2	120	0.151
64780	N2	79.9	0.135
64780	K1	126	0.288
64780	M4	14.4	0.041
64780	O1	159.8	0.186
64780	M6	353.1	0.014
64780	MK3	86.7	0.079
64780	S4	261.8	0.007
64780	MN4	348.5	0.015
64780	S6	64.1	0.001
64780	2N2	76	0.017
64780	OO1	106.4	0.065
64780	M1	256.6	0.015
64780	J1	128.3	0.035
64780	Q1	131.2	0.037
64780	2Q1	48.8	0.011
64780	P1	126.8	0.134
64780	2SM2	209.3	0.007
64780	M3	187.1	0.029
64780	L2	55.2	0.036
64780	2MK3	93.4	0.059
64780	K2	81.7	0.031
64780	M8	119.6	0.01
64780	MS4	51.1	0.018
64781	M2	90.9	0.603
64781	S2	119	0.156
64781	N2	78.9	0.134
64781	K1	125.5	0.287
64781	M4	14.5	0.041
64781	O1	156.8	0.178
64781	M6	346.8	0.014
64781	MK3	87.2	0.081
64781	S4	260.4	0.008
64781	MN4	350.2	0.016
64781	S6	330.2	0.001
64781	2N2	65.7	0.018
64781	OO1	105.8	0.063
64781	M1	255.6	0.014
64781	J1	125.5	0.034
64781	Q1	129.6	0.036
64781	2Q1	58.1	0.011
64781	P1	126.7	0.129
64781	2SM2	202.5	0.004
64781	M3	193	0.027
64781	L2	58.5	0.033
64781	2MK3	96.1	0.055
64781	K2	92.5	0.03
64781	M8	114.3	0.01
64781	MS4	48.5	0.017
64782	M2	91.7	0.609
64782	S2	117.3	0.158
64782	N2	78.4	0.134
64782	K1	125.1	0.286
64782	M4	16.1	0.039
64782	O1	153.6	0.171
64782	M6	341.4	0.016
64782	MK3	87.9	0.082
64782	S4	256	0.007
64782	MN4	353.5	0.018
64782	S6	286.3	0.002
64782	2N2	54.9	0.019
64782	OO1	106.8	0.062
64782	M1	252.9	0.012
64782	J1	124.1	0.034
64782	Q1	128.4	0.035
64782	2Q1	78.4	0.012
64782	P1	127.3	0.124
64782	2SM2	165.8	0.002
64782	M3	199	0.024
64782	L2	63.3	0.031
64782	2MK3	98.6	0.051
64782	K2	100.6	0.033
64782	M8	108	0.009
64782	MS4	49.8	0.018
64783	M2	92.5	0.614
64783	S2	115.7	0.159
64783	N2	78.1	0.134
64783	K1	124.7	0.286
64783	M4	20.3	0.036
64783	O1	150.1	0.163
64783	M6	334.2	0.016
64783	MK3	89.8	0.083
64783	S4	254.4	0.006
64783	MN4	355.9	0.019
64783	S6	280.8	0.003
64783	2N2	46.6	0.019
64783	OO1	110.5	0.062
64783	M1	251.5	0.011
64783	J1	123.3	0.032
64783	Q1	126.8	0.033
64783	2Q1	97.2	0.014
64783	P1	128.2	0.119
64783	2SM2	92.4	0.002
64783	M3	205	0.022
64783	L2	70.1	0.029
64783	2MK3	101.7	0.046
64783	K2	106	0.037
64783	M8	100.6	0.009
64783	MS4	52.1	0.019
64784	M2	93.4	0.618
64784	S2	113.8	0.162
64784	N2	78.2	0.134
64784	K1	124.3	0.286
64784	M4	26	0.035
64784	O1	145.7	0.156
64784	M6	327.9	0.016
64784	MK3	91.9	0.084
64784	S4	253.6	0.004
64784	MN4	1.5	0.019
64784	S6	275.9	0.004
64784	2N2	38.3	0.02
64784	OO1	114.6	0.062
64784	M1	251.4	0.009
64784	J1	124.3	0.029
64784	Q1	127.3	0.031
64784	2Q1	112.4	0.017
64784	P1	128.7	0.113
64784	2SM2	65.6	0.005
64784	M3	210.9	0.019
64784	L2	77.8	0.027
64784	2MK3	104	0.041
64784	K2	113.4	0.042
64784	M8	90.3	0.008
64784	MS4	57.8	0.022
64785	M2	94.2	0.621
64785	S2	112.2	0.164
64785	N2	78.7	0.135
64785	K1	123.7	0.283
64785	M4	33.7	0.033
64785	O1	140.6	0.15
64785	M6	323.8	0.014
64785	MK3	93.8	0.084
64785	S4	244.6	0.002
64785	MN4	6.9	0.018
64785	S6	269.9	0.005
64785	2N2	32.4	0.022
64785	OO1	122	0.062
64785	M1	249.8	0.008
64785	J1	124.1	0.027
64785	Q1	129.4	0.029
64785	2Q1	121.4	0.02
64785	P1	128.3	0.107
64785	2SM2	59.9	0.007
64785	M3	218.4	0.015
64785	L2	86.9	0.025
64785	2MK3	106.8	0.034
64785	K2	118.1	0.048
64785	M8	77.8	0.007
64785	MS4	61.6	0.025
64786	M2	95.1	0.623
64786	S2	110.7	0.166
64786	N2	79.4	0.135
64786	K1	122.8	0.279
64786	M4	41.6	0.032
64786	O1	134.7	0.145
64786	M6	320.7	0.012
64786	MK3	95.4	0.083
64786	S4	185.3	0.001
64786	MN4	15.5	0.017
64786	S6	271.2	0.006
64786	2N2	26.4	0.024
64786	OO1	127.5	0.062
64786	M1	239.8	0.006
64786	J1	128.9	0.026
64786	Q1	132.8	0.03
64786	2Q1	130.2	0.024
64786	P1	127.1	0.101
64786	2SM2	55.4	0.009
64786	M3	225	0.012
64786	L2	97.9	0.024
64786	2MK3	110.4	0.028
64786	K2	123.2	0.053
64786	M8	55.5	0.006
64786	MS4	64.4	0.028
64787	M2	95.9	0.625
64787	S2	110.1	0.167
64787	N2	80	0.134
64787	K1	121.5	0.274
64787	M4	49.9	0.031
64787	O1	128.8	0.142
64787	M6	318.4	0.01
64787	MK3	96.5	0.08
64787	S4	140.7	0.003
64787	MN4	23.4	0.015
64787	S6	275.3	0.007
64787	2N2	25.3	0.028
64787	OO1	132.3	0.063
64787	M1	212.2	0.004
64787	J1	134.6	0.024
64787	Q1	132.5	0.031
64787	2Q1	136.3	0.027
64787	P1	125.4	0.097
64787	2SM2	52.6	0.011
64787	M3	232.7	0.009
64787	L2	109.8	0.024
64787	2MK3	115.3	0.022
64787	K2	125.3	0.057
64787	M8	32.2	0.005
64787	MS4	66.7	0.03
64788	M2	96.5	0.625
64788	S2	109.7	0.168
64788	N2	80.8	0.133
64788	K1	119.6	0.269
64788	M4	56.2	0.03
64788	O1	122.9	0.139
64788	M6	323	0.008
64788	MK3	96.6	0.078
64788	S4	124.3	0.004
64788	MN4	32.7	0.015
64788	S6	273.5	0.007
64788	2N2	25.4	0.031
64788	OO1	138.1	0.064
64788	M1	158.7	0.004
64788	J1	142.8	0.023
64788	Q1	129	0.033
64788	2Q1	141.3	0.029
64788	P1	122.8	0.092
64788	2SM2	47.6	0.011
64788	M3	238.8	0.007
64788	L2	122.8	0.025
64788	2MK3	122.5	0.017
64788	K2	127.7	0.06
64788	M8	10	0.005
64788	MS4	68.6	0.033
64789	M2	97.1	0.626
64789	S2	109.6	0.168
64789	N2	81.3	0.131
64789	K1	116.9	0.267
64789	M4	64	0.028
64789	O1	116.8	0.138
64789	M6	332.6	0.006
64789	MK3	96	0.073
64789	S4	119.5	0.004
64789	MN4	40.6	0.013
64789	S6	275.3	0.006
64789	2N2	27.1	0.035
64789	OO1	142.8	0.066
64789	M1	131.7	0.007
64789	J1	154.4	0.023
64789	Q1	123.9	0.035
64789	2Q1	147.7	0.033
64789	P1	121.1	0.091
64789	2SM2	37.6	0.012
64789	M3	243.3	0.005
64789	L2	134.5	0.026
64789	2MK3	133.7	0.011
64789	K2	129.3	0.063
64789	M8	347.2	0.003
64789	MS4	68.9	0.035
64790	M2	97.4	0.626
64790	S2	109.8	0.165
64790	N2	81.6	0.129
64790	K1	113.5	0.266
64790	M4	71.8	0.029
64790	O1	111.6	0.138
64790	M6	349	0.005
64790	MK3	95.3	0.069
64790	S4	113.7	0.005
64790	MN4	43.5	0.013
64790	S6	269.3	0.006
64790	2N2	30.5	0.037
64790	OO1	147.7	0.07
64790	M1	124.4	0.01
64790	J1	164.1	0.023
64790	Q1	121.6	0.037
64790	2Q1	152.4	0.035
64790	P1	117.9	0.092
64790	2SM2	29.3	0.011
64790	M3	262.5	0.005
64790	L2	142.6	0.028
64790	2MK3	164.8	0.008
64790	K2	128.3	0.064
64790	M8	325.9	0.002
64790	MS4	68.7	0.037
64791	M2	97.7	0.626
64791	S2	109.2	0.163
64791	N2	81.7	0.128
64791	K1	111.4	0.266
64791	M4	80.4	0.028
64791	O1	107	0.141
64791	M6	15.6	0.005
64791	MK3	94.5	0.063
64791	S4	121.6	0.004
64791	MN4	46.8	0.013
64791	S6	262.5	0.006
64791	2N2	36.7	0.039
64791	OO1	153.3	0.074
64791	M1	122.3	0.012
64791	J1	171.9	0.022
64791	Q1	119.1	0.037
64791	2Q1	157.5	0.036
64791	P1	116.2	0.089
64791	2SM2	20.4	0.011
64791	M3	280	0.005
64791	L2	147.4	0.03
64791	2MK3	194	0.01
64791	K2	127.3	0.068
64791	M8	271.2	0.001
64791	MS4	68.6	0.04
64792	M2	97.6	0.627
64792	S2	108	0.16
64792	N2	81.6	0.127
64792	K1	109.8	0.27
64792	M4	89.5	0.029
64792	O1	103.4	0.145
64792	M6	26.6	0.007
64792	MK3	94.3	0.056
64792	S4	155.2	0.004
64792	MN4	48.8	0.013
64792	S6	260	0.006
64792	2N2	43.5	0.04
64792	OO1	156.5	0.076
64792	M1	120.1	0.014
64792	J1	176.9	0.022
64792	Q1	115.7	0.037
64792	2Q1	163.6	0.036
64792	P1	115.8	0.087
64792	2SM2	12.1	0.01
64792	M3	283.1	0.004
64792	L2	147.7	0.03
64792	2MK3	205.8	0.015
64792	K2	126.8	0.073
64792	MS4	67.8	0.042
64793	M2	97.1	0.628
64793	S2	106.5	0.159
64793	N2	81.4	0.125
64793	K1	107.7	0.275
64793	M4	96.2	0.03
64793	O1	100.2	0.148
64793	M6	33.8	0.009
64793	MK3	94.4	0.047
64793	S4	195.9	0.004
64793	MN4	51.8	0.012
64793	S6	257.5	0.006
64793	2N2	49.1	0.039
64793	OO1	157.4	0.075
64793	M1	113.8	0.016
64793	J1	179.2	0.021
64793	Q1	115.2	0.035
64793	2Q1	170.4	0.034
64793	P1	113.6	0.086
64793	2SM2	1.7	0.008
64793	M3	297.2	0.005
64793	L2	145.2	0.032
64793	2MK3	211.9	0.025
64793	K2	129.4	0.08
64793	M8	130	0.002
64793	MS4	66.2	0.044
64794	M2	93.4	0.592
64794	S2	96.9	0.137
64794	N2	78.2	0.108
64794	K1	91.2	0.241
64794	M4	154.5	0.011
64794	O1	75.6	0.117
64794	M6	3.3	0.005
64794	MK3	44.7	0.023
64794	S4	201.6	0.005
64794	MN4	74.1	0.004
64794	S6	278.8	0.003
64794	2N2	68.3	0.043
64794	OO1	169.1	0.058
64794	M1	102.4	0.012
64794	J1	221.6	0.018
64794	Q1	73.4	0.022
64794	2Q1	180.5	0.025
64794	P1	89.2	0.087
64794	2SM2	7.5	0.003
64794	M3	333.1	0.012
64794	L2	131.6	0.037
64794	2MK3	244.3	0.063
64794	K2	130	0.11
64794	M8	136.3	0.004
64794	MS4	66.9	0.026
64795	M2	83.9	0.538
64795	S2	111	0.152
64795	N2	68.6	0.12
64795	K1	118.6	0.227
64795	M4	46.8	0.063
64795	O1	125.8	0.114
64795	M6	76.3	0.015
64795	MK3	67.2	0.037
64795	S4	220.3	0.003
64795	MN4	28.5	0.026
64795	S6	91.5	0.004
64795	2N2	87.7	0.011
64795	OO1	143	0.075
64795	M1	166	0.008
64795	J1	156.8	0.027
64795	Q1	130.6	0.04
64795	2Q1	139.6	0.022
64795	P1	121	0.069
64795	2SM2	253.3	0.005
64795	M3	318	0.003
64795	L2	70	0.03
64795	2MK3	118.2	0.009
64795	K2	106.1	0.029
64795	M8	38.8	0.007
64795	MS4	82.1	0.014
64796	M2	78.5	0.555
64796	S2	102.2	0.122
64796	N2	65.1	0.125
64796	K1	127.8	0.17
64796	M4	36.1	0.033
64796	O1	169.8	0.106
64796	M6	56.6	0.012
64796	MK3	91.5	0.043
64796	S4	141.6	0.005
64796	MN4	41.4	0.024
64796	S6	100.1	0.004
64796	2N2	60.9	0.015
64796	OO1	139.1	0.069
64796	M1	266.8	0.007
64796	J1	146.9	0.016
64796	Q1	154.8	0.026
64796	2Q1	141.8	0.033
64796	P1	126.6	0.079
64796	2SM2	299	0.007
64796	M3	120.4	0.01
64796	L2	44	0.027
64796	2MK3	51.7	0.013
64796	K2	91.1	0.047
64796	M8	333.9	0.001
64796	MS4	46.1	0.024
64797	M2	75.5	0.529
64797	S2	93.1	0.102
64797	N2	58.7	0.109
64797	K1	121.8	0.135
64797	M4	49	0.008
64797	O1	184.6	0.092
64797	M6	103.5	0.02
64797	MK3	98.3	0.028
64797	S4	130.4	0.013
64797	MN4	54.4	0.013
64797	S6	92.5	0.004
64797	2N2	29	0.025
64797	OO1	147.7	0.044
64797	M1	306.3	0.006
64797	J1	231.2	0.007
64797	Q1	187.2	0.014
64797	2Q1	153.6	0.016
64797	P1	124.8	0.074
64797	2SM2	263.1	0.015
64797	M3	118.4	0.008
64797	L2	45.8	0.035
64797	2MK3	157.5	0.014
64797	K2	94.2	0.064
64797	M8	20.8	0.007
64797	MS4	55.9	0.017
64798	M2	71.3	0.725
64798	S2	88.8	0.168
64798	N2	55.2	0.149
64798	K1	80	0.213
64798	M4	141.8	0.058
64798	O1	58.6	0.137
64798	M6	329.2	0.021
64798	MK3	89.3	0.039
64798	S4	105.6	0.012
64798	MN4	188.9	0.023
64798	S6	150.9	0.005
64798	2N2	54.7	0.025
64798	OO1	138.7	0.115
64798	M1	63.2	0.016
64798	J1	193.9	0.038
64798	Q1	113	0.023
64798	2Q1	206.4	0.052
64798	P1	132.6	0.04
64798	2SM2	266.6	0.014
64798	M3	203.4	0.026
64798	L2	57.6	0.071
64798	2MK3	81.5	0.046
64798	K2	107.4	0.104
64798	M8	140.5	0.019
64798	MS4	116.7	0.028
64799	M2	73.5	0.728
64799	S2	92.9	0.169
64799	N2	57.2	0.148
64799	K1	82.2	0.216
64799	M4	139.3	0.054
64799	O1	60.7	0.139
64799	M6	326	0.021
64799	MK3	90.3	0.044
64799	S4	101.7	0.011
64799	MN4	189.6	0.019
64799	S6	137.1	0.002
64799	2N2	52.8	0.027
64799	OO1	138.2	0.117
64799	M1	66.7	0.016
64799	J1	193.3	0.037
64799	Q1	109.9	0.024
64799	2Q1	205	0.051
64799	P1	129.6	0.04
64799	2SM2	274.1	0.012
64799	M3	203.4	0.027
64799	L2	61	0.071
64799	2MK3	85.2	0.05
64799	K2	104.8	0.096
64799	M8	147.8	0.018
64799	MS4	112.7	0.027
64800	M2	75.6	0.726
64800	S2	97.3	0.169
64800	N2	59.7	0.146
64800	K1	83.6	0.221
64800	M4	137.3	0.052
64800	O1	62.8	0.139
64800	M6	324.1	0.021
64800	MK3	90.5	0.047
64800	S4	97.3	0.013
64800	MN4	187.1	0.015
64800	S6	124	0.001
64800	2N2	53.7	0.03
64800	OO1	138	0.116
64800	M1	68.4	0.015
64800	J1	192.1	0.037
64800	Q1	107.8	0.025
64800	2Q1	204.2	0.049
64800	P1	122.5	0.041
64800	2SM2	286	0.01
64800	M3	203.1	0.028
64800	L2	64.7	0.071
64800	2MK3	89.4	0.055
64800	K2	102.2	0.088
64800	M8	155.4	0.016
64800	MS4	109.5	0.026
64801	M2	77.8	0.72
64801	S2	101.5	0.168
64801	N2	62.4	0.143
64801	K1	85.5	0.228
64801	M4	135.4	0.049
64801	O1	65	0.139
64801	M6	324.8	0.021
64801	MK3	91.8	0.049
64801	S4	96.2	0.013
64801	MN4	184.9	0.011
64801	2N2	55	0.031
64801	OO1	138.2	0.112
64801	M1	69.9	0.015
64801	J1	191.6	0.036
64801	Q1	105.5	0.025
64801	2Q1	204.3	0.045
64801	P1	116.1	0.045
64801	2SM2	296.1	0.009
64801	M3	203.2	0.03
64801	L2	69.1	0.069
64801	2MK3	92.4	0.058
64801	K2	98.8	0.081
64801	M8	164.9	0.015
64801	MS4	106.1	0.027
64802	M2	80	0.711
64802	S2	104.6	0.166
64802	N2	65	0.14
64802	K1	87.6	0.237
64802	M4	133.4	0.046
64802	O1	68	0.138
64802	M6	329.7	0.021
64802	MK3	94.1	0.05
64802	S4	93	0.014
64802	MN4	183.2	0.008
64802	S6	248.4	0.002
64802	2N2	56.9	0.03
64802	OO1	139.5	0.103
64802	M1	70.9	0.014
64802	J1	189.9	0.033
64802	Q1	105.3	0.025
64802	2Q1	202	0.041
64802	P1	111.5	0.052
64802	2SM2	302.6	0.008
64802	M3	203.9	0.031
64802	L2	74.2	0.066
64802	2MK3	95.4	0.06
64802	K2	95.9	0.079
64802	M8	174.5	0.013
64802	MS4	102.8	0.028
64803	M2	82.3	0.698
64803	S2	106.8	0.165
64803	N2	67.7	0.138
64803	K1	90.2	0.245
64803	M4	130.2	0.043
64803	O1	71.8	0.134
64803	M6	338.7	0.022
64803	MK3	97.6	0.051
64803	S4	89.5	0.013
64803	MN4	159.2	0.004
64803	S6	261	0.003
64803	2N2	59.3	0.028
64803	OO1	141.1	0.093
64803	M1	71.8	0.012
64803	J1	188.4	0.03
64803	Q1	106.3	0.025
64803	2Q1	198.7	0.037
64803	P1	108.5	0.059
64803	2SM2	299.5	0.006
64803	M3	206.2	0.031
64803	L2	79.1	0.062
64803	2MK3	98.2	0.059
64803	K2	94.7	0.077
64803	M8	183.5	0.012
64803	MS4	101.8	0.029
64804	M2	84.5	0.682
64804	S2	108.6	0.163
64804	N2	70.7	0.136
64804	K1	92.6	0.251
64804	M4	124.9	0.04
64804	O1	76.2	0.131
64804	M6	348.7	0.022
64804	MK3	101.6	0.052
64804	S4	83.2	0.012
64804	MN4	92.9	0.005
64804	S6	279.6	0.004
64804	2N2	60.4	0.026
64804	OO1	142.5	0.081
64804	M1	77.1	0.01
64804	J1	185.4	0.029
64804	Q1	110.9	0.023
64804	2Q1	192.6	0.032
64804	P1	106.9	0.067
64804	2SM2	297.4	0.004
64804	M3	210.9	0.031
64804	L2	84.4	0.057
64804	2MK3	101.1	0.057
64804	K2	95.4	0.075
64804	M8	192.4	0.01
64804	MS4	101.1	0.031
64805	M2	86.5	0.665
64805	S2	110.4	0.161
64805	N2	74.1	0.136
64805	K1	95.2	0.257
64805	M4	116.7	0.037
64805	O1	81.5	0.126
64805	M6	359	0.022
64805	MK3	105.4	0.051
64805	S4	76.6	0.011
64805	MN4	69.6	0.01
64805	S6	290.5	0.005
64805	2N2	61.9	0.022
64805	OO1	142	0.069
64805	M1	87	0.008
64805	J1	179.6	0.027
64805	Q1	119.5	0.02
64805	2Q1	183.1	0.026
64805	P1	106.1	0.074
64805	2SM2	292.1	0.002
64805	M3	215.1	0.03
64805	L2	89.9	0.051
64805	2MK3	103.6	0.054
64805	K2	97.3	0.072
64805	M8	204.7	0.009
64805	MS4	100.8	0.031
64806	M2	88.4	0.646
64806	S2	112	0.159
64806	N2	77.4	0.136
64806	K1	97.6	0.266
64806	M4	105.6	0.035
64806	O1	87.9	0.121
64806	M6	11.6	0.022
64806	MK3	109.6	0.052
64806	S4	73.8	0.011
64806	MN4	65.5	0.015
64806	S6	301.1	0.007
64806	2N2	64.9	0.019
64806	OO1	142.1	0.058
64806	M1	103.8	0.006
64806	J1	173	0.026
64806	Q1	129	0.017
64806	2Q1	170.7	0.021
64806	P1	107.2	0.084
64806	2SM2	141.4	0.002
64806	M3	218.4	0.028
64806	L2	94.6	0.045
64806	2MK3	106.4	0.051
64806	K2	100.2	0.068
64806	M8	220.6	0.008
64806	MS4	100	0.031
64807	M2	90.2	0.625
64807	S2	112.9	0.156
64807	N2	81	0.136
64807	K1	100.4	0.274
64807	M4	92.6	0.035
64807	O1	95.9	0.117
64807	M6	24.4	0.024
64807	MK3	112.7	0.051
64807	S4	73.9	0.01
64807	MN4	62	0.02
64807	S6	310.8	0.008
64807	2N2	69.3	0.016
64807	OO1	139.3	0.046
64807	M1	133.7	0.005
64807	J1	164.7	0.025
64807	Q1	138.2	0.016
64807	2Q1	150.5	0.018
64807	P1	108.3	0.092
64807	2SM2	135.5	0.005
64807	M3	221	0.024
64807	L2	102	0.039
64807	2MK3	109.1	0.046
64807	K2	104	0.066
64807	M8	232.8	0.008
64807	MS4	100.4	0.031
64808	M2	92	0.605
64808	S2	113.3	0.153
64808	N2	83.7	0.136
64808	K1	103.5	0.284
64808	M4	80.5	0.038
64808	O1	105	0.115
64808	M6	36.1	0.026
64808	MK3	114.4	0.05
64808	S4	76.2	0.011
64808	MN4	58.7	0.025
64808	S6	313.6	0.009
64808	2N2	75.4	0.014
64808	OO1	136.7	0.035
64808	M1	161.7	0.006
64808	J1	154.6	0.024
64808	Q1	145.4	0.016
64808	2Q1	125.8	0.018
64808	P1	110.5	0.099
64808	2SM2	142.2	0.007
64808	M3	220.7	0.021
64808	L2	113.9	0.032
64808	2MK3	111	0.041
64808	K2	108.4	0.065
64808	M8	242.1	0.008
64808	MS4	100.3	0.03
64809	M2	93.5	0.583
64809	S2	113.9	0.148
64809	N2	85.8	0.135
64809	K1	106.7	0.292
64809	M4	69.2	0.043
64809	O1	115.4	0.115
64809	M6	45.6	0.027
64809	MK3	113.6	0.047
64809	S4	81.8	0.011
64809	MN4	56.2	0.029
64809	S6	320.3	0.01
64809	2N2	84	0.012
64809	OO1	131.1	0.026
64809	M1	178.4	0.008
64809	J1	142.3	0.026
64809	Q1	149.8	0.015
64809	2Q1	109.2	0.019
64809	P1	113	0.104
64809	2SM2	140.1	0.007
64809	M3	212.4	0.016
64809	L2	133.2	0.027
64809	2MK3	112.4	0.033
64809	K2	111.8	0.062
64809	M8	254.9	0.008
64809	MS4	100.8	0.028
64810	M2	94.7	0.561
64810	S2	114.8	0.145
64810	N2	87.3	0.132
64810	K1	109.8	0.298
64810	M4	62	0.05
64810	O1	125.7	0.116
64810	M6	51.8	0.027
64810	MK3	108.3	0.045
64810	S4	87.6	0.012
64810	MN4	53.1	0.031
64810	S6	329.7	0.01
64810	2N2	87.4	0.01
64810	OO1	114.2	0.021
64810	M1	187	0.009
64810	J1	128.4	0.029
64810	Q1	155.3	0.014
64810	2Q1	97.9	0.02
64810	P1	115.5	0.106
64810	2SM2	131.8	0.008
64810	M3	193.5	0.012
64810	L2	156.4	0.025
64810	2MK3	114.8	0.025
64810	K2	117.8	0.055
64810	M8	268	0.008
64810	MS4	96.9	0.025
64811	M2	95.4	0.539
64811	S2	115.4	0.141
64811	N2	87.5	0.129
64811	K1	112.3	0.3
64811	M4	57.8	0.057
64811	O1	135.4	0.12
64811	M6	52.1	0.026
64811	MK3	99.6	0.046
64811	S4	89.1	0.011
64811	MN4	50.8	0.033
64811	S6	340.1	0.01
64811	2N2	79.3	0.008
64811	OO1	90.9	0.02
64811	M1	190.1	0.011
64811	J1	117.4	0.033
64811	Q1	162	0.013
64811	2Q1	88.2	0.02
64811	P1	117	0.107
64811	2SM2	122.4	0.01
64811	M3	165.3	0.011
64811	L2	177	0.028
64811	2MK3	123.4	0.018
64811	K2	125.7	0.048
64811	M8	280.5	0.008
64811	MS4	86.2	0.021
64812	M2	95.7	0.519
64812	S2	116.1	0.136
64812	N2	86.3	0.125
64812	K1	115.1	0.301
64812	M4	56.3	0.064
64812	O1	144.4	0.125
64812	M6	51.5	0.026
64812	MK3	90.2	0.049
64812	S4	95.7	0.009
64812	MN4	51	0.037
64812	S6	355.4	0.009
64812	2N2	69.5	0.007
64812	OO1	74.5	0.021
64812	M1	189.9	0.014
64812	J1	104.4	0.036
64812	Q1	176.3	0.013
64812	2Q1	76.3	0.022
64812	P1	119.6	0.104
64812	2SM2	114.3	0.012
64812	M3	145.6	0.014
64812	L2	190.5	0.031
64812	2MK3	140.2	0.012
64812	K2	134.1	0.041
64812	M8	291.3	0.009
64812	MS4	75.7	0.018
64813	M2	95.7	0.501
64813	S2	117.9	0.132
64813	N2	83.7	0.123
64813	K1	117.5	0.301
64813	M4	58.1	0.07
64813	O1	151.6	0.134
64813	M6	48.9	0.027
64813	MK3	81.5	0.055
64813	S4	101.4	0.008
64813	MN4	51.1	0.042
64813	S6	13.5	0.007
64813	2N2	65.9	0.007
64813	OO1	66.2	0.026
64813	M1	190.6	0.015
64813	J1	94.3	0.041
64813	Q1	197.4	0.014
64813	2Q1	63.3	0.027
64813	P1	122.4	0.102
64813	2SM2	108.7	0.013
64813	M3	138.3	0.017
64813	L2	197.6	0.033
64813	2MK3	166.9	0.008
64813	K2	147.2	0.032
64813	M8	303	0.01
64813	MS4	63.9	0.015
64814	M2	95.1	0.488
64814	S2	117.5	0.131
64814	N2	80.1	0.122
64814	K1	119.2	0.3
64814	M4	59.4	0.074
64814	O1	158.2	0.143
64814	M6	45.2	0.029
64814	MK3	73.1	0.066
64814	S4	103.8	0.009
64814	MN4	51.9	0.047
64814	S6	41.8	0.004
64814	2N2	55.9	0.007
64814	OO1	63.8	0.035
64814	M1	192.3	0.016
64814	J1	86.9	0.045
64814	Q1	212.4	0.018
64814	2Q1	53.8	0.035
64814	P1	125.9	0.1
64814	2SM2	103.3	0.013
64814	M3	136.6	0.021
64814	L2	206.1	0.033
64814	2MK3	209	0.007
64814	K2	173.9	0.028
64814	M8	313.9	0.011
64814	MS4	44.1	0.013
64815	M2	93.2	0.478
64815	S2	113.4	0.13
64815	N2	76	0.123
64815	K1	119.2	0.286
64815	M4	59.3	0.078
64815	O1	164.9	0.143
64815	M6	39.9	0.033
64815	MK3	64.1	0.085
64815	S4	92.2	0.011
64815	MN4	52.3	0.051
64815	S6	97.3	0.004
64815	2N2	38.5	0.011
64815	OO1	61.5	0.049
64815	M1	196.9	0.015
64815	J1	81.9	0.05
64815	Q1	225	0.02
64815	2Q1	44.5	0.045
64815	P1	123.9	0.089
64815	2SM2	88.7	0.013
64815	M3	131	0.025
64815	L2	219.6	0.031
64815	2MK3	260	0.012
64815	K2	196.5	0.035
64815	M8	322.6	0.013
64815	MS4	6.4	0.014
64816	M2	90.7	0.472
64816	S2	107.9	0.134
64816	N2	71.9	0.12
64816	K1	115.2	0.239
64816	M4	62.7	0.083
64816	O1	169.5	0.133
64816	M6	42	0.039
64816	MK3	59	0.105
64816	S4	91.1	0.013
64816	MN4	56.1	0.052
64816	S6	99.6	0.005
64816	2N2	28.1	0.014
64816	OO1	53.3	0.059
64816	M1	207.5	0.012
64816	J1	77.6	0.054
64816	Q1	238.3	0.027
64816	2Q1	36.9	0.055
64816	P1	101.7	0.079
64816	2SM2	74.1	0.014
64816	M3	125.3	0.028
64816	L2	230.3	0.025
64816	2MK3	292.2	0.018
64816	K2	206	0.056
64816	M8	323.5	0.014
64816	MS4	343.5	0.011
64817	M2	58.5	0.222
64817	S2	72.5	0.06
64817	N2	43.6	0.036
64817	K1	50.7	0.089
64817	M4	67.4	0.013
64817	O1	39.6	0.074
64817	M6	78.7	0.017
64817	MK3	60.2	0.026
64817	S4	64.1	0.005
64817	MN4	83.2	0.006
64817	S6	149.4	0.003
64817	2N2	47.5	0.018
64817	OO1	107.9	0.01
64817	M1	36.4	0.01
64817	J1	100.3	0.007
64817	Q1	107.3	0.003
64817	2Q1	298.5	0.013
64817	P1	71	0.046
64817	2SM2	287.8	0.011
64817	M3	135.4	0.015
64817	L2	43.5	0.013
64817	2MK3	14.4	0.022
64817	K2	59.3	0.023
64817	MS4	77.7	0.013
64818	M2	43.1	0.349
64818	S2	67.7	0.092
64818	N2	26.9	0.069
64818	K1	11.9	0.127
64818	M4	56.6	0.04
64818	O1	31.7	0.07
64818	M6	95.9	0.013
64818	MK3	48.4	0.023
64818	S4	178.4	0.003
64818	MN4	44.8	0.021
64818	S6	98.2	0.002
64818	2N2	276.5	0.006
64818	OO1	307.5	0.014
64818	M1	268	0.008
64818	J1	198.2	0.017
64818	Q1	36	0.032
64818	2Q1	5.8	0.011
64818	P1	38.8	0.061
64818	2SM2	255.2	0.007
64818	M3	79.6	0.009
64818	L2	56.7	0.037
64818	2MK3	13.4	0.01
64818	K2	178.4	0.011
64818	M8	212	0.005
64818	MS4	96.9	0.009
64819	M2	38.7	0.388
64819	S2	68.2	0.099
64819	N2	22.3	0.073
64819	K1	16.8	0.097
64819	M4	48	0.044
64819	O1	58.8	0.036
64819	M6	77	0.019
64819	MK3	24.4	0.038
64819	S4	344	0.006
64819	MN4	12.6	0.031
64819	S6	97.2	0.004
64819	2N2	264	0.009
64819	OO1	189.3	0.033
64819	M1	182.4	0.013
64819	J1	18.3	0.008
64819	Q1	356.3	0.008
64819	2Q1	96.4	0.007
64819	P1	13.8	0.044
64819	2SM2	241.4	0.016
64819	M3	58.5	0.009
64819	L2	54.5	0.052
64819	2MK3	322.6	0.011
64819	K2	40.6	0.015
64819	M8	252.4	0.006
64819	MS4	82.2	0.014
64820	M2	51.9	0.202
64820	S2	87.7	0.049
64820	N2	42.2	0.009
64820	K1	62.5	0.325
64820	M4	338.1	0.008
64820	O1	43.3	0.216
64820	M6	49.8	0.005
64820	MK3	280.8	0.015
64820	S4	289.2	0.001
64820	MN4	11.7	0.013
64820	S6	97.8	0.004
64820	2N2	3.5	0.017
64820	OO1	304.3	0.014
64820	M1	30.5	0.028
64820	J1	299.5	0.014
64820	Q1	9	0.042
64820	2Q1	23.4	0.03
64820	2SM2	254.3	0.012
64820	M3	149.5	0.017
64820	L2	348.4	0.016
64820	2MK3	278.5	0.021
64820	K2	39.3	0.03
64820	M8	173	0.002
64820	MS4	12.7	0.003
64821	M2	52	0.205
64821	S2	89	0.047
64821	N2	33.6	0.009
64821	K1	62.8	0.321
64821	M4	328.6	0.008
64821	O1	44.5	0.213
64821	M6	46.9	0.005
64821	MK3	291.4	0.014
64821	S4	274.3	0.003
64821	MN4	6.4	0.012
64821	S6	111.1	0.003
64821	2N2	0.5	0.018
64821	OO1	307.1	0.017
64821	M1	31.8	0.028
64821	J1	303.7	0.015
64821	Q1	9.4	0.044
64821	2Q1	28.1	0.028
64821	2SM2	255.1	0.013
64821	M3	145.9	0.017
64821	L2	349.4	0.015
64821	2MK3	278.8	0.02
64821	K2	43.6	0.026
64821	M8	143.5	0.003
64821	MS4	30	0.004
64822	M2	51.1	0.204
64822	S2	90.1	0.045
64822	N2	23.1	0.009
64822	K1	63.2	0.315
64822	M4	327.7	0.009
64822	O1	45.9	0.208
64822	M6	44.8	0.004
64822	MK3	305.2	0.015
64822	S4	279.8	0.004
64822	MN4	359.6	0.01
64822	S6	118.2	0.003
64822	2N2	357.1	0.019
64822	OO1	315.2	0.017
64822	M1	33	0.028
64822	J1	307.4	0.015
64822	Q1	8.3	0.044
64822	2Q1	29.6	0.027
64822	2SM2	257.3	0.013
64822	M3	144.1	0.017
64822	L2	356.6	0.016
64822	2MK3	280	0.019
64822	K2	51	0.022
64822	M8	142.2	0.002
64822	MS4	30.7	0.005
64823	M2	49.9	0.2
64823	S2	82.9	0.045
64823	N2	3.4	0.011
64823	K1	63.5	0.303
64823	M4	324.3	0.01
64823	O1	47.1	0.2
64823	M6	48.1	0.005
64823	MK3	317.7	0.017
64823	S4	282.6	0.004
64823	MN4	348.1	0.009
64823	S6	122.5	0.004
64823	2N2	356.7	0.019
64823	OO1	324.8	0.019
64823	M1	31.9	0.028
64823	J1	306.8	0.015
64823	Q1	6.7	0.042
64823	2Q1	26.7	0.027
64823	2SM2	256.8	0.014
64823	M3	142.3	0.017
64823	L2	2.3	0.017
64823	2MK3	281.9	0.017
64823	K2	50.7	0.027
64823	M8	163.8	0.001
64823	MS4	18.5	0.004
64824	M2	49	0.2
64824	S2	78.2	0.044
64824	N2	355.1	0.012
64824	K1	64.3	0.299
64824	M4	322.4	0.011
64824	O1	47.8	0.197
64824	M6	53.3	0.004
64824	MK3	327.7	0.016
64824	S4	285.4	0.003
64824	MN4	335.1	0.008
64824	S6	122.5	0.004
64824	2N2	359.5	0.021
64824	OO1	329.1	0.02
64824	M1	32.7	0.027
64824	J1	309.3	0.016
64824	Q1	6	0.042
64824	2Q1	27.5	0.025
64824	2SM2	257.9	0.012
64824	M3	144.2	0.016
64824	L2	6.7	0.018
64824	2MK3	283.3	0.015
64824	K2	47	0.03
64824	M8	208.2	0.001
64824	MS4	352.8	0.003
64825	M2	48.2	0.201
64825	S2	74.5	0.044
64825	N2	354.4	0.013
64825	K1	65	0.298
64825	M4	322.5	0.012
64825	O1	48.8	0.197
64825	M6	50.5	0.004
64825	MK3	332.6	0.016
64825	S4	293.6	0.002
64825	MN4	323.2	0.008
64825	S6	122.7	0.003
64825	2N2	5.4	0.022
64825	OO1	331.3	0.02
64825	M1	33.3	0.027
64825	J1	312.8	0.015
64825	Q1	5.1	0.042
64825	2Q1	30.7	0.024
64825	2SM2	264.2	0.01
64825	M3	143.7	0.016
64825	L2	9.7	0.019
64825	2MK3	286.7	0.013
64825	K2	43.9	0.032
64825	M8	226	0.001
64825	MS4	303	0.003
64826	M2	47.8	0.202
64826	S2	75.3	0.045
64826	N2	358.7	0.014
64826	K1	65.7	0.295
64826	M4	319.4	0.011
64826	O1	49.5	0.197
64826	M6	56.4	0.004
64826	MK3	333.4	0.017
64826	S4	258	0.001
64826	MN4	318.3	0.008
64826	S6	136.6	0.002
64826	2N2	9.8	0.023
64826	OO1	335.4	0.016
64826	M1	33.8	0.026
64826	J1	310.8	0.014
64826	Q1	5.5	0.041
64826	2Q1	36.5	0.023
64826	2SM2	276.1	0.008
64826	M3	143.3	0.014
64826	L2	8.4	0.019
64826	2MK3	294.4	0.013
64826	K2	50.4	0.033
64826	M8	207.6	0.001
64826	MS4	274.1	0.004
64827	M2	47.9	0.204
64827	S2	79	0.05
64827	N2	6.8	0.016
64827	K1	66.3	0.293
64827	M4	315.1	0.011
64827	O1	50.4	0.198
64827	M6	58.3	0.004
64827	MK3	335.2	0.017
64827	S4	194.7	0.001
64827	MN4	307	0.006
64827	S6	100.7	0.001
64827	2N2	15.7	0.024
64827	OO1	337.7	0.011
64827	M1	33.4	0.026
64827	J1	305	0.012
64827	Q1	6.6	0.041
64827	2Q1	39	0.023
64827	2SM2	287.2	0.006
64827	M3	144.2	0.014
64827	L2	4.2	0.018
64827	2MK3	299.1	0.013
64827	K2	60.7	0.037
64827	M8	217.8	0.001
64827	MS4	261.9	0.008
64828	M2	48.3	0.206
64828	S2	79.5	0.056
64828	N2	9.7	0.019
64828	K1	66.7	0.287
64828	M4	303.7	0.01
64828	O1	51.2	0.197
64828	M6	62.9	0.005
64828	MK3	339.7	0.017
64828	MN4	281.7	0.006
64828	S6	99.3	0.001
64828	2N2	19.6	0.026
64828	OO1	344.9	0.005
64828	M1	31.8	0.025
64828	J1	297	0.01
64828	Q1	9.7	0.039
64828	2Q1	40.6	0.023
64828	2SM2	312.1	0.004
64828	M3	143.7	0.015
64828	L2	359.6	0.017
64828	2MK3	296.5	0.013
64828	K2	63.7	0.043
64828	M8	183.7	0.001
64828	MS4	253.5	0.01
64829	M2	48.8	0.207
64829	S2	77.1	0.061
64829	N2	15.3	0.024
64829	K1	67.1	0.28
64829	M4	297	0.011
64829	O1	52.2	0.195
64829	M6	63.6	0.007
64829	MK3	348.2	0.019
64829	S4	0.1	0.001
64829	MN4	267	0.005
64829	S6	194.3	0.001
64829	2N2	21.5	0.026
64829	OO1	94	0.004
64829	M1	31.4	0.023
64829	J1	292.8	0.008
64829	Q1	12.1	0.037
64829	2Q1	40.7	0.023
64829	2SM2	335.7	0.002
64829	M3	137.3	0.015
64829	L2	354.8	0.016
64829	2MK3	287.5	0.012
64829	K2	60.4	0.046
64829	M8	153.5	0.002
64829	MS4	243.9	0.011
64830	M2	49.8	0.209
64830	S2	73.1	0.063
64830	N2	16.4	0.027
64830	K1	68.2	0.271
64830	M4	293.3	0.01
64830	O1	53.7	0.191
64830	M6	62.4	0.009
64830	MK3	356.1	0.019
64830	S4	26.4	0.001
64830	MN4	271.8	0.006
64830	S6	232.3	0.002
64830	2N2	19.4	0.026
64830	OO1	122.7	0.01
64830	M1	36	0.022
64830	J1	308.7	0.006
64830	Q1	16.5	0.037
64830	2Q1	38.6	0.02
64830	2SM2	89.2	0.003
64830	M3	127.9	0.016
64830	L2	2.8	0.015
64830	2MK3	280.7	0.013
64830	K2	52.9	0.046
64830	M8	154.9	0.002
64830	MS4	230.5	0.012
64831	M2	51.1	0.211
64831	S2	68	0.064
64831	N2	13.7	0.029
64831	K1	69.9	0.26
64831	M4	294	0.01
64831	O1	55.3	0.184
64831	M6	64.6	0.011
64831	MK3	0.5	0.018
64831	S4	187.5	0.002
64831	MN4	274.3	0.007
64831	S6	255.3	0.002
64831	2N2	17.2	0.026
64831	OO1	125.3	0.014
64831	M1	40.8	0.021
64831	J1	335.1	0.008
64831	Q1	21.2	0.035
64831	2Q1	33.1	0.016
64831	2SM2	109	0.006
64831	M3	120	0.018
64831	L2	17.4	0.016
64831	2MK3	272.2	0.014
64831	K2	45.8	0.047
64831	M8	153.6	0.002
64831	MS4	210.5	0.013
64832	M2	52.7	0.214
64832	S2	65.3	0.063
64832	N2	12.5	0.028
64832	K1	71.8	0.246
64832	M4	288.3	0.008
64832	O1	57.6	0.175
64832	M6	66.9	0.013
64832	MK3	13.8	0.017
64832	S4	190.9	0.007
64832	MN4	263.1	0.008
64832	S6	278.1	0.003
64832	2N2	16.6	0.025
64832	OO1	131.6	0.017
64832	M1	46.4	0.022
64832	J1	343.5	0.013
64832	Q1	25.4	0.033
64832	2Q1	15.9	0.014
64832	2SM2	114.5	0.01
64832	M3	112	0.019
64832	L2	30.2	0.019
64832	2MK3	269.5	0.017
64832	K2	40.7	0.043
64832	M8	139.8	0.002
64832	MS4	196.6	0.014
64833	M2	54	0.221
64833	S2	67	0.061
64833	N2	11.3	0.025
64833	K1	73.9	0.228
64833	M4	272	0.004
64833	O1	60.2	0.163
64833	M6	71	0.013
64833	MK3	28.3	0.019
64833	S4	194.4	0.01
64833	MN4	255.7	0.008
64833	S6	294.2	0.005
64833	2N2	19.7	0.023
64833	OO1	138.1	0.016
64833	M1	54.7	0.023
64833	J1	350.8	0.017
64833	Q1	33.5	0.03
64833	2Q1	357.2	0.016
64833	2SM2	124.1	0.013
64833	M3	111.6	0.02
64833	L2	34.8	0.024
64833	2MK3	270	0.018
64833	K2	43.5	0.035
64833	M8	145.5	0.002
64833	MS4	191.8	0.016
64834	M2	54.9	0.231
64834	S2	66.7	0.056
64834	N2	12.3	0.025
64834	K1	75.6	0.208
64834	M4	207.5	0.003
64834	O1	62.8	0.15
64834	M6	76.4	0.013
64834	MK3	35.3	0.024
64834	S4	202.4	0.014
64834	MN4	237	0.008
64834	S6	286.7	0.006
64834	2N2	26.7	0.021
64834	OO1	151.2	0.015
64834	M1	60.8	0.024
64834	J1	348.8	0.019
64834	Q1	41	0.029
64834	2Q1	346.8	0.018
64834	2SM2	135.9	0.013
64834	M3	109.8	0.018
64834	L2	35.3	0.027
64834	2MK3	271.1	0.019
64834	K2	43.4	0.025
64834	M8	101.8	0.002
64834	MS4	189.7	0.016
64835	M2	55.1	0.241
64835	S2	66.4	0.047
64835	N2	13.6	0.026
64835	K1	76.3	0.188
64835	M4	172	0.005
64835	O1	64.6	0.133
64835	M6	80	0.011
64835	MK3	37.2	0.03
64835	S4	202.1	0.017
64835	MN4	201.9	0.008
64835	S6	277.1	0.007
64835	2N2	31.9	0.018
64835	OO1	166.7	0.021
64835	M1	66.2	0.022
64835	J1	342.6	0.019
64835	Q1	54	0.025
64835	2Q1	343	0.021
64835	2SM2	151.4	0.013
64835	M3	104.6	0.015
64835	L2	30	0.029
64835	2MK3	277.9	0.018
64835	K2	11.5	0.009
64835	M8	107.3	0.001
64835	MS4	192.3	0.019
64836	M2	55.2	0.255
64836	S2	62.2	0.037
64836	N2	15.8	0.029
64836	K1	76.2	0.17
64836	M4	184.3	0.009
64836	O1	66.3	0.116
64836	M6	77.1	0.009
64836	MK3	36.1	0.033
64836	S4	198.3	0.019
64836	MN4	177.4	0.01
64836	S6	272.4	0.004
64836	2N2	33.6	0.015
64836	OO1	172.9	0.026
64836	M1	71.8	0.02
64836	J1	332.4	0.018
64836	Q1	72	0.022
64836	2Q1	335.9	0.02
64836	2SM2	165.8	0.013
64836	M3	86.4	0.012
64836	L2	29.2	0.028
64836	2MK3	278.7	0.016
64836	K2	287.9	0.014
64836	M8	198.8	0.001
64836	MS4	194.1	0.022
64837	M2	55.6	0.267
64837	S2	62.1	0.029
64837	N2	17.7	0.032
64837	K1	75	0.149
64837	M4	194.9	0.014
64837	O1	68.3	0.101
64837	M6	73.3	0.008
64837	MK3	35.2	0.03
64837	S4	192.8	0.019
64837	MN4	167.4	0.014
64837	S6	291.9	0.001
64837	2N2	23.7	0.011
64837	OO1	175	0.028
64837	M1	80	0.016
64837	J1	320.6	0.017
64837	Q1	89	0.018
64837	2Q1	322.4	0.017
64837	2SM2	184.3	0.011
64837	M3	60	0.012
64837	L2	25.5	0.027
64837	2MK3	274.1	0.014
64837	K2	268.2	0.021
64837	M8	243.3	0.002
64837	MS4	194	0.024
64838	M2	57	0.277
64838	S2	64.7	0.027
64838	N2	18.2	0.036
64838	K1	74.1	0.127
64838	M4	203.9	0.021
64838	O1	70.3	0.087
64838	M6	65.3	0.007
64838	MK3	37.5	0.024
64838	S4	184.7	0.019
64838	MN4	169.8	0.018
64838	S6	36.1	0.003
64838	2N2	357	0.007
64838	OO1	167.6	0.027
64838	M1	99.8	0.012
64838	J1	308.5	0.018
64838	Q1	107.1	0.016
64838	2Q1	297.9	0.014
64838	2SM2	193	0.01
64838	M3	30.9	0.014
64838	L2	14.3	0.023
64838	2MK3	269.5	0.011
64838	K2	267.6	0.021
64838	M8	250	0.004
64838	MS4	195	0.025
64839	M2	59	0.285
64839	S2	78.2	0.031
64839	N2	20.7	0.04
64839	K1	73.4	0.107
64839	M4	210.5	0.026
64839	O1	73.9	0.076
64839	M6	44.9	0.007
64839	MK3	45.6	0.016
64839	S4	177.1	0.017
64839	MN4	178.4	0.02
64839	S6	18.5	0.004
64839	2N2	309.5	0.009
64839	OO1	150.5	0.024
64839	M1	129.8	0.013
64839	J1	300.8	0.023
64839	Q1	120.5	0.014
64839	2Q1	273	0.014
64839	2SM2	210.5	0.009
64839	M3	15.2	0.017
64839	L2	5.4	0.022
64839	2MK3	269	0.01
64839	K2	248.2	0.012
64839	M8	269.1	0.006
64839	MS4	194.3	0.025
64840	M2	61.8	0.291
64840	S2	94.4	0.04
64840	N2	28.1	0.044
64840	K1	73.1	0.089
64840	M4	211.1	0.031
64840	O1	78.6	0.065
64840	M6	28.4	0.007
64840	MK3	58.5	0.009
64840	S4	176	0.015
64840	MN4	183.1	0.022
64840	S6	319.3	0.003
64840	2N2	289.9	0.012
64840	OO1	140.3	0.02
64840	M1	149.6	0.016
64840	J1	294.3	0.024
64840	Q1	121.5	0.017
64840	2Q1	267.8	0.018
64840	2SM2	220.6	0.008
64840	M3	3.3	0.02
64840	L2	3.6	0.02
64840	2MK3	269.5	0.009
64840	K2	169.2	0.01
64840	M8	294.4	0.005
64840	MS4	194	0.023
64841	M2	64.9	0.295
64841	S2	109.4	0.049
64841	N2	40.5	0.048
64841	K1	72.8	0.077
64841	M4	207.1	0.033
64841	O1	83	0.054
64841	M6	21.9	0.009
64841	MK3	43.7	0.002
64841	S4	166.4	0.013
64841	MN4	184	0.02
64841	S6	271	0.005
64841	2N2	286.8	0.011
64841	OO1	139.1	0.018
64841	M1	159	0.019
64841	J1	284.6	0.02
64841	Q1	127.9	0.023
64841	2Q1	260.2	0.02
64841	2SM2	221.7	0.006
64841	M3	354.9	0.024
64841	L2	10.9	0.017
64841	2MK3	261.2	0.012
64841	K2	153.3	0.02
64841	M8	317.1	0.005
64841	MS4	191	0.019
64842	M2	68.2	0.298
64842	S2	118.1	0.064
64842	N2	51.4	0.054
64842	K1	73.8	0.066
64842	M4	201.7	0.033
64842	O1	91.9	0.045
64842	M6	26.1	0.01
64842	MK3	295.8	0.006
64842	S4	154.4	0.012
64842	MN4	183	0.018
64842	S6	250.4	0.008
64842	2N2	281.5	0.007
64842	OO1	141.6	0.021
64842	M1	166.2	0.022
64842	J1	272.1	0.013
64842	Q1	132.5	0.029
64842	2Q1	254.7	0.019
64842	2SM2	206.2	0.005
64842	M3	353.9	0.026
64842	L2	22.8	0.016
64842	2MK3	255.8	0.013
64842	K2	147.8	0.036
64842	M8	336.5	0.004
64842	MS4	180.9	0.017
64843	M2	71.7	0.299
64843	S2	120.6	0.075
64843	N2	58.3	0.06
64843	K1	78.8	0.054
64843	M4	192.8	0.032
64843	O1	99	0.038
64843	M6	43.7	0.011
64843	MK3	287.6	0.012
64843	S4	152.2	0.01
64843	MN4	175.4	0.014
64843	S6	232.7	0.009
64843	2N2	224.5	0.003
64843	OO1	143	0.024
64843	M1	171	0.023
64843	J1	229.6	0.008
64843	Q1	133.8	0.032
64843	2Q1	247	0.02
64843	2SM2	169.7	0.004
64843	M3	355.9	0.026
64843	L2	39.7	0.012
64843	2MK3	247.8	0.013
64843	K2	146.9	0.048
64843	M8	349.1	0.003
64843	MS4	171.8	0.014
64844	M2	75	0.301
64844	S2	119.4	0.083
64844	N2	63.7	0.065
64844	K1	91.4	0.04
64844	M4	180.6	0.031
64844	O1	110.3	0.031
64844	M6	56.5	0.012
64844	MK3	289.5	0.017
64844	S4	162	0.007
64844	MN4	157.1	0.013
64844	S6	213.4	0.009
64844	2N2	155.4	0.005
64844	OO1	153.3	0.026
64844	M1	172.4	0.024
64844	J1	182.5	0.011
64844	Q1	133.2	0.032
64844	2Q1	248.7	0.02
64844	2SM2	132.7	0.005
64844	M3	353.2	0.025
64844	L2	78.1	0.009
64844	2MK3	240.3	0.012
64844	K2	143.9	0.054
64844	M8	13	0.003
64844	MS4	155.9	0.011
64845	M2	77.8	0.304
64845	S2	116.3	0.09
64845	N2	67.2	0.067
64845	K1	116.6	0.027
64845	M4	168.7	0.032
64845	O1	131.1	0.024
64845	M6	66.3	0.011
64845	MK3	289	0.021
64845	S4	157.1	0.003
64845	MN4	143.8	0.012
64845	S6	203.3	0.01
64845	2N2	128.3	0.008
64845	OO1	161.6	0.025
64845	M1	175.4	0.025
64845	J1	165.4	0.016
64845	Q1	133.8	0.03
64845	2Q1	249.9	0.021
64845	2SM2	116.4	0.008
64845	M3	350.2	0.023
64845	L2	127	0.012
64845	2MK3	232	0.01
64845	K2	135.8	0.06
64845	M8	13.1	0.003
64845	MS4	131.5	0.011
64846	M2	80.2	0.306
64846	S2	109.7	0.095
64846	N2	69.8	0.068
64846	K1	165.5	0.025
64846	M4	160.8	0.032
64846	O1	162.4	0.021
64846	M6	78.1	0.01
64846	MK3	287	0.024
64846	S4	45.5	0.001
64846	MN4	125.9	0.012
64846	S6	205	0.009
64846	2N2	118.4	0.009
64846	OO1	169.8	0.021
64846	M1	179.4	0.025
64846	J1	159.4	0.02
64846	Q1	135	0.024
64846	2Q1	256	0.023
64846	2SM2	105.7	0.01
64846	M3	345.6	0.02
64846	L2	142.6	0.019
64846	2MK3	215.9	0.008
64846	K2	121.9	0.063
64846	M8	355.8	0.004
64846	MS4	117.7	0.012
64847	M2	82.1	0.309
64847	S2	102.6	0.099
64847	N2	70.4	0.068
64847	K1	198	0.035
64847	M4	152.5	0.033
64847	O1	188.2	0.024
64847	M6	82.8	0.01
64847	MK3	281	0.025
64847	S4	4.9	0.004
64847	MN4	115.5	0.012
64847	S6	222.9	0.008
64847	2N2	106.2	0.009
64847	OO1	180.7	0.016
64847	M1	183	0.022
64847	J1	158.2	0.023
64847	Q1	135.6	0.017
64847	2Q1	261.1	0.022
64847	2SM2	106.2	0.011
64847	M3	336.4	0.017
64847	L2	150.1	0.022
64847	2MK3	212.5	0.011
64847	K2	108.8	0.067
64847	M8	353.7	0.003
64847	MS4	102	0.012
64848	M2	82.8	0.31
64848	S2	98.1	0.099
64848	N2	70	0.068
64848	K1	214.5	0.047
64848	M4	146.2	0.032
64848	O1	202.8	0.029
64848	M6	82.4	0.01
64848	MK3	273.9	0.024
64848	S4	2.4	0.006
64848	MN4	111.8	0.013
64848	S6	239.9	0.008
64848	2N2	86.3	0.009
64848	OO1	206.1	0.008
64848	M1	187.7	0.019
64848	J1	157.2	0.026
64848	Q1	132.1	0.013
64848	2Q1	261.2	0.022
64848	2SM2	104.7	0.012
64848	M3	329.3	0.015
64848	L2	158.4	0.026
64848	2MK3	215	0.013
64848	K2	101.6	0.068
64848	M8	19.3	0.002
64848	MS4	91.7	0.011
64849	M2	82.7	0.313
64849	S2	94.8	0.1
64849	N2	70.2	0.068
64849	K1	223.5	0.06
64849	M4	139.7	0.03
64849	O1	215.4	0.031
64849	M6	83.2	0.01
64849	MK3	261	0.023
64849	S4	5	0.007
64849	MN4	110.5	0.014
64849	S6	251.2	0.006
64849	2N2	63.9	0.011
64849	OO1	335	0.001
64849	M1	195.5	0.015
64849	J1	153.7	0.03
64849	Q1	123.6	0.013
64849	2Q1	260.3	0.021
64849	2SM2	91	0.013
64849	M3	320.6	0.012
64849	L2	162.1	0.033
64849	2MK3	221.8	0.015
64849	K2	95.7	0.068
64849	M8	22.4	0.001
64849	MS4	85.4	0.008
64850	M2	82.3	0.316
64850	S2	92.6	0.097
64850	N2	68.9	0.067
64850	K1	228.8	0.069
64850	M4	134.9	0.027
64850	O1	227.1	0.033
64850	M6	74.2	0.01
64850	MK3	247.9	0.023
64850	S4	20.4	0.008
64850	MN4	107.3	0.014
64850	S6	259.1	0.006
64850	2N2	49.1	0.013
64850	OO1	5.9	0.006
64850	M1	205.5	0.013
64850	J1	149	0.032
64850	Q1	127.1	0.013
64850	2Q1	260.5	0.018
64850	2SM2	83.6	0.015
64850	M3	311.6	0.01
64850	L2	161.2	0.041
64850	2MK3	229.3	0.016
64850	K2	89.9	0.061
64850	M8	65.5	0.002
64850	MS4	83.3	0.006
64851	M2	81.8	0.318
64851	S2	88.1	0.097
64851	N2	68.2	0.065
64851	K1	231.2	0.075
64851	M4	133	0.025
64851	O1	236.1	0.038
64851	M6	76.9	0.01
64851	MK3	236.8	0.027
64851	S4	29	0.008
64851	MN4	106.6	0.015
64851	S6	265.9	0.005
64851	2N2	40.5	0.014
64851	OO1	2.3	0.011
64851	M1	210.8	0.012
64851	J1	136.9	0.034
64851	Q1	135.8	0.017
64851	2Q1	258.6	0.017
64851	2SM2	65.8	0.017
64851	M3	302	0.012
64851	L2	159.4	0.046
64851	2MK3	239.2	0.017
64851	K2	81.7	0.058
64851	M8	81.6	0.003
64851	MS4	61.6	0.004
64852	M2	81	0.317
64852	S2	85.1	0.098
64852	N2	64.7	0.062
64852	K1	232.4	0.075
64852	M4	133.1	0.027
64852	O1	244.5	0.042
64852	M6	75.1	0.011
64852	MK3	230	0.031
64852	S4	23.4	0.006
64852	MN4	111.3	0.013
64852	S6	294.1	0.005
64852	2N2	42.3	0.013
64852	OO1	0.9	0.018
64852	M1	214.4	0.011
64852	J1	126.1	0.034
64852	Q1	138.6	0.019
64852	2Q1	250.4	0.02
64852	2SM2	50.8	0.02
64852	M3	304.3	0.013
64852	L2	159.5	0.048
64852	2MK3	239.3	0.016
64852	K2	78.4	0.054
64852	M8	69.9	0.005
64852	MS4	38.9	0.005
64853	M2	82.4	0.308
64853	S2	89.6	0.095
64853	N2	59.6	0.059
64853	K1	221	0.077
64853	M4	159.3	0.028
64853	O1	237.7	0.057
64853	M6	84.6	0.004
64853	MK3	229.1	0.042
64853	S4	10.2	0.005
64853	MN4	147	0.011
64853	S6	314.7	0.004
64853	2N2	39	0.015
64853	OO1	343.3	0.022
64853	M1	205.6	0.007
64853	J1	123.9	0.031
64853	Q1	148.1	0.018
64853	2Q1	243.6	0.023
64853	2SM2	38.7	0.019
64853	M3	315.2	0.016
64853	L2	156.6	0.041
64853	2MK3	229.1	0.025
64853	K2	93.8	0.04
64853	M8	86.1	0.003
64853	MS4	323.9	0.006
64854	M2	49.1	0.806
64854	S2	59.8	0.194
64854	N2	37.6	0.162
64854	K1	46.8	0.201
64854	M4	142.1	0.07
64854	O1	18.7	0.17
64854	M6	60.2	0.077
64854	MK3	258.5	0.059
64854	S4	322.5	0.004
64854	MN4	103.2	0.034
64854	S6	147.6	0.004
64854	2N2	308.4	0.044
64854	OO1	226.1	0.017
64854	M1	17.8	0.006
64854	J1	86.4	0.028
64854	Q1	27.3	0.015
64854	2Q1	277.8	0.015
64854	P1	41	0.083
64854	2SM2	308.6	0.014
64854	M3	324.1	0.025
64854	L2	74.1	0.118
64854	2MK3	235.2	0.047
64854	K2	94.2	0.072
64854	M8	290.6	0.008
64854	MS4	184.3	0.033
64855	M2	49.7	0.811
64855	S2	60.4	0.188
64855	N2	39	0.166
64855	K1	49.4	0.203
64855	M4	144.9	0.072
64855	O1	19.1	0.17
64855	M6	64.5	0.076
64855	MK3	260.2	0.057
64855	S4	343.5	0.006
64855	MN4	108.1	0.034
64855	S6	170.6	0.004
64855	2N2	308.4	0.037
64855	OO1	237	0.018
64855	M1	26.8	0.007
64855	J1	89.4	0.028
64855	Q1	22.8	0.017
64855	2Q1	280.9	0.014
64855	P1	40.7	0.078
64855	2SM2	307.6	0.016
64855	M3	319.3	0.021
64855	L2	72.6	0.117
64855	2MK3	239.8	0.04
64855	K2	88.2	0.076
64855	M8	283.4	0.005
64855	MS4	183.9	0.034
64856	M2	50.5	0.806
64856	S2	61.4	0.179
64856	N2	40.2	0.167
64856	K1	50.8	0.208
64856	M4	148.8	0.074
64856	O1	19.7	0.173
64856	M6	68.8	0.075
64856	MK3	261.7	0.055
64856	S4	355.4	0.009
64856	MN4	114	0.032
64856	S6	192.6	0.004
64856	2N2	308.8	0.029
64856	OO1	240.1	0.024
64856	M1	38.2	0.008
64856	J1	91.7	0.027
64856	Q1	25.5	0.018
64856	2Q1	281.3	0.013
64856	P1	41.1	0.075
64856	2SM2	304.7	0.017
64856	M3	315.5	0.017
64856	L2	71.8	0.115
64856	2MK3	242.4	0.036
64856	K2	82	0.079
64856	M8	282	0.003
64856	MS4	187.1	0.033
64857	M2	51.5	0.795
64857	S2	62.3	0.167
64857	N2	41.9	0.166
64857	K1	51.2	0.212
64857	M4	152.3	0.075
64857	O1	21.6	0.177
64857	M6	72.5	0.072
64857	MK3	263.8	0.053
64857	S4	359.2	0.012
64857	MN4	121.6	0.03
64857	S6	177.6	0.005
64857	2N2	310.4	0.023
64857	OO1	237.3	0.028
64857	M1	43.6	0.009
64857	J1	91.1	0.027
64857	Q1	29.5	0.019
64857	2Q1	282.2	0.013
64857	P1	40.2	0.073
64857	2SM2	302.4	0.018
64857	M3	309.8	0.014
64857	L2	71	0.11
64857	2MK3	244.3	0.033
64857	K2	77.2	0.082
64857	M8	302.1	0.002
64857	MS4	192.2	0.032
64858	M2	52.5	0.782
64858	S2	63.3	0.154
64858	N2	43.4	0.164
64858	K1	51	0.217
64858	M4	155.9	0.077
64858	O1	24	0.181
64858	M6	75.4	0.07
64858	MK3	265.9	0.05
64858	S4	3.6	0.014
64858	MN4	130.6	0.027
64858	S6	164.3	0.005
64858	2N2	314.4	0.018
64858	OO1	237.2	0.032
64858	M1	49.4	0.009
64858	J1	90.8	0.03
64858	Q1	32.9	0.021
64858	2Q1	289.6	0.013
64858	P1	39.6	0.073
64858	2SM2	298.2	0.018
64858	M3	309	0.01
64858	L2	70.6	0.104
64858	2MK3	245.3	0.033
64858	K2	72.5	0.084
64858	M8	310.1	0.002
64858	MS4	195.5	0.031
64859	M2	53.6	0.765
64859	S2	65	0.142
64859	N2	45.2	0.16
64859	K1	50.1	0.221
64859	M4	159.4	0.078
64859	O1	26.6	0.186
64859	M6	78.3	0.067
64859	MK3	267.3	0.047
64859	S4	5.8	0.014
64859	MN4	138.9	0.025
64859	S6	151.6	0.006
64859	2N2	316.4	0.013
64859	OO1	235.9	0.035
64859	M1	54	0.01
64859	J1	91.7	0.033
64859	Q1	35.5	0.023
64859	2Q1	296.6	0.016
64859	P1	38.2	0.075
64859	2SM2	291.3	0.016
64859	M3	319.5	0.007
64859	L2	70.6	0.098
64859	2MK3	247.1	0.032
64859	K2	68.6	0.084
64859	M8	324.7	0.002
64859	MS4	195.9	0.03
64860	M2	54.7	0.746
64860	S2	66.2	0.131
64860	N2	46.8	0.156
64860	K1	50.1	0.227
64860	M4	161.5	0.079
64860	O1	28.6	0.19
64860	M6	81.8	0.064
64860	MK3	269.3	0.043
64860	S4	8.7	0.014
64860	MN4	147.8	0.024
64860	S6	151	0.007
64860	2N2	323.7	0.01
64860	OO1	233.2	0.037
64860	M1	56.8	0.011
64860	J1	92.2	0.035
64860	Q1	36.8	0.024
64860	2Q1	300.8	0.017
64860	P1	39.5	0.074
64860	2SM2	286.5	0.014
64860	M3	337.3	0.006
64860	L2	70.4	0.091
64860	2MK3	250.6	0.033
64860	K2	66.2	0.086
64860	M8	352.8	0.003
64860	MS4	196.1	0.029
64861	M2	55.8	0.724
64861	S2	68.7	0.121
64861	N2	48.3	0.151
64861	K1	50	0.23
64861	M4	163.3	0.079
64861	O1	30.2	0.193
64861	M6	85	0.06
64861	MK3	272.6	0.039
64861	S4	11	0.013
64861	MN4	154.2	0.023
64861	S6	143.5	0.008
64861	2N2	340	0.006
64861	OO1	233.2	0.041
64861	M1	65.5	0.011
64861	J1	91.5	0.039
64861	Q1	40.6	0.026
64861	2Q1	304.4	0.019
64861	P1	39.4	0.073
64861	2SM2	281.8	0.012
64861	M3	3	0.004
64861	L2	70	0.084
64861	2MK3	255.2	0.034
64861	K2	63	0.086
64861	M8	354.3	0.004
64861	MS4	195.9	0.027
64862	M2	56.9	0.702
64862	S2	72.4	0.112
64862	N2	49.7	0.146
64862	K1	50.6	0.232
64862	M4	164.8	0.079
64862	O1	31.5	0.198
64862	M6	87.8	0.057
64862	MK3	275.4	0.035
64862	S4	10.9	0.012
64862	MN4	158.6	0.023
64862	S6	143.4	0.008
64862	2N2	12.2	0.005
64862	OO1	235.4	0.043
64862	M1	72.4	0.011
64862	J1	90.1	0.041
64862	Q1	42.5	0.027
64862	2Q1	305.9	0.021
64862	P1	39.7	0.071
64862	2SM2	272.2	0.009
64862	M3	38.6	0.003
64862	L2	69.5	0.076
64862	2MK3	258	0.034
64862	K2	60.3	0.085
64862	M8	354.4	0.006
64862	MS4	194.3	0.024
64863	M2	57.9	0.679
64863	S2	76.1	0.103
64863	N2	51.1	0.141
64863	K1	51.1	0.231
64863	M4	165.5	0.079
64863	O1	31.4	0.201
64863	M6	90.5	0.055
64863	MK3	278.1	0.032
64863	S4	11.4	0.01
64863	MN4	161.9	0.024
64863	S6	142.8	0.008
64863	2N2	30.9	0.005
64863	OO1	238.9	0.045
64863	M1	79.5	0.011
64863	J1	87.5	0.042
64863	Q1	44.7	0.026
64863	2Q1	304.3	0.023
64863	P1	38.5	0.067
64863	2SM2	263.1	0.008
64863	M3	78.8	0.004
64863	L2	69.4	0.068
64863	2MK3	261	0.034
64863	K2	57.4	0.087
64863	M8	348.3	0.007
64863	MS4	196.1	0.021
64864	M2	58.8	0.657
64864	S2	80.6	0.096
64864	N2	52.9	0.136
64864	K1	52.9	0.228
64864	M4	166.2	0.079
64864	O1	31.4	0.205
64864	M6	91.3	0.055
64864	MK3	280	0.028
64864	S4	9.6	0.009
64864	MN4	164.7	0.024
64864	S6	141.6	0.008
64864	2N2	41.3	0.006
64864	OO1	241.5	0.047
64864	M1	84.7	0.012
64864	J1	84.3	0.041
64864	Q1	50.4	0.026
64864	2Q1	300.1	0.023
64864	P1	37.3	0.06
64864	2SM2	249.8	0.007
64864	M3	111.2	0.005
64864	L2	68.3	0.061
64864	2MK3	261.6	0.034
64864	K2	54.2	0.088
64864	M8	343.9	0.008
64864	MS4	198.1	0.018
64865	M2	59.6	0.636
64865	S2	86.2	0.092
64865	N2	54.3	0.131
64865	K1	53.7	0.225
64865	M4	166	0.08
64865	O1	31.1	0.209
64865	M6	91.4	0.055
64865	MK3	278.9	0.026
64865	S4	6	0.008
64865	MN4	167.3	0.025
64865	S6	137.6	0.007
64865	2N2	47.2	0.008
64865	OO1	244.5	0.047
64865	M1	86.9	0.012
64865	J1	80.1	0.04
64865	Q1	57.6	0.026
64865	2Q1	298.8	0.025
64865	P1	35.8	0.056
64865	2SM2	233.5	0.007
64865	M3	132.7	0.007
64865	L2	67.5	0.055
64865	2MK3	262	0.033
64865	K2	49.6	0.088
64865	M8	338.8	0.009
64865	MS4	201.9	0.016
64866	M2	60.5	0.615
64866	S2	90.5	0.088
64866	N2	55.9	0.127
64866	K1	54.3	0.219
64866	M4	165.9	0.08
64866	O1	30.7	0.211
64866	M6	91.9	0.056
64866	MK3	275.6	0.023
64866	S4	357.2	0.008
64866	MN4	169.7	0.026
64866	S6	139.4	0.006
64866	2N2	54.2	0.008
64866	OO1	247.9	0.048
64866	M1	85.9	0.011
64866	J1	76.9	0.039
64866	Q1	63.2	0.024
64866	2Q1	297.5	0.026
64866	P1	32.1	0.051
64866	2SM2	219.5	0.006
64866	M3	141.4	0.009
64866	L2	68.3	0.046
64866	2MK3	260.9	0.031
64866	K2	46.4	0.091
64866	M8	329.2	0.01
64866	MS4	209	0.015
64867	M2	61.4	0.596
64867	S2	94.7	0.089
64867	N2	57.6	0.123
64867	K1	54.1	0.218
64867	M4	165.9	0.082
64867	O1	30	0.211
64867	M6	91.8	0.058
64867	MK3	265.3	0.02
64867	S4	350.1	0.008
64867	MN4	171.9	0.027
64867	S6	141.4	0.005
64867	2N2	61.7	0.008
64867	OO1	250.7	0.046
64867	M1	84.8	0.011
64867	J1	75.1	0.037
64867	Q1	64.6	0.022
64867	2Q1	296.8	0.025
64867	P1	31.7	0.049
64867	2SM2	215.2	0.006
64867	M3	147	0.01
64867	L2	69.4	0.038
64867	2MK3	257.6	0.03
64867	K2	43.6	0.089
64867	M8	323.8	0.01
64867	MS4	215	0.017
64868	M2	62.4	0.579
64868	S2	98.1	0.089
64868	N2	58.8	0.119
64868	K1	53	0.216
64868	M4	166.5	0.085
64868	O1	29.3	0.21
64868	M6	90.3	0.059
64868	MK3	251.2	0.018
64868	S4	341.5	0.007
64868	MN4	174.2	0.028
64868	S6	144.3	0.003
64868	2N2	67.9	0.01
64868	OO1	252	0.044
64868	M1	83	0.012
64868	J1	72.8	0.035
64868	Q1	63.4	0.02
64868	2Q1	297.7	0.025
64868	P1	30.9	0.049
64868	2SM2	211.7	0.005
64868	M3	153.8	0.011
64868	L2	72.3	0.03
64868	2MK3	253.3	0.03
64868	K2	40.1	0.09
64868	M8	317	0.011
64868	MS4	220.9	0.018
64869	M2	63.5	0.563
64869	S2	100.2	0.091
64869	N2	60.3	0.116
64869	K1	51.6	0.213
64869	M4	167.2	0.089
64869	O1	28.5	0.209
64869	M6	88.8	0.061
64869	MK3	234.2	0.019
64869	S4	322.1	0.007
64869	MN4	175.4	0.03
64869	S6	132.3	0.002
64869	2N2	66.7	0.01
64869	OO1	254.6	0.042
64869	M1	78.5	0.012
64869	J1	71.9	0.035
64869	Q1	60.9	0.017
64869	2Q1	300.1	0.024
64869	P1	30.7	0.049
64869	2SM2	199.3	0.004
64869	M3	157.5	0.013
64869	L2	75.5	0.022
64869	2MK3	248	0.03
64869	K2	37.7	0.09
64869	M8	310.6	0.011
64869	MS4	224.4	0.022
64870	M2	64.7	0.55
64870	S2	103.4	0.093
64870	N2	62.2	0.112
64870	K1	50.3	0.21
64870	M4	167.9	0.094
64870	O1	27.5	0.207
64870	M6	88.2	0.064
64870	MK3	219.8	0.021
64870	S4	302	0.007
64870	MN4	175.5	0.032
64870	S6	90.2	0.001
64870	2N2	63.1	0.011
64870	OO1	261.2	0.043
64870	M1	74.4	0.012
64870	J1	70.3	0.034
64870	Q1	58.3	0.014
64870	2Q1	300.5	0.023
64870	P1	30.7	0.049
64870	2SM2	189.7	0.002
64870	M3	162.8	0.013
64870	L2	89.6	0.015
64870	2MK3	243.7	0.03
64870	K2	33.7	0.09
64870	M8	306.1	0.011
64870	MS4	226	0.026
64871	M2	66	0.538
64871	S2	106.2	0.097
64871	N2	63.9	0.11
64871	K1	49.5	0.208
64871	M4	168.6	0.1
64871	O1	26.3	0.205
64871	M6	87.2	0.065
64871	MK3	206.6	0.025
64871	S4	292	0.007
64871	MN4	175.2	0.036
64871	S6	63.4	0.002
64871	2N2	59.4	0.013
64871	OO1	266	0.043
64871	M1	73.9	0.013
64871	J1	70.4	0.034
64871	Q1	55.2	0.013
64871	2Q1	300.2	0.022
64871	P1	32.1	0.047
64871	2SM2	21.3	0.001
64871	M3	167	0.014
64871	L2	120.4	0.011
64871	2MK3	239.3	0.032
64871	K2	28.6	0.089
64871	M8	301.9	0.011
64871	MS4	227.2	0.03
64872	M2	67.3	0.528
64872	S2	108.1	0.102
64872	N2	65.7	0.107
64872	K1	48.6	0.209
64872	M4	168.8	0.108
64872	O1	25.1	0.202
64872	M6	85.6	0.067
64872	MK3	198.1	0.03
64872	S4	282.4	0.005
64872	MN4	173.7	0.039
64872	S6	60.2	0.003
64872	2N2	50.6	0.015
64872	OO1	269.8	0.046
64872	M1	75.7	0.013
64872	J1	68.6	0.032
64872	Q1	52.4	0.01
64872	2Q1	296.7	0.021
64872	P1	35.6	0.045
64872	2SM2	14.3	0.004
64872	M3	174.5	0.013
64872	L2	158.3	0.013
64872	2MK3	232.5	0.036
64872	K2	24	0.087
64872	M8	298.8	0.013
64872	MS4	226	0.035
64873	M2	68.8	0.52
64873	S2	109.1	0.105
64873	N2	67.6	0.103
64873	K1	48.2	0.212
64873	M4	169.3	0.117
64873	O1	23.9	0.2
64873	M6	84.3	0.069
64873	MK3	194.1	0.036
64873	S4	261.5	0.005
64873	MN4	172	0.043
64873	S6	65.7	0.004
64873	2N2	40	0.018
64873	OO1	272.7	0.05
64873	M1	77.1	0.013
64873	J1	64	0.031
64873	Q1	47.5	0.009
64873	2Q1	289.7	0.019
64873	P1	42.1	0.044
64873	2SM2	12.5	0.007
64873	M3	187.8	0.012
64873	L2	180	0.018
64873	2MK3	225	0.04
64873	K2	20	0.086
64873	M8	295.4	0.014
64873	MS4	224.2	0.04
64874	M2	70.4	0.514
64874	S2	109.6	0.106
64874	N2	69.8	0.1
64874	K1	47.6	0.215
64874	M4	169.3	0.127
64874	O1	22.5	0.197
64874	M6	83.4	0.07
64874	MK3	191.8	0.042
64874	S4	242.6	0.005
64874	MN4	170.2	0.047
64874	S6	74.4	0.004
64874	2N2	34.7	0.021
64874	OO1	277.1	0.056
64874	M1	75.3	0.012
64874	J1	60.6	0.031
64874	Q1	43.1	0.007
64874	2Q1	279.9	0.019
64874	P1	48.5	0.046
64874	2SM2	10.4	0.008
64874	M3	201.9	0.012
64874	L2	188.1	0.026
64874	2MK3	219	0.047
64874	K2	17.6	0.086
64874	M8	288.9	0.015
64874	MS4	221.3	0.045
64875	M2	72	0.509
64875	S2	109.4	0.109
64875	N2	71.7	0.098
64875	K1	47	0.217
64875	M4	169.1	0.137
64875	O1	21	0.192
64875	M6	83.6	0.071
64875	MK3	190.2	0.048
64875	S4	229	0.006
64875	MN4	168.3	0.051
64875	S6	83.8	0.005
64875	2N2	31.7	0.026
64875	OO1	281.2	0.059
64875	M1	72.1	0.012
64875	J1	57.8	0.032
64875	Q1	51.5	0.005
64875	2Q1	267.1	0.018
64875	P1	54.2	0.048
64875	2SM2	6.1	0.01
64875	M3	215.1	0.013
64875	L2	192.6	0.032
64875	2MK3	215.5	0.054
64875	K2	15.6	0.084
64875	M8	282.8	0.015
64875	MS4	219.7	0.051
64876	M2	73.6	0.505
64876	S2	108.8	0.11
64876	N2	74.2	0.096
64876	K1	46.9	0.218
64876	M4	168.7	0.147
64876	O1	19.2	0.187
64876	M6	84.9	0.072
64876	MK3	188.8	0.055
64876	S4	221	0.007
64876	MN4	167.3	0.057
64876	S6	99.1	0.006
64876	2N2	29	0.029
64876	OO1	284.1	0.062
64876	M1	66.4	0.011
64876	J1	54.8	0.034
64876	Q1	57.8	0.003
64876	2Q1	255.8	0.018
64876	P1	60.3	0.05
64876	2SM2	2.3	0.012
64876	M3	222.9	0.015
64876	L2	195	0.038
64876	2MK3	212.7	0.061
64876	K2	15.7	0.082
64876	M8	274.1	0.016
64876	MS4	218	0.056
64877	M2	75.2	0.503
64877	S2	108.1	0.111
64877	N2	75.9	0.095
64877	K1	47	0.217
64877	M4	168.5	0.158
64877	O1	17.6	0.182
64877	M6	86.9	0.072
64877	MK3	187.3	0.061
64877	S4	214.1	0.01
64877	MN4	166.6	0.063
64877	S6	102.6	0.007
64877	2N2	26.9	0.031
64877	OO1	285.4	0.065
64877	M1	62.3	0.01
64877	J1	54.1	0.033
64877	Q1	73.4	0.002
64877	2Q1	249	0.018
64877	P1	65.5	0.052
64877	2SM2	3.7	0.013
64877	M3	228.2	0.016
64877	L2	194.6	0.043
64877	2MK3	210.3	0.068
64877	K2	15.9	0.081
64877	M8	266	0.016
64877	MS4	216.8	0.062
64878	M2	76.7	0.501
64878	S2	108.1	0.111
64878	N2	77	0.095
64878	K1	48.1	0.212
64878	M4	168.3	0.17
64878	O1	16.2	0.177
64878	M6	89	0.071
64878	MK3	185.2	0.067
64878	S4	209.7	0.012
64878	MN4	166.5	0.069
64878	S6	106.4	0.008
64878	2N2	23.7	0.034
64878	OO1	286.3	0.067
64878	M1	60.6	0.009
64878	J1	52.3	0.033
64878	Q1	77.4	0.002
64878	2Q1	242.4	0.018
64878	P1	72.5	0.049
64878	2SM2	7.8	0.014
64878	M3	232.8	0.016
64878	L2	192.9	0.049
64878	2MK3	209.3	0.075
64878	K2	14.9	0.082
64878	M8	256.2	0.016
64878	MS4	216.2	0.068
64879	M2	78.2	0.499
64879	S2	107.8	0.111
64879	N2	77.3	0.094
64879	K1	49.2	0.206
64879	M4	168.4	0.181
64879	O1	14.6	0.173
64879	M6	91.4	0.071
64879	MK3	182.8	0.076
64879	S4	203.9	0.014
64879	MN4	166.1	0.075
64879	S6	95.5	0.01
64879	2N2	20.4	0.037
64879	OO1	287	0.066
64879	M1	56	0.007
64879	J1	53.5	0.032
64879	Q1	89.4	0.003
64879	2Q1	243.4	0.019
64879	P1	79.2	0.05
64879	2SM2	7.3	0.015
64879	M3	240	0.014
64879	L2	191.1	0.055
64879	2MK3	208.7	0.081
64879	K2	14.5	0.082
64879	M8	245.3	0.016
64879	MS4	216.2	0.072
64880	M2	79.7	0.497
64880	S2	106.6	0.11
64880	N2	77.3	0.094
64880	K1	49.7	0.197
64880	M4	168.5	0.195
64880	O1	13.2	0.17
64880	M6	94.4	0.071
64880	MK3	181.3	0.084
64880	S4	207.8	0.016
64880	MN4	164.9	0.078
64880	S6	88.6	0.01
64880	2N2	19.1	0.04
64880	OO1	287.3	0.063
64880	M1	55.2	0.005
64880	J1	55	0.029
64880	Q1	102.6	0.005
64880	2Q1	245.9	0.021
64880	P1	83.2	0.048
64880	2SM2	8.8	0.015
64880	M3	247.4	0.011
64880	L2	191.9	0.061
64880	2MK3	207.2	0.087
64880	K2	15.3	0.081
64880	M8	236.5	0.015
64880	MS4	215.8	0.076
64881	M2	81.1	0.491
64881	S2	104.9	0.111
64881	N2	77.5	0.093
64881	K1	50.8	0.183
64881	M4	169	0.208
64881	O1	12.2	0.163
64881	M6	97.5	0.069
64881	MK3	181.2	0.092
64881	S4	216.2	0.02
64881	MN4	165.1	0.082
64881	S6	88.1	0.01
64881	2N2	18.3	0.042
64881	OO1	283.7	0.056
64881	M1	52.5	0.002
64881	J1	62.4	0.026
64881	Q1	116.7	0.008
64881	2Q1	238.4	0.025
64881	P1	86.6	0.043
64881	2SM2	9.1	0.013
64881	M3	274.6	0.008
64881	L2	192.9	0.064
64881	2MK3	204.9	0.095
64881	K2	19.3	0.074
64881	M8	231.1	0.016
64881	MS4	215.8	0.084
64882	M2	35.5	0.458
64882	S2	49.7	0.114
64882	N2	26.2	0.074
64882	K1	24.6	0.134
64882	M4	216.6	0.139
64882	O1	2.6	0.105
64882	M6	140.9	0.025
64882	MK3	243.9	0.076
64882	S4	343.8	0.007
64882	MN4	184.6	0.056
64882	S6	94.8	0.005
64882	2N2	324.3	0.034
64882	OO1	213.5	0.028
64882	M1	354.1	0.009
64882	J1	15.7	0.009
64882	Q1	336.9	0.024
64882	2Q1	191.9	0.014
64882	P1	13.9	0.033
64882	2SM2	223.9	0.008
64882	M3	313.4	0.016
64882	L2	35.1	0.052
64882	2MK3	241	0.054
64882	K2	81.9	0.033
64882	M8	286.2	0.023
64882	MS4	247.5	0.076
64883	M2	37.3	0.491
64883	S2	50.5	0.121
64883	N2	27.3	0.079
64883	K1	25.5	0.146
64883	M4	215.6	0.148
64883	O1	3.1	0.113
64883	M6	144.1	0.029
64883	MK3	244.2	0.079
64883	S4	346.2	0.008
64883	MN4	184.3	0.059
64883	S6	95	0.005
64883	2N2	326	0.038
64883	OO1	214.1	0.03
64883	M1	356.1	0.009
64883	J1	14.3	0.01
64883	Q1	337.2	0.025
64883	2Q1	191.4	0.015
64883	P1	17.1	0.034
64883	2SM2	223.9	0.007
64883	M3	317.1	0.016
64883	L2	38.1	0.053
64883	2MK3	242.4	0.058
64883	K2	81.3	0.037
64883	M8	282.9	0.025
64883	MS4	246.4	0.079
64884	M2	39	0.516
64884	S2	51	0.126
64884	N2	28.8	0.082
64884	K1	26.3	0.156
64884	M4	214.5	0.153
64884	O1	3.3	0.12
64884	M6	148	0.033
64884	MK3	243.2	0.08
64884	S4	346	0.007
64884	MN4	183.5	0.063
64884	S6	94.3	0.004
64884	2N2	329.3	0.041
64884	OO1	214.7	0.032
64884	M1	356.7	0.01
64884	J1	15.5	0.011
64884	Q1	337.7	0.026
64884	2Q1	195.3	0.017
64884	P1	20.8	0.036
64884	2SM2	217.9	0.007
64884	M3	318.2	0.016
64884	L2	41.8	0.054
64884	2MK3	243.7	0.06
64884	K2	81.1	0.041
64884	M8	278.8	0.026
64884	MS4	245.4	0.081
64885	M2	40.6	0.536
64885	S2	52	0.131
64885	N2	29.6	0.085
64885	K1	27.2	0.167
64885	M4	213.7	0.157
64885	O1	3.8	0.126
64885	M6	150.1	0.036
64885	MK3	241.9	0.08
64885	S4	343.6	0.007
64885	MN4	182.2	0.065
64885	S6	94	0.003
64885	2N2	331.7	0.044
64885	OO1	215.3	0.033
64885	M1	357.7	0.01
64885	J1	17	0.011
64885	Q1	337	0.026
64885	2Q1	196.8	0.018
64885	P1	25.8	0.038
64885	2SM2	215.1	0.007
64885	M3	319.2	0.015
64885	L2	45.3	0.053
64885	2MK3	244.9	0.061
64885	K2	82	0.043
64885	M8	275.3	0.027
64885	MS4	243.8	0.081
64886	M2	42	0.551
64886	S2	52.3	0.136
64886	N2	30.6	0.086
64886	K1	27.5	0.177
64886	M4	213	0.16
64886	O1	4.1	0.132
64886	M6	152.5	0.039
64886	MK3	240.1	0.079
64886	S4	345.1	0.007
64886	MN4	181	0.068
64886	S6	93	0.003
64886	2N2	333.2	0.046
64886	OO1	218.3	0.035
64886	M1	357.2	0.01
64886	J1	17.5	0.012
64886	Q1	335	0.026
64886	2Q1	198	0.02
64886	P1	28.6	0.041
64886	2SM2	212.1	0.006
64886	M3	318.5	0.014
64886	L2	48.6	0.054
64886	2MK3	247	0.061
64886	K2	83.7	0.047
64886	M8	270.7	0.029
64886	MS4	242.7	0.081
64887	M2	43.1	0.562
64887	S2	52.9	0.139
64887	N2	31.7	0.087
64887	K1	27.4	0.185
64887	M4	212.6	0.163
64887	O1	4.3	0.136
64887	M6	154.7	0.041
64887	MK3	238.4	0.079
64887	S4	345.8	0.007
64887	MN4	179.9	0.069
64887	S6	99.1	0.002
64887	2N2	335	0.049
64887	OO1	220.1	0.036
64887	M1	358.3	0.011
64887	J1	15.9	0.012
64887	Q1	334.6	0.026
64887	2Q1	200	0.022
64887	P1	30.9	0.044
64887	2SM2	205.2	0.006
64887	M3	320.6	0.013
64887	L2	51.8	0.055
64887	2MK3	248.7	0.062
64887	K2	85	0.048
64887	M8	267.5	0.03
64887	MS4	241.8	0.079
64888	M2	44.3	0.568
64888	S2	53.6	0.14
64888	N2	32.6	0.087
64888	K1	27.2	0.192
64888	M4	211.9	0.165
64888	O1	4.5	0.138
64888	M6	156.6	0.041
64888	MK3	236.8	0.079
64888	S4	340.1	0.007
64888	MN4	178.9	0.071
64888	S6	93.4	0.001
64888	2N2	335.6	0.05
64888	OO1	221.1	0.037
64888	M1	0	0.011
64888	J1	11	0.012
64888	Q1	334.2	0.026
64888	2Q1	199.3	0.024
64888	P1	32.5	0.046
64888	2SM2	200.9	0.006
64888	M3	320.6	0.012
64888	L2	54.1	0.055
64888	2MK3	250.8	0.062
64888	K2	87.3	0.048
64888	M8	263.8	0.032
64888	MS4	240.9	0.078
64889	M2	45.3	0.57
64889	S2	54.2	0.141
64889	N2	32.9	0.086
64889	K1	27	0.198
64889	M4	211.1	0.166
64889	O1	4.8	0.14
64889	M6	158.8	0.041
64889	MK3	234.7	0.079
64889	S4	332.9	0.007
64889	MN4	177.7	0.073
64889	2N2	336.4	0.05
64889	OO1	223.4	0.039
64889	M1	0.1	0.011
64889	J1	8.2	0.012
64889	Q1	334.4	0.026
64889	2Q1	199.1	0.026
64889	P1	34.6	0.048
64889	2SM2	193.8	0.006
64889	M3	320.7	0.012
64889	L2	56.6	0.055
64889	2MK3	252.5	0.062
64889	K2	89.1	0.047
64889	M8	260.8	0.034
64889	MS4	239.8	0.077
64890	M2	46.1	0.568
64890	S2	55	0.141
64890	N2	33.2	0.085
64890	K1	26.5	0.202
64890	M4	210.1	0.167
64890	O1	5.1	0.14
64890	M6	161.7	0.039
64890	MK3	232	0.078
64890	S4	326.3	0.007
64890	MN4	176.2	0.075
64890	2N2	337.4	0.05
64890	OO1	224.8	0.042
64890	M1	1.8	0.011
64890	J1	8	0.012
64890	Q1	335.4	0.026
64890	2Q1	198.5	0.029
64890	P1	34.8	0.049
64890	2SM2	187.1	0.005
64890	M3	317.2	0.011
64890	L2	58.3	0.054
64890	2MK3	253.7	0.062
64890	K2	91.5	0.045
64890	M8	257.2	0.035
64890	MS4	238.5	0.076
64891	M2	47	0.563
64891	S2	55.7	0.14
64891	N2	33.1	0.083
64891	K1	25.9	0.203
64891	M4	208.9	0.169
64891	O1	5.4	0.139
64891	M6	164.9	0.036
64891	MK3	229.1	0.077
64891	S4	320.1	0.007
64891	MN4	175	0.077
64891	2N2	337.2	0.05
64891	OO1	226.4	0.045
64891	M1	0.9	0.011
64891	J1	5.8	0.011
64891	Q1	337.2	0.025
64891	2Q1	196.9	0.031
64891	P1	33.5	0.048
64891	2SM2	171.3	0.006
64891	M3	316.2	0.011
64891	L2	59.4	0.053
64891	2MK3	255	0.062
64891	K2	93.5	0.042
64891	M8	254.6	0.035
64891	MS4	237	0.076
64892	M2	47.7	0.557
64892	S2	55.9	0.141
64892	N2	32.8	0.081
64892	K1	25.4	0.203
64892	M4	207.5	0.17
64892	O1	5.9	0.136
64892	M6	170	0.032
64892	MK3	225.4	0.075
64892	S4	311.6	0.008
64892	MN4	173.9	0.078
64892	S6	286.7	0.001
64892	2N2	338.4	0.048
64892	OO1	225.6	0.047
64892	M1	2.5	0.01
64892	J1	2.7	0.01
64892	Q1	340.1	0.026
64892	2Q1	195.5	0.033
64892	P1	33.2	0.048
64892	2SM2	160.1	0.006
64892	M3	313.6	0.01
64892	L2	60.4	0.052
64892	2MK3	256.5	0.061
64892	K2	98.6	0.042
64892	M8	252.2	0.036
64892	MS4	235.4	0.076
64893	M2	48.4	0.549
64893	S2	56.1	0.141
64893	N2	32.9	0.08
64893	K1	24.5	0.203
64893	M4	206	0.171
64893	O1	6.1	0.133
64893	M6	176.7	0.028
64893	MK3	221.4	0.074
64893	S4	306.8	0.008
64893	MN4	172.9	0.08
64893	S6	293	0.002
64893	2N2	339.2	0.047
64893	OO1	225.5	0.049
64893	M1	2.3	0.011
64893	J1	4	0.01
64893	Q1	339.9	0.026
64893	2Q1	194.7	0.035
64893	P1	32.4	0.047
64893	2SM2	149.2	0.007
64893	M3	305.9	0.009
64893	L2	60.4	0.05
64893	2MK3	257.6	0.061
64893	K2	101.9	0.041
64893	M8	249.6	0.036
64893	MS4	233.6	0.076
64894	M2	48.9	0.538
64894	S2	56.5	0.14
64894	N2	32.8	0.079
64894	K1	23.7	0.203
64894	M4	204.5	0.172
64894	O1	6.6	0.128
64894	M6	183.9	0.025
64894	MK3	217	0.073
64894	S4	301.1	0.007
64894	MN4	171.6	0.081
64894	S6	299.9	0.003
64894	2N2	340	0.044
64894	OO1	225.5	0.051
64894	M1	4.3	0.011
64894	J1	0.6	0.008
64894	Q1	341.8	0.026
64894	2Q1	194.6	0.037
64894	P1	33.3	0.048
64894	2SM2	139.9	0.009
64894	M3	297	0.008
64894	L2	59.9	0.048
64894	2MK3	258.6	0.06
64894	K2	106.7	0.04
64894	M8	246.7	0.036
64894	MS4	232.2	0.076
64895	M2	49.3	0.526
64895	S2	57.2	0.139
64895	N2	32.7	0.078
64895	K1	22.7	0.201
64895	M4	202.9	0.172
64895	O1	7.2	0.124
64895	M6	192.2	0.023
64895	MK3	212.3	0.074
64895	S4	300.3	0.007
64895	MN4	170.4	0.082
64895	S6	309.7	0.003
64895	2N2	341.4	0.041
64895	OO1	225.3	0.051
64895	M1	3.5	0.011
64895	J1	355.3	0.006
64895	Q1	343.6	0.025
64895	2Q1	193.5	0.038
64895	P1	32.3	0.049
64895	2SM2	135.8	0.011
64895	M3	282.2	0.008
64895	L2	58.7	0.045
64895	2MK3	258.9	0.058
64895	K2	111	0.037
64895	M8	244.1	0.036
64895	MS4	230.4	0.077
64896	M2	50.9	0.511
64896	S2	63.5	0.128
64896	N2	36.4	0.072
64896	K1	27.8	0.186
64896	M4	197.9	0.171
64896	O1	16	0.111
64896	M6	179.6	0.019
64896	MK3	201.8	0.085
64896	S4	320.7	0.005
64896	MN4	166.5	0.088
64896	S6	299.5	0.002
64896	2N2	331.3	0.04
64896	OO1	211	0.043
64896	M1	354.2	0.01
64896	J1	216.4	0.001
64896	Q1	345.2	0.016
64896	2Q1	201.8	0.041
64896	P1	50.8	0.038
64896	2SM2	124.9	0.014
64896	M3	272.4	0.013
64896	L2	54.5	0.039
64896	2MK3	252.4	0.046
64896	K2	72.3	0.024
64896	M8	240.9	0.03
64896	MS4	224.7	0.071
64897	M2	71.4	2.593
64897	S2	94	0.586
64897	N2	53.7	0.501
64897	K1	87.5	0.78
64897	M4	88	0.278
64897	O1	94.2	0.377
64897	M6	106.1	0.064
64897	MK3	58.4	0.207
64897	S4	77.5	0.02
64897	MN4	81.2	0.082
64897	NU2	73.7	0.113
64897	MU2	224.5	0.044
64897	2N2	28.6	0.034
64897	OO1	123.6	0.089
64897	LDA2	76	0.081
64897	M1	132.9	0.018
64897	J1	119.6	0.035
64897	RHO1	95.5	0.012
64897	Q1	85.9	0.07
64897	2Q1	145.1	0.023
64897	P1	83.8	0.226
64897	2SM2	313.1	0.016
64897	M3	159.6	0.028
64897	L2	100	0.188
64897	2MK3	101.2	0.03
64897	K2	82.7	0.207
64897	M8	119.4	0.04
64897	MS4	102.1	0.113
64898	M2	72.6	2.767
64898	S2	93.8	0.65
64898	N2	53	0.539
64898	K1	85.5	0.88
64898	M4	80.2	0.334
64898	O1	84.8	0.419
64898	M6	133.7	0.137
64898	MK3	57.7	0.232
64898	S4	61.7	0.026
64898	MN4	68.1	0.095
64898	NU2	70.3	0.115
64898	MU2	248.7	0.026
64898	2N2	38.6	0.048
64898	OO1	118.1	0.088
64898	LDA2	77.2	0.082
64898	M1	109.1	0.023
64898	J1	119.2	0.051
64898	RHO1	45.8	0.021
64898	Q1	74.5	0.066
64898	2Q1	143.3	0.036
64898	P1	80.9	0.26
64898	2SM2	286.8	0.017
64898	M3	143.2	0.049
64898	L2	106.1	0.161
64898	2MK3	24.7	0.061
64898	K2	80.7	0.225
64898	M8	143.7	0.033
64898	MS4	94.3	0.149
64899	M2	74	2.527
64899	S2	94.7	0.599
64899	N2	52.5	0.48
64899	K1	82.4	0.845
64899	M4	74	0.275
64899	O1	78.3	0.358
64899	M6	127.9	0.172
64899	MK3	39.5	0.175
64899	S4	64.9	0.025
64899	MN4	57.5	0.078
64899	NU2	63.4	0.113
64899	S6	84.1	0.004
64899	MU2	283.9	0.018
64899	2N2	38.5	0.061
64899	OO1	134.5	0.094
64899	LDA2	83.2	0.059
64899	M1	107.5	0.012
64899	J1	102.6	0.046
64899	RHO1	50.8	0.009
64899	Q1	66.9	0.06
64899	2Q1	117.4	0.053
64899	P1	80.3	0.23
64899	2SM2	249.4	0.019
64899	M3	137.7	0.052
64899	L2	110.5	0.122
64899	2MK3	347.3	0.056
64899	K2	81.5	0.218
64899	M8	152.2	0.027
64899	MS4	86.8	0.15
64900	M2	47.2	0.854
64900	S2	78.9	0.16
64900	N2	41	0.168
64900	K1	114.2	0.327
64900	M4	1.3	0.52
64900	O1	143	0.374
64900	M6	14.7	0.14
64900	MK3	13.2	0.294
64900	S4	29.6	0.032
64900	MN4	352.6	0.197
64900	S6	155.7	0.005
64900	2N2	180.6	0.047
64900	OO1	144.8	0.079
64900	M1	219.2	0.027
64900	J1	127.9	0.032
64900	Q1	154	0.065
64900	2Q1	60	0.069
64900	P1	123.3	0.111
64900	2SM2	205.8	0.009
64900	M3	78.1	0.055
64900	L2	33.7	0.078
64900	2MK3	343.8	0.114
64900	K2	62.8	0.082
64900	M8	29.7	0.143
64900	MS4	28.8	0.241
64901	M2	50.2	0.976
64901	S2	77.9	0.181
64901	N2	42.5	0.189
64901	K1	110.9	0.384
64901	M4	0.2	0.591
64901	O1	141.2	0.416
64901	M6	17.2	0.133
64901	MK3	10.6	0.344
64901	S4	27.5	0.038
64901	MN4	350.7	0.218
64901	S6	164.1	0.007
64901	2N2	165.3	0.046
64901	OO1	144.3	0.091
64901	M1	226.1	0.027
64901	J1	131.5	0.034
64901	Q1	153.2	0.074
64901	2Q1	59.4	0.083
64901	P1	116.1	0.13
64901	2SM2	192.2	0.012
64901	M3	79.2	0.066
64901	L2	38.4	0.081
64901	2MK3	339.9	0.152
64901	K2	71.8	0.107
64901	M8	26.5	0.157
64901	MS4	28.4	0.279
64902	M2	52.7	0.988
64902	S2	75.3	0.187
64902	N2	42.5	0.188
64902	K1	107	0.406
64902	M4	358.8	0.624
64902	O1	140.7	0.416
64902	M6	13.9	0.121
64902	MK3	7.8	0.376
64902	S4	28	0.039
64902	MN4	347.8	0.224
64902	S6	159.1	0.009
64902	2N2	140.8	0.048
64902	OO1	149.1	0.092
64902	M1	232.9	0.026
64902	J1	132.4	0.029
64902	Q1	156	0.071
64902	2Q1	57.2	0.094
64902	P1	108.8	0.143
64902	2SM2	186.4	0.014
64902	M3	82.1	0.071
64902	L2	41.5	0.073
64902	2MK3	338.7	0.18
64902	K2	85	0.126
64902	M8	23.2	0.162
64902	MS4	27.1	0.292
64903	M2	60.1	1.671
64903	S2	81.9	0.386
64903	N2	46.4	0.321
64903	K1	58.9	0.553
64903	M4	186.8	0.427
64903	O1	20.8	0.485
64903	M6	54.1	0.123
64903	MK3	218.9	0.237
64903	S4	195.5	0.008
64903	MN4	164.4	0.17
64903	S6	125.5	0.004
64903	2N2	335.3	0.077
64903	OO1	174.6	0.02
64903	M1	75.3	0.033
64903	J1	60.5	0.02
64903	Q1	19	0.076
64903	2Q1	252.1	0.068
64903	P1	46.1	0.141
64903	2SM2	318.8	0.015
64903	M3	302.2	0.062
64903	L2	77.8	0.129
64903	2MK3	195.2	0.176
64903	K2	71.5	0.119
64903	M8	242	0.075
64903	MS4	220.1	0.218
64904	M2	64.9	1.875
64904	S2	83.8	0.445
64904	N2	52.9	0.346
64904	K1	62.6	0.584
64904	M4	181	0.391
64904	O1	25.2	0.494
64904	M6	63.9	0.117
64904	MK3	211.3	0.207
64904	S4	207.8	0.022
64904	MN4	159.1	0.155
64904	S6	28.6	0.008
64904	2N2	329.9	0.089
64904	OO1	175.9	0.053
64904	M1	84.5	0.028
64904	J1	63.9	0.019
64904	Q1	30.3	0.081
64904	2Q1	242.1	0.065
64904	P1	45	0.155
64904	2SM2	322.8	0.022
64904	M3	297.5	0.054
64904	L2	77.3	0.162
64904	2MK3	199	0.171
64904	K2	95.2	0.146
64904	M8	236	0.071
64904	MS4	212.4	0.204
64905	M2	67.1	1.836
64905	S2	86.7	0.446
64905	N2	57.3	0.326
64905	K1	64.3	0.573
64905	M4	181.4	0.37
64905	O1	23.4	0.437
64905	M6	58.3	0.109
64905	MK3	212.9	0.185
64905	S4	195.1	0.029
64905	MN4	159.6	0.144
64905	S6	0.1	0.01
64905	2N2	327.7	0.101
64905	OO1	158.4	0.111
64905	M1	100.1	0.02
64905	J1	162.8	0.015
64905	Q1	30.6	0.064
64905	2Q1	228.7	0.067
64905	P1	42.7	0.139
64905	2SM2	293.3	0.008
64905	M3	299.2	0.052
64905	L2	73.7	0.155
64905	2MK3	201.8	0.172
64905	K2	110.3	0.153
64905	M8	233.6	0.063
64905	MS4	211.7	0.208
64906	M2	68.4	2.992
64906	S2	92.1	0.722
64906	N2	46.8	0.587
64906	K1	81.1	0.987
64906	M4	106.9	0.117
64906	O1	70	0.53
64906	M6	63	0.115
64906	MK3	58.3	0.088
64906	S4	122.5	0.026
64906	MN4	85.4	0.042
64906	NU2	64.7	0.142
64906	S6	253.8	0.006
64906	MU2	200.3	0.029
64906	2N2	58.4	0.062
64906	OO1	116.8	0.099
64906	LDA2	69.5	0.067
64906	M1	102.9	0.039
64906	J1	122.6	0.061
64906	RHO1	41.2	0.04
64906	Q1	54.1	0.063
64906	2Q1	241.8	0.016
64906	P1	75.3	0.279
64906	2SM2	274.9	0.014
64906	M3	168.2	0.022
64906	L2	90.2	0.169
64906	2MK3	149.8	0.067
64906	K2	81.8	0.239
64906	M8	71.8	0.029
64906	MS4	131.9	0.042
64907	M2	68.6	3.09
64907	S2	92.2	0.748
64907	N2	46.9	0.609
64907	K1	81.1	1.023
64907	M4	108.6	0.118
64907	O1	69.5	0.548
64907	M6	65.8	0.116
64907	MK3	58.7	0.091
64907	S4	122.7	0.027
64907	MN4	87.3	0.045
64907	NU2	64.7	0.147
64907	S6	252.9	0.006
64907	MU2	198.9	0.03
64907	2N2	58.5	0.065
64907	OO1	116.8	0.101
64907	LDA2	69.4	0.069
64907	M1	101.5	0.04
64907	J1	122.3	0.062
64907	RHO1	41.9	0.04
64907	Q1	54	0.066
64907	2Q1	242.9	0.017
64907	P1	75.1	0.291
64907	2SM2	271.4	0.014
64907	M3	169.3	0.024
64907	L2	90.7	0.173
64907	2MK3	148.2	0.065
64907	K2	81.8	0.247
64907	M8	74.9	0.029
64907	MS4	133.3	0.045
64908	M2	68.8	3.17
64908	S2	92.2	0.768
64908	N2	47.1	0.625
64908	K1	81.1	1.053
64908	M4	109.6	0.118
64908	O1	69.1	0.564
64908	M6	68.6	0.116
64908	MK3	58.6	0.094
64908	S4	123.8	0.028
64908	MN4	89.2	0.047
64908	NU2	64.7	0.151
64908	S6	255.6	0.005
64908	MU2	198.4	0.029
64908	2N2	57.9	0.067
64908	OO1	116.2	0.101
64908	LDA2	69.6	0.07
64908	M1	100.3	0.04
64908	J1	121.8	0.063
64908	RHO1	41.3	0.04
64908	Q1	53.1	0.067
64908	2Q1	246.2	0.016
64908	P1	74.8	0.3
64908	2SM2	266.5	0.014
64908	M3	167.5	0.026
64908	L2	91	0.176
64908	2MK3	145.2	0.063
64908	K2	81.7	0.255
64908	M8	77.9	0.028
64908	MS4	133.8	0.047
64909	M2	69	3.237
64909	S2	92.3	0.785
64909	N2	47.4	0.64
64909	K1	81.1	1.08
64909	M4	110.7	0.117
64909	O1	69	0.577
64909	M6	71.2	0.115
64909	MK3	57.7	0.098
64909	S4	124.3	0.029
64909	MN4	90.4	0.047
64909	NU2	65	0.153
64909	S6	257.6	0.005
64909	MU2	198.6	0.029
64909	2N2	57.2	0.069
64909	OO1	115.6	0.101
64909	LDA2	69.4	0.071
64909	M1	100.3	0.04
64909	J1	121.5	0.063
64909	RHO1	41.8	0.041
64909	Q1	52.5	0.069
64909	2Q1	249.4	0.015
64909	P1	74.7	0.308
64909	2SM2	265.7	0.014
64909	M3	167.1	0.027
64909	L2	91.6	0.18
64909	2MK3	142.2	0.061
64909	K2	81.8	0.262
64909	M8	79.9	0.027
64909	MS4	134.6	0.049
64910	M2	69.2	3.296
64910	S2	92.4	0.8
64910	N2	47.6	0.651
64910	K1	81.2	1.103
64910	M4	111.1	0.115
64910	O1	68.9	0.587
64910	M6	73.9	0.114
64910	MK3	56.8	0.102
64910	S4	123.6	0.029
64910	MN4	91.2	0.047
64910	NU2	65.1	0.155
64910	S6	250.6	0.005
64910	MU2	201.5	0.028
64910	2N2	57.1	0.07
64910	OO1	115.4	0.103
64910	LDA2	69.4	0.073
64910	M1	100.6	0.04
64910	J1	120.8	0.062
64910	RHO1	39.7	0.042
64910	Q1	51.9	0.07
64910	2Q1	251.4	0.013
64910	P1	74.5	0.314
64910	2SM2	265.5	0.014
64910	M3	167.1	0.029
64910	L2	92.5	0.183
64910	2MK3	139.2	0.059
64910	K2	82	0.268
64910	M8	82.9	0.026
64910	MS4	134.7	0.049
64911	M2	69.4	3.348
64911	S2	92.5	0.811
64911	N2	47.7	0.66
64911	K1	81.3	1.122
64911	M4	110.8	0.113
64911	O1	69	0.595
64911	M6	76.6	0.115
64911	MK3	55	0.107
64911	S4	123.5	0.03
64911	MN4	91.6	0.047
64911	NU2	65.1	0.156
64911	S6	254.8	0.004
64911	MU2	207	0.028
64911	2N2	57.1	0.07
64911	OO1	115.5	0.104
64911	LDA2	69.7	0.074
64911	M1	100.6	0.04
64911	J1	120.4	0.062
64911	RHO1	39	0.042
64911	Q1	52.3	0.071
64911	2Q1	254.4	0.012
64911	P1	74.5	0.32
64911	2SM2	266.6	0.015
64911	M3	166.6	0.03
64911	L2	93.3	0.186
64911	2MK3	137.3	0.056
64911	K2	82.1	0.274
64911	M8	85.9	0.026
64911	MS4	133.8	0.049
64912	M2	69.5	3.392
64912	S2	92.6	0.821
64912	N2	47.9	0.668
64912	K1	81.5	1.138
64912	M4	109.6	0.11
64912	O1	69.4	0.602
64912	M6	78.5	0.116
64912	MK3	52.8	0.112
64912	S4	122.9	0.03
64912	MN4	91.6	0.046
64912	NU2	65.4	0.157
64912	MU2	212.3	0.028
64912	2N2	57	0.071
64912	OO1	115.8	0.104
64912	LDA2	70	0.076
64912	M1	101	0.039
64912	J1	119.8	0.061
64912	RHO1	38.8	0.042
64912	Q1	52.6	0.073
64912	2Q1	257.6	0.01
64912	P1	74.5	0.324
64912	2SM2	267.9	0.016
64912	M3	164.5	0.03
64912	L2	94.2	0.19
64912	2MK3	136.9	0.052
64912	K2	82.5	0.277
64912	M8	88.6	0.026
64912	MS4	132.4	0.047
64913	M2	69.7	3.43
64913	S2	92.7	0.827
64913	N2	48.1	0.674
64913	K1	81.6	1.149
64913	M4	107.8	0.108
64913	O1	69.7	0.607
64913	M6	80.4	0.118
64913	MK3	50.5	0.116
64913	S4	121.3	0.03
64913	MN4	91.9	0.045
64913	NU2	65.9	0.158
64913	MU2	218.3	0.03
64913	2N2	56.9	0.07
64913	OO1	116.4	0.105
64913	LDA2	70.5	0.078
64913	M1	101.7	0.039
64913	J1	119.6	0.061
64913	RHO1	39.3	0.042
64913	Q1	53	0.075
64913	2Q1	265.9	0.008
64913	P1	74.7	0.328
64913	2SM2	268.2	0.017
64913	M3	162.8	0.031
64913	L2	95.1	0.195
64913	2MK3	136.4	0.047
64913	K2	82.7	0.281
64913	M8	93.3	0.026
64913	MS4	130.5	0.046
64914	M2	69.8	3.462
64914	S2	92.8	0.831
64914	N2	48.2	0.678
64914	K1	81.8	1.157
64914	M4	105.7	0.108
64914	O1	70	0.61
64914	M6	81.8	0.121
64914	MK3	48.1	0.119
64914	S4	120.6	0.03
64914	MN4	90.8	0.045
64914	NU2	66.4	0.159
64914	MU2	224.3	0.034
64914	2N2	56.4	0.069
64914	OO1	116.9	0.106
64914	LDA2	70.9	0.079
64914	M1	102	0.038
64914	J1	119.8	0.06
64914	RHO1	38.9	0.039
64914	Q1	53.8	0.077
64914	2Q1	272.7	0.007
64914	P1	74.7	0.331
64914	2SM2	270.8	0.017
64914	M3	161.5	0.031
64914	L2	95.8	0.199
64914	2MK3	135.9	0.042
64914	K2	82.9	0.284
64914	M8	97	0.026
64914	MS4	127.4	0.045
64915	M2	69.9	3.49
64915	S2	92.8	0.834
64915	N2	48.5	0.681
64915	K1	81.9	1.162
64915	M4	103.3	0.109
64915	O1	70.4	0.611
64915	M6	82.8	0.123
64915	MK3	46	0.122
64915	S4	117.5	0.03
64915	MN4	90.6	0.045
64915	NU2	66.9	0.16
64915	MU2	228.8	0.037
64915	2N2	54.7	0.069
64915	OO1	117.3	0.106
64915	LDA2	71.6	0.08
64915	M1	103	0.038
64915	J1	119.2	0.058
64915	RHO1	38.2	0.039
64915	Q1	53.4	0.079
64915	P1	74.9	0.333
64915	2SM2	273	0.018
64915	M3	159.2	0.03
64915	L2	96.7	0.203
64915	2MK3	136.6	0.036
64915	K2	83	0.287
64915	M8	100.2	0.027
64915	MS4	124.6	0.044
64916	M2	70.1	3.514
64916	S2	92.8	0.836
64916	N2	48.6	0.684
64916	K1	82	1.166
64916	M4	101.4	0.112
64916	O1	70.4	0.612
64916	M6	83.5	0.126
64916	MK3	44.5	0.124
64916	S4	115.5	0.029
64916	MN4	91.2	0.045
64916	NU2	67.5	0.161
64916	MU2	231.2	0.041
64916	2N2	53.8	0.068
64916	OO1	117.9	0.106
64916	LDA2	72.1	0.081
64916	M1	103.5	0.037
64916	J1	118.9	0.057
64916	RHO1	38.5	0.038
64916	Q1	53.2	0.081
64916	P1	75	0.335
64916	2SM2	276.1	0.019
64916	M3	156.9	0.03
64916	L2	97.5	0.208
64916	2MK3	137.2	0.031
64916	K2	82.7	0.289
64916	M8	103.1	0.027
64916	MS4	122.2	0.043
64917	M2	70.2	3.537
64917	S2	92.8	0.837
64917	N2	48.8	0.686
64917	K1	82.1	1.169
64917	M4	100.3	0.117
64917	O1	70.5	0.612
64917	M6	83.8	0.128
64917	MK3	44.1	0.126
64917	S4	114.5	0.028
64917	MN4	91.3	0.047
64917	NU2	68.1	0.162
64917	MU2	234.9	0.045
64917	2N2	52.4	0.065
64917	OO1	119	0.106
64917	LDA2	73.1	0.083
64917	M1	103.7	0.036
64917	J1	118.7	0.056
64917	RHO1	40.4	0.036
64917	Q1	53.6	0.083
64917	P1	75	0.337
64917	2SM2	279.8	0.019
64917	M3	153.7	0.03
64917	L2	98.3	0.213
64917	2MK3	138.8	0.026
64917	K2	82.7	0.289
64917	M8	107.1	0.027
64917	MS4	119.7	0.044
64918	M2	70.3	3.557
64918	S2	92.9	0.839
64918	N2	49	0.689
64918	K1	82.2	1.172
64918	M4	100.1	0.124
64918	O1	70.3	0.611
64918	M6	83.9	0.13
64918	MK3	44	0.127
64918	S4	113.8	0.027
64918	MN4	92	0.049
64918	NU2	68.6	0.163
64918	MU2	236.8	0.049
64918	2N2	51	0.064
64918	OO1	120.2	0.106
64918	LDA2	74.3	0.085
64918	M1	103.6	0.035
64918	J1	117.2	0.054
64918	RHO1	40.7	0.034
64918	Q1	53.6	0.085
64918	P1	75.2	0.339
64918	2SM2	281.9	0.019
64918	M3	151.3	0.03
64918	L2	99	0.217
64918	2MK3	140.2	0.021
64918	K2	82.7	0.289
64918	M8	109	0.028
64918	MS4	118.6	0.045
64919	M2	70.4	3.577
64919	S2	92.8	0.841
64919	N2	49.1	0.691
64919	K1	82.2	1.174
64919	M4	100.4	0.133
64919	O1	70	0.612
64919	M6	83.9	0.131
64919	MK3	44.5	0.127
64919	S4	111.7	0.027
64919	MN4	92.9	0.052
64919	NU2	68.8	0.164
64919	MU2	238	0.053
64919	2N2	48.9	0.063
64919	OO1	122.3	0.106
64919	LDA2	74.5	0.086
64919	M1	102.6	0.035
64919	J1	115.6	0.055
64919	RHO1	42.2	0.033
64919	Q1	54	0.088
64919	P1	75.3	0.342
64919	2SM2	284.5	0.019
64919	M3	150	0.03
64919	L2	99.5	0.221
64919	2MK3	138.7	0.017
64919	K2	82.5	0.289
64919	M8	110.1	0.028
64919	MS4	118.2	0.047
64920	M2	70.6	3.596
64920	S2	92.8	0.843
64920	N2	49.3	0.694
64920	K1	82.3	1.177
64920	M4	101.6	0.142
64920	O1	69.4	0.613
64920	M6	83.5	0.132
64920	MK3	45.8	0.128
64920	S4	111.9	0.026
64920	MN4	94.3	0.054
64920	NU2	69.4	0.165
64920	MU2	239.5	0.055
64920	2N2	46.1	0.062
64920	OO1	123.5	0.107
64920	LDA2	74.7	0.088
64920	M1	102	0.034
64920	J1	114.5	0.054
64920	RHO1	44.3	0.032
64920	Q1	54.6	0.09
64920	P1	75.6	0.343
64920	2SM2	288.1	0.019
64920	M3	149	0.029
64920	L2	100.2	0.224
64920	2MK3	135.8	0.014
64920	K2	82.5	0.288
64920	M8	109	0.029
64920	MS4	118.1	0.05
64921	M2	70.7	3.615
64921	S2	92.9	0.847
64921	N2	49.6	0.697
64921	K1	82.2	1.181
64921	M4	103.5	0.152
64921	O1	68.9	0.614
64921	M6	82.7	0.131
64921	MK3	47.5	0.129
64921	S4	109	0.027
64921	MN4	96	0.058
64921	NU2	69.8	0.165
64921	MU2	240.8	0.058
64921	2N2	42.7	0.062
64921	OO1	125.8	0.108
64921	LDA2	74.4	0.09
64921	M1	101.3	0.035
64921	J1	113.4	0.055
64921	RHO1	47.2	0.033
64921	Q1	54.7	0.092
64921	2Q1	187.7	0.005
64921	P1	75.8	0.345
64921	2SM2	289.9	0.02
64921	M3	147.8	0.03
64921	L2	100.3	0.228
64921	2MK3	132.8	0.011
64921	K2	82.5	0.287
64921	M8	106.8	0.029
64921	MS4	118	0.053
64922	M2	70.8	3.633
64922	S2	92.9	0.85
64922	N2	49.9	0.699
64922	K1	82.1	1.184
64922	M4	105.6	0.163
64922	O1	68.2	0.615
64922	M6	81.5	0.128
64922	MK3	49.8	0.131
64922	S4	108.1	0.028
64922	MN4	97.2	0.062
64922	NU2	70.4	0.166
64922	MU2	241.4	0.06
64922	2N2	40	0.063
64922	OO1	127.2	0.111
64922	LDA2	74.4	0.092
64922	M1	101.1	0.035
64922	J1	113.5	0.055
64922	RHO1	47.4	0.033
64922	Q1	55.3	0.093
64922	2Q1	188.8	0.007
64922	P1	76.1	0.347
64922	2SM2	291.3	0.019
64922	M3	145.9	0.03
64922	L2	100.7	0.231
64922	2MK3	124.9	0.009
64922	K2	82.7	0.286
64922	M8	103	0.029
64922	MS4	118.1	0.057
64923	M2	70.9	3.651
64923	S2	92.8	0.852
64923	N2	50	0.701
64923	K1	81.9	1.187
64923	M4	107.8	0.175
64923	O1	67.4	0.615
64923	M6	80.7	0.124
64923	MK3	52.3	0.135
64923	S4	105.8	0.029
64923	MN4	98	0.065
64923	NU2	70.6	0.166
64923	MU2	242.5	0.063
64923	2N2	36.6	0.064
64923	OO1	128.5	0.114
64923	LDA2	74.2	0.095
64923	M1	99.5	0.035
64923	J1	116.1	0.055
64923	RHO1	46.3	0.033
64923	Q1	56.6	0.094
64923	2Q1	189.6	0.01
64923	P1	76.4	0.347
64923	2SM2	290.9	0.018
64923	M3	144.8	0.03
64923	L2	100.8	0.235
64923	2MK3	109.8	0.007
64923	K2	82.8	0.284
64923	M8	100.2	0.029
64923	MS4	118.6	0.062
64924	M2	70.7	3.629
64924	S2	92.6	0.84
64924	N2	49.5	0.689
64924	K1	80.2	1.168
64924	M4	120	0.172
64924	O1	63.4	0.595
64924	M6	86.4	0.112
64924	MK3	42.4	0.104
64924	S4	101.4	0.027
64924	MN4	111.2	0.065
64924	NU2	70.6	0.168
64924	S6	314.5	0.004
64924	MU2	249.9	0.067
64924	2N2	40	0.073
64924	OO1	133.7	0.122
64924	LDA2	73.4	0.103
64924	M1	98.1	0.032
64924	J1	110.9	0.055
64924	RHO1	48	0.035
64924	Q1	52.6	0.088
64924	2Q1	156.1	0.014
64924	P1	75.4	0.344
64924	2SM2	284	0.016
64924	M3	142.1	0.019
64924	L2	102.8	0.243
64924	2MK3	243.9	0.029
64924	K2	85.1	0.299
64924	M8	107.2	0.031
64924	MS4	137.7	0.061
64925	M2	70.1	3.211
64925	S2	93.8	0.787
64925	N2	48.9	0.605
64925	K1	73.3	0.987
64925	M4	174.6	0.318
64925	O1	44.1	0.501
64925	M6	124.3	0.102
64925	MK3	230.9	0.192
64925	S4	71.8	0.041
64925	MN4	148.4	0.101
64925	NU2	64.3	0.14
64925	S6	8	0.011
64925	MU2	311.3	0.046
64925	2N2	24.4	0.082
64925	OO1	122.6	0.13
64925	LDA2	62.1	0.092
64925	M1	91.5	0.014
64925	J1	103.6	0.07
64925	RHO1	5	0.035
64925	Q1	47.8	0.041
64925	2Q1	161.9	0.03
64925	P1	74.9	0.306
64925	2SM2	160.1	0.013
64925	M3	310.3	0.035
64925	L2	109.1	0.206
64925	2MK3	242.5	0.149
64925	K2	84.4	0.313
64925	M8	128.6	0.029
64925	MS4	189.9	0.093
64926	M2	69.6	2.801
64926	S2	90.6	0.679
64926	N2	58.3	0.557
64926	K1	79.6	0.923
64926	M4	99.2	0.107
64926	O1	66.7	0.49
64926	M6	75.2	0.111
64926	MK3	53.8	0.08
64926	S4	108.4	0.019
64926	MN4	83.5	0.048
64926	2N2	1.8	0.054
64926	OO1	146.6	0.122
64926	M1	115.5	0.027
64926	J1	110.3	0.039
64926	Q1	72.8	0.067
64926	2Q1	302.6	0.01
64926	P1	74.4	0.265
64926	2SM2	290.3	0.022
64926	M3	187.3	0.018
64926	L2	74	0.2
64926	2MK3	149.9	0.041
64926	K2	88.3	0.24
64926	M8	134.3	0.004
64926	MS4	128.1	0.046
64927	M2	69.7	2.891
64927	S2	90.5	0.7
64927	N2	58.5	0.575
64927	K1	79.6	0.951
64927	M4	98.5	0.112
64927	O1	66.5	0.503
64927	M6	77.5	0.117
64927	MK3	52.1	0.08
64927	S4	108.2	0.019
64927	MN4	84.2	0.051
64927	2N2	0.4	0.057
64927	OO1	147.7	0.126
64927	M1	115.8	0.028
64927	J1	108.7	0.041
64927	Q1	71.7	0.068
64927	2Q1	306.1	0.01
64927	P1	74.3	0.271
64927	2SM2	292.5	0.022
64927	M3	190.3	0.017
64927	L2	74.4	0.205
64927	2MK3	153	0.04
64927	K2	88.2	0.248
64927	M8	128.4	0.006
64927	MS4	127	0.048
64928	M2	69.8	2.965
64928	S2	90.5	0.718
64928	N2	58.7	0.59
64928	K1	79.6	0.976
64928	M4	98.7	0.117
64928	O1	66.1	0.515
64928	M6	79.2	0.122
64928	MK3	51.7	0.081
64928	S4	112.2	0.019
64928	MN4	85.1	0.053
64928	2N2	358.9	0.06
64928	OO1	147.4	0.13
64928	M1	116.2	0.028
64928	J1	109.7	0.041
64928	Q1	70.2	0.068
64928	2Q1	310.3	0.009
64928	P1	74.6	0.279
64928	2SM2	293.5	0.023
64928	M3	190.8	0.017
64928	L2	74.6	0.21
64928	2MK3	153.8	0.039
64928	K2	88.3	0.254
64928	M8	125.2	0.009
64928	MS4	126.9	0.049
64929	M2	69.9	3.029
64929	S2	90.5	0.735
64929	N2	58.9	0.602
64929	K1	79.5	0.998
64929	M4	99.6	0.123
64929	O1	65.5	0.526
64929	M6	80.3	0.126
64929	MK3	52.5	0.08
64929	S4	114.1	0.019
64929	MN4	86.8	0.055
64929	2N2	358.1	0.063
64929	OO1	146.8	0.133
64929	M1	115.3	0.029
64929	J1	110.6	0.043
64929	Q1	68.3	0.069
64929	2Q1	311	0.008
64929	P1	74.8	0.286
64929	2SM2	294.4	0.023
64929	M3	192.6	0.017
64929	L2	75	0.214
64929	2MK3	154	0.038
64929	K2	88.4	0.258
64929	M8	125.8	0.011
64929	MS4	128.4	0.051
64930	M2	70	3.086
64930	S2	90.6	0.749
64930	N2	59.1	0.614
64930	K1	79.5	1.016
64930	M4	101.4	0.128
64930	O1	64.7	0.536
64930	M6	81.1	0.128
64930	MK3	54.8	0.079
64930	S4	115.9	0.02
64930	MN4	89.2	0.059
64930	2N2	357.4	0.066
64930	OO1	145.6	0.135
64930	M1	113.4	0.029
64930	J1	111.6	0.045
64930	Q1	65.7	0.071
64930	2Q1	321.9	0.006
64930	P1	74.9	0.292
64930	2SM2	295.4	0.024
64930	M3	193.7	0.018
64930	L2	75.5	0.217
64930	2MK3	152.7	0.038
64930	K2	88.3	0.261
64930	M8	125.4	0.014
64930	MS4	131	0.053
64931	M2	70.1	3.135
64931	S2	90.6	0.76
64931	N2	59.3	0.625
64931	K1	79.4	1.03
64931	M4	103.7	0.134
64931	O1	63.9	0.545
64931	M6	81.6	0.13
64931	MK3	57.8	0.079
64931	S4	117.5	0.019
64931	MN4	91.6	0.061
64931	2N2	356.2	0.068
64931	OO1	144.1	0.135
64931	M1	111.1	0.03
64931	J1	111.7	0.047
64931	Q1	63.9	0.074
64931	P1	74.8	0.297
64931	2SM2	296.2	0.025
64931	M3	194	0.019
64931	L2	76	0.219
64931	2MK3	151.6	0.038
64931	K2	88.1	0.265
64931	M8	127.5	0.016
64931	MS4	133.9	0.055
64932	M2	70.2	3.177
64932	S2	90.7	0.768
64932	N2	59.5	0.634
64932	K1	79.4	1.041
64932	M4	106.1	0.141
64932	O1	63.1	0.554
64932	M6	82.1	0.131
64932	MK3	60.9	0.078
64932	S4	118.6	0.019
64932	MN4	93.3	0.064
64932	2N2	355	0.071
64932	OO1	142.7	0.136
64932	M1	109.9	0.03
64932	J1	112.2	0.049
64932	Q1	62.9	0.075
64932	P1	74.9	0.301
64932	2SM2	297	0.025
64932	M3	194.5	0.019
64932	L2	76.2	0.221
64932	2MK3	150.5	0.039
64932	K2	87.5	0.268
64932	M8	129.6	0.019
64932	MS4	136.9	0.057
64933	M2	70.3	3.213
64933	S2	90.8	0.773
64933	N2	59.7	0.641
64933	K1	79.4	1.049
64933	M4	108.4	0.148
64933	O1	62.4	0.561
64933	M6	82.2	0.132
64933	MK3	63.7	0.078
64933	S4	118.9	0.018
64933	MN4	95.8	0.066
64933	2N2	352.9	0.073
64933	OO1	141.9	0.137
64933	M1	107.9	0.031
64933	J1	112	0.05
64933	Q1	62.6	0.076
64933	P1	75	0.303
64933	2SM2	299.1	0.026
64933	M3	195.9	0.02
64933	L2	76.7	0.224
64933	2MK3	149.8	0.039
64933	K2	86.9	0.272
64933	M8	132	0.023
64933	MS4	139.9	0.058
64934	M2	70.4	3.242
64934	S2	90.8	0.776
64934	N2	59.9	0.647
64934	K1	79.4	1.057
64934	M4	110.8	0.155
64934	O1	61.7	0.566
64934	M6	82.2	0.132
64934	MK3	66.6	0.078
64934	S4	120.5	0.017
64934	MN4	98.1	0.069
64934	2N2	351.2	0.076
64934	OO1	141.2	0.137
64934	M1	105.8	0.031
64934	J1	111.9	0.052
64934	Q1	61.5	0.076
64934	P1	75.5	0.306
64934	2SM2	299.3	0.025
64934	M3	194.5	0.02
64934	L2	77.1	0.227
64934	2MK3	148.7	0.039
64934	K2	86.4	0.275
64934	M8	132.5	0.026
64934	MS4	142.3	0.06
64935	M2	70.5	3.267
64935	S2	90.8	0.779
64935	N2	60.1	0.652
64935	K1	79.3	1.06
64935	M4	112.9	0.163
64935	O1	61.1	0.571
64935	M6	82.2	0.133
64935	MK3	69.1	0.078
64935	S4	121.1	0.018
64935	MN4	99.9	0.071
64935	2N2	348.8	0.079
64935	OO1	141.1	0.138
64935	M1	103.2	0.031
64935	J1	111.4	0.054
64935	Q1	60.7	0.078
64935	P1	75.4	0.308
64935	2SM2	301.1	0.026
64935	M3	194.8	0.02
64935	L2	77.6	0.231
64935	2MK3	147.4	0.039
64935	K2	85.8	0.279
64935	M8	133.4	0.03
64935	MS4	144.8	0.063
64936	M2	70.6	3.29
64936	S2	90.8	0.782
64936	N2	60.3	0.655
64936	K1	79.4	1.063
64936	M4	114.7	0.172
64936	O1	60.7	0.574
64936	M6	82.4	0.133
64936	MK3	71.9	0.079
64936	S4	123.5	0.018
64936	MN4	102.3	0.073
64936	2N2	346.5	0.083
64936	OO1	140.9	0.139
64936	M1	101.5	0.031
64936	J1	110.5	0.056
64936	Q1	59.9	0.08
64936	2Q1	129.3	0.005
64936	P1	75.5	0.309
64936	2SM2	303.3	0.026
64936	M3	193.2	0.021
64936	L2	78.1	0.234
64936	2MK3	146.5	0.038
64936	K2	85.8	0.28
64936	M8	133.5	0.033
64936	MS4	146.4	0.065
64937	M2	70.7	3.31
64937	S2	90.7	0.783
64937	N2	60.5	0.657
64937	K1	79.5	1.064
64937	M4	116.3	0.182
64937	O1	60.3	0.575
64937	M6	82.4	0.134
64937	MK3	73.8	0.08
64937	S4	125.1	0.018
64937	MN4	104.4	0.075
64937	2N2	344.6	0.087
64937	OO1	141	0.141
64937	M1	100.1	0.031
64937	J1	110.6	0.057
64937	Q1	60.1	0.081
64937	2Q1	146.9	0.007
64937	P1	75.6	0.309
64937	2SM2	304.8	0.027
64937	M3	189.8	0.021
64937	L2	78.5	0.237
64937	2MK3	144.7	0.037
64937	K2	85.6	0.282
64937	M8	133.7	0.036
64937	MS4	147.5	0.067
64938	M2	70.7	3.327
64938	S2	90.8	0.785
64938	N2	60.6	0.658
64938	K1	79.5	1.066
64938	M4	117.3	0.193
64938	O1	60	0.574
64938	M6	82.6	0.134
64938	MK3	75.3	0.082
64938	S4	128.9	0.017
64938	MN4	106.7	0.078
64938	2N2	342.2	0.091
64938	OO1	141.4	0.143
64938	M1	98	0.032
64938	J1	110.2	0.057
64938	Q1	60.5	0.084
64938	2Q1	158.4	0.01
64938	P1	76.2	0.31
64938	2SM2	304.6	0.027
64938	M3	185.6	0.022
64938	L2	79	0.239
64938	2MK3	141.2	0.035
64938	K2	85.1	0.282
64938	M8	132.9	0.039
64938	MS4	148	0.07
64939	M2	70.8	3.341
64939	S2	90.7	0.784
64939	N2	60.7	0.66
64939	K1	79.6	1.064
64939	M4	118.3	0.205
64939	O1	59.7	0.573
64939	M6	82.6	0.135
64939	MK3	75.9	0.085
64939	S4	131.1	0.017
64939	MN4	108.9	0.08
64939	2N2	340.1	0.096
64939	OO1	141.3	0.146
64939	M1	97	0.032
64939	J1	110.8	0.057
64939	Q1	61.2	0.086
64939	2Q1	166.1	0.013
64939	P1	76.6	0.309
64939	2SM2	305.4	0.028
64939	M3	179.7	0.023
64939	L2	79.5	0.241
64939	2MK3	138.1	0.033
64939	K2	84.8	0.282
64939	M8	131.5	0.041
64939	MS4	147.7	0.073
64940	M2	70.8	3.353
64940	S2	90.6	0.784
64940	N2	60.8	0.66
64940	K1	79.7	1.063
64940	M4	118.9	0.218
64940	O1	59.4	0.571
64940	M6	82.7	0.135
64940	MK3	76.1	0.09
64940	S4	133.1	0.017
64940	MN4	110.5	0.082
64940	2N2	338.7	0.101
64940	OO1	142	0.149
64940	M1	95.6	0.032
64940	J1	111.7	0.058
64940	Q1	62.8	0.088
64940	2Q1	172.6	0.017
64940	P1	77.3	0.308
64940	2SM2	304.9	0.027
64940	M3	176.3	0.025
64940	L2	79.8	0.243
64940	2MK3	132.4	0.031
64940	K2	84.8	0.283
64940	M8	129.3	0.042
64940	MS4	147.1	0.075
64941	M2	70.8	3.361
64941	S2	90.4	0.785
64941	N2	60.8	0.66
64941	K1	79.7	1.058
64941	M4	119.2	0.23
64941	O1	59.2	0.569
64941	M6	82.2	0.135
64941	MK3	76.3	0.096
64941	S4	130.2	0.016
64941	MN4	111.7	0.085
64941	2N2	337.7	0.106
64941	OO1	143.6	0.152
64941	M1	94.8	0.032
64941	J1	114	0.058
64941	Q1	64.7	0.089
64941	2Q1	181.1	0.021
64941	P1	77.6	0.306
64941	2SM2	304.4	0.026
64941	M3	171.5	0.027
64941	L2	79.7	0.245
64941	2MK3	128.2	0.03
64941	K2	85.1	0.282
64941	M8	127.6	0.042
64941	MS4	146	0.079
64942	M2	70.7	3.362
64942	S2	90	0.783
64942	N2	60.8	0.655
64942	K1	79.6	1.048
64942	M4	120.3	0.239
64942	O1	59.2	0.562
64942	M6	81.7	0.135
64942	MK3	74.7	0.098
64942	S4	136.1	0.017
64942	MN4	113.6	0.087
64942	S6	350.6	0.004
64942	2N2	337	0.114
64942	OO1	145	0.162
64942	M1	92.6	0.032
64942	J1	118.3	0.058
64942	Q1	67.8	0.089
64942	2Q1	187.9	0.026
64942	P1	77.7	0.302
64942	2SM2	299.7	0.025
64942	M3	164	0.025
64942	L2	79.5	0.249
64942	2MK3	132.8	0.029
64942	K2	86	0.284
64942	M8	123.9	0.043
64942	MS4	147.7	0.083
64943	M2	70.3	3.133
64943	S2	90.7	0.692
64943	N2	61	0.584
64943	K1	75.7	0.932
64943	M4	151.9	0.246
64943	O1	53.3	0.421
64943	M6	84.8	0.12
64943	MK3	287.7	0.083
64943	S4	153	0.026
64943	MN4	149.3	0.106
64943	S6	312.3	0.008
64943	2N2	344.4	0.159
64943	OO1	163	0.162
64943	M1	98.6	0.024
64943	J1	103.4	0.035
64943	Q1	63.7	0.045
64943	2Q1	274.8	0.016
64943	P1	75.2	0.263
64943	2SM2	256.2	0.012
64943	M3	321.2	0.027
64943	L2	82.6	0.256
64943	2MK3	212.1	0.133
64943	K2	87.5	0.337
64943	M8	133.4	0.046
64943	MS4	179.9	0.135
64944	M2	108.2	0.56
64944	S2	109.5	0.13
64944	N2	86.4	0.071
64944	K1	75.9	0.165
64944	M4	172.8	0.087
64944	O1	69.6	0.059
64944	M6	190.3	0.068
64944	MK3	98.4	0.039
64944	S4	162.8	0.022
64944	MN4	112.8	0.024
64944	S6	234.5	0.003
64944	2N2	25.5	0.061
64944	OO1	206.9	0.05
64944	M1	177.2	0.009
64944	J1	270.9	0.014
64944	Q1	226.2	0.011
64944	2Q1	254.3	0.02
64944	P1	94.2	0.053
64944	2SM2	5.5	0.013
64944	M3	36.3	0.011
64944	L2	143.1	0.057
64944	2MK3	295.3	0.025
64944	K2	133.3	0.068
64944	M8	254.5	0.03
64944	MS4	196.3	0.033
64945	M2	94.6	0.605
64945	S2	98.8	0.128
64945	N2	72.3	0.074
64945	K1	52	0.148
64945	M4	187.1	0.122
64945	O1	22.1	0.024
64945	M6	184.5	0.06
64945	MK3	104	0.047
64945	S4	159.7	0.019
64945	MN4	142.2	0.027
64945	S6	182.3	0.005
64945	2N2	5.3	0.083
64945	OO1	182.2	0.062
64945	M1	193.4	0.009
64945	J1	250.2	0.024
64945	Q1	286.5	0.022
64945	2Q1	206.2	0.002
64945	P1	84.7	0.05
64945	2SM2	357.5	0.019
64945	M3	50.8	0.014
64945	L2	130.2	0.077
64945	2MK3	319.6	0.026
64945	K2	109.5	0.056
64945	M8	248.5	0.036
64945	MS4	207.1	0.043
64946	M2	84.2	0.603
64946	S2	88.8	0.102
64946	N2	66.8	0.084
64946	K1	40.8	0.144
64946	M4	193	0.152
64946	O1	3.8	0.039
64946	M6	189.3	0.045
64946	MK3	129.8	0.054
64946	S4	172.7	0.029
64946	MN4	161.3	0.043
64946	S6	244.8	0.003
64946	2N2	353.6	0.077
64946	OO1	182.3	0.07
64946	M1	182.9	0.008
64946	J1	236	0.022
64946	Q1	301.6	0.018
64946	2Q1	236.6	0.017
64946	P1	51.4	0.038
64946	2SM2	4.3	0.026
64946	M3	43.1	0.022
64946	L2	111	0.089
64946	2MK3	321.3	0.024
64946	K2	81	0.067
64946	M8	242.8	0.035
64946	MS4	216.8	0.06
64947	M2	33.5	0.906
64947	S2	46	0.184
64947	N2	20.3	0.141
64947	K1	43.4	0.092
64947	M4	51	0.243
64947	O1	141.7	0.093
64947	M6	80.4	0.101
64947	MK3	17.9	0.141
64947	S4	50	0.025
64947	MN4	32.8	0.078
64947	S6	31.9	0.007
64947	2N2	286.7	0.078
64947	OO1	152.8	0.068
64947	M1	191	0.016
64947	J1	205.1	0.009
64947	Q1	152	0.016
64947	2Q1	111.7	0.019
64947	P1	63.5	0.027
64947	2SM2	301.8	0.016
64947	M3	65.7	0.031
64947	L2	51.2	0.104
64947	2MK3	299.6	0.044
64947	K2	43.5	0.059
64947	M8	122.2	0.036
64947	MS4	63.3	0.112
64948	M2	33.7	0.977
64948	S2	46.2	0.199
64948	N2	20.6	0.151
64948	K1	45.8	0.1
64948	M4	50.5	0.259
64948	O1	141.9	0.1
64948	M6	79.6	0.11
64948	MK3	16.8	0.152
64948	S4	50.3	0.025
64948	MN4	33	0.083
64948	S6	34.7	0.007
64948	2N2	287.3	0.083
64948	OO1	153.7	0.073
64948	M1	192.1	0.018
64948	J1	210.1	0.01
64948	Q1	152.3	0.017
64948	2Q1	111.3	0.02
64948	P1	66.1	0.029
64948	2SM2	301.5	0.018
64948	M3	66	0.033
64948	L2	51.8	0.112
64948	2MK3	299.9	0.048
64948	K2	44	0.063
64948	M8	120.9	0.04
64948	MS4	62.6	0.118
64949	M2	33.7	1.022
64949	S2	45.9	0.209
64949	N2	20.4	0.157
64949	K1	46.1	0.105
64949	M4	50.5	0.27
64949	O1	142.2	0.104
64949	M6	79.2	0.118
64949	MK3	16	0.16
64949	S4	50.7	0.025
64949	MN4	33.6	0.087
64949	S6	36.7	0.007
64949	2N2	287.5	0.087
64949	OO1	154.9	0.076
64949	M1	193.2	0.019
64949	J1	215.2	0.011
64949	Q1	154.3	0.018
64949	2Q1	111.4	0.021
64949	P1	64.2	0.029
64949	2SM2	301.4	0.02
64949	M3	65.6	0.035
64949	L2	51.7	0.118
64949	2MK3	300	0.05
64949	K2	46.5	0.067
64949	M8	119.8	0.044
64949	MS4	62.5	0.124
64950	M2	33.6	1.052
64950	S2	45.5	0.216
64950	N2	20.1	0.16
64950	K1	45.7	0.11
64950	M4	50.5	0.28
64950	O1	142.2	0.106
64950	M6	79.2	0.125
64950	MK3	15.1	0.166
64950	S4	51.1	0.025
64950	MN4	34.2	0.091
64950	S6	37.7	0.007
64950	2N2	287.8	0.09
64950	OO1	156.1	0.078
64950	M1	193.6	0.019
64950	J1	221.3	0.012
64950	Q1	154.7	0.018
64950	2Q1	111.7	0.022
64950	P1	63.3	0.031
64950	2SM2	301.2	0.021
64950	M3	65.3	0.036
64950	L2	51.5	0.123
64950	2MK3	299.6	0.052
64950	K2	47.1	0.07
64950	M8	118.9	0.047
64950	MS4	62.6	0.128
64951	M2	33.5	1.074
64951	S2	45.1	0.22
64951	N2	19.6	0.163
64951	K1	45.4	0.113
64951	M4	50.6	0.289
64951	O1	141.9	0.107
64951	M6	79.4	0.131
64951	MK3	14.6	0.171
64951	S4	52.2	0.025
64951	MN4	34.8	0.093
64951	S6	40	0.007
64951	2N2	287.9	0.092
64951	OO1	156.3	0.081
64951	M1	194.6	0.02
64951	J1	219.5	0.012
64951	Q1	154.5	0.019
64951	2Q1	113.9	0.022
64951	P1	61.6	0.031
64951	2SM2	301.7	0.022
64951	M3	64.8	0.037
64951	L2	51.2	0.125
64951	2MK3	298.7	0.052
64951	K2	47.5	0.073
64951	M8	118.4	0.05
64951	MS4	62.9	0.133
64952	M2	33.4	1.091
64952	S2	44.9	0.223
64952	N2	19.1	0.166
64952	K1	45.2	0.115
64952	M4	50.7	0.297
64952	O1	141.2	0.107
64952	M6	79.6	0.137
64952	MK3	14.6	0.175
64952	S4	52.7	0.025
64952	MN4	35	0.095
64952	S6	38.4	0.007
64952	2N2	287.9	0.094
64952	OO1	156.8	0.083
64952	M1	195	0.02
64952	J1	216.5	0.012
64952	Q1	152.2	0.02
64952	2Q1	115.4	0.023
64952	P1	61.8	0.032
64952	2SM2	301.6	0.023
64952	M3	65.1	0.038
64952	L2	50.9	0.126
64952	2MK3	298.6	0.054
64952	K2	47.9	0.074
64952	M8	118.1	0.053
64952	MS4	63.1	0.136
64953	M2	33.3	1.105
64953	S2	44.6	0.226
64953	N2	18.7	0.168
64953	K1	45.2	0.118
64953	M4	50.4	0.303
64953	O1	140.5	0.109
64953	M6	79.6	0.141
64953	MK3	14.7	0.177
64953	S4	53	0.025
64953	MN4	35.1	0.097
64953	S6	35.7	0.007
64953	2N2	288	0.096
64953	OO1	156.9	0.084
64953	M1	194.6	0.02
64953	J1	215.5	0.012
64953	Q1	150.7	0.02
64953	2Q1	118.1	0.024
64953	P1	63.7	0.032
64953	2SM2	301.3	0.023
64953	M3	66	0.038
64953	L2	50.3	0.126
64953	2MK3	298.3	0.054
64953	K2	48.3	0.076
64953	M8	117.7	0.056
64953	MS4	63.1	0.139
64954	M2	33.2	1.115
64954	S2	44.5	0.228
64954	N2	18.1	0.171
64954	K1	45	0.12
64954	M4	50.2	0.309
64954	O1	139.7	0.109
64954	M6	79.6	0.145
64954	MK3	14.8	0.179
64954	S4	51.6	0.025
64954	MN4	34.9	0.099
64954	S6	31.9	0.007
64954	2N2	288.2	0.096
64954	OO1	157	0.086
64954	M1	194.6	0.02
64954	J1	212.7	0.013
64954	Q1	149.3	0.02
64954	2Q1	118.4	0.024
64954	P1	64.2	0.032
64954	2SM2	301.2	0.023
64954	M3	66	0.039
64954	L2	49.9	0.127
64954	2MK3	298.8	0.054
64954	K2	48.2	0.078
64954	M8	117.8	0.058
64954	MS4	63.2	0.142
64955	M2	33.1	1.123
64955	S2	44.3	0.23
64955	N2	17.9	0.173
64955	K1	45.1	0.121
64955	M4	49.9	0.314
64955	O1	139.3	0.108
64955	M6	79.6	0.149
64955	MK3	15	0.18
64955	S4	51.2	0.025
64955	MN4	34.3	0.1
64955	S6	30.1	0.007
64955	2N2	288.4	0.096
64955	OO1	156	0.088
64955	M1	194	0.02
64955	J1	210.5	0.014
64955	Q1	148.7	0.02
64955	2Q1	120.2	0.025
64955	P1	65.4	0.032
64955	2SM2	300.9	0.022
64955	M3	66.4	0.039
64955	L2	49.3	0.127
64955	2MK3	299.2	0.055
64955	K2	48.8	0.079
64955	M8	118	0.06
64955	MS4	63.3	0.144
64956	M2	33	1.128
64956	S2	44.4	0.232
64956	N2	17.8	0.174
64956	K1	44.4	0.123
64956	M4	49.5	0.318
64956	O1	139.3	0.107
64956	M6	79.3	0.152
64956	MK3	15.1	0.181
64956	S4	50.5	0.025
64956	MN4	33.9	0.101
64956	S6	24.8	0.008
64956	2N2	288.6	0.096
64956	OO1	155.6	0.089
64956	M1	193.7	0.02
64956	J1	210.6	0.015
64956	Q1	148.5	0.02
64956	2Q1	122.4	0.025
64956	P1	66.3	0.032
64956	2SM2	300.4	0.022
64956	M3	66.1	0.039
64956	L2	48.7	0.127
64956	2MK3	299.1	0.055
64956	K2	49.4	0.08
64956	M8	118	0.062
64956	MS4	63.2	0.146
64957	M2	32.9	1.129
64957	S2	44.1	0.233
64957	N2	17.6	0.175
64957	K1	44.3	0.125
64957	M4	49	0.322
64957	O1	139.4	0.106
64957	M6	78.7	0.156
64957	MK3	15	0.182
64957	S4	49.8	0.025
64957	MN4	33.3	0.101
64957	S6	21.9	0.008
64957	2N2	288.7	0.095
64957	OO1	154	0.09
64957	M1	193.9	0.02
64957	J1	212	0.016
64957	Q1	149.1	0.019
64957	2Q1	123.9	0.025
64957	P1	67.9	0.031
64957	2SM2	299.3	0.022
64957	M3	66.3	0.039
64957	L2	48	0.126
64957	2MK3	298.8	0.055
64957	K2	49.7	0.082
64957	M8	118	0.064
64957	MS4	62.9	0.148
64958	M2	32.8	1.129
64958	S2	44.3	0.234
64958	N2	17.5	0.177
64958	K1	43.5	0.126
64958	M4	48.4	0.324
64958	O1	139.2	0.105
64958	M6	78.4	0.159
64958	MK3	14.8	0.183
64958	S4	49.7	0.025
64958	MN4	32.6	0.102
64958	S6	17	0.008
64958	2N2	289	0.095
64958	OO1	154.4	0.09
64958	M1	193.4	0.019
64958	J1	213	0.017
64958	Q1	148.4	0.019
64958	2Q1	125.3	0.025
64958	P1	68.1	0.031
64958	2SM2	299.2	0.021
64958	M3	66.3	0.039
64958	L2	47.3	0.125
64958	2MK3	298.8	0.054
64958	K2	50.2	0.082
64958	M8	118	0.065
64958	MS4	62.7	0.148
64959	M2	32.7	1.127
64959	S2	44.1	0.234
64959	N2	17.4	0.176
64959	K1	42.2	0.129
64959	M4	47.8	0.327
64959	O1	139.2	0.104
64959	M6	77.7	0.162
64959	MK3	14.6	0.184
64959	S4	48.3	0.025
64959	MN4	31.8	0.103
64959	S6	15.9	0.007
64959	2N2	289.1	0.095
64959	OO1	154.4	0.091
64959	M1	193.4	0.019
64959	J1	213.9	0.017
64959	Q1	149.7	0.019
64959	2Q1	126.5	0.025
64959	P1	67.5	0.033
64959	2SM2	298.2	0.021
64959	M3	66	0.04
64959	L2	46.6	0.124
64959	2MK3	298.9	0.054
64959	K2	50.8	0.084
64959	M8	117.5	0.066
64959	MS4	62.3	0.149
64960	M2	32.6	1.124
64960	S2	44.2	0.235
64960	N2	17.2	0.176
64960	K1	41.3	0.131
64960	M4	47	0.329
64960	O1	139.1	0.103
64960	M6	77	0.165
64960	MK3	14.1	0.185
64960	S4	48.2	0.025
64960	MN4	31	0.104
64960	S6	11	0.008
64960	2N2	289.3	0.094
64960	OO1	154.1	0.092
64960	M1	193.4	0.018
64960	J1	214.7	0.017
64960	Q1	150.8	0.019
64960	2Q1	126.8	0.024
64960	P1	66.6	0.033
64960	2SM2	297.9	0.021
64960	M3	65.9	0.04
64960	L2	45.9	0.122
64960	2MK3	298.7	0.054
64960	K2	51.7	0.084
64960	M8	117	0.067
64960	MS4	61.8	0.148
64961	M2	32.6	1.12
64961	S2	43.9	0.235
64961	N2	17.2	0.176
64961	K1	40.4	0.133
64961	M4	46.1	0.331
64961	O1	139.1	0.101
64961	M6	76.3	0.168
64961	MK3	13.8	0.187
64961	S4	46.8	0.024
64961	MN4	30.5	0.104
64961	S6	8	0.008
64961	2N2	289.9	0.094
64961	OO1	154.1	0.091
64961	M1	193.1	0.018
64961	J1	217.4	0.018
64961	Q1	152.4	0.018
64961	2Q1	128.8	0.024
64961	P1	66.2	0.034
64961	2SM2	296.6	0.021
64961	M3	66.1	0.04
64961	L2	45.4	0.12
64961	2MK3	299.1	0.053
64961	K2	52.3	0.086
64961	M8	116.7	0.067
64961	MS4	61.4	0.149
64962	M2	32.5	1.114
64962	S2	43.9	0.235
64962	N2	17.2	0.175
64962	K1	39.7	0.133
64962	M4	45.3	0.332
64962	O1	138.6	0.101
64962	M6	75.7	0.171
64962	MK3	13.3	0.188
64962	S4	47.7	0.024
64962	MN4	29.8	0.106
64962	S6	6.7	0.008
64962	2N2	290.3	0.095
64962	OO1	154.2	0.091
64962	M1	194	0.018
64962	J1	219.5	0.018
64962	Q1	151.8	0.018
64962	2Q1	129.9	0.024
64962	P1	63.2	0.034
64962	2SM2	296.1	0.02
64962	M3	67.1	0.041
64962	L2	45.1	0.118
64962	2MK3	299.6	0.052
64962	K2	52.4	0.086
64962	M8	116.2	0.068
64962	MS4	60.8	0.148
64963	M2	32.4	1.109
64963	S2	43.6	0.234
64963	N2	17.1	0.174
64963	K1	38.7	0.135
64963	M4	44.5	0.334
64963	O1	138.6	0.099
64963	M6	75.1	0.174
64963	MK3	12.9	0.189
64963	S4	47.7	0.024
64963	MN4	29.4	0.108
64963	S6	1.7	0.008
64963	2N2	290.8	0.095
64963	OO1	153.9	0.091
64963	M1	194.7	0.017
64963	J1	221.3	0.018
64963	Q1	152.5	0.018
64963	2Q1	131.5	0.024
64963	P1	61.2	0.035
64963	2SM2	296.3	0.02
64963	M3	67.8	0.041
64963	L2	44.6	0.115
64963	2MK3	300.6	0.051
64963	K2	52	0.089
64963	M8	115.7	0.069
64963	MS4	60.5	0.147
64964	M2	32.3	1.102
64964	S2	43.4	0.233
64964	N2	16.6	0.172
64964	K1	38.2	0.134
64964	M4	43.7	0.336
64964	O1	137.8	0.098
64964	M6	74.6	0.176
64964	MK3	12.3	0.19
64964	S4	49.1	0.023
64964	MN4	28.6	0.109
64964	S6	354.3	0.008
64964	2N2	291.4	0.097
64964	OO1	154.5	0.092
64964	M1	196.9	0.017
64964	J1	223.7	0.018
64964	Q1	155.4	0.018
64964	2Q1	132.3	0.023
64964	P1	59.5	0.034
64964	2SM2	295.6	0.02
64964	M3	67.7	0.041
64964	L2	44.2	0.114
64964	2MK3	300.7	0.049
64964	K2	52.4	0.091
64964	M8	115.4	0.071
64964	MS4	60.3	0.146
64965	M2	31.8	1.082
64965	S2	42.3	0.237
64965	N2	13.6	0.165
64965	K1	33.3	0.131
64965	M4	43.3	0.318
64965	O1	142.3	0.101
64965	M6	77.7	0.17
64965	MK3	6.4	0.187
64965	S4	55.5	0.019
64965	MN4	25.7	0.097
64965	S6	343.1	0.007
64965	2N2	294.7	0.103
64965	OO1	157.8	0.094
64965	M1	205.2	0.015
64965	J1	231.1	0.022
64965	Q1	172.6	0.023
64965	2Q1	139	0.02
64965	P1	53.9	0.036
64965	2SM2	290.2	0.019
64965	M3	60.1	0.046
64965	L2	42.3	0.119
64965	2MK3	283.2	0.045
64965	K2	61.7	0.095
64965	M8	120.2	0.073
64965	MS4	63	0.135
64966	M2	79.3	1.861
64966	S2	101.1	0.48
64966	N2	57.3	0.319
64966	K1	85.6	0.691
64966	M4	180.2	0.052
64966	O1	66	0.359
64966	M6	340.1	0.032
64966	MK3	145.4	0.065
64966	S4	60.4	0.018
64966	MN4	149.6	0.028
64966	S6	153.2	0.01
64966	2N2	69.4	0.061
64966	OO1	138.3	0.066
64966	M1	131.5	0.01
64966	J1	146.4	0.016
64966	Q1	21.7	0.038
64966	2Q1	68.5	0.04
64966	P1	76.5	0.24
64966	2SM2	335.2	0.004
64966	M3	220.7	0.023
64966	L2	117.4	0.05
64966	2MK3	112.2	0.027
64966	K2	85	0.166
64966	M8	355.9	0.031
64966	MS4	174.6	0.041
64967	M2	79.2	1.913
64967	S2	100.9	0.491
64967	N2	57.2	0.326
64967	K1	84.8	0.705
64967	M4	179.7	0.058
64967	O1	64.9	0.37
64967	M6	346.4	0.03
64967	MK3	147.6	0.067
64967	S4	62.7	0.018
64967	MN4	150.3	0.03
64967	S6	149.6	0.008
64967	2N2	66.9	0.062
64967	OO1	135.5	0.059
64967	M1	121.5	0.011
64967	J1	140.9	0.017
64967	Q1	20.7	0.037
64967	2Q1	66.4	0.038
64967	P1	77	0.245
64967	2SM2	321.7	0.007
64967	M3	214.5	0.022
64967	L2	117.6	0.053
64967	2MK3	108.9	0.024
64967	K2	84.8	0.166
64967	M8	359.4	0.029
64967	MS4	175	0.042
64968	M2	79	1.947
64968	S2	100.6	0.497
64968	N2	57	0.329
64968	K1	84	0.712
64968	M4	179	0.065
64968	O1	63.6	0.377
64968	M6	349.1	0.028
64968	MK3	147.2	0.068
64968	S4	65.6	0.017
64968	MN4	150.6	0.032
64968	S6	145.4	0.007
64968	2N2	63.9	0.063
64968	OO1	129.3	0.053
64968	M1	114.3	0.011
64968	J1	136.2	0.018
64968	Q1	22	0.038
64968	2Q1	63.6	0.035
64968	P1	77.8	0.247
64968	2SM2	314.2	0.009
64968	M3	208.8	0.022
64968	L2	118.7	0.056
64968	2MK3	105.6	0.022
64968	K2	84.6	0.163
64968	M8	4.1	0.027
64968	MS4	175	0.045
64969	M2	78.8	1.974
64969	S2	100.5	0.5
64969	N2	56.8	0.332
64969	K1	83	0.716
64969	M4	177.8	0.073
64969	O1	62.2	0.382
64969	M6	348.8	0.027
64969	MK3	146.3	0.07
64969	S4	71.6	0.016
64969	MN4	149.7	0.035
64969	S6	141.8	0.006
64969	2N2	61.1	0.064
64969	OO1	120.8	0.048
64969	M1	107.4	0.012
64969	J1	134.7	0.02
64969	Q1	23	0.038
64969	2Q1	61.2	0.031
64969	P1	78.6	0.249
64969	2SM2	307.7	0.01
64969	M3	202.6	0.022
64969	L2	118.9	0.058
64969	2MK3	102.8	0.022
64969	K2	84.6	0.159
64969	M8	7.6	0.027
64969	MS4	174.7	0.048
64970	M2	78.5	1.995
64970	S2	100.2	0.502
64970	N2	56.5	0.333
64970	K1	82.1	0.717
64970	M4	176.8	0.082
64970	O1	61.1	0.385
64970	M6	347.7	0.027
64970	MK3	143.3	0.071
64970	S4	76.6	0.018
64970	MN4	148.3	0.037
64970	S6	135.7	0.007
64970	2N2	58.7	0.065
64970	OO1	111.9	0.043
64970	M1	102.4	0.013
64970	J1	132.7	0.023
64970	Q1	25.4	0.038
64970	2Q1	58	0.027
64970	P1	79.2	0.251
64970	2SM2	302.2	0.011
64970	M3	197.9	0.023
64970	L2	119	0.06
64970	2MK3	102.3	0.022
64970	K2	83.5	0.156
64970	M8	12.4	0.027
64970	MS4	173.7	0.052
64971	M2	78.1	2.012
64971	S2	99.8	0.505
64971	N2	56.1	0.333
64971	K1	81.3	0.716
64971	M4	175	0.09
64971	O1	59.9	0.387
64971	M6	346.2	0.027
64971	MK3	139.7	0.074
64971	S4	81.7	0.019
64971	MN4	146.8	0.04
64971	S6	129.6	0.007
64971	2N2	56.3	0.067
64971	OO1	100.1	0.039
64971	M1	99.5	0.013
64971	J1	130.4	0.026
64971	Q1	26.9	0.038
64971	2Q1	54.1	0.024
64971	P1	79.5	0.253
64971	2SM2	299.5	0.011
64971	M3	195.2	0.025
64971	L2	118.6	0.061
64971	2MK3	102.1	0.024
64971	K2	82.5	0.157
64971	M8	16.3	0.029
64971	MS4	173.6	0.056
64972	M2	77.7	2.024
64972	S2	99.6	0.508
64972	N2	55.6	0.334
64972	K1	80.4	0.716
64972	M4	173.3	0.098
64972	O1	59.1	0.388
64972	M6	347	0.028
64972	MK3	135.7	0.078
64972	S4	84.3	0.022
64972	MN4	145.8	0.042
64972	S6	131.2	0.007
64972	2N2	54.7	0.068
64972	OO1	86.4	0.036
64972	M1	97.3	0.014
64972	J1	129.5	0.03
64972	Q1	28.7	0.037
64972	2Q1	47.5	0.021
64972	P1	80.1	0.251
64972	2SM2	293.4	0.012
64972	M3	194.3	0.026
64972	L2	118.5	0.061
64972	2MK3	101.8	0.025
64972	K2	82	0.158
64972	M8	20.3	0.03
64972	MS4	173.4	0.06
64973	M2	77.3	2.033
64973	S2	99.2	0.509
64973	N2	54.8	0.333
64973	K1	79.6	0.715
64973	M4	170.9	0.107
64973	O1	58.2	0.386
64973	M6	348.1	0.028
64973	MK3	131.2	0.083
64973	S4	86	0.025
64973	MN4	143.2	0.045
64973	S6	133.8	0.007
64973	2N2	53.9	0.069
64973	OO1	73.1	0.035
64973	M1	96.1	0.015
64973	J1	129.4	0.032
64973	Q1	31.4	0.037
64973	2Q1	40.2	0.019
64973	P1	80.2	0.249
64973	2SM2	289.4	0.013
64973	M3	194.6	0.027
64973	L2	118.6	0.061
64973	2MK3	99.7	0.027
64973	K2	80.5	0.158
64973	M8	24.1	0.031
64973	MS4	174.1	0.064
64974	M2	76.8	2.039
64974	S2	98.8	0.509
64974	N2	54.1	0.332
64974	K1	78.8	0.713
64974	M4	168.4	0.116
64974	O1	57.5	0.384
64974	M6	351.2	0.028
64974	MK3	126.5	0.09
64974	S4	87.5	0.028
64974	MN4	140.5	0.047
64974	S6	139.7	0.006
64974	2N2	53.4	0.071
64974	OO1	61.4	0.036
64974	M1	94.6	0.016
64974	J1	128.5	0.035
64974	Q1	33.7	0.036
64974	2Q1	32.2	0.018
64974	P1	80.5	0.246
64974	2SM2	285.4	0.014
64974	M3	195.5	0.028
64974	L2	118.1	0.061
64974	2MK3	100.3	0.028
64974	K2	78.8	0.157
64974	M8	28.4	0.031
64974	MS4	174.3	0.068
64975	M2	76.3	2.042
64975	S2	98.3	0.508
64975	N2	53.5	0.331
64975	K1	78.1	0.712
64975	M4	166.1	0.126
64975	O1	56.9	0.38
64975	M6	356	0.027
64975	MK3	121.9	0.097
64975	S4	86.2	0.03
64975	MN4	138.4	0.05
64975	S6	146.2	0.006
64975	2N2	52.9	0.072
64975	OO1	53.1	0.038
64975	M1	95	0.017
64975	J1	129	0.036
64975	Q1	36.8	0.036
64975	2Q1	25.1	0.017
64975	P1	80.7	0.242
64975	2SM2	284.4	0.014
64975	M3	196.7	0.029
64975	L2	116.9	0.061
64975	2MK3	99.1	0.029
64975	K2	76.8	0.157
64975	M8	32.4	0.032
64975	MS4	175	0.072
64976	M2	75.8	2.041
64976	S2	97.8	0.504
64976	N2	52.8	0.329
64976	K1	77.6	0.708
64976	M4	163.6	0.137
64976	O1	56.4	0.373
64976	M6	2.8	0.027
64976	MK3	118.3	0.104
64976	S4	84.7	0.031
64976	MN4	137	0.053
64976	S6	152	0.005
64976	2N2	53.1	0.072
64976	OO1	50.7	0.043
64976	M1	96	0.017
64976	J1	127.6	0.037
64976	Q1	38.7	0.036
64976	2Q1	19	0.017
64976	P1	80.6	0.237
64976	2SM2	284.3	0.014
64976	M3	198.4	0.029
64976	L2	117.2	0.061
64976	2MK3	99.1	0.03
64976	K2	74.8	0.159
64976	M8	36.4	0.031
64976	MS4	175.3	0.075
64977	M2	75.3	2.039
64977	S2	97	0.501
64977	N2	52.3	0.325
64977	K1	77.2	0.703
64977	M4	161.1	0.149
64977	O1	56	0.363
64977	M6	10.8	0.025
64977	MK3	115.2	0.112
64977	S4	83.5	0.032
64977	MN4	135.9	0.056
64977	S6	158.1	0.005
64977	2N2	53.8	0.072
64977	OO1	50.1	0.045
64977	M1	97.2	0.018
64977	J1	126	0.037
64977	Q1	42	0.037
64977	2Q1	15.2	0.016
64977	P1	80.3	0.231
64977	2SM2	285.3	0.012
64977	M3	199.5	0.029
64977	L2	118	0.061
64977	2MK3	97.2	0.03
64977	K2	72.4	0.16
64977	M8	40.5	0.03
64977	MS4	175.2	0.08
64978	M2	74.8	2.033
64978	S2	96.4	0.495
64978	N2	51.9	0.321
64978	K1	76.9	0.697
64978	M4	159.1	0.163
64978	O1	55.5	0.352
64978	M6	19.7	0.024
64978	MK3	113.5	0.12
64978	S4	82.6	0.033
64978	MN4	135	0.059
64978	S6	158.1	0.005
64978	2N2	54.6	0.071
64978	OO1	49.4	0.048
64978	M1	98.5	0.018
64978	J1	126.3	0.036
64978	Q1	45	0.038
64978	2Q1	13.6	0.015
64978	P1	80.1	0.224
64978	2SM2	289.5	0.011
64978	M3	200.4	0.029
64978	L2	118.6	0.061
64978	2MK3	94.8	0.029
64978	K2	70.4	0.159
64978	M8	45.6	0.029
64978	MS4	174.8	0.084
64979	M2	74.3	2.025
64979	S2	95.6	0.488
64979	N2	51.6	0.317
64979	K1	76.7	0.688
64979	M4	157.5	0.179
64979	O1	55.2	0.34
64979	M6	29.7	0.023
64979	MK3	112.6	0.128
64979	S4	81.3	0.034
64979	MN4	134.3	0.062
64979	S6	161.4	0.005
64979	2N2	56.2	0.071
64979	OO1	47.6	0.05
64979	M1	100.7	0.018
64979	J1	125	0.035
64979	Q1	48.5	0.039
64979	2Q1	15.7	0.015
64979	P1	79.7	0.218
64979	2SM2	289.5	0.009
64979	M3	201.2	0.029
64979	L2	119.4	0.061
64979	2MK3	92.3	0.029
64979	K2	68.4	0.157
64979	M8	51.6	0.027
64979	MS4	174.5	0.088
64980	M2	73.8	2.013
64980	S2	94.6	0.478
64980	N2	51.2	0.312
64980	K1	76.3	0.678
64980	M4	156.6	0.195
64980	O1	54.8	0.326
64980	M6	38	0.022
64980	MK3	112.6	0.136
64980	S4	81.9	0.035
64980	MN4	133.2	0.066
64980	S6	154.8	0.004
64980	2N2	58.8	0.068
64980	OO1	46.5	0.051
64980	M1	103.3	0.018
64980	J1	121.3	0.034
64980	Q1	50.2	0.038
64980	2Q1	18.9	0.016
64980	P1	79.8	0.209
64980	2SM2	290.4	0.008
64980	M3	201.6	0.029
64980	L2	120.8	0.061
64980	2MK3	89.4	0.029
64980	K2	65.5	0.151
64980	M8	60.2	0.024
64980	MS4	173.9	0.093
64981	M2	73.4	1.999
64981	S2	93.6	0.467
64981	N2	50.5	0.307
64981	K1	75.7	0.666
64981	M4	156.2	0.213
64981	O1	54.7	0.31
64981	M6	42.7	0.021
64981	MK3	113.3	0.144
64981	S4	83.9	0.037
64981	MN4	131.6	0.071
64981	S6	133.7	0.003
64981	2N2	63.3	0.066
64981	OO1	46.2	0.052
64981	M1	105	0.018
64981	J1	115.7	0.032
64981	Q1	50.9	0.038
64981	2Q1	28.4	0.015
64981	P1	80.5	0.2
64981	2SM2	295.2	0.008
64981	M3	201.2	0.029
64981	L2	121.5	0.062
64981	2MK3	87.2	0.033
64981	K2	62.7	0.142
64981	M8	73.8	0.022
64981	MS4	173	0.098
64982	M2	72.9	1.981
64982	S2	92.2	0.457
64982	N2	49.8	0.303
64982	K1	75.2	0.652
64982	M4	156.1	0.23
64982	O1	54.3	0.292
64982	M6	41.6	0.021
64982	MK3	114	0.152
64982	S4	84.3	0.039
64982	MN4	130.3	0.076
64982	2N2	68.3	0.063
64982	OO1	44.9	0.052
64982	M1	108.3	0.018
64982	J1	109.9	0.032
64982	Q1	49.9	0.037
64982	2Q1	37.9	0.014
64982	P1	80.3	0.191
64982	2SM2	294.3	0.009
64982	M3	200.5	0.029
64982	L2	122.7	0.062
64982	2MK3	85.8	0.036
64982	K2	59.5	0.135
64982	M8	93.1	0.021
64982	MS4	171.5	0.104
64983	M2	71.9	1.942
64983	S2	91.2	0.441
64983	N2	48.7	0.297
64983	K1	73.4	0.634
64983	M4	160.9	0.247
64983	O1	49.8	0.269
64983	M6	27.4	0.005
64983	MK3	118.3	0.134
64983	S4	84.4	0.038
64983	MN4	135.8	0.078
64983	2N2	73.4	0.067
64983	OO1	52.9	0.052
64983	M1	110.3	0.017
64983	J1	101	0.03
64983	Q1	42.7	0.035
64983	2Q1	50.5	0.016
64983	P1	79	0.178
64983	2SM2	290.3	0.011
64983	M3	209.2	0.027
64983	L2	125.1	0.064
64983	2MK3	89.4	0.022
64983	K2	63.8	0.13
64983	M8	120.9	0.025
64983	MS4	179.3	0.114
64984	M2	83.8	0.26
64984	S2	110.2	0.103
64984	N2	70.1	0.061
64984	K1	62.9	0.198
64984	M4	241.9	0.108
64984	O1	62.9	0.151
64984	M6	38.2	0.041
64984	MK3	202	0.112
64984	S4	182.9	0.02
64984	MN4	230.9	0.042
64984	S6	350	0.005
64984	2N2	204.3	0.026
64984	OO1	125.1	0.016
64984	M1	146.6	0.008
64984	J1	85.1	0.002
64984	Q1	59.4	0.031
64984	2Q1	275.1	0.028
64984	P1	108.8	0.039
64984	2SM2	337.4	0.017
64984	M3	320.2	0.033
64984	L2	34.9	0.005
64984	2MK3	184	0.048
64984	K2	66.1	0.044
64984	M8	178	0.009
64984	MS4	251.1	0.049
64985	M2	84.7	0.262
64985	S2	110.3	0.098
64985	N2	69.9	0.058
64985	K1	66.3	0.19
64985	M4	237.7	0.102
64985	O1	65.6	0.144
64985	M6	28.9	0.033
64985	MK3	201.6	0.105
64985	S4	185.4	0.021
64985	MN4	229.8	0.038
64985	S6	2.3	0.006
64985	2N2	206.7	0.032
64985	OO1	125.8	0.022
64985	M1	156	0.01
64985	J1	69.8	0.003
64985	Q1	56.8	0.032
64985	2Q1	276.6	0.031
64985	P1	109.6	0.038
64985	2SM2	344.3	0.015
64985	M3	324.4	0.031
64985	L2	69	0.007
64985	2MK3	191.6	0.044
64985	K2	56.3	0.048
64985	M8	170.5	0.007
64985	MS4	249.1	0.044
64986	M2	85.6	0.263
64986	S2	108.5	0.091
64986	N2	70.3	0.055
64986	K1	71.2	0.18
64986	M4	233.5	0.094
64986	O1	68	0.138
64986	M6	18.5	0.027
64986	MK3	201.1	0.096
64986	S4	185.2	0.021
64986	MN4	228	0.034
64986	S6	16	0.007
64986	2N2	208.2	0.037
64986	OO1	131.4	0.026
64986	M1	165.1	0.012
64986	J1	62.8	0.003
64986	Q1	53.2	0.033
64986	2Q1	278.9	0.033
64986	P1	106.9	0.036
64986	2SM2	353.1	0.013
64986	M3	326.1	0.029
64986	L2	95.2	0.009
64986	2MK3	198.7	0.04
64986	K2	46.1	0.054
64986	M8	162.4	0.006
64986	MS4	247.4	0.038
64987	M2	86.7	0.265
64987	S2	108.2	0.083
64987	N2	70.2	0.052
64987	K1	77.1	0.172
64987	M4	228.8	0.085
64987	O1	70.1	0.131
64987	M6	4.9	0.02
64987	MK3	200.7	0.086
64987	S4	186.6	0.021
64987	MN4	227.4	0.029
64987	S6	27.7	0.008
64987	2N2	208.9	0.039
64987	OO1	141.1	0.03
64987	M1	172.8	0.013
64987	J1	42.5	0.003
64987	Q1	49.4	0.033
64987	2Q1	279.2	0.033
64987	P1	102.3	0.035
64987	2SM2	12.6	0.01
64987	M3	329.1	0.026
64987	L2	110.2	0.013
64987	2MK3	207.5	0.037
64987	K2	38.9	0.055
64987	M8	156.5	0.004
64987	MS4	246.8	0.033
64988	M2	88	0.267
64988	S2	108.3	0.078
64988	N2	69.5	0.049
64988	K1	83.9	0.163
64988	M4	223.5	0.076
64988	O1	71.9	0.124
64988	M6	341.1	0.015
64988	MK3	200.1	0.074
64988	S4	187.3	0.02
64988	MN4	230.3	0.024
64988	S6	36.9	0.008
64988	2N2	210.1	0.04
64988	OO1	152.7	0.038
64988	M1	178.6	0.015
64988	J1	43.1	0.004
64988	Q1	44.2	0.033
64988	2Q1	277.7	0.032
64988	P1	94.3	0.035
64988	2SM2	31.7	0.01
64988	M3	332.1	0.022
64988	L2	122.4	0.016
64988	2MK3	214.2	0.034
64988	K2	35.3	0.055
64988	M8	142.4	0.003
64988	MS4	245.6	0.029
64989	M2	89.7	0.268
64989	S2	107.4	0.075
64989	N2	69.7	0.046
64989	K1	89.9	0.155
64989	M4	218.3	0.067
64989	O1	72.4	0.118
64989	M6	308.3	0.014
64989	MK3	199	0.06
64989	S4	190.7	0.019
64989	MN4	233.2	0.018
64989	S6	44.2	0.008
64989	2N2	213.1	0.037
64989	OO1	162.7	0.047
64989	M1	180.5	0.015
64989	J1	37	0.007
64989	Q1	40.5	0.033
64989	2Q1	276.7	0.029
64989	P1	89.1	0.038
64989	2SM2	47.6	0.009
64989	M3	329.2	0.018
64989	L2	132	0.02
64989	2MK3	217.6	0.031
64989	K2	36.7	0.059
64989	M8	121.6	0.002
64989	MS4	244.8	0.025
64990	M2	91.5	0.267
64990	S2	107.7	0.071
64990	N2	70	0.043
64990	K1	94.6	0.148
64990	M4	211.9	0.057
64990	O1	71.6	0.113
64990	M6	283.2	0.017
64990	MK3	198.2	0.046
64990	S4	191.5	0.017
64990	MN4	235.6	0.013
64990	S6	55.1	0.008
64990	2N2	219.8	0.032
64990	OO1	170.9	0.05
64990	M1	181.2	0.015
64990	J1	44.8	0.007
64990	Q1	35.9	0.031
64990	2Q1	274.4	0.025
64990	P1	89.3	0.041
64990	2SM2	56.2	0.009
64990	M3	319	0.015
64990	L2	139.9	0.023
64990	2MK3	218.3	0.026
64990	K2	39.6	0.058
64990	M8	78.6	0.001
64990	MS4	244.6	0.021
64991	M2	93.3	0.266
64991	S2	106.6	0.068
64991	N2	70	0.043
64991	K1	97.9	0.144
64991	M4	203.5	0.047
64991	O1	69.8	0.111
64991	M6	268.2	0.02
64991	MK3	198.8	0.034
64991	S4	193.6	0.014
64991	MN4	238	0.008
64991	S6	68.7	0.008
64991	2N2	230.6	0.026
64991	OO1	179.3	0.046
64991	M1	177.8	0.013
64991	J1	64.2	0.006
64991	Q1	33.1	0.029
64991	2Q1	270.2	0.02
64991	P1	94.6	0.044
64991	2SM2	61.7	0.009
64991	M3	304.9	0.014
64991	L2	147.6	0.026
64991	2MK3	216.9	0.024
64991	K2	43.9	0.058
64991	M8	44.3	0.002
64991	MS4	242.1	0.017
64992	M2	94.6	0.263
64992	S2	106.5	0.064
64992	N2	70	0.041
64992	K1	100.2	0.141
64992	M4	191.7	0.037
64992	O1	68.1	0.113
64992	M6	262	0.02
64992	MK3	201.9	0.025
64992	S4	197.4	0.011
64992	MN4	243.2	0.004
64992	S6	77.9	0.01
64992	2N2	245.5	0.019
64992	OO1	187.9	0.038
64992	M1	168.8	0.011
64992	J1	99.2	0.006
64992	Q1	35.7	0.028
64992	2Q1	261.7	0.016
64992	P1	103	0.045
64992	2SM2	71.9	0.008
64992	M3	293.7	0.014
64992	L2	152.9	0.028
64992	2MK3	217.1	0.022
64992	K2	48.8	0.055
64992	M8	34.3	0.003
64992	MS4	236	0.011
64993	M2	95.3	0.259
64993	S2	106.8	0.06
64993	N2	70.4	0.04
64993	K1	101.7	0.135
64993	M4	171	0.028
64993	O1	67.3	0.118
64993	M6	256.9	0.019
64993	MK3	212.7	0.021
64993	S4	205.6	0.01
64993	MN4	270.1	0.002
64993	S6	81.4	0.01
64993	2N2	273.1	0.014
64993	OO1	195.7	0.027
64993	M1	146.6	0.009
64993	J1	124.2	0.008
64993	Q1	40.1	0.027
64993	2Q1	255.8	0.014
64993	P1	111.3	0.049
64993	2SM2	82.5	0.007
64993	M3	290.1	0.015
64993	L2	157.5	0.029
64993	2MK3	221.4	0.022
64993	K2	53.1	0.049
64993	M8	30.1	0.004
64993	MS4	221.5	0.007
64994	M2	95.5	0.254
64994	S2	108.4	0.058
64994	N2	70.4	0.039
64994	K1	102.6	0.13
64994	M4	141.2	0.025
64994	O1	67.6	0.122
64994	M6	250.9	0.016
64994	MK3	226.5	0.021
64994	S4	215.6	0.009
64994	MN4	295.9	0.003
64994	S6	84.3	0.01
64994	2N2	313.6	0.012
64994	OO1	204.3	0.016
64994	M1	121.6	0.009
64994	J1	143.8	0.01
64994	Q1	46.4	0.026
64994	2Q1	245	0.011
64994	P1	119.1	0.055
64994	2SM2	87.3	0.006
64994	M3	294.6	0.017
64994	L2	161	0.028
64994	2MK3	228.3	0.026
64994	K2	59.2	0.047
64994	M8	18	0.004
64994	MS4	198	0.005
64995	M2	95.3	0.249
64995	S2	112.5	0.058
64995	N2	70.9	0.036
64995	K1	105.5	0.123
64995	M4	117.3	0.029
64995	O1	69.2	0.125
64995	M6	236.2	0.013
64995	MK3	240.5	0.026
64995	S4	223.5	0.011
64995	MN4	303.7	0.004
64995	S6	86.5	0.008
64995	2N2	344.6	0.018
64995	OO1	229.8	0.007
64995	M1	97.6	0.01
64995	J1	143.7	0.011
64995	Q1	48.3	0.023
64995	2Q1	222.9	0.009
64995	P1	121.4	0.064
64995	2SM2	78.4	0.005
64995	M3	303.3	0.02
64995	L2	162.1	0.025
64995	2MK3	232.3	0.032
64995	K2	67.2	0.044
64995	M8	6.3	0.005
64995	MS4	164.4	0.005
64996	M2	94.5	0.243
64996	S2	115.9	0.059
64996	N2	75.4	0.033
64996	K1	108.5	0.119
64996	M4	103.8	0.033
64996	O1	71.7	0.121
64996	M6	216.5	0.013
64996	MK3	250.7	0.035
64996	S4	227.7	0.012
64996	MN4	295	0.005
64996	S6	82.7	0.007
64996	2N2	355.4	0.025
64996	OO1	327.8	0.006
64996	M1	78	0.012
64996	J1	145.8	0.012
64996	Q1	54	0.02
64996	2Q1	208.2	0.008
64996	P1	122.1	0.074
64996	2SM2	60	0.005
64996	M3	308	0.023
64996	L2	163	0.021
64996	2MK3	232.6	0.039
64996	K2	71.9	0.044
64996	M8	349.1	0.005
64996	MS4	140.3	0.008
64997	M2	93	0.237
64997	S2	118.3	0.058
64997	N2	82.2	0.032
64997	K1	111.1	0.119
64997	M4	95.5	0.036
64997	O1	75.1	0.112
64997	M6	198	0.016
64997	MK3	257.3	0.047
64997	S4	228.6	0.012
64997	MN4	280	0.005
64997	S6	77	0.007
64997	2N2	354.7	0.032
64997	OO1	7.2	0.011
64997	M1	65.3	0.014
64997	J1	152.8	0.012
64997	Q1	70.6	0.018
64997	2Q1	192.8	0.008
64997	P1	121	0.082
64997	2SM2	58.9	0.006
64997	M3	310.8	0.028
64997	L2	162.9	0.018
64997	2MK3	230.1	0.048
64997	K2	71.1	0.046
64997	M8	318.9	0.005
64997	MS4	136.9	0.013
64998	M2	90.9	0.229
64998	S2	119.4	0.059
64998	N2	87.5	0.032
64998	K1	113.6	0.123
64998	M4	91.7	0.038
64998	O1	80.5	0.101
64998	M6	188.9	0.02
64998	MK3	261.1	0.062
64998	S4	229.1	0.012
64998	MN4	275.9	0.004
64998	S6	79.8	0.006
64998	2N2	350.2	0.039
64998	OO1	19	0.02
64998	M1	56.3	0.015
64998	J1	156.9	0.012
64998	Q1	82	0.019
64998	2Q1	171.3	0.011
64998	P1	117.1	0.085
64998	2SM2	58	0.007
64998	M3	311.3	0.033
64998	L2	161.9	0.017
64998	2MK3	227.2	0.058
64998	K2	67.3	0.051
64998	M8	282.9	0.006
64998	MS4	136.8	0.016
64999	M2	88.5	0.221
64999	S2	122.5	0.06
64999	N2	88.1	0.033
64999	K1	113.9	0.133
64999	M4	92.1	0.04
64999	O1	88.1	0.087
64999	M6	183.6	0.024
64999	MK3	262.4	0.079
64999	S4	233.8	0.012
64999	MN4	23.3	0.001
64999	S6	60.6	0.004
64999	2N2	343.8	0.046
64999	OO1	19.7	0.026
64999	M1	45.5	0.016
64999	J1	160.5	0.014
64999	Q1	82.4	0.025
64999	2Q1	158.1	0.014
64999	P1	113.2	0.085
64999	2SM2	44.6	0.009
64999	M3	313	0.037
64999	L2	163.1	0.018
64999	2MK3	226	0.066
64999	K2	64	0.051
64999	M8	276.3	0.008
64999	MS4	138.1	0.019
65000	M2	85.1	0.209
65000	S2	126.4	0.06
65000	N2	86	0.035
65000	K1	113.4	0.146
65000	M4	95.6	0.04
65000	O1	98.2	0.073
65000	M6	181.7	0.028
65000	MK3	261.6	0.095
65000	S4	234.3	0.01
65000	MN4	61.6	0.005
65000	S6	346.1	0.005
65000	2N2	333.9	0.053
65000	OO1	20.6	0.033
65000	M1	29.1	0.015
65000	J1	173.5	0.014
65000	Q1	77.3	0.031
65000	2Q1	152.5	0.019
65000	P1	107.4	0.083
65000	2SM2	20	0.011
65000	M3	318.1	0.038
65000	L2	159.3	0.022
65000	2MK3	226.3	0.073
65000	K2	59.1	0.046
65000	M8	268.4	0.009
65000	MS4	135.3	0.021
65001	M2	62.5	0.356
65001	S2	62.8	0.081
65001	N2	23.9	0.053
65001	K1	36.9	0.106
65001	M4	310.6	0.019
65001	O1	39	0.076
65001	M6	103.8	0.014
65001	MK3	286.8	0.051
65001	S4	287.5	0.001
65001	MN4	286.9	0.011
65001	S6	18.7	0.004
65001	2N2	45.6	0.035
65001	OO1	37.8	0.048
65001	M1	48.7	0.001
65001	J1	256.9	0.007
65001	Q1	12.7	0.008
65001	2Q1	342.5	0.021
65001	2SM2	20.2	0.003
65001	M3	343.3	0.013
65001	L2	132	0.027
65001	2MK3	316.5	0.014
65001	K2	54.2	0.052
65001	M8	67.9	0.01
65001	MS4	303.8	0.009
65002	M2	64.2	0.346
65002	S2	64.6	0.073
65002	N2	27.3	0.048
65002	K1	41.7	0.104
65002	M4	308.4	0.018
65002	O1	39.5	0.071
65002	M6	105.5	0.012
65002	MK3	283.7	0.05
65002	S4	312.2	0.001
65002	MN4	289.3	0.011
65002	S6	23.9	0.004
65002	2N2	38.7	0.035
65002	OO1	37.7	0.047
65002	M1	67.1	0.002
65002	J1	270.4	0.006
65002	Q1	2.1	0.01
65002	2Q1	339.6	0.015
65002	2SM2	63.5	0.002
65002	M3	350	0.013
65002	L2	128.5	0.025
65002	2MK3	287.1	0.016
65002	K2	51.3	0.044
65002	M8	70.2	0.011
65002	MS4	302.1	0.006
65003	M2	66	0.334
65003	S2	65.7	0.068
65003	N2	31.1	0.043
65003	K1	47.4	0.102
65003	M4	302.1	0.016
65003	O1	42.3	0.064
65003	M6	104.6	0.012
65003	MK3	279.1	0.048
65003	S4	42.3	0.001
65003	MN4	295.6	0.012
65003	S6	22.9	0.005
65003	2N2	34	0.033
65003	OO1	35.9	0.044
65003	M1	74	0.003
65003	J1	287.1	0.007
65003	Q1	6.9	0.011
65003	2Q1	326.5	0.006
65003	2SM2	109.2	0.002
65003	M3	357	0.014
65003	L2	129.5	0.023
65003	2MK3	267.6	0.023
65003	K2	47	0.04
65003	M8	76.4	0.011
65003	MS4	293.7	0.003
65004	M2	67.8	0.323
65004	S2	70.6	0.063
65004	N2	35	0.04
65004	K1	53.5	0.103
65004	M4	294.3	0.016
65004	O1	45.9	0.058
65004	M6	98.4	0.012
65004	MK3	275.2	0.045
65004	S4	59.6	0.002
65004	MN4	297.5	0.012
65004	S6	22.6	0.006
65004	2N2	29.4	0.031
65004	OO1	37.8	0.04
65004	M1	92.2	0.002
65004	J1	291.3	0.008
65004	Q1	22.2	0.012
65004	2Q1	209.7	0.003
65004	2SM2	133.1	0.003
65004	M3	0.4	0.015
65004	L2	133.3	0.023
65004	2MK3	260	0.032
65004	K2	47.1	0.034
65004	M8	82	0.012
65004	MS4	312.4	0.002
65005	M2	69.9	0.312
65005	S2	75.5	0.061
65005	N2	37.8	0.038
65005	K1	58.9	0.107
65005	M4	286.1	0.017
65005	O1	48.8	0.051
65005	M6	91.4	0.012
65005	MK3	270.1	0.04
65005	S4	66.6	0.004
65005	MN4	292.1	0.013
65005	S6	23	0.007
65005	2N2	27.2	0.03
65005	OO1	43.4	0.036
65005	M1	96.5	0.003
65005	J1	285.2	0.008
65005	Q1	37.6	0.012
65005	2Q1	181.7	0.007
65005	2SM2	163.5	0.004
65005	M3	4.1	0.016
65005	L2	135.9	0.023
65005	2MK3	259.2	0.038
65005	K2	50.1	0.034
65005	M8	82.9	0.011
65005	MS4	5.8	0.002
65006	M2	71.8	0.301
65006	S2	81.1	0.059
65006	N2	38.9	0.036
65006	K1	64.3	0.111
65006	M4	284	0.017
65006	O1	47.5	0.043
65006	M6	86.5	0.012
65006	MK3	264.9	0.032
65006	S4	76.4	0.005
65006	MN4	286.8	0.013
65006	S6	24.3	0.007
65006	2N2	29	0.028
65006	OO1	55.4	0.034
65006	M1	105	0.003
65006	J1	275.5	0.008
65006	Q1	42.9	0.01
65006	2Q1	176.5	0.008
65006	2SM2	184	0.004
65006	M3	10.4	0.015
65006	L2	135.5	0.021
65006	2MK3	261.1	0.041
65006	K2	56.6	0.032
65006	M8	78.2	0.009
65006	MS4	20	0.005
65007	M2	72.8	0.288
65007	S2	82.7	0.053
65007	N2	39.3	0.034
65007	K1	69.1	0.114
65007	M4	284.3	0.017
65007	O1	40.8	0.034
65007	M6	81.4	0.011
65007	MK3	263.5	0.023
65007	S4	82.7	0.007
65007	MN4	284.2	0.013
65007	S6	26.3	0.006
65007	2N2	34.1	0.024
65007	OO1	75.9	0.034
65007	M1	117.4	0.003
65007	J1	264.9	0.005
65007	Q1	36.9	0.007
65007	2Q1	177.3	0.006
65007	2SM2	176.2	0.004
65007	M3	19.4	0.012
65007	L2	130.5	0.021
65007	2MK3	264.3	0.039
65007	K2	56.6	0.028
65007	M8	77.2	0.008
65007	MS4	36.4	0.007
65008	M2	73	0.273
65008	S2	82.4	0.049
65008	N2	38.5	0.032
65008	K1	72.7	0.113
65008	M4	287.8	0.017
65008	O1	23.7	0.025
65008	M6	63	0.01
65008	MK3	274.4	0.015
65008	S4	84.3	0.009
65008	MN4	283.6	0.01
65008	S6	10.7	0.005
65008	2N2	46.4	0.02
65008	OO1	97.2	0.039
65008	M1	123.8	0.003
65008	J1	272.9	0.004
65008	Q1	3.2	0.005
65008	2Q1	173.4	0.004
65008	2SM2	169.9	0.006
65008	M3	35	0.01
65008	L2	123.1	0.02
65008	2MK3	271.5	0.033
65008	K2	63.2	0.025
65008	M8	86	0.007
65008	MS4	46.3	0.011
65009	M2	72.4	0.258
65009	S2	82.7	0.048
65009	N2	37.5	0.031
65009	K1	75.8	0.113
65009	M4	295.4	0.014
65009	O1	355.3	0.023
65009	M6	42	0.01
65009	MK3	309.2	0.013
65009	S4	83.6	0.011
65009	MN4	289.3	0.006
65009	S6	352.8	0.005
65009	2N2	62.6	0.017
65009	OO1	114.2	0.043
65009	M1	111	0.004
65009	J1	297.9	0.004
65009	Q1	334.3	0.007
65009	2Q1	185	0.004
65009	2SM2	168	0.009
65009	M3	58	0.01
65009	L2	115.3	0.019
65009	2MK3	286.3	0.026
65009	K2	74.9	0.025
65009	M8	96.1	0.004
65009	MS4	49.1	0.015
65010	M2	70.9	0.245
65010	S2	81.5	0.047
65010	N2	38.6	0.032
65010	K1	78.2	0.112
65010	M4	317.9	0.011
65010	O1	332.9	0.029
65010	M6	23.2	0.011
65010	MK3	339.7	0.018
65010	S4	80.3	0.012
65010	MN4	0.9	0.002
65010	S6	348.7	0.005
65010	2N2	76.2	0.012
65010	OO1	130	0.047
65010	M1	89.9	0.005
65010	J1	337.2	0.004
65010	Q1	331.2	0.008
65010	2Q1	200	0.005
65010	2SM2	165.8	0.011
65010	M3	81.8	0.011
65010	L2	111.8	0.017
65010	2MK3	307.7	0.021
65010	K2	79.1	0.025
65010	M8	115.2	0.001
65010	MS4	51.6	0.019
65011	M2	69.5	0.232
65011	S2	79.7	0.047
65011	N2	42.6	0.033
65011	K1	79.6	0.112
65011	M4	358.4	0.012
65011	O1	326.6	0.039
65011	M6	9.7	0.011
65011	MK3	0	0.027
65011	S4	77	0.013
65011	MN4	66.3	0.006
65011	S6	355.3	0.003
65011	2N2	91.2	0.006
65011	OO1	141.5	0.048
65011	M1	69.9	0.007
65011	J1	358.2	0.008
65011	Q1	348.6	0.007
65011	2Q1	212.3	0.006
65011	2SM2	166.3	0.013
65011	M3	95.7	0.013
65011	L2	115.8	0.015
65011	2MK3	326.9	0.018
65011	K2	74.9	0.021
65011	M8	258.8	0.002
65011	MS4	54.5	0.022
65012	M2	67.8	0.224
65012	S2	75.2	0.052
65012	N2	49.3	0.034
65012	K1	79.1	0.115
65012	M4	26.3	0.016
65012	O1	327.5	0.045
65012	M6	355.3	0.012
65012	MK3	11.3	0.037
65012	S4	79.2	0.014
65012	MN4	73.8	0.01
65012	S6	44.8	0.002
65012	2N2	310.7	0.001
65012	OO1	154.9	0.045
65012	M1	58.2	0.008
65012	J1	9.2	0.013
65012	Q1	21.1	0.01
65012	2Q1	230.2	0.008
65012	2SM2	163.2	0.014
65012	M3	107.1	0.014
65012	L2	122.4	0.011
65012	2MK3	344.7	0.016
65012	K2	59	0.021
65012	M8	274.4	0.004
65012	MS4	58.3	0.024
65013	M2	66.6	0.221
65013	S2	75.9	0.059
65013	N2	58.4	0.036
65013	K1	77.1	0.124
65013	M4	42	0.021
65013	O1	335.9	0.047
65013	M6	346.8	0.015
65013	MK3	17	0.045
65013	S4	81.4	0.014
65013	MN4	71.1	0.012
65013	S6	66.4	0.002
65013	2N2	283.4	0.009
65013	OO1	168.5	0.046
65013	M1	59.7	0.008
65013	J1	18.1	0.019
65013	Q1	32.2	0.013
65013	2Q1	244.3	0.007
65013	2SM2	154.8	0.014
65013	M3	113.3	0.015
65013	L2	126.8	0.007
65013	2MK3	354.9	0.016
65013	K2	52.8	0.023
65013	M8	275.9	0.006
65013	MS4	62.3	0.025
65014	M2	66.7	0.219
65014	S2	81.2	0.064
65014	N2	68.6	0.04
65014	K1	74.3	0.138
65014	M4	51.8	0.025
65014	O1	352.3	0.048
65014	M6	346.1	0.018
65014	MK3	18.7	0.052
65014	S4	81.3	0.014
65014	MN4	63.6	0.013
65014	S6	117.8	0.002
65014	2N2	281.8	0.015
65014	OO1	174.7	0.051
65014	M1	67.7	0.008
65014	J1	18.9	0.024
65014	Q1	25.7	0.016
65014	2Q1	196.7	0.002
65014	2SM2	146.9	0.014
65014	M3	113.2	0.017
65014	L2	106	0.004
65014	2MK3	354.4	0.015
65014	K2	52.2	0.02
65014	M8	272.8	0.009
65014	MS4	63.5	0.026
65015	M2	69.2	0.22
65015	S2	87.3	0.072
65015	N2	76.3	0.044
65015	K1	71.9	0.155
65015	M4	59.4	0.033
65015	O1	10.6	0.054
65015	M6	345	0.02
65015	MK3	20.6	0.06
65015	S4	80	0.013
65015	MN4	55.1	0.016
65015	S6	152.3	0.002
65015	2N2	272.7	0.018
65015	OO1	174.1	0.055
65015	M1	71.4	0.009
65015	J1	18.1	0.03
65015	Q1	15	0.017
65015	2Q1	99.8	0.008
65015	2SM2	146.2	0.014
65015	M3	110	0.019
65015	L2	37.7	0.004
65015	2MK3	342.2	0.015
65015	K2	67.5	0.017
65015	M8	268.4	0.011
65015	MS4	64	0.026
65016	M2	74.8	0.224
65016	S2	93.5	0.084
65016	N2	80	0.048
65016	K1	70.1	0.172
65016	M4	62.3	0.044
65016	O1	21.6	0.065
65016	M6	339.9	0.021
65016	MK3	26.7	0.072
65016	S4	71.9	0.013
65016	MN4	50.7	0.022
65016	S6	170.1	0.003
65016	2N2	251.9	0.02
65016	OO1	174	0.061
65016	M1	63	0.01
65016	J1	17.6	0.036
65016	Q1	3.6	0.019
65016	2Q1	96.8	0.018
65016	2SM2	147	0.012
65016	M3	109.5	0.019
65016	L2	5.5	0.005
65016	2MK3	333.6	0.017
65016	K2	102.9	0.02
65016	M8	267.2	0.013
65016	MS4	64.8	0.025
65017	M2	82.7	0.239
65017	S2	98.2	0.098
65017	N2	81.4	0.052
65017	K1	68.6	0.189
65017	M4	66.1	0.061
65017	O1	27.4	0.072
65017	M6	333.6	0.021
65017	MK3	35.5	0.09
65017	S4	63.1	0.014
65017	MN4	51.2	0.03
65017	S6	181.3	0.003
65017	2N2	228	0.025
65017	OO1	173.6	0.068
65017	M1	57.1	0.012
65017	J1	16.9	0.041
65017	Q1	0.1	0.023
65017	2Q1	99.5	0.026
65017	2SM2	151.2	0.01
65017	M3	117.8	0.022
65017	L2	331.3	0.006
65017	2MK3	339.2	0.018
65017	K2	123.7	0.032
65017	M8	265.3	0.017
65017	MS4	66.3	0.025
65018	M2	91.3	0.274
65018	S2	102.8	0.108
65018	N2	81	0.061
65018	K1	68.7	0.209
65018	M4	71.6	0.084
65018	O1	30.8	0.073
65018	M6	329.3	0.021
65018	MK3	45.9	0.122
65018	S4	56.7	0.016
65018	MN4	52.4	0.04
65018	S6	212.2	0.003
65018	2N2	211	0.032
65018	OO1	169.8	0.074
65018	M1	58.8	0.011
65018	J1	14.9	0.041
65018	Q1	0.2	0.027
65018	2Q1	101.4	0.032
65018	2SM2	178.9	0.007
65018	M3	132.1	0.029
65018	L2	285.9	0.009
65018	2MK3	2.3	0.022
65018	K2	132.9	0.048
65018	M8	260.6	0.019
65018	MS4	66	0.028
65019	M2	47	1.391
65019	S2	76.9	0.313
65019	N2	33.9	0.194
65019	K1	69.8	0.34
65019	M4	22.2	0.088
65019	O1	71.3	0.131
65019	M6	45.5	0.142
65019	MK3	313.8	0.095
65019	S4	69.1	0.017
65019	MN4	352.7	0.032
65019	S6	109.5	0.008
65019	2N2	339.8	0.081
65019	OO1	51.7	0.037
65019	M1	99.5	0.012
65019	J1	130.1	0.028
65019	Q1	63.9	0.024
65019	2Q1	212.8	0.011
65019	P1	66.2	0.107
65019	2SM2	354.4	0.006
65019	M3	350.9	0.024
65019	L2	58.6	0.061
65019	2MK3	215	0.123
65019	K2	49.4	0.099
65019	M8	24.5	0.018
65019	MS4	24.6	0.074
65020	M2	49.3	1.79
65020	S2	78.1	0.398
65020	N2	36.4	0.243
65020	K1	69.8	0.43
65020	M4	25.8	0.083
65020	O1	76.8	0.174
65020	M6	44.2	0.182
65020	MK3	313	0.126
65020	S4	64.3	0.021
65020	MN4	356.4	0.036
65020	S6	109.9	0.004
65020	2N2	344.4	0.107
65020	OO1	52.4	0.056
65020	M1	107.5	0.017
65020	J1	137.4	0.039
65020	Q1	66	0.031
65020	2Q1	198.1	0.019
65020	P1	71.5	0.143
65020	2SM2	29.2	0.004
65020	M3	1.5	0.032
65020	L2	62.3	0.081
65020	2MK3	217.7	0.155
65020	K2	54.1	0.129
65020	M8	46.6	0.006
65020	MS4	25	0.092
65021	M2	50.8	1.809
65021	S2	77.2	0.398
65021	N2	35.1	0.249
65021	K1	71.5	0.442
65021	M4	23.5	0.051
65021	O1	74.1	0.174
65021	M6	45	0.176
65021	MK3	306.7	0.135
65021	S4	67.6	0.02
65021	MN4	6.5	0.034
65021	S6	107.4	0.005
65021	2N2	351	0.102
65021	OO1	57.7	0.06
65021	M1	106	0.019
65021	J1	134	0.033
65021	Q1	63.3	0.034
65021	2Q1	196.5	0.016
65021	P1	72.5	0.137
65021	2SM2	67.5	0.004
65021	M3	2.2	0.031
65021	L2	72.8	0.082
65021	2MK3	218.7	0.148
65021	K2	53.1	0.139
65021	M8	162.8	0.011
65021	MS4	23.7	0.082
65022	M2	39.8	0.861
65022	S2	59.5	0.165
65022	N2	26.9	0.104
65022	K1	52.8	0.144
65022	M4	236.4	0.008
65022	O1	127.1	0.035
65022	M6	27.4	0.086
65022	MK3	304.5	0.024
65022	S4	44.7	0.006
65022	MN4	192.5	0.002
65022	S6	93.7	0.002
65022	2N2	357.1	0.052
65022	OO1	64	0.025
65022	M1	118.6	0.002
65022	J1	131.5	0.016
65022	Q1	98.6	0.006
65022	2Q1	151.7	0.007
65022	P1	66.6	0.046
65022	2SM2	226.7	0.006
65022	M3	341.5	0.01
65022	L2	62.1	0.053
65022	2MK3	219.7	0.057
65022	K2	38.3	0.064
65022	M8	210.4	0.007
65022	MS4	340.2	0.002
65023	M2	36.6	1.035
65023	S2	61.2	0.202
65023	N2	23.4	0.14
65023	K1	51.9	0.174
65023	M4	233.6	0.054
65023	O1	153.3	0.061
65023	M6	18.5	0.093
65023	MK3	288.6	0.05
65023	S4	66.7	0.01
65023	MN4	223.1	0.012
65023	S6	115.3	0.006
65023	2N2	348.4	0.063
65023	OO1	43.9	0.037
65023	M1	139.2	0.006
65023	J1	139.4	0.019
65023	Q1	162	0.011
65023	2Q1	180.1	0.008
65023	P1	62.2	0.062
65023	2SM2	218.7	0.01
65023	M3	346.3	0.015
65023	L2	47.9	0.064
65023	2MK3	204.8	0.071
65023	K2	35.4	0.061
65023	M8	198.4	0.017
65023	MS4	288.7	0.021
65024	M2	42.5	0.324
65024	S2	70.8	0.074
65024	N2	20.7	0.051
65024	K1	30.9	0.086
65024	M4	38.1	0.028
65024	O1	346.8	0.045
65024	M6	98.2	0.01
65024	MK3	311.5	0.017
65024	S4	79.7	0.004
65024	MN4	312.1	0.007
65024	S6	194.2	0.004
65024	2N2	353	0.019
65024	OO1	64.3	0.023
65024	M1	32.1	0.005
65024	J1	105.6	0.006
65024	Q1	71.4	0.01
65024	2Q1	312.5	0.006
65024	P1	89.1	0.031
65024	2SM2	199.5	0.002
65024	M3	309.7	0.01
65024	L2	36.5	0.012
65024	2MK3	199	0.025
65024	K2	56.4	0.032
65024	M8	86.2	0.004
65024	MS4	36.8	0.02
65025	M2	45.4	0.371
65025	S2	75.3	0.083
65025	N2	33	0.059
65025	K1	53.5	0.059
65025	M4	41.2	0.027
65025	O1	79.8	0.005
65025	M6	44.4	0.042
65025	MK3	267.9	0.04
65025	S4	35.5	0.004
65025	MN4	34.1	0.008
65025	S6	71.7	0.002
65025	2N2	335.1	0.025
65025	OO1	17.4	0.014
65025	M1	125.8	0.006
65025	J1	135	0.019
65025	Q1	54.1	0.014
65025	2Q1	182.8	0.001
65025	P1	64.2	0.03
65025	2SM2	326	0.001
65025	M3	332.9	0.011
65025	L2	43.9	0.017
65025	2MK3	216.9	0.044
65025	K2	51.8	0.042
65025	M8	64.6	0.007
65025	MS4	46.7	0.011
65026	M2	40.6	0.366
65026	S2	69.3	0.094
65026	N2	27.7	0.048
65026	K1	60.1	0.05
65026	M4	155.2	0.061
65026	O1	182.7	0.012
65026	M6	6.4	0.045
65026	MK3	243	0.04
65026	S4	84.8	0.005
65026	MN4	114.7	0.015
65026	S6	83.6	0.005
65026	2N2	322.3	0.022
65026	OO1	297.6	0.011
65026	M1	139	0.013
65026	J1	157.7	0.023
65026	Q1	295.2	0.014
65026	2Q1	133.4	0.011
65026	P1	39.3	0.021
65026	2SM2	319	0.006
65026	M3	314.9	0.014
65026	L2	99.3	0.013
65026	2MK3	217.9	0.043
65026	K2	62.9	0.05
65026	M8	114.2	0.01
65026	MS4	217.2	0.013
65027	M2	71.1	0.488
65027	S2	109.7	0.084
65027	N2	50.6	0.075
65027	K1	63.1	0.135
65027	M4	187.3	0.025
65027	O1	69.7	0.079
65027	M6	104	0.029
65027	MK3	231.2	0.008
65027	S4	18.7	0.016
65027	MN4	110.8	0.004
65027	S6	181.8	0.006
65027	2N2	30.9	0.032
65027	OO1	68.1	0.04
65027	M1	104	0.007
65027	J1	171.3	0.002
65027	Q1	87.3	0.012
65027	2Q1	83.6	0.006
65027	P1	80	0.047
65027	2SM2	78	0.004
65027	M3	3.6	0.007
65027	L2	89.1	0.013
65027	2MK3	219.9	0.027
65027	K2	111.4	0.026
65027	M8	221.3	0.006
65027	MS4	206.3	0.012
65028	M2	76.5	0.347
65028	S2	106.5	0.096
65028	N2	61.2	0.061
65028	K1	90.5	0.126
65028	M4	182.1	0.054
65028	O1	56.9	0.036
65028	M6	81.1	0.011
65028	MK3	158.5	0.034
65028	S4	135.9	0.011
65028	MN4	161.9	0.023
65028	S6	53.1	0.002
65028	2N2	152.2	0.014
65028	OO1	84.3	0.011
65028	M1	135.7	0.011
65028	J1	214.6	0.006
65028	Q1	0.8	0.004
65028	2Q1	243.3	0.006
65028	P1	116.2	0.034
65028	2SM2	278.4	0.006
65028	M3	246.5	0.011
65028	L2	119.5	0.006
65028	2MK3	166.9	0.021
65028	K2	111.1	0.014
65028	M8	46.2	0.008
65028	MS4	200.7	0.018
65029	M2	77.6	0.332
65029	S2	99.7	0.087
65029	N2	57.4	0.053
65029	K1	107.5	0.157
65029	M4	155.5	0.036
65029	O1	45.4	0.066
65029	M6	53.3	0.017
65029	MK3	148.7	0.017
65029	S4	63.2	0.007
65029	MN4	148.8	0.019
65029	S6	11.4	0.004
65029	2N2	137.1	0.018
65029	OO1	112.7	0.004
65029	M1	80	0.002
65029	J1	325.8	0.006
65029	Q1	342.5	0.025
65029	2Q1	211.6	0.006
65029	P1	92.1	0.042
65029	2SM2	115.7	0.005
65029	M3	214.4	0.008
65029	L2	118.8	0.013
65029	2MK3	141.9	0.023
65029	K2	100.8	0.035
65029	M8	38.8	0.005
65029	MS4	254.5	0.023
65030	M2	69.6	1.718
65030	S2	92.6	0.384
65030	N2	50	0.323
65030	K1	82.9	0.494
65030	M4	41.6	0.093
65030	O1	81.1	0.249
65030	M6	97.9	0.124
65030	MK3	349.8	0.063
65030	S4	67.1	0.016
65030	MN4	54.1	0.022
65030	NU2	68.5	0.066
65030	S6	121	0.002
65030	MU2	252.1	0.023
65030	2N2	27.8	0.034
65030	OO1	129.7	0.077
65030	LDA2	75.7	0.054
65030	M1	109.3	0.013
65030	J1	122.8	0.027
65030	RHO1	33	0.011
65030	Q1	73.8	0.037
65030	2Q1	175.8	0.015
65030	P1	78.6	0.138
65030	2SM2	308.8	0.016
65030	M3	129.9	0.007
65030	L2	98.7	0.116
65030	2MK3	230.4	0.043
65030	K2	73.9	0.15
65030	M8	31.7	0.027
65030	MS4	56.9	0.028
65031	M2	71.3	1.8
65031	S2	93.8	0.39
65031	N2	50	0.329
65031	K1	82.6	0.507
65031	M4	79	0.056
65031	O1	84.6	0.272
65031	M6	98.3	0.129
65031	MK3	7.3	0.079
65031	S4	97.3	0.015
65031	MN4	71.8	0.019
65031	NU2	71	0.072
65031	S6	114.4	0.003
65031	MU2	261.7	0.045
65031	2N2	35.1	0.031
65031	OO1	122.9	0.058
65031	LDA2	81.2	0.051
65031	M1	122	0.014
65031	J1	116.1	0.026
65031	RHO1	36	0.012
65031	Q1	72.1	0.036
65031	2Q1	132.4	0.016
65031	P1	76.9	0.147
65031	2SM2	318.1	0.01
65031	M3	94.7	0.014
65031	L2	103.9	0.123
65031	2MK3	250.9	0.037
65031	K2	78.4	0.14
65031	M8	355.3	0.011
65031	MS4	80	0.033
65032	M2	72.9	1.742
65032	S2	96.3	0.38
65032	N2	53	0.321
65032	K1	83.9	0.508
65032	M4	101.6	0.052
65032	O1	84.9	0.268
65032	M6	93	0.106
65032	MK3	356.4	0.06
65032	S4	95.3	0.009
65032	MN4	105.2	0.012
65032	NU2	70	0.066
65032	S6	127.4	0.005
65032	MU2	255.8	0.038
65032	2N2	38.5	0.032
65032	OO1	129.6	0.06
65032	LDA2	80.1	0.045
65032	M1	129.6	0.018
65032	J1	107	0.026
65032	RHO1	58.6	0.015
65032	Q1	72.3	0.037
65032	2Q1	146.9	0.008
65032	P1	75.4	0.148
65032	2SM2	309	0.007
65032	M3	94.3	0.005
65032	L2	103	0.119
65032	2MK3	234	0.039
65032	K2	77.3	0.136
65032	M8	23.5	0.012
65032	MS4	84.4	0.025
65033	M2	86.3	0.251
65033	S2	123	0.087
65033	N2	76.4	0.047
65033	K1	69	0.142
65033	M4	290.3	0.043
65033	O1	37.1	0.161
65033	M6	37.7	0.032
65033	MK3	223.9	0.053
65033	S4	297.9	0.004
65033	MN4	278.4	0.014
65033	S6	233	0.003
65033	2N2	28.6	0.022
65033	OO1	80.7	0.016
65033	M1	65.2	0.012
65033	J1	114.3	0.027
65033	Q1	66.1	0.026
65033	2Q1	74	0.019
65033	P1	127.9	0.047
65033	2SM2	243.5	0.005
65033	M3	306.5	0.011
65033	L2	235	0.006
65033	2MK3	172.9	0.035
65033	K2	79.9	0.04
65033	M8	85.6	0.006
65033	MS4	357	0.018
65034	M2	94.9	0.309
65034	S2	116.6	0.088
65034	N2	75.5	0.053
65034	K1	93.6	0.175
65034	M4	338.6	0.022
65034	O1	71.7	0.151
65034	M6	54	0.021
65034	MK3	207.4	0.023
65034	S4	224.4	0.003
65034	MN4	266.6	0.008
65034	S6	296.8	0.004
65034	2N2	134.7	0.006
65034	OO1	357.2	0.005
65034	M1	120.5	0.012
65034	J1	120	0.013
65034	Q1	38	0.016
65034	2Q1	35.1	0.011
65034	P1	96.7	0.048
65034	2SM2	315.9	0.003
65034	M3	296.8	0.008
65034	L2	191.5	0.009
65034	2MK3	161.9	0.019
65034	K2	55.5	0.026
65034	M8	89.4	0.008
65034	MS4	344.9	0.018
65035	M2	95	0.337
65035	S2	115.4	0.081
65035	N2	74.5	0.06
65035	K1	91.1	0.197
65035	M4	68.7	0.019
65035	O1	72.9	0.136
65035	M6	93.2	0.019
65035	MK3	285.5	0.025
65035	S4	132.1	0.004
65035	MN4	219.5	0.003
65035	S6	257.6	0.001
65035	2N2	86.8	0.009
65035	OO1	128.4	0.007
65035	M1	138	0.012
65035	J1	122.4	0.008
65035	Q1	3.1	0.019
65035	2Q1	27.9	0.014
65035	P1	83.7	0.062
65035	2SM2	75.8	0.006
65035	M3	324.4	0.01
65035	L2	26.2	0.004
65035	2MK3	214.6	0.033
65035	K2	79.3	0.031
65035	M8	151.7	0.006
65035	MS4	14.5	0.006
65036	M2	44.7	0.295
65036	S2	76.4	0.05
65036	N2	33.3	0.029
65036	K1	53.7	0.042
65036	M4	27.5	0.023
65036	O1	54.4	0.029
65036	M6	54.8	0.023
65036	MK3	297.4	0.025
65036	S4	61.1	0.007
65036	MN4	339.8	0.005
65036	S6	76.6	0.003
65036	2N2	340.3	0.018
65036	OO1	10.1	0.016
65036	M1	14.7	0.002
65036	J1	113.8	0.013
65036	Q1	46	0.012
65036	2Q1	335.2	0.005
65036	P1	82.9	0.024
65036	2SM2	270.8	0.003
65036	M3	352.5	0.003
65036	L2	60.5	0.027
65036	2MK3	238	0.02
65036	K2	15.2	0.022
65036	M8	239.4	0.006
65036	MS4	19.7	0.012
65037	M2	48.9	0.333
65037	S2	76.1	0.06
65037	N2	30.9	0.036
65037	K1	54.9	0.049
65037	M4	28.6	0.027
65037	O1	61.8	0.033
65037	M6	57.1	0.028
65037	MK3	310.7	0.022
65037	S4	62	0.006
65037	MN4	349.4	0.006
65037	S6	76.1	0.003
65037	2N2	355.1	0.019
65037	OO1	10.3	0.019
65037	M1	51.9	0.002
65037	J1	123.9	0.013
65037	Q1	42.7	0.012
65037	2Q1	341.6	0.005
65037	P1	81.5	0.024
65037	2SM2	255.1	0.004
65037	M3	55.3	0.004
65037	L2	70.8	0.027
65037	2MK3	255.3	0.019
65037	K2	26.7	0.022
65037	M8	252.2	0.005
65037	MS4	33.4	0.014
65038	M2	52.5	0.363
65038	S2	76.9	0.069
65038	N2	30.5	0.042
65038	K1	56.9	0.057
65038	M4	32.3	0.03
65038	O1	68.4	0.038
65038	M6	62.8	0.031
65038	MK3	328.1	0.022
65038	S4	61.4	0.006
65038	MN4	357.4	0.007
65038	S6	81.7	0.003
65038	2N2	6.7	0.02
65038	OO1	8.9	0.019
65038	M1	86.8	0.002
65038	J1	133.9	0.013
65038	Q1	42.8	0.012
65038	2Q1	357.9	0.005
65038	P1	79.9	0.024
65038	2SM2	242	0.004
65038	M3	87.9	0.006
65038	L2	79.5	0.025
65038	2MK3	272.1	0.018
65038	K2	39.8	0.022
65038	M8	268.5	0.005
65038	MS4	46.5	0.016
65039	M2	55.6	0.388
65039	S2	78.5	0.074
65039	N2	30.7	0.048
65039	K1	60.8	0.064
65039	M4	38.5	0.034
65039	O1	73.3	0.043
65039	M6	70.1	0.033
65039	MK3	347.9	0.023
65039	S4	70.1	0.008
65039	MN4	0.7	0.008
65039	S6	102.6	0.003
65039	2N2	17.4	0.02
65039	OO1	4.4	0.018
65039	M1	112	0.002
65039	J1	136.5	0.012
65039	Q1	44.6	0.013
65039	2Q1	11.4	0.005
65039	P1	77.7	0.024
65039	2SM2	238.4	0.004
65039	M3	103.3	0.007
65039	L2	86.1	0.023
65039	2MK3	288.8	0.016
65039	K2	45.1	0.021
65039	M8	286	0.003
65039	MS4	58.9	0.018
65040	M2	58.5	0.405
65040	S2	80.7	0.079
65040	N2	32.5	0.055
65040	K1	65.3	0.069
65040	M4	48.9	0.037
65040	O1	77.1	0.047
65040	M6	78.8	0.035
65040	MK3	7.3	0.024
65040	S4	78.8	0.008
65040	MN4	16.1	0.009
65040	S6	127.1	0.003
65040	2N2	27.5	0.019
65040	OO1	7.8	0.015
65040	M1	123	0.002
65040	J1	135.5	0.009
65040	Q1	51.5	0.011
65040	2Q1	25.7	0.005
65040	P1	75.4	0.022
65040	2SM2	233.8	0.004
65040	M3	114.9	0.008
65040	L2	89.4	0.02
65040	2MK3	299.5	0.014
65040	K2	46	0.019
65040	M8	347.7	0.002
65040	MS4	72.9	0.02
65041	M2	61	0.414
65041	S2	83.2	0.082
65041	N2	34	0.059
65041	K1	69.5	0.071
65041	M4	61.3	0.037
65041	O1	80.1	0.047
65041	M6	88.1	0.037
65041	MK3	26.1	0.027
65041	S4	84.2	0.007
65041	MN4	28.8	0.009
65041	S6	143.6	0.003
65041	2N2	37.5	0.019
65041	OO1	22.8	0.012
65041	M1	136.7	0.002
65041	J1	128	0.006
65041	Q1	61.8	0.009
65041	2Q1	30	0.005
65041	P1	71.5	0.023
65041	2SM2	229.2	0.004
65041	M3	124.8	0.008
65041	L2	95.3	0.018
65041	2MK3	308.4	0.012
65041	K2	46.3	0.019
65041	M8	60.1	0.003
65041	MS4	81.9	0.022
65042	M2	63.4	0.417
65042	S2	85.2	0.084
65042	N2	35.7	0.062
65042	K1	73	0.074
65042	M4	74.6	0.037
65042	O1	83.6	0.047
65042	M6	95.5	0.037
65042	MK3	40	0.033
65042	S4	96.1	0.005
65042	MN4	41.2	0.009
65042	S6	164.1	0.002
65042	2N2	47	0.019
65042	OO1	41.7	0.011
65042	M1	149.1	0.002
65042	J1	111.7	0.005
65042	Q1	79.5	0.008
65042	2Q1	16.8	0.005
65042	P1	70.6	0.024
65042	2SM2	234.5	0.004
65042	M3	131.7	0.007
65042	L2	100.6	0.017
65042	2MK3	318.8	0.009
65042	K2	45.1	0.018
65042	M8	89.1	0.003
65042	MS4	88.9	0.023
65043	M2	65.8	0.418
65043	S2	85.1	0.084
65043	N2	38.5	0.062
65043	K1	75.6	0.079
65043	M4	87.6	0.039
65043	O1	89.5	0.047
65043	M6	101.3	0.035
65043	MK3	51.5	0.041
65043	S4	102.2	0.004
65043	MN4	59.4	0.01
65043	S6	173.1	0.002
65043	2N2	54.8	0.018
65043	OO1	59	0.012
65043	M1	184.5	0.002
65043	J1	104.2	0.003
65043	Q1	100.6	0.007
65043	2Q1	24.9	0.005
65043	P1	75.5	0.025
65043	2SM2	252.8	0.004
65043	M3	138.5	0.007
65043	L2	106.4	0.015
65043	2MK3	336.3	0.009
65043	K2	35.3	0.019
65043	M8	123.1	0.003
65043	MS4	100	0.022
65044	M2	68.2	0.418
65044	S2	84.9	0.087
65044	N2	39.8	0.063
65044	K1	79.9	0.086
65044	M4	100.1	0.042
65044	O1	94.6	0.05
65044	M6	104.9	0.033
65044	MK3	58	0.047
65044	S4	95	0.005
65044	MN4	75.2	0.011
65044	S6	153.7	0.002
65044	2N2	66.4	0.019
65044	OO1	85.1	0.014
65044	M1	206.2	0.003
65044	Q1	112.4	0.007
65044	2Q1	52.3	0.006
65044	P1	75.9	0.025
65044	2SM2	287.1	0.004
65044	M3	135.3	0.008
65044	L2	111.9	0.014
65044	2MK3	354.4	0.012
65044	K2	44.9	0.019
65044	M8	173.8	0.004
65044	MS4	111.1	0.019
65045	M2	66.8	0.41
65045	S2	75.9	0.084
65045	N2	32.1	0.058
65045	K1	72.8	0.098
65045	M4	105.8	0.025
65045	O1	61.9	0.046
65045	M6	116.1	0.017
65045	MK3	32.8	0.05
65045	S4	205.2	0.001
65045	MN4	145.4	0.004
65045	S6	185.7	0.003
65045	2N2	92.3	0.03
65045	OO1	136.4	0.032
65045	M1	268.1	0.006
65045	J1	9	0.007
65045	Q1	317.1	0.002
65045	2Q1	96.5	0.012
65045	P1	58	0.025
65045	2SM2	298.7	0.008
65045	M3	51.7	0.01
65045	L2	156.2	0.01
65045	2MK3	325.4	0.032
65045	K2	82.2	0.015
65045	M8	229.6	0.01
65045	MS4	204.1	0.005
65046	M2	44.1	0.371
65046	S2	54.3	0.071
65046	N2	1.7	0.048
65046	K1	11	0.066
65046	M4	260.4	0.088
65046	O1	0.9	0.027
65046	M6	103.9	0.056
65046	MK3	250.8	0.054
65046	S4	191.2	0.008
65046	MN4	220.4	0.028
65046	S6	83	0.003
65046	2N2	38.9	0.018
65046	OO1	350.4	0.003
65046	M1	331.4	0.004
65046	J1	328.2	0.007
65046	Q1	3.3	0.01
65046	2Q1	205.4	0.005
65046	P1	185.9	0.012
65046	2SM2	292.8	0.011
65046	M3	326.3	0.008
65046	L2	115	0.019
65046	2MK3	269.9	0.029
65046	K2	5.1	0.033
65046	M8	303.1	0.021
65046	MS4	305.7	0.023
65047	M2	45.7	0.406
65047	S2	51.7	0.078
65047	N2	3.7	0.054
65047	K1	11.5	0.075
65047	M4	256.9	0.092
65047	O1	12.2	0.037
65047	M6	102.9	0.062
65047	MK3	248.5	0.058
65047	S4	201.2	0.006
65047	MN4	219.4	0.028
65047	S6	82.6	0.004
65047	2N2	43.1	0.021
65047	OO1	10.2	0.007
65047	M1	358.3	0.004
65047	J1	307.2	0.003
65047	Q1	12.5	0.009
65047	2Q1	254.9	0.003
65047	P1	186	0.013
65047	2SM2	294.5	0.01
65047	M3	334	0.007
65047	L2	112.6	0.022
65047	2MK3	272.2	0.03
65047	K2	4.8	0.042
65047	M8	298.7	0.023
65047	MS4	301	0.021
65048	M2	47.1	0.426
65048	S2	52.2	0.084
65048	N2	6	0.058
65048	K1	9.5	0.083
65048	M4	254.4	0.091
65048	O1	24.5	0.046
65048	M6	103	0.065
65048	MK3	247.5	0.057
65048	S4	209.1	0.004
65048	MN4	216	0.026
65048	S6	76.7	0.004
65048	2N2	44.8	0.025
65048	OO1	4.2	0.013
65048	M1	24.7	0.005
65048	J1	181.3	0.004
65048	Q1	20.9	0.008
65048	2Q1	321.4	0.004
65048	P1	179.2	0.013
65048	2SM2	297.8	0.008
65048	M3	336.7	0.006
65048	L2	110.7	0.023
65048	2MK3	273.7	0.033
65048	K2	5.6	0.048
65048	M8	293.8	0.025
65048	MS4	295.2	0.018
65049	M2	48.3	0.44
65049	S2	55.8	0.089
65049	N2	7.7	0.064
65049	K1	5.3	0.092
65049	M4	252.6	0.089
65049	O1	34	0.054
65049	M6	103.3	0.066
65049	MK3	248.5	0.055
65049	S4	200.9	0.002
65049	MN4	214.5	0.023
65049	S6	64.4	0.005
65049	2N2	45.8	0.03
65049	OO1	353.5	0.021
65049	M1	41.2	0.007
65049	J1	167.8	0.01
65049	Q1	14.8	0.006
65049	2Q1	345.5	0.008
65049	P1	160.6	0.014
65049	2SM2	299.9	0.006
65049	M3	353.1	0.005
65049	L2	104.6	0.025
65049	2MK3	276.6	0.04
65049	K2	10.3	0.047
65049	M8	287.6	0.027
65049	MS4	293.1	0.015
65050	M2	47.9	0.454
65050	S2	58.9	0.102
65050	N2	4.9	0.073
65050	K1	354.5	0.109
65050	M4	256.1	0.089
65050	O1	31.5	0.071
65050	M6	105	0.061
65050	MK3	265	0.056
65050	S4	3.6	0.004
65050	MN4	236.6	0.02
65050	S6	34.1	0.005
65050	2N2	55.8	0.039
65050	OO1	322	0.021
65050	M1	48.1	0.01
65050	J1	144.9	0.009
65050	Q1	336.2	0.016
65050	2Q1	32.6	0.012
65050	P1	105.6	0.024
65050	2SM2	321.1	0.008
65050	M3	37.8	0.012
65050	L2	101.1	0.025
65050	2MK3	284.8	0.058
65050	K2	32	0.04
65050	M8	277.3	0.028
65050	MS4	313.2	0.02
65051	M2	47.8	0.455
65051	S2	63.9	0.103
65051	N2	3.4	0.073
65051	K1	354.9	0.127
65051	M4	250.3	0.09
65051	O1	25.8	0.076
65051	M6	108.9	0.07
65051	MK3	269.7	0.063
65051	S4	146.2	0.004
65051	MN4	236.4	0.02
65051	S6	42.4	0.004
65051	2N2	45.6	0.046
65051	OO1	337.5	0.041
65051	M1	29.3	0.009
65051	J1	131.1	0.014
65051	Q1	321.9	0.015
65051	2Q1	7.1	0.022
65051	P1	102.8	0.031
65051	2SM2	298.2	0.007
65051	M3	28	0.019
65051	L2	102.3	0.019
65051	2MK3	276	0.068
65051	K2	41.2	0.036
65051	M8	273.8	0.026
65051	MS4	299.2	0.012
65052	M2	67	1.197
65052	S2	93.8	0.225
65052	N2	53.8	0.151
65052	K1	78.2	0.308
65052	M4	92.8	0.091
65052	O1	76.2	0.179
65052	M6	74.4	0.103
65052	MK3	32.2	0.031
65052	S4	102.5	0.014
65052	MN4	68.7	0.026
65052	S6	53.4	0.004
65052	2N2	19.5	0.073
65052	OO1	50.7	0.044
65052	M1	125.8	0.012
65052	J1	159.7	0.03
65052	Q1	74.6	0.024
65052	2Q1	307.5	0.012
65052	P1	93.4	0.089
65052	2SM2	298.1	0.004
65052	M3	356.3	0.008
65052	L2	81.5	0.062
65052	2MK3	237.3	0.088
65052	K2	64.5	0.072
65052	M8	47.1	0.011
65052	MS4	76.3	0.056
65053	M2	66	1.319
65053	S2	91.3	0.246
65053	N2	52.3	0.165
65053	K1	76.5	0.337
65053	M4	99.5	0.11
65053	O1	70	0.193
65053	M6	81.4	0.127
65053	MK3	37	0.026
65053	S4	102.7	0.017
65053	MN4	72.4	0.032
65053	S6	54.6	0.005
65053	2N2	15.8	0.082
65053	OO1	45.5	0.047
65053	M1	118.9	0.013
65053	J1	158.5	0.03
65053	Q1	75.1	0.023
65053	2Q1	297.9	0.015
65053	P1	88.6	0.086
65053	2SM2	296.6	0.004
65053	M3	5.5	0.008
65053	L2	79.2	0.07
65053	2MK3	236.3	0.095
65053	K2	59.3	0.082
65053	M8	94.6	0.014
65053	MS4	75.3	0.065
65054	M2	64.4	1.31
65054	S2	89.3	0.237
65054	N2	50.1	0.165
65054	K1	73.4	0.337
65054	M4	126.2	0.084
65054	O1	64	0.164
65054	M6	101.9	0.103
65054	MK3	283.2	0.046
65054	S4	139.1	0.012
65054	MN4	92.6	0.022
65054	S6	26.7	0.006
65054	2N2	17.7	0.104
65054	OO1	34.7	0.066
65054	M1	120.3	0.019
65054	J1	177.3	0.02
65054	Q1	56.7	0.021
65054	2Q1	339.1	0.023
65054	P1	82.8	0.073
65054	2SM2	245.7	0.007
65054	M3	330.6	0.019
65054	L2	86.8	0.078
65054	2MK3	237.1	0.141
65054	K2	54.5	0.1
65054	M8	180.7	0.021
65054	MS4	102.7	0.023
65055	M2	74.9	1.079
65055	S2	94.4	0.246
65055	N2	54.6	0.16
65055	K1	78.3	0.299
65055	M4	122.2	0.141
65055	O1	56.1	0.149
65055	M6	142.5	0.065
65055	MK3	91.6	0.067
65055	S4	89.2	0.008
65055	MN4	104.6	0.044
65055	S6	206.7	0.003
65055	2N2	38.6	0.052
65055	OO1	53.5	0.052
65055	M1	103	0.01
65055	J1	151.3	0.026
65055	Q1	74	0.016
65055	2Q1	327.8	0.008
65055	P1	83.2	0.096
65055	2SM2	329.7	0.007
65055	M3	163.2	0.014
65055	L2	110.3	0.036
65055	2MK3	258.9	0.022
65055	K2	69.6	0.101
65055	M8	213.7	0.009
65055	MS4	142.8	0.043
65056	M2	74	1.099
65056	S2	96.2	0.236
65056	N2	57.2	0.161
65056	K1	76.2	0.314
65056	M4	132.8	0.136
65056	O1	51.1	0.164
65056	M6	123.3	0.054
65056	MK3	116.7	0.057
65056	S4	92	0.016
65056	MN4	113.6	0.043
65056	S6	236.1	0.004
65056	2N2	28	0.053
65056	OO1	68.8	0.05
65056	M1	103.7	0.01
65056	J1	153.2	0.024
65056	Q1	83.1	0.014
65056	2Q1	326.2	0.017
65056	P1	88.2	0.101
65056	2SM2	335.7	0.009
65056	M3	190.7	0.009
65056	L2	99.1	0.039
65056	2MK3	222.3	0.027
65056	K2	67.4	0.089
65056	M8	172.3	0.017
65056	MS4	140.9	0.035
65057	M2	74.3	1.1
65057	S2	99.2	0.239
65057	N2	60.8	0.168
65057	K1	80.3	0.351
65057	M4	135.6	0.136
65057	O1	55.4	0.193
65057	M6	105.2	0.053
65057	MK3	149.2	0.053
65057	S4	75.6	0.019
65057	MN4	111.7	0.035
65057	S6	278.8	0.003
65057	2N2	30	0.049
65057	OO1	90.4	0.049
65057	M1	90	0.009
65057	J1	169.3	0.019
65057	Q1	72.1	0.02
65057	2Q1	335.4	0.02
65057	P1	89.8	0.098
65057	2SM2	300.5	0.009
65057	M3	232.1	0.012
65057	L2	85.3	0.036
65057	2MK3	196.8	0.043
65057	K2	74.4	0.087
65057	M8	158.9	0.017
65057	MS4	129	0.034
65058	M2	99.7	1.894
65058	S2	130.2	0.412
65058	N2	88.3	0.277
65058	K1	108	0.55
65058	M4	182	0.171
65058	O1	119.6	0.334
65058	M6	131.4	0.14
65058	MK3	200.9	0.186
65058	S4	216.2	0.004
65058	MN4	167.3	0.052
65058	S6	317.2	0.005
65058	2N2	44.5	0.089
65058	OO1	97.9	0.1
65058	M1	147.1	0.022
65058	J1	176.5	0.042
65058	Q1	121.2	0.04
65058	2Q1	133.2	0.012
65058	P1	109	0.189
65058	2SM2	306.1	0.016
65058	M3	306.3	0.057
65058	L2	97.9	0.083
65058	2MK3	232.5	0.226
65058	K2	93.1	0.18
65058	M8	194.7	0.034
65058	MS4	208.3	0.049
65059	M2	99.8	1.978
65059	S2	130.2	0.429
65059	N2	88.4	0.288
65059	K1	108.4	0.573
65059	M4	182.6	0.174
65059	O1	120.3	0.35
65059	M6	130.9	0.148
65059	MK3	201.9	0.191
65059	S4	209	0.004
65059	MN4	168	0.054
65059	S6	313.4	0.006
65059	2N2	44.6	0.094
65059	OO1	98.3	0.104
65059	M1	148.7	0.024
65059	J1	177.6	0.044
65059	Q1	121.6	0.041
65059	2Q1	132.4	0.014
65059	P1	109.2	0.198
65059	2SM2	306.8	0.017
65059	M3	306.7	0.059
65059	L2	98.6	0.086
65059	2MK3	233.1	0.236
65059	K2	93.3	0.189
65059	M8	195.3	0.036
65059	MS4	208.2	0.05
65060	M2	99.9	2.042
65060	S2	130.4	0.443
65060	N2	88.8	0.297
65060	K1	108.8	0.591
65060	M4	183.3	0.176
65060	O1	121	0.364
65060	M6	130.2	0.153
65060	MK3	202.8	0.195
65060	S4	209.4	0.005
65060	MN4	168.6	0.055
65060	S6	313.8	0.006
65060	2N2	44.4	0.097
65060	OO1	98.6	0.109
65060	M1	148.8	0.025
65060	J1	178.5	0.045
65060	Q1	121.8	0.043
65060	2Q1	131	0.014
65060	P1	109.5	0.205
65060	2SM2	307.6	0.018
65060	M3	307.3	0.061
65060	L2	98.8	0.09
65060	2MK3	233.4	0.243
65060	K2	93.3	0.195
65060	M8	194.9	0.036
65060	MS4	209	0.049
65061	M2	100.1	2.097
65061	S2	130.5	0.454
65061	N2	89	0.305
65061	K1	109.2	0.608
65061	M4	184.4	0.176
65061	O1	121.7	0.377
65061	M6	129.6	0.157
65061	MK3	203.8	0.198
65061	S4	204.6	0.005
65061	MN4	168.9	0.056
65061	S6	307.2	0.006
65061	2N2	44.2	0.1
65061	OO1	98.3	0.112
65061	M1	149.6	0.026
65061	J1	179.1	0.047
65061	Q1	121.9	0.044
65061	2Q1	130.1	0.015
65061	P1	109.9	0.212
65061	2SM2	308	0.018
65061	M3	308.1	0.062
65061	L2	99.2	0.092
65061	2MK3	233.9	0.251
65061	K2	93.4	0.2
65061	M8	195.1	0.037
65061	MS4	209.7	0.048
65062	M2	100.2	2.146
65062	S2	130.7	0.464
65062	N2	89.1	0.311
65062	K1	109.7	0.621
65062	M4	185.7	0.176
65062	O1	122.4	0.388
65062	M6	128.9	0.16
65062	MK3	205.1	0.201
65062	S4	208.5	0.005
65062	MN4	170.1	0.056
65062	S6	309.4	0.006
65062	2N2	44.6	0.103
65062	OO1	98.5	0.115
65062	M1	150.6	0.026
65062	J1	179.4	0.047
65062	Q1	121.8	0.046
65062	2Q1	130.3	0.016
65062	P1	110.2	0.218
65062	2SM2	308.6	0.018
65062	M3	309.1	0.064
65062	L2	99.3	0.095
65062	2MK3	234.4	0.256
65062	K2	93.5	0.205
65062	M8	194.8	0.037
65062	MS4	210.5	0.047
65063	M2	100.3	2.189
65063	S2	130.9	0.472
65063	N2	89.3	0.317
65063	K1	110	0.634
65063	M4	187	0.176
65063	O1	123	0.398
65063	M6	128.3	0.163
65063	MK3	206.1	0.203
65063	S4	207.6	0.005
65063	MN4	170.8	0.057
65063	S6	309.9	0.007
65063	2N2	44.7	0.105
65063	OO1	98.8	0.118
65063	M1	151.4	0.027
65063	J1	179.7	0.048
65063	Q1	121.9	0.047
65063	2Q1	129.8	0.017
65063	P1	110.7	0.222
65063	2SM2	307.6	0.019
65063	M3	309.9	0.065
65063	L2	99.7	0.097
65063	2MK3	234.8	0.262
65063	K2	93.4	0.207
65063	M8	194.5	0.037
65063	MS4	212.5	0.046
65064	M2	100.4	2.229
65064	S2	131.1	0.478
65064	N2	89.4	0.323
65064	K1	110.3	0.647
65064	M4	188.2	0.175
65064	O1	123.6	0.408
65064	M6	127.7	0.166
65064	MK3	207.2	0.205
65064	S4	207.6	0.006
65064	MN4	171.7	0.057
65064	S6	307.2	0.007
65064	2N2	44.8	0.108
65064	OO1	99.3	0.12
65064	M1	151.9	0.028
65064	J1	180.5	0.049
65064	Q1	122	0.048
65064	2Q1	130.8	0.018
65064	P1	111.4	0.226
65064	2SM2	307.4	0.019
65064	M3	310.2	0.066
65064	L2	99.9	0.099
65064	2MK3	235.2	0.267
65064	K2	93.4	0.21
65064	M8	194.7	0.036
65064	MS4	213.6	0.045
65065	M2	100.5	2.264
65065	S2	131.3	0.485
65065	N2	89.5	0.328
65065	K1	110.6	0.658
65065	M4	189.3	0.175
65065	O1	124.1	0.416
65065	M6	127.1	0.168
65065	MK3	208.1	0.207
65065	S4	209.1	0.006
65065	MN4	172.7	0.056
65065	S6	303.3	0.007
65065	2N2	44.8	0.11
65065	OO1	99	0.123
65065	M1	152.2	0.028
65065	J1	180.6	0.049
65065	Q1	122.2	0.049
65065	2Q1	131.5	0.019
65065	P1	111.7	0.23
65065	2SM2	308.3	0.019
65065	M3	310.8	0.067
65065	L2	99.8	0.1
65065	2MK3	235.6	0.271
65065	K2	93.4	0.213
65065	M8	194.7	0.036
65065	MS4	215.1	0.044
65066	M2	100.6	2.295
65066	S2	131.5	0.49
65066	N2	89.7	0.333
65066	K1	110.9	0.668
65066	M4	190.6	0.175
65066	O1	124.5	0.423
65066	M6	126.7	0.17
65066	MK3	209.1	0.209
65066	S4	205.1	0.006
65066	MN4	173.4	0.057
65066	S6	301.7	0.007
65066	2N2	45.1	0.111
65066	OO1	99.2	0.125
65066	M1	152.6	0.029
65066	J1	180.7	0.05
65066	Q1	122.8	0.049
65066	2Q1	130.4	0.019
65066	P1	111.7	0.233
65066	2SM2	307.9	0.02
65066	M3	311.6	0.068
65066	L2	100	0.102
65066	2MK3	236	0.276
65066	K2	93.3	0.215
65066	M8	194.9	0.036
65066	MS4	217.8	0.043
65067	M2	99.9	2.321
65067	S2	129.1	0.501
65067	N2	88.1	0.335
65067	K1	109.5	0.663
65067	M4	190.3	0.152
65067	O1	121.3	0.409
65067	M6	120.3	0.169
65067	MK3	212.6	0.18
65067	S4	27	0.01
65067	MN4	176	0.044
65067	S6	351.6	0.008
65067	2N2	54.5	0.105
65067	OO1	116.3	0.119
65067	M1	154.8	0.026
65067	J1	174.6	0.046
65067	Q1	114	0.041
65067	2Q1	140.6	0.038
65067	P1	108.4	0.242
65067	2SM2	331.9	0.028
65067	M3	317.7	0.06
65067	L2	99.5	0.101
65067	2MK3	240.7	0.262
65067	K2	98.6	0.231
65067	M8	186.3	0.026
65067	MS4	241.6	0.018
65068	M2	100.7	1.081
65068	S2	122.3	0.287
65068	N2	81.8	0.2
65068	K1	97	0.415
65068	M4	87.6	0.05
65068	O1	86.4	0.198
65068	M6	158	0.015
65068	MK3	42.6	0.105
65068	S4	128.9	0.015
65068	MN4	62	0.018
65068	S6	43.7	0.004
65068	2N2	103.3	0.027
65068	OO1	94.9	0.018
65068	M1	143.1	0.003
65068	J1	114.2	0.014
65068	Q1	49.3	0.027
65068	2Q1	70.6	0.031
65068	P1	95.7	0.15
65068	2SM2	214.1	0.006
65068	M3	64.2	0.013
65068	L2	115.3	0.022
65068	2MK3	3.1	0.019
65068	K2	98.2	0.118
65068	M8	133.7	0.012
65068	MS4	173.4	0.027
65069	M2	100.5	1.337
65069	S2	118.7	0.339
65069	N2	79.2	0.23
65069	K1	95.5	0.49
65069	M4	135.9	0.052
65069	O1	84.7	0.235
65069	M6	149	0.03
65069	MK3	49.2	0.098
65069	S4	121	0.016
65069	MN4	69.2	0.016
65069	2N2	88.6	0.045
65069	OO1	102.8	0.032
65069	M1	133.7	0.008
65069	J1	143.6	0.021
65069	Q1	64.8	0.033
65069	2Q1	49.9	0.018
65069	P1	97.7	0.167
65069	2SM2	216.6	0.004
65069	M3	122.1	0.015
65069	L2	141.9	0.029
65069	2MK3	14	0.035
65069	K2	99.3	0.146
65069	M8	166	0.009
65069	MS4	161.5	0.047
65070	M2	99.8	1.441
65070	S2	115.6	0.35
65070	N2	75.6	0.241
65070	K1	93.2	0.498
65070	M4	175.5	0.06
65070	O1	85.8	0.236
65070	M6	153.5	0.028
65070	MK3	68.8	0.094
65070	S4	108.5	0.011
65070	MN4	117.2	0.014
65070	S6	315	0.003
65070	2N2	94.2	0.063
65070	OO1	104.6	0.053
65070	M1	125.8	0.014
65070	J1	162.6	0.024
65070	Q1	89.5	0.033
65070	2Q1	32.9	0.009
65070	P1	93.5	0.161
65070	2SM2	314	0.004
65070	M3	138.9	0.017
65070	L2	156.1	0.042
65070	2MK3	19.3	0.042
65070	K2	101.1	0.152
65070	M8	229.7	0.015
65070	MS4	168.2	0.046
65071	M2	97.5	1.018
65071	S2	122.9	0.258
65071	N2	79.2	0.187
65071	K1	98.2	0.393
65071	M4	94.2	0.069
65071	O1	101.7	0.191
65071	M6	129.6	0.035
65071	MK3	73	0.122
65071	S4	99.1	0.014
65071	MN4	59.4	0.026
65071	S6	82	0.002
65071	2N2	126.8	0.013
65071	OO1	103.5	0.036
65071	M1	145.1	0.009
65071	J1	136.3	0.016
65071	Q1	65.9	0.033
65071	2Q1	125.9	0.023
65071	P1	92.3	0.139
65071	2SM2	72	0.003
65071	M3	164.7	0.021
65071	L2	107.6	0.017
65071	2MK3	50.3	0.024
65071	K2	110.4	0.083
65071	M8	211.5	0.005
65071	MS4	108.8	0.029
65072	M2	97.7	1.085
65072	S2	122.6	0.272
65072	N2	79.3	0.197
65072	K1	98.2	0.418
65072	M4	94.1	0.072
65072	O1	100.7	0.202
65072	M6	133.1	0.039
65072	MK3	72.3	0.127
65072	S4	99	0.015
65072	MN4	59.7	0.025
65072	S6	73.6	0.002
65072	2N2	113.6	0.014
65072	OO1	104.4	0.037
65072	M1	147.3	0.009
65072	J1	134.3	0.016
65072	Q1	65.3	0.036
65072	2Q1	126	0.024
65072	P1	92.1	0.146
65072	2SM2	65.9	0.003
65072	M3	163.4	0.023
65072	L2	110.7	0.02
65072	2MK3	45.4	0.027
65072	K2	109.6	0.089
65072	M8	212	0.005
65072	MS4	108.8	0.03
65073	M2	97.9	1.128
65073	S2	122.3	0.281
65073	N2	79.5	0.204
65073	K1	97.9	0.434
65073	M4	95	0.075
65073	O1	99.4	0.211
65073	M6	135.5	0.04
65073	MK3	72	0.133
65073	S4	99.1	0.016
65073	MN4	61.2	0.026
65073	S6	71.2	0.002
65073	2N2	106.5	0.017
65073	OO1	103.7	0.038
65073	M1	144.5	0.009
65073	J1	133.7	0.016
65073	Q1	66.1	0.037
65073	2Q1	125.8	0.023
65073	P1	92.6	0.149
65073	2SM2	74.4	0.002
65073	M3	163.2	0.024
65073	L2	114	0.022
65073	2MK3	45.1	0.03
65073	K2	109	0.093
65073	M8	216.1	0.005
65073	MS4	109.1	0.032
65074	M2	98.2	1.159
65074	S2	122	0.289
65074	N2	79.6	0.208
65074	K1	97.5	0.447
65074	M4	96.6	0.077
65074	O1	98.1	0.219
65074	M6	137.6	0.041
65074	MK3	72.1	0.138
65074	S4	99.9	0.016
65074	MN4	64.4	0.027
65074	S6	74.6	0.003
65074	2N2	100.5	0.02
65074	OO1	102.1	0.039
65074	M1	142	0.009
65074	J1	136.1	0.017
65074	Q1	67.4	0.039
65074	2Q1	126	0.023
65074	P1	93.3	0.151
65074	2SM2	79.7	0.002
65074	M3	160.7	0.026
65074	L2	118.7	0.022
65074	2MK3	45.1	0.033
65074	K2	109.1	0.097
65074	M8	216.8	0.005
65074	MS4	110	0.034
65075	M2	98.4	1.184
65075	S2	121.7	0.297
65075	N2	79.5	0.212
65075	K1	97	0.457
65075	M4	98.2	0.08
65075	O1	96.8	0.226
65075	M6	140.2	0.041
65075	MK3	72.7	0.142
65075	S4	100.9	0.016
65075	MN4	68.3	0.028
65075	S6	74.9	0.003
65075	2N2	96.3	0.024
65075	OO1	100.4	0.04
65075	M1	136.5	0.009
65075	J1	136.2	0.018
65075	Q1	68.7	0.04
65075	2Q1	128.1	0.022
65075	P1	94.8	0.151
65075	M3	160	0.027
65075	L2	123.1	0.023
65075	2MK3	45	0.036
65075	K2	109.3	0.101
65075	M8	224.9	0.005
65075	MS4	111	0.034
65076	M2	98.7	1.202
65076	S2	121.5	0.302
65076	N2	79.5	0.214
65076	K1	96.5	0.463
65076	M4	100.4	0.082
65076	O1	95.5	0.232
65076	M6	143.5	0.041
65076	MK3	73.3	0.144
65076	S4	102.3	0.017
65076	MN4	72.5	0.029
65076	S6	81.7	0.003
65076	2N2	94.3	0.027
65076	OO1	97.7	0.041
65076	M1	132	0.01
65076	J1	138.1	0.019
65076	Q1	69.3	0.041
65076	2Q1	129.9	0.02
65076	P1	96.3	0.152
65076	M3	159.5	0.028
65076	L2	129	0.024
65076	2MK3	45.7	0.037
65076	K2	109.5	0.104
65076	M8	235.3	0.004
65076	MS4	111.1	0.035
65077	M2	98.9	1.217
65077	S2	121.4	0.307
65077	N2	79.3	0.215
65077	K1	96.1	0.47
65077	M4	103.1	0.084
65077	O1	94.6	0.237
65077	M6	147.2	0.04
65077	MK3	74.2	0.143
65077	S4	105.8	0.017
65077	MN4	76.1	0.03
65077	S6	93.9	0.003
65077	2N2	93.3	0.03
65077	OO1	95.6	0.04
65077	M1	127.6	0.01
65077	J1	138.1	0.022
65077	Q1	68.9	0.043
65077	2Q1	132.4	0.018
65077	P1	97.7	0.153
65077	M3	157.5	0.029
65077	L2	133.6	0.025
65077	2MK3	44.9	0.039
65077	K2	110.1	0.106
65077	M8	246.2	0.004
65077	MS4	111.2	0.035
65078	M2	99.1	1.229
65078	S2	121.3	0.31
65078	N2	79.1	0.216
65078	K1	95.8	0.476
65078	M4	106.4	0.085
65078	O1	93.6	0.241
65078	M6	150.9	0.039
65078	MK3	75	0.14
65078	S4	110.7	0.017
65078	MN4	79.4	0.031
65078	S6	107.3	0.002
65078	2N2	91.8	0.033
65078	OO1	94.2	0.039
65078	M1	127.4	0.011
65078	J1	138.1	0.024
65078	Q1	68.7	0.044
65078	2Q1	136.1	0.016
65078	P1	98.7	0.153
65078	M3	155.9	0.03
65078	L2	136.6	0.027
65078	2MK3	43.7	0.039
65078	K2	110.2	0.107
65078	M8	251.4	0.003
65078	MS4	112.8	0.035
65079	M2	99.4	1.24
65079	S2	121.1	0.311
65079	N2	78.9	0.216
65079	K1	95.5	0.48
65079	M4	110.1	0.084
65079	O1	92.9	0.244
65079	M6	154.5	0.036
65079	MK3	74.9	0.136
65079	S4	116.8	0.018
65079	MN4	81.7	0.031
65079	S6	127.9	0.002
65079	2N2	92.1	0.036
65079	OO1	92.1	0.037
65079	M1	128.8	0.012
65079	J1	139.3	0.027
65079	Q1	68.8	0.047
65079	2Q1	137.7	0.013
65079	P1	99.5	0.153
65079	M3	155.1	0.029
65079	L2	140.4	0.029
65079	2MK3	41.4	0.039
65079	K2	108.4	0.105
65079	M8	252.1	0.003
65079	MS4	114.3	0.036
65080	M2	99.7	1.251
65080	S2	120.5	0.312
65080	N2	78.5	0.217
65080	K1	95.6	0.483
65080	M4	113.5	0.082
65080	O1	91.9	0.246
65080	M6	159.2	0.034
65080	MK3	74.9	0.132
65080	S4	122.4	0.018
65080	MN4	84.5	0.031
65080	S6	157.5	0.002
65080	2N2	93	0.038
65080	OO1	89.8	0.036
65080	M1	128.5	0.012
65080	J1	140.9	0.029
65080	Q1	70.3	0.048
65080	2Q1	133.8	0.01
65080	P1	99.6	0.153
65080	M3	153.8	0.028
65080	L2	143.8	0.032
65080	2MK3	39	0.038
65080	K2	105.6	0.106
65080	M8	255.4	0.002
65080	MS4	116.2	0.036
65081	M2	100.1	1.263
65081	S2	119.6	0.315
65081	N2	78	0.216
65081	K1	95.3	0.486
65081	M4	117.1	0.079
65081	O1	90.7	0.248
65081	M6	162.8	0.033
65081	MK3	74.8	0.127
65081	S4	127.5	0.019
65081	MN4	87.4	0.03
65081	S6	167.2	0.003
65081	2N2	91.4	0.04
65081	OO1	86.9	0.037
65081	M1	127.8	0.013
65081	J1	143.6	0.031
65081	Q1	72.9	0.047
65081	2Q1	120.1	0.008
65081	P1	100.8	0.153
65081	M3	153	0.028
65081	L2	148.4	0.033
65081	2MK3	37.5	0.039
65081	K2	102.9	0.108
65081	M8	265	0.002
65081	MS4	118.8	0.037
65082	M2	100.5	1.275
65082	S2	118.8	0.318
65082	N2	77.8	0.216
65082	K1	95.1	0.488
65082	M4	121	0.076
65082	O1	89.4	0.249
65082	M6	166.7	0.033
65082	MK3	74.4	0.122
65082	S4	129.4	0.019
65082	MN4	88.7	0.029
65082	S6	163	0.004
65082	2N2	89.6	0.042
65082	OO1	80.7	0.039
65082	M1	125.3	0.014
65082	J1	146.4	0.032
65082	Q1	76	0.045
65082	2Q1	93.2	0.007
65082	P1	101.8	0.153
65082	M3	153.4	0.027
65082	L2	153.7	0.034
65082	2MK3	35.8	0.039
65082	K2	101.2	0.113
65082	M8	275.6	0.002
65082	MS4	122.4	0.037
65083	M2	100.9	1.285
65083	S2	118.4	0.322
65083	N2	78.2	0.216
65083	K1	95.2	0.491
65083	M4	124.4	0.073
65083	O1	87.8	0.25
65083	M6	170.9	0.034
65083	MK3	74.4	0.115
65083	S4	133.8	0.019
65083	MN4	89.3	0.027
65083	S6	151.7	0.005
65083	2N2	87.5	0.043
65083	OO1	74.7	0.039
65083	M1	122.1	0.014
65083	J1	150.2	0.032
65083	Q1	80.6	0.042
65083	2Q1	70	0.009
65083	P1	101.7	0.153
65083	M3	154.5	0.027
65083	L2	157	0.034
65083	2MK3	36.5	0.04
65083	K2	101.4	0.116
65083	M8	295.8	0.002
65083	MS4	126.6	0.038
65084	M2	101.3	1.293
65084	S2	118.8	0.324
65084	N2	78.5	0.218
65084	K1	95.5	0.495
65084	M4	127.6	0.07
65084	O1	86	0.252
65084	M6	174.3	0.035
65084	MK3	74.4	0.107
65084	S4	136.4	0.019
65084	MN4	91.8	0.025
65084	S6	149.9	0.006
65084	2N2	86.9	0.044
65084	OO1	72.5	0.039
65084	M1	117.6	0.014
65084	J1	152.2	0.032
65084	Q1	86.1	0.038
65084	2Q1	53.6	0.011
65084	P1	101.4	0.151
65084	2SM2	141	0.003
65084	M3	156.9	0.026
65084	L2	159.3	0.032
65084	2MK3	38	0.039
65084	K2	102.8	0.117
65084	M8	322.1	0.002
65084	MS4	129.7	0.039
65085	M2	101.7	1.297
65085	S2	119.4	0.328
65085	N2	79	0.22
65085	K1	95.8	0.498
65085	M4	131.5	0.067
65085	O1	84.1	0.256
65085	M6	176.5	0.036
65085	MK3	74.5	0.1
65085	S4	138.2	0.018
65085	MN4	92.3	0.022
65085	S6	146.7	0.007
65085	2N2	87.7	0.046
65085	OO1	73.9	0.036
65085	M1	115	0.015
65085	J1	153.1	0.03
65085	Q1	88.5	0.035
65085	2Q1	41.6	0.014
65085	P1	100.6	0.148
65085	2SM2	143.3	0.004
65085	M3	158.4	0.025
65085	L2	159.9	0.03
65085	2MK3	43.3	0.037
65085	K2	105.2	0.121
65085	M8	339.6	0.002
65085	MS4	132.9	0.039
65086	M2	101.8	1.294
65086	S2	120.2	0.328
65086	N2	79.5	0.217
65086	K1	95.4	0.505
65086	M4	135.5	0.06
65086	O1	80.8	0.257
65086	M6	181.5	0.036
65086	MK3	70.8	0.092
65086	S4	132.4	0.016
65086	MN4	98.1	0.018
65086	S6	133.9	0.007
65086	2N2	89.8	0.05
65086	OO1	86.2	0.031
65086	M1	113.1	0.013
65086	J1	148.7	0.029
65086	Q1	89.2	0.032
65086	2Q1	34	0.017
65086	P1	100	0.141
65086	2SM2	128	0.006
65086	M3	159.5	0.02
65086	L2	167.1	0.027
65086	2MK3	43.8	0.034
65086	K2	110	0.122
65086	M8	302.7	0.002
65086	MS4	136.9	0.035
65087	M2	100.6	1.247
65087	S2	117.4	0.319
65087	N2	77	0.208
65087	K1	90.9	0.472
65087	M4	191	0.035
65087	O1	66.2	0.259
65087	M6	212.1	0.055
65087	MK3	22.7	0.067
65087	S4	178.7	0.006
65087	MN4	136.5	0.006
65087	S6	184.2	0.006
65087	2N2	101.1	0.068
65087	OO1	132.6	0.055
65087	M1	103.7	0.012
65087	J1	127.2	0.016
65087	Q1	59.2	0.03
65087	2Q1	64.7	0.015
65087	P1	92.2	0.144
65087	M3	126.8	0.011
65087	L2	176.1	0.029
65087	2MK3	347.4	0.04
65087	K2	112.2	0.166
65087	M8	228.2	0.014
65087	MS4	229.8	0.029
65088	M2	84.8	0.569
65088	S2	112.2	0.13
65088	N2	61.8	0.088
65088	K1	75.3	0.203
65088	M4	177.8	0.037
65088	O1	40.3	0.124
65088	M6	107.5	0.019
65088	MK3	159.6	0.023
65088	S4	158.3	0.005
65088	MN4	179.8	0.012
65088	S6	58.3	0.002
65088	2N2	43.6	0.029
65088	OO1	77.8	0.027
65088	M1	144.8	0.008
65088	J1	208.6	0.017
65088	Q1	340.2	0.009
65088	2Q1	346.6	0.017
65088	P1	66.1	0.04
65088	2SM2	184.7	0.002
65088	M3	270.3	0.012
65088	L2	119.7	0.018
65088	2MK3	241.9	0.011
65088	K2	84	0.052
65088	MS4	193.4	0.025
65089	M2	86.3	0.584
65089	S2	110.4	0.132
65089	N2	63.1	0.09
65089	K1	75.8	0.198
65089	M4	177.2	0.037
65089	O1	41.8	0.115
65089	M6	111	0.019
65089	MK3	141.7	0.023
65089	S4	159.1	0.005
65089	MN4	166.4	0.01
65089	S6	79.6	0.002
65089	2N2	41.3	0.026
65089	OO1	71.4	0.028
65089	M1	147.3	0.008
65089	J1	205.6	0.015
65089	Q1	346.9	0.008
65089	2Q1	330.7	0.013
65089	P1	69.6	0.047
65089	2SM2	224.9	0.002
65089	M3	267	0.011
65089	L2	128.1	0.019
65089	2MK3	267.5	0.006
65089	K2	79	0.054
65089	M8	325.6	0.003
65089	MS4	188.4	0.025
65090	M2	88.2	0.59
65090	S2	109.3	0.134
65090	N2	65.8	0.092
65090	K1	77	0.197
65090	M4	172.2	0.035
65090	O1	44.7	0.109
65090	M6	116.2	0.018
65090	MK3	123	0.028
65090	S4	169.5	0.006
65090	MN4	150.2	0.009
65090	S6	90.7	0.002
65090	2N2	42	0.023
65090	OO1	66.3	0.026
65090	M1	148.2	0.008
65090	J1	203.7	0.013
65090	Q1	349.7	0.007
65090	2Q1	318.6	0.011
65090	P1	72.2	0.051
65090	2SM2	277.4	0.002
65090	M3	258.4	0.011
65090	L2	136	0.019
65090	2MK3	342.4	0.003
65090	K2	75.3	0.054
65090	M8	324.7	0.005
65090	MS4	181	0.022
65091	M2	90.2	0.589
65091	S2	109.1	0.135
65091	N2	69.6	0.093
65091	K1	80	0.199
65091	M4	165.9	0.033
65091	O1	49.5	0.106
65091	M6	127.2	0.016
65091	MK3	111.1	0.037
65091	S4	179.8	0.006
65091	MN4	135.2	0.009
65091	S6	129.3	0.001
65091	2N2	48	0.02
65091	OO1	62.4	0.025
65091	M1	146.7	0.008
65091	J1	205.7	0.012
65091	Q1	345	0.006
65091	2Q1	316.5	0.009
65091	P1	74.9	0.052
65091	2SM2	306.2	0.005
65091	M3	239.5	0.01
65091	L2	142.4	0.017
65091	2MK3	50.2	0.006
65091	K2	72.4	0.052
65091	M8	331.9	0.007
65091	MS4	168	0.018
65092	M2	92.6	0.583
65092	S2	108.4	0.135
65092	N2	73.3	0.093
65092	K1	83.9	0.202
65092	M4	159.1	0.031
65092	O1	55.6	0.104
65092	M6	144.4	0.015
65092	MK3	105.4	0.048
65092	S4	182.9	0.005
65092	MN4	125.3	0.008
65092	2N2	58.8	0.018
65092	OO1	59.8	0.026
65092	M1	139.5	0.009
65092	J1	200.1	0.011
65092	Q1	339.5	0.003
65092	2Q1	323.4	0.007
65092	P1	80	0.053
65092	2SM2	317.7	0.007
65092	M3	216.9	0.011
65092	L2	147.9	0.015
65092	2MK3	66.1	0.01
65092	K2	68.2	0.05
65092	M8	336.7	0.009
65092	MS4	142.5	0.015
65093	M2	95.4	0.574
65093	S2	108.4	0.134
65093	N2	76.2	0.092
65093	K1	88.6	0.209
65093	M4	153.5	0.031
65093	O1	62.6	0.103
65093	M6	162.2	0.014
65093	MK3	101.2	0.059
65093	S4	159.3	0.003
65093	MN4	117.7	0.007
65093	S6	4	0.001
65093	2N2	72.1	0.019
65093	OO1	58.9	0.025
65093	M1	128.3	0.009
65093	J1	190.1	0.011
65093	2Q1	353	0.006
65093	P1	86.9	0.053
65093	2SM2	324.7	0.007
65093	M3	203.5	0.013
65093	L2	155.2	0.015
65093	2MK3	70.3	0.013
65093	K2	68.9	0.048
65093	M8	343.1	0.009
65093	MS4	116.7	0.016
65094	M2	98.5	0.565
65094	S2	110.2	0.135
65094	N2	77.9	0.091
65094	K1	94.3	0.221
65094	M4	149.2	0.032
65094	O1	71.3	0.104
65094	M6	177	0.014
65094	MK3	97.2	0.067
65094	S4	102.4	0.002
65094	MN4	107.9	0.007
65094	S6	345.1	0.002
65094	2N2	90.2	0.021
65094	OO1	64.2	0.021
65094	M1	113.8	0.008
65094	J1	183.5	0.01
65094	Q1	111.3	0.006
65094	2Q1	21.9	0.008
65094	P1	92.6	0.051
65094	2SM2	326.9	0.006
65094	M3	194	0.012
65094	L2	162	0.017
65094	2MK3	63.7	0.016
65094	K2	81.1	0.047
65094	M8	343.5	0.009
65094	MS4	104.3	0.019
65095	M2	101.7	0.555
65095	S2	112.6	0.136
65095	N2	78.8	0.092
65095	K1	100.2	0.236
65095	M4	145.6	0.037
65095	O1	82.6	0.107
65095	M6	192.9	0.014
65095	MK3	93.1	0.074
65095	S4	76.8	0.003
65095	MN4	101.5	0.01
65095	S6	312.7	0.003
65095	2N2	106.9	0.026
65095	OO1	85	0.019
65095	M1	97.5	0.007
65095	J1	202	0.007
65095	Q1	105.4	0.013
65095	2Q1	43.5	0.01
65095	P1	99.8	0.051
65095	2SM2	336.8	0.005
65095	M3	178	0.01
65095	L2	172.4	0.019
65095	2MK3	51.8	0.017
65095	K2	99.8	0.049
65095	M8	323.1	0.008
65095	MS4	100.9	0.022
65096	M2	104.9	0.544
65096	S2	114.5	0.139
65096	N2	80.8	0.093
65096	K1	106.5	0.25
65096	M4	143.8	0.041
65096	O1	95.2	0.113
65096	M6	204.4	0.015
65096	MK3	89.4	0.079
65096	S4	79.8	0.006
65096	MN4	107.7	0.014
65096	S6	292	0.002
65096	2N2	116.8	0.031
65096	OO1	116.9	0.025
65096	M1	77.8	0.006
65096	J1	255	0.004
65096	Q1	109.2	0.021
65096	2Q1	73.3	0.011
65096	P1	104.1	0.054
65096	2SM2	14.3	0.004
65096	M3	150.3	0.009
65096	L2	185.8	0.018
65096	2MK3	46.1	0.02
65096	K2	117.3	0.056
65096	M8	297.8	0.009
65096	MS4	103.8	0.022
65097	M2	107.2	0.537
65097	S2	115.3	0.14
65097	N2	84.6	0.094
65097	K1	112.4	0.259
65097	M4	146.8	0.043
65097	O1	107.2	0.121
65097	M6	204.7	0.017
65097	MK3	88.3	0.079
65097	S4	82.8	0.01
65097	MN4	110.5	0.018
65097	S6	231.2	0.002
65097	2N2	120.7	0.037
65097	OO1	140.7	0.034
65097	M1	56.9	0.007
65097	J1	340.1	0.004
65097	Q1	120.1	0.027
65097	2Q1	108.1	0.011
65097	P1	106.9	0.055
65097	2SM2	77.8	0.004
65097	M3	137.7	0.011
65097	L2	203.4	0.015
65097	2MK3	53.9	0.024
65097	K2	126.9	0.06
65097	M8	288.3	0.011
65097	MS4	112.8	0.021
65098	M2	107.1	0.52
65098	S2	115.6	0.135
65098	N2	86.7	0.095
65098	K1	115	0.25
65098	M4	161.6	0.037
65098	O1	110.7	0.113
65098	M6	216.4	0.019
65098	MK3	81.5	0.066
65098	S4	68.8	0.012
65098	MN4	105.7	0.015
65098	S6	199.1	0.004
65098	2N2	122.5	0.043
65098	OO1	163.3	0.053
65098	M1	31.4	0.009
65098	J1	31.4	0.011
65098	Q1	130.1	0.03
65098	2Q1	141.5	0.014
65098	P1	102.9	0.06
65098	2SM2	86.3	0.005
65098	M3	116.3	0.015
65098	L2	244.8	0.012
65098	2MK3	39.4	0.029
65098	K2	141	0.066
65098	M8	282.2	0.014
65098	MS4	117.8	0.009
65099	M2	49.4	0.563
65099	S2	62.7	0.13
65099	N2	22	0.085
65099	K1	72.2	0.228
65099	M4	344.4	0.016
65099	O1	45.9	0.128
65099	M6	5.7	0.032
65099	MK3	47.4	0.043
65099	S4	260.4	0.01
65099	MN4	293.9	0.024
65099	S6	344.7	0.001
65099	2N2	5.6	0.016
65099	OO1	86.1	0.033
65099	M1	89.8	0.019
65099	J1	103.4	0.008
65099	Q1	36.1	0.016
65099	2Q1	324.7	0.013
65099	P1	57.9	0.072
65099	2SM2	271.8	0.002
65099	M3	304.1	0.005
65099	L2	79.4	0.021
65099	2MK3	358.2	0.035
65099	K2	65.5	0.034
65099	M8	60.5	0.004
65099	MS4	8.1	0.019
65100	M2	47.7	0.551
65100	S2	64.5	0.123
65100	N2	18.1	0.097
65100	K1	74.5	0.215
65100	M4	57	0.026
65100	O1	46.7	0.123
65100	M6	29.6	0.025
65100	MK3	30.2	0.021
65100	S4	342.5	0.001
65100	MN4	68.2	0.006
65100	S6	83.8	0.004
65100	2N2	283.4	0.004
65100	OO1	105.3	0.014
65100	M1	86.9	0.013
65100	J1	72	0.007
65100	Q1	355.8	0.008
65100	2Q1	280.1	0.019
65100	P1	62.1	0.051
65100	2SM2	278.8	0.007
65100	M3	62.9	0.006
65100	L2	57.7	0.012
65100	2MK3	12.1	0.027
65100	K2	31.3	0.042
65100	M8	356.4	0.008
65100	MS4	49.2	0.004
65101	M2	33.9	0.585
65101	S2	42.2	0.105
65101	N2	4.3	0.087
65101	K1	75.7	0.164
65101	M4	16.9	0.089
65101	O1	79	0.128
65101	M6	40.5	0.059
65101	MK3	320.8	0.045
65101	S4	260.4	0.015
65101	MN4	15.1	0.034
65101	S6	311.2	0.01
65101	2N2	128.4	0.003
65101	OO1	169.9	0.012
65101	M1	187.1	0.029
65101	J1	21.3	0.017
65101	Q1	109.5	0.022
65101	2Q1	35.1	0.01
65101	P1	87.9	0.046
65101	2SM2	129.4	0.005
65101	M3	83.8	0.006
65101	L2	62.1	0.028
65101	2MK3	183.8	0.014
65101	K2	27.4	0.058
65101	M8	253.5	0.003
65101	MS4	339.9	0.023
65102	M2	39.7	0.644
65102	S2	61	0.159
65102	N2	8	0.114
65102	K1	65.8	0.311
65102	M4	337.7	0.049
65102	O1	52.8	0.242
65102	M6	347.1	0.034
65102	MK3	31.9	0.017
65102	S4	321.6	0.008
65102	MN4	331.2	0.008
65102	S6	134.4	0.004
65102	2N2	80.2	0.017
65102	OO1	105.1	0.045
65102	M1	101.4	0.019
65102	J1	114.1	0.014
65102	Q1	55.5	0.035
65102	2Q1	197.3	0.005
65102	P1	79.2	0.09
65102	2SM2	284.4	0.013
65102	M3	218.4	0.014
65102	L2	110.6	0.025
65102	2MK3	40.4	0.022
65102	K2	355.9	0.044
65102	M8	279.3	0.008
65102	MS4	77	0.022
65103	M2	48.3	0.752
65103	S2	60.9	0.155
65103	N2	16.7	0.126
65103	K1	74.3	0.287
65103	M4	13.4	0.038
65103	O1	44.7	0.127
65103	M6	50	0.042
65103	MK3	358.5	0.072
65103	S4	332.1	0.011
65103	MN4	326.4	0.013
65103	S6	10.7	0.003
65103	2N2	95.4	0.016
65103	OO1	73.4	0.011
65103	M1	18.2	0.004
65103	J1	70.7	0.012
65103	Q1	12.7	0.019
65103	2Q1	43.3	0.017
65103	P1	58.1	0.101
65103	2SM2	37.9	0.012
65103	M3	66.1	0.006
65103	L2	63.3	0.017
65103	2MK3	318.3	0.055
65103	K2	68.7	0.05
65103	MS4	41.5	0.023
65104	M2	46.2	0.777
65104	S2	59.8	0.16
65104	N2	14.5	0.123
65104	K1	69.6	0.293
65104	M4	29.3	0.041
65104	O1	41.2	0.143
65104	M6	47.4	0.043
65104	MK3	4	0.064
65104	S4	322.1	0.008
65104	MN4	349.2	0.01
65104	S6	19.5	0.003
65104	2N2	67.1	0.018
65104	OO1	313.6	0.009
65104	M1	322.7	0.007
65104	J1	22.3	0.025
65104	Q1	2.7	0.027
65104	2Q1	27.9	0.012
65104	P1	50.4	0.102
65104	2SM2	55.5	0.006
65104	M3	44.3	0.008
65104	L2	64.3	0.019
65104	2MK3	310.8	0.048
65104	K2	70.1	0.051
65104	M8	186.6	0.001
65104	MS4	52.3	0.023
65105	M2	49	0.839
65105	S2	59.6	0.174
65105	N2	20.2	0.134
65105	K1	55.5	0.345
65105	M4	309.2	0.012
65105	O1	31.6	0.224
65105	M6	36.6	0.041
65105	MK3	28	0.023
65105	S4	207.7	0.005
65105	MN4	267	0.01
65105	S6	309.7	0.005
65105	2N2	74.6	0.017
65105	OO1	86.2	0.049
65105	M1	42.8	0.022
65105	J1	48.1	0.007
65105	Q1	1.1	0.062
65105	2Q1	168.3	0.014
65105	P1	47.1	0.132
65105	2SM2	126.1	0.01
65105	M3	224.9	0.004
65105	L2	95.5	0.061
65105	2MK3	344.9	0.031
65105	K2	84.6	0.03
65105	M8	328	0.004
65105	MS4	47.1	0.028
65106	M2	52.8	0.776
65106	S2	63.1	0.19
65106	N2	17.9	0.128
65106	K1	77.8	0.339
65106	M4	63.6	0.023
65106	O1	57.4	0.185
65106	M6	45.4	0.034
65106	MK3	90.5	0.055
65106	S4	313.1	0.009
65106	MN4	39.5	0.009
65106	S6	173.1	0.002
65106	2N2	57.8	0.022
65106	OO1	120.5	0.025
65106	M1	67	0.007
65106	J1	96	0.015
65106	Q1	44.7	0.022
65106	2Q1	34.4	0.011
65106	P1	68.2	0.082
65106	2SM2	353.7	0.004
65106	M3	340.1	0.002
65106	L2	100.2	0.033
65106	2MK3	354.8	0.031
65106	K2	39.6	0.054
65106	M8	194.9	0.005
65106	MS4	63.8	0.022
65107	M2	47.9	0.71
65107	S2	66.5	0.176
65107	N2	14.8	0.138
65107	K1	79.1	0.326
65107	M4	358.5	0.064
65107	O1	65.5	0.211
65107	M6	1.8	0.035
65107	MK3	6.5	0.085
65107	S4	286.3	0.011
65107	MN4	353.2	0.018
65107	S6	41.1	0.002
65107	2N2	114.5	0.026
65107	OO1	156.1	0.03
65107	M1	152.1	0.018
65107	J1	99.6	0.025
65107	Q1	103.3	0.021
65107	2Q1	11.7	0.012
65107	P1	71.1	0.099
65107	2SM2	300.2	0.007
65107	M3	60.7	0.026
65107	L2	275.9	0.021
65107	2MK3	340.6	0.077
65107	K2	54.5	0.059
65107	M8	346.1	0.006
65107	MS4	357.1	0.022
65108	M2	45.5	0.722
65108	S2	59.4	0.173
65108	N2	20.3	0.124
65108	K1	68.2	0.303
65108	M4	1.6	0.048
65108	O1	49.7	0.189
65108	M6	321.7	0.021
65108	MK3	29.5	0.063
65108	S4	22	0.005
65108	MN4	21.2	0.016
65108	S6	46.4	0.002
65108	2N2	165	0.015
65108	OO1	96.9	0.035
65108	M1	356	0.003
65108	J1	111.1	0.006
65108	Q1	356.8	0.015
65108	2Q1	46.5	0.014
65108	P1	58.4	0.078
65108	2SM2	89.3	0.007
65108	M3	83.4	0.011
65108	L2	114.7	0.027
65108	2MK3	0.9	0.035
65108	K2	44.1	0.019
65108	M8	319.5	0.006
65108	MS4	60.7	0.034
65109	M2	42.8	0.751
65109	S2	56.3	0.166
65109	N2	10.7	0.133
65109	K1	63	0.329
65109	M4	49.4	0.079
65109	O1	33.6	0.204
65109	M6	107.6	0.006
65109	MK3	67.4	0.091
65109	S4	327.8	0.005
65109	MN4	5.6	0.03
65109	2N2	61.4	0.018
65109	OO1	102.2	0.023
65109	M1	92.6	0.014
65109	J1	80.3	0.016
65109	Q1	29.7	0.025
65109	2Q1	349.5	0.012
65109	P1	54.1	0.098
65109	2SM2	324	0.007
65109	M3	70.8	0.012
65109	L2	101.1	0.021
65109	2MK3	1.6	0.043
65109	K2	6.7	0.036
65109	M8	11.4	0.006
65109	MS4	66.7	0.027
65110	M2	64.2	0.273
65110	S2	70.8	0.076
65110	N2	17.8	0.042
65110	K1	81.9	0.146
65110	M4	215.1	0.033
65110	O1	52.5	0.101
65110	M6	255	0.017
65110	MK3	264.4	0.011
65110	S4	345.6	0.002
65110	MN4	176.1	0.021
65110	S6	97.5	0.002
65110	2N2	91.6	0.016
65110	OO1	150.3	0.019
65110	M1	128.7	0.022
65110	J1	115.8	0.003
65110	Q1	63.6	0.029
65110	2Q1	122.1	0.011
65110	P1	80.5	0.026
65110	2SM2	300.3	0.01
65110	M3	131	0.009
65110	L2	166.4	0.026
65110	2MK3	286	0.016
65110	K2	61.1	0.033
65110	M8	44.9	0.002
65110	MS4	258.7	0.008
65111	M2	64.2	0.313
65111	S2	84.2	0.072
65111	N2	14.7	0.06
65111	K1	78.8	0.158
65111	M4	204.2	0.007
65111	O1	52.1	0.11
65111	M6	286.3	0.015
65111	MK3	347.5	0.009
65111	S4	277.7	0.003
65111	MN4	107.4	0.007
65111	S6	168.7	0.002
65111	2N2	103.4	0.021
65111	OO1	101.9	0.035
65111	M1	106.2	0.014
65111	J1	67.5	0.01
65111	Q1	36.9	0.025
65111	2Q1	52	0.019
65111	P1	48.1	0.042
65111	2SM2	338.7	0.003
65111	M3	44.8	0.011
65111	L2	246	0.009
65111	2MK3	352	0.022
65111	K2	74.3	0.011
65111	M8	313	0.003
65111	MS4	147.5	0.013
65112	M2	62.2	0.332
65112	S2	73.8	0.099
65112	N2	9.4	0.027
65112	K1	85.8	0.134
65112	M4	40.8	0.039
65112	O1	95.7	0.061
65112	M6	335.7	0.012
65112	MK3	359.5	0.026
65112	S4	36	0.006
65112	MN4	23.7	0.024
65112	S6	336.5	0.003
65112	2N2	200.8	0.006
65112	OO1	123.4	0.035
65112	M1	225.9	0.015
65112	J1	345.4	0.018
65112	Q1	187.5	0.006
65112	2Q1	127.5	0.016
65112	P1	44.7	0.061
65112	2SM2	50.2	0.004
65112	M3	325.3	0.022
65112	L2	128	0.025
65112	2MK3	249.4	0.009
65112	K2	111.2	0.044
65112	M8	338.8	0.004
65112	MS4	118.2	0.013
65113	M2	55	0.471
65113	S2	70.6	0.305
65113	N2	22.9	0.187
65113	K1	81	0.233
65113	M4	180.1	0.052
65113	O1	356.2	0.117
65113	M6	310.9	0.074
65113	MK3	144	0.151
65113	S4	339.7	0.054
65113	MN4	222.1	0.045
65113	S6	28.4	0.004
65113	2N2	199.6	0.124
65113	OO1	238.2	0.063
65113	M1	340.7	0.03
65113	J1	31.5	0.059
65113	Q1	203.9	0.027
65113	2Q1	16.8	0.076
65113	P1	27.6	0.043
65113	2SM2	188.9	0.031
65113	M3	205.3	0.064
65113	L2	315.5	0.046
65113	2MK3	86.5	0.141
65113	K2	36.6	0.118
65113	M8	58.1	0.051
65113	MS4	225.6	0.092
65114	M2	61.5	0.901
65114	S2	76.8	0.175
65114	N2	30.8	0.118
65114	K1	70.1	0.344
65114	M4	310.9	0.048
65114	O1	77	0.141
65114	M6	301.4	0.014
65114	MK3	276.7	0.068
65114	MN4	246.4	0.006
65114	S6	250.1	0.011
65114	2N2	66.3	0.047
65114	OO1	162.2	0.031
65114	M1	115.8	0.015
65114	J1	47.6	0.012
65114	Q1	118.1	0.031
65114	2Q1	261.3	0.022
65114	P1	75.7	0.093
65114	2SM2	354.9	0.023
65114	M3	282.5	0.018
65114	L2	135.7	0.02
65114	2MK3	110.6	0.012
65114	K2	12.1	0.046
65114	M8	82.8	0.009
65114	MS4	293.9	0.034
65115	M2	61.4	0.896
65115	S2	77.5	0.198
65115	N2	29.1	0.117
65115	K1	75.4	0.344
65115	M4	322.8	0.061
65115	O1	79.7	0.14
65115	M6	190.5	0.009
65115	MK3	280.5	0.096
65115	S4	6.7	0.011
65115	MN4	317.8	0.011
65115	S6	232.6	0.008
65115	2N2	73.3	0.047
65115	OO1	157.3	0.035
65115	M1	134.4	0.015
65115	J1	48.4	0.026
65115	Q1	86.4	0.037
65115	2Q1	234.7	0.024
65115	P1	70.1	0.088
65115	2SM2	2.8	0.024
65115	M3	272.2	0.017
65115	L2	155.3	0.043
65115	2MK3	3.4	0.015
65115	K2	33.4	0.054
65115	M8	46.4	0.008
65115	MS4	309.4	0.022
65116	M2	60.3	0.874
65116	S2	86.3	0.178
65116	N2	45.4	0.173
65116	K1	76.1	0.473
65116	M4	120.1	0.114
65116	O1	51.8	0.408
65116	M6	209.3	0.066
65116	MK3	199.7	0.037
65116	S4	347	0.018
65116	MN4	82.3	0.046
65116	S6	178.2	0.004
65116	2N2	20.3	0.036
65116	OO1	100.4	0.082
65116	M1	121.8	0.069
65116	J1	151.2	0.047
65116	Q1	61.9	0.074
65116	2Q1	318.9	0.07
65116	P1	74.9	0.177
65116	2SM2	268.1	0.022
65116	M3	302.1	0.048
65116	L2	41.2	0.011
65116	2MK3	177.4	0.109
65116	K2	75.7	0.146
65116	M8	278.5	0.044
65116	MS4	55.2	0.022
65117	M2	66.7	0.79
65117	S2	99	0.186
65117	N2	35.7	0.11
65117	K1	87.4	0.425
65117	M4	310.9	0.084
65117	O1	48.9	0.391
65117	M6	148.4	0.046
65117	MK3	274.2	0.14
65117	S4	322.8	0.012
65117	MN4	289.8	0.03
65117	S6	48.8	0.005
65117	2N2	325.6	0.05
65117	OO1	55	0.138
65117	M1	81.5	0.037
65117	J1	133.9	0.058
65117	Q1	31.2	0.121
65117	2Q1	195.7	0.073
65117	P1	67.5	0.176
65117	2SM2	126.9	0.012
65117	M3	301.4	0.011
65117	L2	123.1	0.026
65117	2MK3	216.7	0.05
65117	K2	35.3	0.086
65117	M8	271.2	0.01
65117	MS4	290.1	0.031
65118	M2	67	0.759
65118	S2	97.9	0.166
65118	N2	27.4	0.105
65118	K1	89.2	0.414
65118	M4	292.2	0.101
65118	O1	47.4	0.381
65118	M6	123	0.043
65118	MK3	280.4	0.155
65118	S4	301.8	0.015
65118	MN4	259.3	0.024
65118	S6	55	0.003
65118	2N2	327.8	0.054
65118	OO1	41	0.164
65118	M1	81.2	0.033
65118	J1	145.2	0.061
65118	Q1	32.1	0.126
65118	2Q1	195.2	0.082
65118	P1	63.2	0.149
65118	2SM2	92.8	0.012
65118	M3	299.5	0.005
65118	L2	125.5	0.033
65118	2MK3	217.6	0.068
65118	K2	36.7	0.083
65118	M8	302.9	0.002
65118	MS4	292.1	0.041
65119	M2	39.3	0.554
65119	S2	59.2	0.187
65119	N2	11.1	0.143
65119	K1	50.7	0.191
65119	M4	318.7	0.117
65119	O1	341.7	0.14
65119	M6	332.4	0.018
65119	MK3	312.8	0.074
65119	S4	287.7	0.006
65119	MN4	292.3	0.059
65119	NU2	13.4	0.025
65119	S6	355.3	0.005
65119	MU2	312.7	0.041
65119	2N2	193.9	0.023
65119	OO1	32.5	0.055
65119	LDA2	158.7	0.011
65119	M1	138.5	0.018
65119	J1	297.5	0.004
65119	RHO1	301.9	0.002
65119	Q1	190.8	0.014
65119	2Q1	15.6	0.027
65119	P1	24.9	0.056
65119	2SM2	306.1	0.006
65119	M3	332.6	0.038
65119	L2	172	0.019
65119	2MK3	358.1	0.022
65119	K2	319.9	0.019
65119	M8	100.9	0.012
65119	MS4	334.5	0.052
65120	M2	52.2	0.723
65120	S2	65.1	0.167
65120	N2	19.8	0.138
65120	K1	73.8	0.325
65120	M4	93.2	0.071
65120	O1	77.8	0.233
65120	M6	83.2	0.042
65120	MK3	64.4	0.1
65120	S4	176.8	0.001
65120	MN4	52.4	0.039
65120	NU2	38.4	0.016
65120	S6	91.4	0.007
65120	MU2	289.2	0.028
65120	2N2	29	0.02
65120	LDA2	88.7	0.02
65120	M1	94.8	0.007
65120	J1	107.6	0.014
65120	RHO1	59.9	0.01
65120	Q1	33.7	0.044
65120	2Q1	232.8	0.011
65120	P1	74.3	0.096
65120	2SM2	238.2	0.004
65120	M3	103.2	0.02
65120	L2	78.3	0.039
65120	2MK3	335.3	0.044
65120	K2	84.5	0.072
65120	M8	154.1	0.011
65120	MS4	104.7	0.055
65121	M2	54.7	0.746
65121	S2	74.8	0.148
65121	N2	35.3	0.149
65121	K1	87	0.326
65121	M4	95.6	0.131
65121	O1	91.4	0.208
65121	M6	80	0.03
65121	MK3	60.5	0.087
65121	S4	217.5	0.005
65121	MN4	63.2	0.044
65121	NU2	22.4	0.04
65121	S6	98	0.007
65121	2N2	346.5	0.023
65121	OO1	80.9	0.02
65121	LDA2	94.3	0.017
65121	M1	64.2	0.009
65121	J1	107.8	0.018
65121	RHO1	18.4	0.013
65121	Q1	61.2	0.03
65121	2Q1	216.1	0.007
65121	P1	94.6	0.112
65121	2SM2	172.4	0.01
65121	M3	150.4	0.018
65121	L2	72.9	0.052
65121	2MK3	303.6	0.025
65121	K2	80.7	0.051
65121	M8	182.6	0.017
65121	MS4	104	0.057
65122	M2	59.3	0.308
65122	S2	67.3	0.074
65122	N2	43	0.037
65122	K1	84.2	0.112
65122	M4	161.6	0.017
65122	O1	85.2	0.061
65122	M6	261.2	0.01
65122	MK3	104.4	0.006
65122	S4	291	0.001
65122	MN4	164.1	0.01
65122	S6	112.1	0.003
65122	2N2	295.1	0.005
65122	OO1	191.8	0.002
65122	M1	258.4	0.003
65122	J1	73.2	0.005
65122	Q1	209.6	0.012
65122	2Q1	358.1	0.002
65122	P1	81.1	0.032
65122	2SM2	32.6	0.008
65122	M3	270.7	0.01
65122	L2	123.7	0.012
65122	2MK3	282.5	0.007
65122	K2	63	0.032
65122	M8	148.8	0.004
65122	MS4	254.8	0.005
65123	M2	64.1	0.315
65123	S2	81	0.058
65123	N2	43.2	0.068
65123	K1	85.7	0.149
65123	M4	270.8	0.024
65123	O1	62.9	0.1
65123	M6	290.6	0.018
65123	MK3	310.4	0.015
65123	S4	339.7	0.011
65123	MN4	204.1	0.008
65123	S6	149.5	0.001
65123	2N2	93.7	0.006
65123	OO1	56.3	0.002
65123	M1	65.2	0.005
65123	J1	91.5	0.023
65123	Q1	64	0.02
65123	2Q1	294.2	0.005
65123	P1	86.1	0.062
65123	2SM2	210.5	0.009
65123	M3	145.1	0.006
65123	L2	65.3	0.005
65123	2MK3	317.9	0.012
65123	K2	29.2	0.023
65123	M8	15.3	0.002
65123	MS4	298.6	0.002
65124	M2	71.7	0.299
65124	S2	98.4	0.075
65124	N2	39.9	0.073
65124	K1	74.6	0.154
65124	M4	278.8	0.036
65124	O1	49.7	0.111
65124	M6	296.6	0.025
65124	MK3	338.9	0.033
65124	S4	325.2	0.001
65124	MN4	224.8	0.008
65124	S6	261.3	0.003
65124	2N2	126.4	0.017
65124	OO1	111.9	0.021
65124	M1	90.6	0.017
65124	J1	134.8	0.019
65124	Q1	61.3	0.028
65124	2Q1	152.4	0.008
65124	P1	73.5	0.079
65124	2SM2	173.7	0.006
65124	M3	103	0.021
65124	L2	144.9	0.016
65124	2MK3	340.6	0.023
65124	K2	45.5	0.017
65124	M8	23.5	0.006
65124	MS4	141.3	0.012
65125	M2	66.6	1.746
65125	S2	81	0.402
65125	N2	37.1	0.33
65125	K1	78.9	0.695
65125	M4	63.4	0.061
65125	O1	66.8	0.344
65125	M6	121.5	0.025
65125	MK3	354.6	0.091
65125	S4	308	0.007
65125	MN4	18.4	0.016
65125	NU2	54.5	0.062
65125	MU2	279	0.077
65125	2N2	334.3	0.014
65125	OO1	154.9	0.045
65125	LDA2	120.5	0.037
65125	M1	139.3	0.026
65125	J1	55.6	0.023
65125	RHO1	32.2	0.02
65125	Q1	72.8	0.034
65125	2Q1	153.9	0.014
65125	P1	77	0.207
65125	2SM2	42.3	0.004
65125	M3	62.6	0.031
65125	L2	109.4	0.112
65125	2MK3	319.1	0.093
65125	K2	99.3	0.105
65125	M8	100.5	0.007
65125	MS4	86	0.011
65126	M2	65.4	1.796
65126	S2	84.6	0.432
65126	N2	32.3	0.363
65126	K1	69	0.7
65126	M4	190.5	0.162
65126	O1	54	0.358
65126	M6	118.6	0.019
65126	MK3	167.2	0.057
65126	S4	5.3	0.012
65126	MN4	137.5	0.041
65126	NU2	27.4	0.058
65126	S6	30.3	0.006
65126	MU2	312.4	0.078
65126	2N2	2.3	0.034
65126	OO1	106.4	0.054
65126	LDA2	129.3	0.05
65126	M1	124.2	0.045
65126	J1	107.7	0.018
65126	RHO1	50.8	0.025
65126	Q1	79.9	0.054
65126	2Q1	77.7	0.019
65126	P1	73.6	0.172
65126	2SM2	14.7	0.02
65126	M3	318.5	0.015
65126	L2	115.2	0.091
65126	2MK3	291.2	0.049
65126	K2	84.4	0.099
65126	M8	141.3	0.019
65126	MS4	219.4	0.049
65127	M2	62.5	1.542
65127	S2	83.3	0.401
65127	N2	28.5	0.328
65127	K1	60.6	0.646
65127	M4	196.5	0.253
65127	O1	37.6	0.294
65127	M6	140.6	0.053
65127	MK3	200.8	0.154
65127	S4	357.7	0.014
65127	MN4	152.4	0.074
65127	NU2	31.4	0.049
65127	S6	68.7	0.003
65127	MU2	335.3	0.069
65127	2N2	347.4	0.052
65127	OO1	95.4	0.039
65127	LDA2	148.1	0.055
65127	M1	100.9	0.05
65127	J1	130.7	0.038
65127	RHO1	57.5	0.021
65127	Q1	80.1	0.042
65127	2Q1	32.5	0.026
65127	P1	70.4	0.143
65127	2SM2	24.5	0.021
65127	M3	309	0.032
65127	L2	108.2	0.059
65127	2MK3	257.1	0.035
65127	K2	71.2	0.075
65127	M8	120.8	0.033
65127	MS4	221.7	0.091
65128	M2	42.9	0.99
65128	S2	63.9	0.186
65128	N2	14.7	0.147
65128	K1	59.8	0.2
65128	M4	104.2	0.083
65128	O1	79.6	0.073
65128	M6	285.1	0.032
65128	MK3	53.4	0.086
65128	S4	148.3	0.007
65128	MN4	89.6	0.038
65128	S6	246.6	0.01
65128	2N2	27.5	0.053
65128	OO1	60.6	0.053
65128	M1	115	0.01
65128	J1	199.2	0.029
65128	Q1	107.2	0.008
65128	2Q1	236.3	0.036
65128	P1	46.7	0.071
65128	2SM2	234.1	0.016
65128	M3	261	0.012
65128	L2	78.2	0.049
65128	2MK3	301.9	0.054
65128	K2	19.1	0.043
65128	M8	252	0.03
65128	MS4	15.6	0.04
65129	M2	51.8	0.888
65129	S2	60.7	0.22
65129	N2	20.8	0.142
65129	K1	66.6	0.392
65129	M4	175.8	0.033
65129	O1	48.8	0.207
65129	M6	356.6	0.023
65129	MK3	141.3	0.075
65129	S4	295.7	0.004
65129	MN4	128.7	0.036
65129	S6	172.3	0.008
65129	2N2	88.7	0.067
65129	OO1	207.1	0.058
65129	M1	295.8	0.025
65129	J1	53.9	0.035
65129	Q1	286.3	0.025
65129	2Q1	69	0.02
65129	P1	59.3	0.073
65129	2SM2	327.3	0.01
65129	M3	188.4	0.041
65129	L2	126.7	0.052
65129	2MK3	56.1	0.069
65129	K2	21.1	0.062
65129	M8	296.3	0.02
65129	MS4	139.6	0.035
65130	M2	58.1	0.904
65130	S2	44.3	0.185
65130	N2	10.7	0.094
65130	K1	73.4	0.401
65130	M4	186.8	0.036
65130	O1	90.3	0.185
65130	M6	343.4	0.032
65130	MK3	129.9	0.054
65130	S4	234.1	0.019
65130	MN4	193.8	0.027
65130	S6	226.7	0.004
65130	2N2	66.1	0.089
65130	OO1	177.5	0.078
65130	M1	260.9	0.044
65130	J1	68.7	0.028
65130	Q1	267.7	0.022
65130	2Q1	82.1	0.017
65130	P1	103	0.072
65130	2SM2	127.1	0.007
65130	M3	192.2	0.046
65130	L2	117.4	0.078
65130	2MK3	46.5	0.068
65130	K2	5.4	0.129
65130	M8	288	0.032
65130	MS4	154.9	0.024
65131	M2	58.5	0.904
65131	S2	41.4	0.189
65131	N2	7.9	0.088
65131	K1	72.9	0.394
65131	M4	195.3	0.04
65131	O1	94.3	0.185
65131	M6	340.9	0.026
65131	MK3	134.3	0.043
65131	S4	233.7	0.025
65131	MN4	200.1	0.03
65131	S6	235.8	0.006
65131	2N2	67.3	0.094
65131	OO1	178.9	0.094
65131	M1	258.5	0.046
65131	J1	57	0.028
65131	Q1	267.4	0.022
65131	2Q1	104.2	0.018
65131	P1	101.1	0.078
65131	2SM2	155.4	0.006
65131	M3	192.2	0.044
65131	L2	116	0.083
65131	2MK3	40.8	0.061
65131	K2	11.2	0.128
65131	M8	285.1	0.029
65131	MS4	175.5	0.025
65132	M2	45.1	0.396
65132	S2	88.4	0.098
65132	N2	6.3	0.094
65132	K1	49.6	0.13
65132	M4	283.7	0.048
65132	O1	356.1	0.08
65132	M6	272.1	0.011
65132	MK3	262.2	0.047
65132	S4	65.1	0.007
65132	MN4	210.2	0.017
65132	S6	26.4	0.001
65132	2N2	92.6	0.02
65132	OO1	234.4	0.011
65132	M1	330	0.019
65132	J1	78.6	0.028
65132	Q1	277.9	0.024
65132	2Q1	325.5	0.004
65132	P1	45.4	0.029
65132	2SM2	304.3	0.004
65132	M3	194.2	0.018
65132	L2	326.4	0.008
65132	2MK3	20.7	0.007
65132	M8	197.3	0.004
65132	MS4	297.5	0.015
65133	M2	42.6	0.313
65133	S2	86	0.07
65133	N2	9.7	0.071
65133	K1	70.3	0.104
65133	M4	274.1	0.056
65133	O1	20.7	0.032
65133	M6	170.7	0.014
65133	MK3	269.6	0.04
65133	S4	56.2	0.005
65133	MN4	226.9	0.016
65133	S6	45	0.004
65133	2N2	84.5	0.013
65133	OO1	307.5	0.012
65133	M1	252.8	0.006
65133	J1	80.4	0.03
65133	Q1	194.3	0.012
65133	2Q1	201.1	0.003
65133	P1	104.3	0.032
65133	2SM2	343.7	0.001
65133	M3	157.5	0.012
65133	L2	58.3	0.009
65133	2MK3	299.4	0.007
65133	M8	161.1	0.012
65133	MS4	300.1	0.022
65134	M2	38	0.225
65134	S2	61.2	0.063
65134	N2	13.8	0.062
65134	K1	71.7	0.107
65134	M4	219.3	0.027
65134	O1	57.6	0.058
65134	M6	104.8	0.015
65134	MK3	254.5	0.032
65134	S4	153.8	0.007
65134	MN4	152.8	0.016
65134	S6	100.3	0.003
65134	2N2	300.7	0.003
65134	OO1	227.4	0.018
65134	M1	202.8	0.012
65134	J1	107.7	0.022
65134	Q1	100.8	0.017
65134	2Q1	282.2	0.006
65134	P1	97.8	0.051
65134	2SM2	125.6	0.01
65134	M3	208.2	0.004
65134	L2	52.2	0.009
65134	2MK3	296.9	0.009
65134	M8	90.7	0.008
65134	MS4	170.3	0.027
65135	M2	349.4	0.077
65135	S2	164.4	0.011
65135	N2	230.3	0.026
65135	K1	111.6	0.023
65135	M4	294.3	0.032
65135	O1	163.8	0.011
65135	M6	154.2	0.007
65135	MK3	289.3	0.023
65135	S4	292.5	0.002
65135	MN4	186.5	0.007
65135	S6	339.5	0.001
65135	2N2	333.6	0.023
65135	OO1	5.3	0.004
65135	M1	278.9	0.011
65135	J1	122.1	0.012
65135	Q1	321.1	0.005
65135	2Q1	62.8	0.003
65135	2SM2	327.6	0.004
65135	M3	297.3	0.008
65135	L2	236.5	0.006
65135	2MK3	249.2	0.009
65135	M8	204.2	0.001
65135	MS4	296.4	0.01
65136	M2	357.4	2.463
65136	S2	17.5	0.523
65136	N2	318.9	0.217
65136	K1	35.7	0.294
65136	M4	331	0.376
65136	O1	110.4	0.148
65136	M6	184.1	0.191
65136	MK3	319.1	0.263
65136	S4	251.5	0.008
65136	MN4	279.1	0.102
65136	S6	61.8	0.008
65136	2N2	4.3	0.185
65136	OO1	54.7	0.126
65136	M1	107.9	0.039
65136	J1	197.1	0.046
65136	Q1	92	0.045
65136	2Q1	203.3	0.03
65136	P1	17.8	0.144
65136	2SM2	183	0.036
65136	M3	346.8	0.039
65136	L2	48.8	0.253
65136	2MK3	243.8	0.092
65136	K2	41.8	0.191
65136	M8	183.5	0.068
65136	MS4	3.9	0.126
65137	M2	358	3.084
65137	S2	11.6	0.588
65137	N2	316.7	0.351
65137	K1	36.8	0.365
65137	M4	336.6	0.46
65137	O1	110.9	0.182
65137	M6	179.9	0.249
65137	MK3	318.1	0.321
65137	S4	304.7	0.021
65137	MN4	290.3	0.142
65137	S6	14.1	0.006
65137	2N2	351.8	0.196
65137	OO1	57	0.125
65137	M1	109.8	0.041
65137	J1	177.2	0.045
65137	Q1	96.5	0.059
65137	2Q1	202.8	0.033
65137	P1	12.9	0.152
65137	2SM2	217.8	0.011
65137	M3	358.3	0.04
65137	L2	42.3	0.222
65137	2MK3	234.3	0.095
65137	K2	11.7	0.177
65137	M8	179.7	0.087
65137	MS4	2.8	0.167
65138	M2	36.7	1.393
65138	S2	46.1	0.313
65138	N2	2.8	0.232
65138	K1	52.3	0.396
65138	M4	97.2	0.057
65138	O1	41.6	0.179
65138	M6	215	0.082
65138	MK3	359.3	0.169
65138	S4	69	0.014
65138	MN4	320.8	0.022
65138	S6	26.5	0.007
65138	2N2	71.1	0.056
65138	OO1	48.5	0.036
65138	M1	57.5	0.018
65138	J1	174.4	0.021
65138	Q1	19.5	0.035
65138	2Q1	42.3	0.007
65138	P1	23.7	0.117
65138	2SM2	48.4	0.01
65138	M3	296.5	0.015
65138	L2	100.4	0.07
65138	2MK3	307.8	0.093
65138	K2	44.8	0.118
65138	M8	304.5	0.017
65138	MS4	71	0.057
65139	M2	39.8	1.912
65139	S2	47.8	0.447
65139	N2	2.5	0.346
65139	K1	47.3	0.637
65139	M4	106.4	0.18
65139	O1	31	0.339
65139	M6	197.8	0.14
65139	MK3	27.4	0.247
65139	S4	48.2	0.023
65139	MN4	52.7	0.065
65139	S6	71.9	0.007
65139	2N2	93.5	0.093
65139	OO1	101.3	0.054
65139	M1	122.8	0.028
65139	J1	213.9	0.014
65139	Q1	36.6	0.041
65139	2Q1	354.8	0.031
65139	P1	32.6	0.149
65139	2SM2	30.2	0.005
65139	M3	288.2	0.034
65139	L2	106.7	0.069
65139	2MK3	337	0.174
65139	K2	47.6	0.126
65139	M8	323.9	0.022
65139	MS4	100.2	0.127
65140	M2	40.5	1.854
65140	S2	45.4	0.425
65140	N2	358.2	0.326
65140	K1	52.7	0.689
65140	M4	98	0.28
65140	O1	32	0.379
65140	M6	192.2	0.183
65140	MK3	39.2	0.319
65140	S4	67.9	0.02
65140	MN4	55.6	0.099
65140	S6	127.7	0.012
65140	2N2	94.1	0.1
65140	OO1	131.3	0.06
65140	M1	127.7	0.026
65140	J1	77.3	0.017
65140	Q1	57.5	0.04
65140	2Q1	352.6	0.034
65140	P1	38	0.136
65140	2SM2	251.3	0.011
65140	M3	295.3	0.03
65140	L2	106.2	0.066
65140	2MK3	347.2	0.199
65140	K2	49.1	0.12
65140	M8	319.3	0.021
65140	MS4	108.2	0.169
65141	M2	55.1	1.933
65141	S2	79.7	0.424
65141	N2	32	0.358
65141	K1	74.6	0.694
65141	M4	0.9	0.128
65141	O1	78.2	0.331
65141	M6	40.9	0.026
65141	MK3	321.2	0.17
65141	S4	273.4	0.006
65141	MN4	320.8	0.045
65141	NU2	49.5	0.082
65141	S6	17.7	0.004
65141	MU2	272	0.032
65141	2N2	337.6	0.041
65141	OO1	354.6	0.015
65141	LDA2	92.3	0.018
65141	M1	28.8	0.019
65141	J1	97.8	0.069
65141	RHO1	161.8	0.029
65141	Q1	32.4	0.06
65141	2Q1	309.8	0.012
65141	P1	69.3	0.258
65141	2SM2	300.4	0.003
65141	M3	56.7	0.015
65141	L2	83.2	0.112
65141	2MK3	285.7	0.13
65141	K2	72.3	0.154
65141	M8	0.7	0.032
65141	MS4	357.5	0.034
65142	M2	61.2	1.991
65142	S2	77.3	0.528
65142	N2	31.3	0.43
65142	K1	73.7	0.849
65142	M4	98	0.05
65142	O1	57.6	0.408
65142	M6	342.1	0.017
65142	MK3	32	0.125
65142	S4	337.5	0.013
65142	MN4	21.1	0.02
65142	NU2	68.3	0.056
65142	S6	312.5	0.005
65142	MU2	315.5	0.073
65142	2N2	52.3	0.029
65142	OO1	135.5	0.048
65142	LDA2	83.1	0.02
65142	M1	118.5	0.029
65142	J1	100.3	0.04
65142	RHO1	54.9	0.078
65142	Q1	83.8	0.069
65142	2Q1	16.1	0.024
65142	P1	75.3	0.233
65142	2SM2	250.6	0.029
65142	M3	287.9	0.014
65142	L2	115.9	0.071
65142	2MK3	358.8	0.118
65142	K2	99	0.148
65142	M8	111.9	0.014
65142	MS4	124.1	0.013
65143	M2	61.7	1.974
65143	S2	77.6	0.526
65143	N2	32.8	0.441
65143	K1	73.1	0.849
65143	M4	106.3	0.069
65143	O1	57.3	0.416
65143	M6	307.5	0.012
65143	MK3	50	0.183
65143	S4	348.9	0.022
65143	MN4	68.7	0.027
65143	NU2	73	0.051
65143	S6	268.8	0.004
65143	MU2	332.4	0.073
65143	2N2	62.2	0.034
65143	OO1	148.8	0.053
65143	LDA2	121.8	0.018
65143	M1	117.3	0.04
65143	J1	126	0.027
65143	RHO1	41.9	0.068
65143	Q1	86	0.073
65143	2Q1	19.8	0.032
65143	P1	75.6	0.232
65143	2SM2	262.2	0.022
65143	M3	246.1	0.014
65143	L2	115.2	0.061
65143	2MK3	13.2	0.159
65143	K2	101.5	0.138
65143	M8	129.1	0.017
65143	MS4	145.8	0.031
65144	M2	48.3	2.252
65144	S2	65.1	0.472
65144	N2	17.7	0.327
65144	K1	70.1	0.744
65144	M4	151.4	0.039
65144	O1	49.7	0.433
65144	M6	275.5	0.098
65144	MK3	337.4	0.015
65144	S4	61.2	0.01
65144	MN4	92.2	0.037
65144	S6	49.7	0.005
65144	2N2	40.6	0.06
65144	OO1	105.9	0.117
65144	M1	117	0.035
65144	J1	16.1	0.013
65144	Q1	73.3	0.061
65144	2Q1	202.1	0.016
65144	P1	59.7	0.239
65144	2SM2	326.8	0.014
65144	M3	15.8	0.045
65144	L2	107.7	0.074
65144	2MK3	261.1	0.07
65144	K2	39.9	0.146
65144	M8	316	0.025
65144	MS4	344.8	0.028
65145	M2	48.7	2.249
65145	S2	62.4	0.486
65145	N2	13.8	0.336
65145	K1	66	0.818
65145	M4	105	0.068
65145	O1	42.5	0.528
65145	M6	297.8	0.022
65145	MK3	245.5	0.041
65145	S4	346.7	0.02
65145	MN4	45.4	0.036
65145	S6	78.7	0.01
65145	2N2	65	0.104
65145	OO1	97.2	0.126
65145	M1	138.6	0.064
65145	J1	295.6	0.019
65145	Q1	71.1	0.046
65145	2Q1	340.9	0.035
65145	P1	58.8	0.214
65145	2SM2	353.6	0.022
65145	M3	355.6	0.022
65145	L2	118.8	0.108
65145	2MK3	258.1	0.029
65145	K2	38.9	0.132
65145	M8	227.1	0.009
65145	MS4	6.3	0.046
65146	M2	49	2.226
65146	S2	60.9	0.492
65146	N2	16.1	0.326
65146	K1	64.5	0.786
65146	M4	114.6	0.074
65146	O1	46.5	0.512
65146	M6	9.5	0.013
65146	MK3	219.4	0.042
65146	S4	334.6	0.024
65146	MN4	42.3	0.038
65146	S6	109.3	0.01
65146	2N2	58.7	0.104
65146	OO1	102.7	0.188
65146	M1	132	0.082
65146	J1	288.4	0.033
65146	Q1	96.1	0.077
65146	2Q1	323.4	0.073
65146	P1	64	0.204
65146	2SM2	335.1	0.007
65146	M3	340.8	0.018
65146	L2	111.7	0.115
65146	2MK3	229.8	0.016
65146	K2	44.4	0.157
65146	M8	226.9	0.023
65146	MS4	358.4	0.058
65147	M2	63.2	0.273
65147	S2	86.4	0.062
65147	N2	30.3	0.047
65147	K1	100.6	0.14
65147	M4	273	0.018
65147	O1	60.9	0.048
65147	M6	276.3	0.011
65147	MK3	318.1	0.023
65147	S4	355.8	0.002
65147	MN4	231.8	0.012
65147	S6	195.4	0.003
65147	2N2	190.2	0.006
65147	OO1	82.7	0.01
65147	M1	121.3	0.006
65147	J1	7.1	0.008
65147	Q1	128	0.003
65147	2Q1	293.4	0.003
65147	2SM2	130.9	0.008
65147	M3	225.5	0.002
65147	L2	153.2	0.014
65147	2MK3	344.1	0.015
65147	M8	71.5	0.002
65147	MS4	263.1	0.005
65148	M2	70.9	0.364
65148	S2	89.5	0.064
65148	N2	29.8	0.055
65148	K1	73.2	0.143
65148	M4	187.4	0.011
65148	O1	56.8	0.079
65148	M6	242.2	0.004
65148	MK3	358.4	0.021
65148	S4	20	0.003
65148	MN4	130.1	0.006
65148	S6	335.7	0.002
65148	2N2	108.8	0.015
65148	OO1	79.9	0.025
65148	M1	83.4	0.008
65148	J1	212.3	0.006
65148	Q1	101	0.013
65148	2Q1	289.3	0.005
65148	2SM2	10.9	0.005
65148	M3	36	0.011
65148	L2	170	0.011
65148	2MK3	278.5	0.016
65148	M8	82.7	0.002
65148	MS4	105	0.006
65149	M2	72.7	0.407
65149	S2	93	0.083
65149	N2	37.8	0.062
65149	K1	63.9	0.167
65149	M4	160.8	0.024
65149	O1	50.5	0.08
65149	M6	190	0.005
65149	MK3	45.6	0.017
65149	S4	113.4	0.005
65149	MN4	116.9	0.018
65149	S6	131.2	0.001
65149	2N2	108.8	0.017
65149	OO1	86.9	0.026
65149	M1	68.1	0.007
65149	J1	159.2	0.006
65149	Q1	11.2	0.016
65149	2Q1	92.3	0.002
65149	2SM2	193.7	0.005
65149	M3	358	0.003
65149	L2	150	0.024
65149	2MK3	295	0.017
65149	M8	234.4	0.003
65149	MS4	128.3	0.014
65150	M2	47.5	2.35
65150	S2	60.4	0.522
65150	N2	11.2	0.342
65150	K1	68.5	0.783
65150	M4	261.6	0.123
65150	O1	49.3	0.448
65150	M6	328.7	0.087
65150	MK3	267.7	0.164
65150	S4	280.9	0.034
65150	MN4	226.1	0.046
65150	S6	154.1	0.005
65150	2N2	47.5	0.101
65150	OO1	67.8	0.097
65150	M1	84.4	0.039
65150	J1	103.9	0.054
65150	Q1	47.9	0.083
65150	2Q1	231.3	0.01
65150	P1	62.7	0.247
65150	2SM2	291.6	0.014
65150	M3	291.7	0.021
65150	L2	103.9	0.096
65150	2MK3	238.7	0.105
65150	K2	31.4	0.222
65150	M8	41.4	0.024
65150	MS4	315	0.092
65151	M2	50.9	2.662
65151	S2	66.4	0.58
65151	N2	20.3	0.402
65151	K1	66.5	1.016
65151	M4	199	0.047
65151	O1	38.3	0.604
65151	M6	257.5	0.065
65151	MK3	221.9	0.175
65151	S4	244.4	0.039
65151	MN4	187.1	0.028
65151	S6	117.6	0.014
65151	2N2	2.7	0.086
65151	OO1	62.8	0.162
65151	M1	102.2	0.056
65151	J1	125.9	0.054
65151	Q1	37.3	0.108
65151	2Q1	348	0.018
65151	P1	71.8	0.34
65151	2SM2	286.1	0.042
65151	M3	262	0.047
65151	L2	101.4	0.092
65151	2MK3	173.3	0.076
65151	K2	29.9	0.291
65151	M8	351.2	0.051
65151	MS4	278.8	0.112
65152	M2	54	2.736
65152	S2	70	0.594
65152	N2	25.3	0.418
65152	K1	70.5	1.125
65152	M4	139	0.026
65152	O1	39.9	0.66
65152	M6	246	0.061
65152	MK3	205.5	0.187
65152	S4	237.2	0.033
65152	MN4	143.4	0.019
65152	S6	117	0.014
65152	2N2	335.9	0.083
65152	OO1	60	0.178
65152	M1	110.1	0.061
65152	J1	115.5	0.057
65152	Q1	42.5	0.119
65152	2Q1	352.6	0.027
65152	P1	75.3	0.368
65152	2SM2	282.4	0.041
65152	M3	240.1	0.057
65152	L2	109.3	0.092
65152	2MK3	131.4	0.1
65152	K2	31.3	0.284
65152	M8	325.5	0.059
65152	MS4	259.3	0.129
65153	M2	66.3	2.075
65153	S2	77.9	0.593
65153	N2	30.4	0.419
65153	K1	73.7	0.99
65153	M4	173.4	0.172
65153	O1	43.3	0.612
65153	M6	216.2	0.08
65153	MK3	151.6	0.175
65153	S4	87	0.009
65153	MN4	123.6	0.08
65153	S6	220.3	0.007
65153	2N2	135.8	0.137
65153	OO1	153.4	0.137
65153	M1	118.8	0.038
65153	J1	20.4	0.011
65153	Q1	357.5	0.013
65153	2Q1	8.3	0.086
65153	P1	53.4	0.239
65153	2SM2	16	0.012
65153	M3	217.2	0.031
65153	L2	156.8	0.047
65153	2MK3	50.1	0.078
65153	K2	72.7	0.186
65153	M8	300.9	0.02
65153	MS4	133.8	0.085
65154	M2	64.1	2.263
65154	S2	78	0.649
65154	N2	31.7	0.452
65154	K1	72.5	1.068
65154	M4	171.5	0.124
65154	O1	44.2	0.673
65154	M6	231	0.096
65154	MK3	128.3	0.188
65154	S4	193.3	0.015
65154	MN4	119.4	0.076
65154	S6	125.4	0.007
65154	2N2	127.8	0.096
65154	OO1	137.2	0.146
65154	M1	107	0.045
65154	J1	63.4	0.024
65154	Q1	40	0.029
65154	2Q1	355.7	0.079
65154	P1	58.9	0.257
65154	2SM2	308.6	0.023
65154	M3	123.9	0.023
65154	L2	166.6	0.057
65154	2MK3	47.1	0.085
65154	K2	79.4	0.196
65154	M8	305.9	0.037
65154	MS4	119.8	0.046
65155	M2	64.8	2.436
65155	S2	79	0.649
65155	N2	35.1	0.441
65155	K1	74.3	1.157
65155	M4	161.2	0.077
65155	O1	46.7	0.684
65155	M6	250.7	0.087
65155	MK3	119.8	0.196
65155	S4	189	0.024
65155	MN4	101.6	0.087
65155	S6	85.2	0.017
65155	2N2	109.1	0.053
65155	OO1	132.2	0.156
65155	M1	118.1	0.044
65155	J1	33.2	0.018
65155	Q1	52.2	0.045
65155	2Q1	358.1	0.078
65155	P1	69.9	0.269
65155	2SM2	274.4	0.031
65155	M3	117.4	0.034
65155	L2	132.3	0.078
65155	2MK3	49.5	0.101
65155	K2	94.7	0.191
65155	M8	316.5	0.066
65155	MS4	170.8	0.055
65156	M2	66.5	0.241
65156	S2	85.5	0.058
65156	N2	25.4	0.054
65156	K1	74.7	0.088
65156	M4	238.2	0.014
65156	O1	57.5	0.046
65156	M6	330.8	0.009
65156	MK3	242.3	0.012
65156	S4	85.9	0.004
65156	MN4	212.1	0.006
65156	S6	122	0.002
65156	2N2	276.6	0.013
65156	OO1	295.5	0.017
65156	M1	154.2	0.003
65156	J1	88.2	0.007
65156	Q1	85.1	0.01
65156	2Q1	347.6	0.003
65156	P1	105.3	0.026
65156	2SM2	346.9	0.005
65156	M3	216.1	0.003
65156	L2	162.4	0.01
65156	2MK3	355.6	0.011
65156	K2	53.4	0.019
65156	M8	132.7	0.001
65156	MS4	237.2	0.01
65157	M2	73.4	0.219
65157	S2	69.1	0.05
65157	N2	44	0.063
65157	K1	75.2	0.096
65157	M4	202.4	0.006
65157	O1	85	0.04
65157	M6	306.4	0.01
65157	MK3	286.5	0.016
65157	S4	219.6	0.001
65157	MN4	121.7	0.004
65157	S6	196.5	0.001
65157	2N2	342.8	0.01
65157	OO1	214.8	0.007
65157	M1	92.5	0.009
65157	J1	103.3	0.011
65157	Q1	80.2	0.009
65157	2Q1	147.9	0.001
65157	P1	61.8	0.014
65157	2SM2	297.8	0.001
65157	M3	203.5	0.004
65157	L2	121.6	0.026
65157	2MK3	343.5	0.014
65157	K2	82.5	0.014
65157	M8	212.8	0.002
65157	MS4	211.1	0.007
65158	M2	66.5	0.245
65158	S2	61.1	0.077
65158	N2	29.6	0.055
65158	K1	98.9	0.102
65158	M4	164	0.011
65158	O1	78.3	0.03
65158	M6	354.1	0.007
65158	MK3	293.3	0.017
65158	S4	292.7	0.004
65158	MN4	135.7	0.006
65158	S6	247.1	0.002
65158	2N2	208.6	0.008
65158	OO1	148.6	0.007
65158	M1	66.5	0.012
65158	J1	6.6	0.013
65158	Q1	0.3	0.021
65158	2Q1	103.2	0.016
65158	P1	66.4	0.041
65158	2SM2	321.4	0.011
65158	M3	266.2	0.003
65158	L2	119.1	0.02
65158	2MK3	297.1	0.008
65158	K2	318.3	0.01
65158	M8	123.5	0.002
65158	MS4	97.1	0.001
65159	M2	43.4	2.329
65159	S2	53.9	0.524
65159	N2	10	0.34
65159	K1	68.4	0.749
65159	M4	70.5	0.274
65159	O1	55.7	0.328
65159	M6	349.3	0.096
65159	MK3	45.1	0.13
65159	S4	79.6	0.01
65159	MN4	9.2	0.064
65159	S6	16.1	0.018
65159	2N2	17.4	0.061
65159	OO1	81.4	0.08
65159	M1	74.2	0.037
65159	J1	136.7	0.043
65159	Q1	72	0.066
65159	2Q1	13.4	0.018
65159	P1	67.5	0.216
65159	2SM2	220.9	0.011
65159	M3	339.7	0.045
65159	L2	75.9	0.141
65159	2MK3	212.7	0.094
65159	K2	54.3	0.256
65159	M8	340.5	0.034
65159	MS4	77	0.071
65160	M2	45.8	2.242
65160	S2	49.4	0.571
65160	N2	3.9	0.353
65160	K1	74.6	0.733
65160	M4	60.3	0.187
65160	O1	86.3	0.264
65160	M6	357.5	0.102
65160	MK3	35.5	0.131
65160	S4	50.4	0.006
65160	MN4	346.8	0.081
65160	S6	35.6	0.017
65160	2N2	57.8	0.087
65160	OO1	50.1	0.072
65160	M1	21.3	0.029
65160	J1	224.5	0.021
65160	Q1	88.2	0.084
65160	2Q1	57.2	0.042
65160	P1	74.5	0.211
65160	2SM2	145.2	0.004
65160	M3	35.4	0.058
65160	L2	92	0.163
65160	2MK3	257.7	0.193
65160	K2	71.1	0.252
65160	M8	357.4	0.049
65160	MS4	94.4	0.098
65161	M2	47.3	2.131
65161	S2	48.8	0.552
65161	N2	3.6	0.325
65161	K1	82.7	0.681
65161	M4	347.6	0.096
65161	O1	118.3	0.312
65161	M6	344.1	0.084
65161	MK3	7.8	0.082
65161	S4	353.7	0.009
65161	MN4	333.1	0.073
65161	S6	57.7	0.009
65161	2N2	59	0.102
65161	OO1	2.4	0.094
65161	M1	339.2	0.039
65161	J1	290.9	0.043
65161	Q1	91	0.078
65161	2Q1	75.3	0.083
65161	P1	77.2	0.227
65161	2SM2	77.4	0.01
65161	M3	52.5	0.094
65161	L2	97	0.165
65161	2MK3	263.8	0.281
65161	K2	91.9	0.198
65161	M8	9.9	0.057
65161	MS4	113.5	0.079
65162	M2	55.6	2.369
65162	S2	80.7	0.605
65162	N2	34.2	0.518
65162	K1	71.8	0.949
65162	M4	39	0.147
65162	O1	66.8	0.535
65162	M6	294.7	0.066
65162	MK3	25.3	0.16
65162	S4	90.4	0.023
65162	MN4	19.4	0.055
65162	NU2	11.1	0.102
65162	S6	180.1	0.009
65162	MU2	20.6	0.059
65162	2N2	354.9	0.077
65162	OO1	108.5	0.066
65162	LDA2	128.7	0.042
65162	M1	93.6	0.065
65162	J1	104.8	0.098
65162	RHO1	21.3	0.027
65162	Q1	60.2	0.103
65162	2Q1	20.9	0.009
65162	P1	73.7	0.322
65162	2SM2	277.1	0.008
65162	M3	67.6	0.013
65162	L2	69.8	0.04
65162	2MK3	42.8	0.08
65162	K2	56.5	0.15
65162	M8	285.7	0.007
65162	MS4	60	0.075
65163	M2	61.5	2.837
65163	S2	81.8	0.717
65163	N2	35.1	0.592
65163	K1	74.8	1.185
65163	M4	22.6	0.151
65163	O1	65.2	0.639
65163	M6	43.2	0.025
65163	MK3	10.1	0.183
65163	S4	87	0.015
65163	MN4	325.6	0.038
65163	NU2	36.2	0.115
65163	S6	156.2	0.006
65163	MU2	312.9	0.072
65163	2N2	9.2	0.078
65163	OO1	106.2	0.055
65163	LDA2	118	0.056
65163	M1	101.1	0.041
65163	J1	91.5	0.084
65163	RHO1	22.4	0.023
65163	Q1	51.2	0.109
65163	2Q1	172.5	0.013
65163	P1	76.5	0.388
65163	2SM2	314.1	0.018
65163	M3	105.7	0.026
65163	L2	111.1	0.124
65163	2MK3	9.1	0.13
65163	K2	78.1	0.176
65163	M8	355.3	0.016
65163	MS4	64.7	0.061
65164	M2	64.2	2.982
65164	S2	82.9	0.721
65164	N2	36.3	0.611
65164	K1	74.3	1.238
65164	M4	345.4	0.025
65164	O1	61	0.663
65164	M6	106.2	0.051
65164	MK3	335.4	0.053
65164	S4	65.2	0.009
65164	MN4	313.2	0.009
65164	NU2	43.8	0.121
65164	MU2	311.9	0.095
65164	2N2	14.2	0.078
65164	OO1	57.1	0.027
65164	LDA2	113.2	0.053
65164	M1	100.6	0.056
65164	J1	103.6	0.087
65164	RHO1	20.1	0.018
65164	Q1	55	0.107
65164	2Q1	118.2	0.015
65164	P1	78.4	0.411
65164	2SM2	285.8	0.01
65164	M3	19.3	0.034
65164	L2	111.3	0.158
65164	2MK3	336.9	0.101
65164	K2	89.1	0.212
65164	M8	80.7	0.005
65164	MS4	89.8	0.047
65165	M2	50	2.534
65165	S2	58	0.613
65165	N2	6.3	0.437
65165	K1	66.3	0.918
65165	M4	282.7	0.256
65165	O1	51.9	0.479
65165	M6	209.6	0.087
65165	MK3	321.1	0.353
65165	S4	300.2	0.076
65165	MN4	231.8	0.106
65165	S6	193.8	0.016
65165	2N2	122.9	0.129
65165	OO1	153	0.061
65165	M1	152.3	0.007
65165	J1	4.8	0.047
65165	Q1	347.8	0.073
65165	2Q1	159.2	0.024
65165	P1	50.9	0.295
65165	2SM2	5	0.056
65165	M3	322.2	0.047
65165	L2	133.5	0.147
65165	2MK3	303.1	0.218
65165	K2	66.9	0.202
65165	M8	159.1	0.029
65165	MS4	283.9	0.133
65166	M2	51.3	2.832
65166	S2	54.4	0.63
65166	N2	3.5	0.421
65166	K1	66	1.029
65166	M4	255.9	0.261
65166	O1	44.1	0.633
65166	M6	197.1	0.06
65166	MK3	307.7	0.313
65166	S4	298	0.079
65166	MN4	218.8	0.122
65166	S6	142.1	0.013
65166	2N2	94	0.201
65166	OO1	170.1	0.092
65166	M1	171.7	0.018
65166	J1	353.9	0.06
65166	Q1	345.2	0.085
65166	2Q1	40.4	0.042
65166	P1	46.1	0.3
65166	2SM2	356.2	0.063
65166	M3	329.8	0.06
65166	L2	119.4	0.194
65166	2MK3	284.8	0.223
65166	K2	71.1	0.253
65166	M8	133.5	0.047
65166	MS4	278.7	0.153
65167	M2	51.7	2.879
65167	S2	53.8	0.619
65167	N2	4	0.407
65167	K1	66	1.039
65167	M4	243.5	0.285
65167	O1	37.4	0.667
65167	M6	170.9	0.053
65167	MK3	296.4	0.313
65167	S4	292.7	0.065
65167	MN4	212.1	0.113
65167	S6	146.7	0.011
65167	2N2	83.5	0.214
65167	OO1	176.8	0.077
65167	M1	149.4	0.027
65167	J1	2.3	0.056
65167	Q1	355.6	0.092
65167	2Q1	358.7	0.039
65167	P1	51.6	0.325
65167	2SM2	358.7	0.07
65167	M3	329.9	0.09
65167	L2	116.1	0.193
65167	2MK3	271.2	0.214
65167	K2	66.6	0.299
65167	M8	131.2	0.06
65167	MS4	273.4	0.17
65168	M2	81.1	0.396
65168	S2	100.7	0.09
65168	N2	37.6	0.095
65168	K1	66	0.21
65168	M4	283.7	0.022
65168	O1	32.5	0.067
65168	M6	36.8	0.011
65168	MK3	322.5	0.037
65168	S4	183.4	0.014
65168	MN4	245.7	0.019
65168	S6	135.5	0.007
65168	2N2	352.9	0.022
65168	OO1	30.3	0.014
65168	M1	12.6	0.006
65168	J1	148.2	0.022
65168	Q1	271.4	0.014
65168	2Q1	50.3	0.01
65168	P1	71.6	0.044
65168	2SM2	172.3	0.009
65168	M3	333.4	0.03
65168	L2	139.3	0.041
65168	2MK3	352.3	0.042
65168	K2	127.7	0.074
65168	M8	98.4	0.01
65168	MS4	297.6	0.005
65169	M2	90.5	0.43
65169	S2	101	0.125
65169	N2	62.2	0.087
65169	K1	93.6	0.273
65169	M4	204.5	0.029
65169	O1	95.4	0.084
65169	M6	358.6	0.019
65169	MK3	46.2	0.042
65169	S4	25.6	0.006
65169	MN4	158.6	0.025
65169	S6	118.4	0.004
65169	2N2	333.8	0.026
65169	OO1	13.8	0.056
65169	M1	105.3	0.021
65169	J1	132.4	0.005
65169	Q1	244	0.005
65169	2Q1	26.7	0.033
65169	P1	97.3	0.053
65169	2SM2	319.1	0.01
65169	M3	121.4	0.01
65169	L2	156.3	0.039
65169	2MK3	40.3	0.048
65169	K2	173	0.019
65169	M8	213.8	0.009
65169	MS4	75	0.005
65170	M2	110.6	0.399
65170	S2	125.1	0.093
65170	N2	78.8	0.072
65170	K1	120.2	0.327
65170	M4	175	0.091
65170	O1	110.8	0.1
65170	M6	31.2	0.029
65170	MK3	156.4	0.071
65170	S4	358.2	0.01
65170	MN4	145.3	0.054
65170	S6	81.6	0.006
65170	2N2	283.8	0.021
65170	OO1	89.6	0.019
65170	M1	145.3	0.016
65170	J1	8.7	0.017
65170	Q1	10.5	0.018
65170	2Q1	211.9	0.015
65170	P1	89.9	0.073
65170	2SM2	28.2	0.015
65170	M3	213.6	0.02
65170	L2	192.3	0.032
65170	2MK3	138.7	0.032
65170	K2	113.9	0.058
65170	M8	107.8	0.007
65170	MS4	220.8	0.043
65171	M2	148.3	1.219
65171	S2	160.8	0.211
65171	N2	111.9	0.251
65171	K1	116.1	0.359
65171	M4	143.6	0.089
65171	O1	109.2	0.213
65171	M6	58.6	0.157
65171	MK3	37.5	0.124
65171	S4	313.3	0.002
65171	MN4	97	0.042
65171	S6	207.9	0.003
65171	2N2	274.3	0.103
65171	OO1	31.9	0.057
65171	M1	199.7	0.028
65171	J1	329.7	0.012
65171	Q1	78.4	0.031
65171	2Q1	226.9	0.045
65171	P1	130.8	0.079
65171	2SM2	353.9	0.021
65171	M3	223	0.034
65171	L2	194.2	0.17
65171	2MK3	29.5	0.164
65171	K2	188.5	0.096
65171	M8	131.9	0.014
65171	MS4	149.7	0.021
65172	M2	152.5	1.439
65172	S2	156.3	0.228
65172	N2	115.1	0.299
65172	K1	121.6	0.481
65172	M4	146.4	0.083
65172	O1	109.1	0.226
65172	M6	55.6	0.191
65172	MK3	51.1	0.137
65172	S4	64.9	0.006
65172	MN4	102.4	0.041
65172	S6	272.7	0.003
65172	2N2	286.6	0.135
65172	OO1	48.9	0.105
65172	M1	228.2	0.025
65172	J1	3.9	0.013
65172	Q1	84	0.029
65172	2Q1	249.2	0.033
65172	P1	115.3	0.105
65172	2SM2	359.6	0.032
65172	M3	219.3	0.034
65172	L2	201.1	0.213
65172	2MK3	38.5	0.218
65172	K2	209	0.108
65172	M8	128.8	0.03
65172	MS4	138	0.019
65173	M2	158.4	1.533
65173	S2	153.2	0.24
65173	N2	116.2	0.308
65173	K1	115.6	0.437
65173	M4	190.5	0.054
65173	O1	100.2	0.217
65173	M6	62.1	0.231
65173	MK3	56.8	0.075
65173	S4	76.2	0.011
65173	MN4	126.3	0.033
65173	S6	68.6	0.005
65173	2N2	314.2	0.131
65173	OO1	66.7	0.072
65173	M1	228.5	0.018
65173	J1	95.2	0.01
65173	Q1	65.1	0.033
65173	2Q1	238.5	0.01
65173	P1	122	0.101
65173	2SM2	6.5	0.035
65173	M3	236.9	0.046
65173	L2	214.2	0.247
65173	2MK3	51.2	0.198
65173	K2	207.7	0.076
65173	M8	94.7	0.038
65173	MS4	210.1	0.014
65174	M2	181.4	1.591
65174	S2	192.3	0.266
65174	N2	147	0.324
65174	K1	201.2	0.331
65174	M4	134.5	0.124
65174	O1	188.3	0.187
65174	M6	57.5	0.2
65174	MK3	72.6	0.166
65174	S4	162.5	0.003
65174	MN4	92.2	0.062
65174	2N2	330.2	0.121
65174	OO1	48.2	0.057
65174	M1	267.8	0.016
65174	J1	9.8	0.017
65174	Q1	172.2	0.065
65174	2Q1	330.7	0.018
65174	P1	197.6	0.081
65174	2SM2	357.6	0.03
65174	M3	190.1	0.062
65174	L2	225.4	0.215
65174	2MK3	32.5	0.179
65174	K2	222.1	0.097
65174	M8	190.9	0.015
65174	MS4	143	0.033
65175	M2	179	1.713
65175	S2	190.3	0.26
65175	N2	144.2	0.34
65175	K1	193.8	0.315
65175	M4	138	0.081
65175	O1	188	0.197
65175	M6	54.3	0.206
65175	MK3	66.3	0.127
65175	S4	144.4	0.004
65175	MN4	85.9	0.043
65175	S6	261.9	0.004
65175	2N2	317.3	0.125
65175	OO1	49.6	0.068
65175	M1	255.9	0.024
65175	J1	345.5	0.019
65175	Q1	177.4	0.055
65175	2Q1	269	0.019
65175	P1	198.8	0.072
65175	2SM2	2.4	0.029
65175	M3	189.4	0.058
65175	L2	222.6	0.243
65175	2MK3	31.8	0.178
65175	K2	236.1	0.118
65175	M8	168.6	0.03
65175	MS4	146.4	0.031
65176	M2	173.8	1.773
65176	S2	191	0.241
65176	N2	138.7	0.343
65176	K1	170	0.297
65176	M4	183.1	0.043
65176	O1	178.2	0.185
65176	M6	46	0.192
65176	MK3	36.7	0.062
65176	S4	114.6	0.008
65176	MN4	75.6	0.016
65176	S6	335.8	0.003
65176	2N2	293.7	0.131
65176	OO1	40.6	0.07
65176	M1	237.8	0.034
65176	J1	296.5	0.019
65176	Q1	179.7	0.041
65176	2Q1	238.6	0.031
65176	P1	205.5	0.043
65176	2SM2	22.1	0.024
65176	M3	202.9	0.041
65176	L2	214.8	0.255
65176	2MK3	30.4	0.148
65176	K2	244.4	0.15
65176	M8	132.4	0.041
65176	MS4	146.4	0.026
65177	M2	6.6	2.465
65177	S2	25.9	0.407
65177	N2	332.1	0.497
65177	K1	22.1	0.482
65177	M4	20.7	0.09
65177	O1	10.3	0.188
65177	M6	227.5	0.214
65177	MK3	196.7	0.058
65177	S4	283.3	0.01
65177	MN4	353.6	0.034
65177	S6	187.6	0.005
65177	2N2	135.4	0.117
65177	OO1	242.9	0.074
65177	M1	57.9	0.043
65177	J1	100.9	0.036
65177	Q1	9.9	0.036
65177	2Q1	41.5	0.022
65177	P1	39.5	0.125
65177	2SM2	206.5	0.031
65177	M3	28.1	0.02
65177	L2	43.6	0.299
65177	2MK3	211.4	0.132
65177	K2	59.3	0.169
65177	M8	214.2	0.032
65177	MS4	18.9	0.038
65178	M2	6.6	2.464
65178	S2	27.1	0.417
65178	N2	332	0.501
65178	K1	23.1	0.485
65178	M4	19.9	0.104
65178	O1	11	0.216
65178	M6	225.8	0.212
65178	MK3	184.8	0.057
65178	S4	304.4	0.008
65178	MN4	2.5	0.045
65178	S6	169.1	0.004
65178	2N2	134.5	0.113
65178	OO1	234.8	0.063
65178	M1	62	0.042
65178	J1	97.1	0.038
65178	Q1	5.3	0.04
65178	2Q1	51.8	0.024
65178	P1	43.6	0.124
65178	2SM2	213.1	0.027
65178	M3	5.9	0.013
65178	L2	44.1	0.299
65178	2MK3	207.4	0.117
65178	K2	54.6	0.172
65178	M8	205.1	0.036
65178	MS4	28.6	0.034
65179	M2	6.6	2.451
65179	S2	27.7	0.421
65179	N2	332.3	0.498
65179	K1	23.9	0.484
65179	M4	22.8	0.111
65179	O1	11.5	0.217
65179	M6	224.8	0.207
65179	MK3	174.7	0.061
65179	S4	301.3	0.005
65179	MN4	7.3	0.053
65179	S6	156.6	0.005
65179	2N2	131.5	0.11
65179	OO1	236.9	0.065
65179	M1	66.5	0.044
65179	J1	103.5	0.04
65179	Q1	10.1	0.038
65179	2Q1	60.1	0.029
65179	P1	45.7	0.119
65179	2SM2	214	0.029
65179	M3	15	0.009
65179	L2	43.5	0.301
65179	2MK3	202.3	0.111
65179	K2	49.4	0.171
65179	M8	208.9	0.037
65179	MS4	44.3	0.031
65180	M2	35.4	0.676
65180	S2	58.1	0.124
65180	N2	354.3	0.132
65180	K1	50.5	0.243
65180	M4	264	0.072
65180	O1	56.6	0.262
65180	M6	170.8	0.013
65180	MK3	268.6	0.129
65180	S4	321.5	0.004
65180	MN4	226.5	0.038
65180	S6	130.3	0.008
65180	2N2	224.7	0.022
65180	OO1	145.8	0.053
65180	M1	261.3	0.012
65180	J1	66.2	0.033
65180	Q1	8.9	0.056
65180	2Q1	177.7	0.01
65180	P1	74.1	0.091
65180	2SM2	236.1	0.025
65180	M3	256.4	0.038
65180	L2	96.5	0.036
65180	2MK3	279.3	0.107
65180	K2	81.4	0.094
65180	M8	50.8	0.009
65180	MS4	239.6	0.039
65181	M2	43.5	0.82
65181	S2	48.5	0.174
65181	N2	356.9	0.173
65181	K1	49.9	0.274
65181	M4	295.2	0.1
65181	O1	41.6	0.26
65181	M6	132.6	0.022
65181	MK3	274.6	0.108
65181	S4	219.7	0.011
65181	MN4	253.9	0.038
65181	S6	328.5	0.009
65181	2N2	240.2	0.064
65181	OO1	169.1	0.06
65181	M1	329	0.017
65181	J1	32.5	0.053
65181	Q1	356.8	0.051
65181	2Q1	309.6	0.039
65181	P1	65.3	0.094
65181	2SM2	296.6	0.04
65181	M3	264.1	0.056
65181	L2	136.4	0.048
65181	2MK3	292.1	0.073
65181	K2	101.3	0.068
65181	M8	276.9	0.012
65181	MS4	280.4	0.058
65182	M2	46.1	0.89
65182	S2	48.4	0.182
65182	N2	356.9	0.196
65182	K1	47.5	0.309
65182	M4	298.4	0.126
65182	O1	34	0.284
65182	M6	131.7	0.016
65182	MK3	279.1	0.128
65182	S4	218.9	0.034
65182	MN4	292.2	0.025
65182	S6	310.3	0.002
65182	2N2	251.9	0.092
65182	OO1	180	0.049
65182	M1	343.6	0.032
65182	J1	42.8	0.056
65182	Q1	2.5	0.048
65182	2Q1	310	0.082
65182	P1	54.2	0.092
65182	2SM2	325.8	0.045
65182	M3	259.4	0.057
65182	L2	152.3	0.036
65182	2MK3	297.2	0.089
65182	K2	151.1	0.059
65182	M8	232.4	0.011
65182	MS4	286.7	0.096
65183	M2	358.5	0.393
65183	S2	50.7	0.093
65183	N2	356	0.086
65183	K1	54.8	0.156
65183	M4	207.8	0.078
65183	O1	33.1	0.106
65183	M6	242.6	0.02
65183	MK3	220.8	0.07
65183	S4	254.3	0.029
65183	MN4	157.2	0.037
65183	S6	148.4	0.006
65183	2N2	113.7	0.011
65183	OO1	207.7	0.025
65183	M1	221.1	0.011
65183	J1	220.9	0.007
65183	Q1	0.2	0.035
65183	2Q1	138.8	0.023
65183	P1	22.4	0.076
65183	2SM2	292.6	0.016
65183	M3	247.3	0.038
65183	L2	15	0.024
65183	2MK3	118.8	0.043
65183	M8	334.2	0.012
65183	MS4	246.1	0.05
65184	M2	28	0.587
65184	S2	47.9	0.04
65184	N2	352.1	0.105
65184	K1	51	0.164
65184	M4	197.3	0.038
65184	O1	63.4	0.124
65184	M6	83.5	0.021
65184	MK3	20.4	0.028
65184	S4	22.4	0.027
65184	MN4	140.2	0.028
65184	S6	295	0.005
65184	2N2	314.3	0.048
65184	OO1	267.6	0.049
65184	M1	93.1	0.047
65184	J1	194.6	0.035
65184	Q1	32.5	0.017
65184	2Q1	5.5	0.015
65184	P1	18.4	0.011
65184	2SM2	173.1	0.026
65184	M3	16.2	0.013
65184	L2	353.2	0.083
65184	2MK3	274.2	0.05
65184	M8	301.2	0.007
65184	MS4	31.7	0.012
65185	M2	30.6	0.646
65185	S2	337.6	0.044
65185	N2	343.8	0.131
65185	K1	32.7	0.13
65185	M4	176.7	0.031
65185	O1	57.6	0.157
65185	M6	93.4	0.034
65185	MK3	20.3	0.064
65185	S4	21	0.03
65185	MN4	136	0.031
65185	S6	314	0.009
65185	2N2	294.2	0.055
65185	OO1	326.6	0.055
65185	M1	101	0.057
65185	J1	207.9	0.049
65185	Q1	314.3	0.028
65185	2Q1	324.7	0.016
65185	P1	195.8	0.066
65185	2SM2	174.3	0.041
65185	M3	353.9	0.021
65185	L2	7.1	0.092
65185	2MK3	258.8	0.093
65185	M8	29.8	0.009
65185	MS4	15.4	0.038
65186	M2	53.4	0.405
65186	S2	2.1	0.069
65186	N2	27.2	0.09
65186	K1	102.7	0.207
65186	M4	203.9	0.031
65186	O1	83.1	0.133
65186	M6	314.9	0.021
65186	MK3	5	0.108
65186	S4	145.1	0.004
65186	MN4	73.1	0.005
65186	S6	14.5	0.015
65186	2N2	293.9	0.02
65186	OO1	259.7	0.043
65186	M1	185.8	0.021
65186	J1	354.7	0.034
65186	Q1	148.3	0.031
65186	2Q1	172.1	0.053
65186	P1	106.8	0.043
65186	2SM2	296	0.021
65186	M3	24.1	0.03
65186	L2	166.5	0.039
65186	2MK3	18.8	0.084
65186	K2	125.7	0.066
65186	M8	107.4	0.019
65186	MS4	15.8	0.052
65187	M2	62.4	0.516
65187	S2	51.3	0.076
65187	N2	24.3	0.118
65187	K1	80.5	0.301
65187	M4	43.7	0.063
65187	O1	60.8	0.303
65187	M6	59.3	0.007
65187	MK3	320.1	0.107
65187	S4	186.2	0.027
65187	MN4	10.2	0.022
65187	S6	236.9	0.006
65187	2N2	322.1	0.054
65187	OO1	48.2	0.045
65187	M1	176	0.022
65187	J1	91.6	0.02
65187	Q1	22.8	0.027
65187	2Q1	204.6	0.026
65187	P1	98	0.107
65187	2SM2	270.5	0.028
65187	M3	78.4	0.025
65187	L2	122.8	0.018
65187	2MK3	314.7	0.037
65187	K2	143.8	0.065
65187	M8	202.7	0.012
65187	MS4	111.8	0.05
65188	M2	69	0.852
65188	S2	69.3	0.148
65188	N2	35.4	0.175
65188	K1	53.7	0.378
65188	M4	76.4	0.049
65188	O1	58.8	0.241
65188	M6	79.2	0.029
65188	MK3	242.3	0.109
65188	S4	71.3	0.012
65188	MN4	77.2	0.037
65188	S6	212	0.006
65188	2N2	312.1	0.023
65188	OO1	55.5	0.103
65188	M1	104.5	0.034
65188	J1	134.1	0.043
65188	Q1	2.5	0.034
65188	2Q1	357.3	0.074
65188	P1	28.8	0.026
65188	2SM2	275.8	0.019
65188	M3	335.6	0.012
65188	L2	99.2	0.075
65188	2MK3	234.4	0.122
65188	K2	14.6	0.042
65188	M8	255.7	0.017
65188	MS4	141	0.082
65189	M2	28.9	0.292
65189	S2	57.5	0.05
65189	N2	354.9	0.055
65189	K1	9.3	0.215
65189	M4	214.5	0.037
65189	O1	50.6	0.144
65189	M6	272.1	0.003
65189	MK3	202.3	0.079
65189	S4	38.2	0.011
65189	MN4	223.9	0.029
65189	S6	321.8	0.002
65189	2N2	275.1	0.012
65189	OO1	326.3	0.019
65189	M1	68.7	0.048
65189	J1	146.7	0.03
65189	Q1	3.1	0.022
65189	2Q1	62.3	0.048
65189	P1	185.4	0.011
65189	2SM2	157.3	0.006
65189	M3	228.4	0.016
65189	L2	31.6	0.033
65189	2MK3	219.7	0.052
65189	M8	21.4	0.003
65189	MS4	205.5	0.035
65190	M2	41.2	0.263
65190	S2	2	0.057
65190	N2	6.5	0.028
65190	K1	359.2	0.111
65190	M4	212	0.049
65190	O1	51.6	0.104
65190	M6	24.2	0.009
65190	MK3	201.6	0.07
65190	S4	69	0.009
65190	MN4	222.4	0.009
65190	S6	269.6	0.003
65190	2N2	130	0.032
65190	OO1	309.8	0.05
65190	M1	24.2	0.028
65190	J1	95.5	0.034
65190	Q1	59.7	0.021
65190	2Q1	124.4	0.016
65190	P1	93.5	0.018
65190	2SM2	173.5	0.013
65190	M3	170.8	0.009
65190	L2	71.1	0.063
65190	2MK3	280.6	0.026
65190	M8	329.4	0.004
65190	MS4	191.7	0.022
65191	M2	38.3	0.213
65191	S2	342.4	0.038
65191	N2	358.8	0.032
65191	K1	309.1	0.087
65191	M4	222.6	0.017
65191	O1	102.4	0.035
65191	M6	46.4	0.015
65191	MK3	352.4	0.008
65191	S4	126.1	0.034
65191	MN4	272.1	0.006
65191	S6	248.5	0.009
65191	2N2	180.6	0.039
65191	OO1	336	0.087
65191	M1	167.1	0.026
65191	J1	147.5	0.03
65191	Q1	81.4	0.016
65191	2Q1	135.8	0.023
65191	P1	183.5	0.039
65191	2SM2	166.8	0.01
65191	M3	155	0.011
65191	L2	96.7	0.044
65191	2MK3	299.4	0.038
65191	M8	48.3	0.006
65191	MS4	99	0.023
65192	M2	45.5	0.356
65192	S2	92.6	0.127
65192	N2	49.1	0.074
65192	K1	69.8	0.244
65192	M4	48.2	0.069
65192	O1	33.9	0.169
65192	M6	82.6	0.01
65192	MK3	78	0.066
65192	S4	98.5	0.003
65192	MN4	86.2	0.021
65192	S6	36.5	0.008
65192	2N2	325.7	0.049
65192	OO1	91.6	0.083
65192	M1	300.9	0.027
65192	J1	57.3	0.036
65192	Q1	345.2	0.045
65192	2Q1	184	0.021
65192	P1	57.4	0.079
65192	2SM2	105.2	0.023
65192	M3	174.1	0.031
65192	L2	326.3	0.052
65192	2MK3	200.3	0.033
65192	K2	327.7	0.028
65192	M8	70.2	0.011
65192	MS4	91.5	0.025
65193	M2	89.6	0.369
65193	S2	122.2	0.129
65193	N2	62.1	0.101
65193	K1	68.9	0.208
65193	M4	124.6	0.019
65193	O1	62.2	0.039
65193	M6	150.5	0.011
65193	MK3	119.9	0.084
65193	S4	232.6	0.01
65193	MN4	35	0.001
65193	S6	357.3	0.007
65193	2N2	309.3	0.036
65193	OO1	169.8	0.044
65193	M1	354.8	0.011
65193	J1	239.5	0.014
65193	Q1	38.5	0.04
65193	2Q1	223.4	0.039
65193	P1	323.6	0.03
65193	2SM2	152.3	0.011
65193	M3	198.4	0.029
65193	L2	98.3	0.009
65193	2MK3	155.5	0.043
65193	K2	65.1	0.058
65193	M8	279.4	0.004
65193	MS4	140.3	0.024
65194	M2	98	0.37
65194	S2	123.1	0.138
65194	N2	65	0.099
65194	K1	82	0.188
65194	M4	165.1	0.026
65194	O1	171.3	0.007
65194	M6	254.1	0.01
65194	MK3	138.8	0.092
65194	S4	242.6	0.003
65194	MN4	220.2	0.008
65194	S6	270	0.003
65194	2N2	305.3	0.039
65194	OO1	148.6	0.035
65194	M1	119.3	0.026
65194	J1	234.2	0.04
65194	Q1	122.2	0.022
65194	2Q1	176.6	0.035
65194	P1	317.9	0.023
65194	2SM2	261.8	0.017
65194	M3	209.2	0.027
65194	L2	103.8	0.035
65194	2MK3	137.3	0.045
65194	K2	61.1	0.06
65194	M8	7.1	0.008
65194	MS4	161.1	0.015
65195	M2	99.6	0.372
65195	S2	124.9	0.144
65195	N2	66.4	0.097
65195	K1	86.3	0.187
65195	M4	171.2	0.024
65195	O1	197.7	0.012
65195	M6	262.2	0.014
65195	MK3	145.9	0.098
65195	S4	278.7	0.003
65195	MN4	228.5	0.012
65195	S6	253.2	0.005
65195	2N2	304.7	0.034
65195	OO1	136.1	0.019
65195	M1	122.4	0.033
65195	J1	231.8	0.047
65195	Q1	144.4	0.029
65195	2Q1	159.6	0.039
65195	P1	322.5	0.022
65195	2SM2	260.8	0.019
65195	M3	213.4	0.027
65195	L2	96	0.039
65195	2MK3	134.7	0.046
65195	K2	65	0.068
65195	M8	3	0.006
65195	MS4	172.5	0.011
65196	M2	104.5	0.372
65196	S2	126.5	0.128
65196	N2	70.3	0.092
65196	K1	88.1	0.223
65196	M4	207.2	0.021
65196	O1	200.8	0.046
65196	M6	271.8	0.023
65196	MK3	158.3	0.116
65196	S4	339	0.005
65196	MN4	236.5	0.02
65196	S6	268.8	0.005
65196	2N2	290.2	0.016
65196	OO1	358	0.033
65196	M1	129.4	0.057
65196	J1	220.4	0.064
65196	Q1	169	0.045
65196	2Q1	135.8	0.055
65196	P1	302.2	0.057
65196	2SM2	281.3	0.02
65196	M3	232.9	0.034
65196	L2	79.8	0.044
65196	2MK3	134.6	0.049
65196	K2	66.2	0.052
65196	M8	32.8	0.006
65196	MS4	224.2	0.005
65197	M2	106.6	0.372
65197	S2	123.5	0.089
65197	N2	77.1	0.088
65197	K1	83.6	0.258
65197	M4	222.1	0.021
65197	O1	206.7	0.075
65197	M6	273.1	0.022
65197	MK3	165.8	0.119
65197	S4	324.4	0.012
65197	MN4	226.1	0.014
65197	S6	242.9	0.004
65197	2N2	196.4	0.021
65197	OO1	345.5	0.066
65197	M1	136.9	0.069
65197	J1	208.2	0.08
65197	Q1	171.1	0.061
65197	2Q1	125	0.077
65197	P1	285.6	0.115
65197	2SM2	296.3	0.024
65197	M3	237.1	0.036
65197	L2	72.4	0.057
65197	2MK3	124.7	0.039
65197	K2	63.3	0.017
65197	M8	72.5	0.005
65197	MS4	288.3	0.004
65198	M2	70.5	1.073
65198	S2	100.2	0.213
65198	N2	38.1	0.254
65198	K1	89.8	0.516
65198	M4	53.9	0.139
65198	O1	137.4	0.255
65198	M6	132.7	0.046
65198	MK3	28.5	0.217
65198	S4	245.3	0.026
65198	MN4	34.8	0.062
65198	S6	6.1	0.018
65198	2N2	301.1	0.028
65198	OO1	299	0.099
65198	M1	58.2	0.041
65198	J1	124.1	0.078
65198	Q1	113.3	0.083
65198	2Q1	336.5	0.076
65198	P1	105.2	0.172
65198	2SM2	345.6	0.013
65198	M3	100.5	0.039
65198	L2	99.2	0.033
65198	2MK3	113.4	0.019
65198	K2	156.9	0.138
65198	M8	104.3	0.002
65198	MS4	60	0.066
65199	M2	62.2	0.877
65199	S2	84.3	0.224
65199	N2	26.9	0.217
65199	K1	84.7	0.525
65199	M4	230.6	0.035
65199	O1	70.5	0.32
65199	M6	276.1	0.038
65199	MK3	191.7	0.081
65199	S4	4	0.006
65199	MN4	190.5	0.023
65199	S6	130.4	0.014
65199	2N2	339.1	0.042
65199	OO1	302.2	0.021
65199	M1	120.7	0.055
65199	J1	138.8	0.047
65199	Q1	42.4	0.022
65199	2Q1	106	0.059
65199	P1	100.9	0.132
65199	2SM2	296.6	0.015
65199	M3	6.8	0.013
65199	L2	179.5	0.027
65199	2MK3	298.3	0.014
65199	K2	54.1	0.058
65199	M8	63.6	0.021
65199	MS4	214.5	0.032
65200	M2	64.4	0.818
65200	S2	93.2	0.216
65200	N2	27.5	0.2
65200	K1	81.5	0.498
65200	M4	185.1	0.051
65200	O1	65.3	0.307
65200	M6	312	0.037
65200	MK3	176.4	0.114
65200	S4	94.5	0.016
65200	MN4	153	0.032
65200	S6	143.1	0.017
65200	2N2	332.4	0.037
65200	OO1	8.6	0.054
65200	M1	141.8	0.041
65200	J1	180.5	0.028
65200	Q1	358.1	0.036
65200	2Q1	112.9	0.028
65200	P1	97	0.142
65200	2SM2	294.4	0.013
65200	M3	207.6	0.019
65200	L2	152.9	0.034
65200	2MK3	224.3	0.016
65200	K2	62.4	0.109
65200	M8	355.6	0.007
65200	MS4	184.9	0.035
65201	M2	63.7	0.909
65201	S2	97.9	0.186
65201	N2	36.7	0.218
65201	K1	80.7	0.322
65201	M4	115.3	0.133
65201	O1	145.5	0.137
65201	M6	212.1	0.049
65201	MK3	74.4	0.158
65201	S4	22.9	0.016
65201	MN4	73	0.068
65201	S6	52.7	0.003
65201	2N2	48.8	0.055
65201	OO1	306.7	0.151
65201	M1	68.9	0.027
65201	J1	96.6	0.032
65201	Q1	115.4	0.071
65201	2Q1	33.8	0.031
65201	P1	120.3	0.139
65201	2SM2	280.7	0.02
65201	M3	115.2	0.039
65201	L2	92.6	0.083
65201	2MK3	25.2	0.089
65201	K2	325.4	0.032
65201	M8	351.1	0.018
65201	MS4	137.9	0.091
65202	M2	65.8	0.86
65202	S2	85	0.264
65202	N2	36.3	0.171
65202	K1	84	0.442
65202	M4	242.7	0.02
65202	O1	64.3	0.17
65202	M6	323.2	0.033
65202	MK3	359	0.057
65202	S4	54.1	0.008
65202	MN4	217.2	0.018
65202	S6	214.9	0.015
65202	2N2	325.9	0.053
65202	OO1	36.9	0.047
65202	M1	75.5	0.028
65202	J1	75.8	0.059
65202	Q1	112.9	0.016
65202	2Q1	347.4	0.041
65202	P1	121.8	0.087
65202	2SM2	200	0.013
65202	M3	9.7	0.015
65202	L2	128.6	0.032
65202	2MK3	59.1	0.026
65202	K2	70.8	0.1
65202	M8	203.4	0.003
65202	MS4	286.5	0.038
65203	M2	69.2	0.728
65203	S2	86.6	0.212
65203	N2	33.1	0.167
65203	K1	83.9	0.55
65203	M4	10.1	0.043
65203	O1	72.1	0.257
65203	M6	331.6	0.016
65203	MK3	30.9	0.093
65203	S4	251.3	0.008
65203	MN4	333.9	0.019
65203	S6	222.1	0.019
65203	2N2	289.8	0.076
65203	OO1	147	0.044
65203	M1	119.6	0.01
65203	J1	106.5	0.043
65203	Q1	35	0.058
65203	2Q1	318.5	0.028
65203	P1	85.1	0.173
65203	2SM2	272	0.014
65203	M3	328.5	0.02
65203	L2	235	0.049
65203	2MK3	16.7	0.043
65203	K2	127.3	0.116
65203	M8	296.4	0.014
65203	MS4	341.4	0.034
65204	M2	57.5	1.346
65204	S2	76.3	0.363
65204	N2	20.3	0.321
65204	K1	71.7	0.51
65204	M4	330.4	0.066
65204	O1	72.8	0.288
65204	M6	119.4	0.01
65204	MK3	301	0.077
65204	S4	334.7	0.03
65204	MN4	294.8	0.027
65204	S6	21.8	0.013
65204	2N2	157.5	0.047
65204	OO1	233.6	0.015
65204	M1	91.6	0.059
65204	J1	149.8	0.06
65204	Q1	68.6	0.062
65204	2Q1	138.3	0.084
65204	P1	91.4	0.223
65204	2SM2	210.3	0.038
65204	M3	68.2	0.049
65204	L2	88.3	0.1
65204	2MK3	308.6	0.106
65204	K2	81	0.121
65204	M8	138.9	0.002
65204	MS4	312.3	0.028
65205	M2	62.7	1.488
65205	S2	104	0.38
65205	N2	40.5	0.355
65205	K1	78.8	0.878
65205	M4	148.3	0.045
65205	O1	64.1	0.344
65205	M6	275.9	0.019
65205	MK3	76.5	0.058
65205	S4	159	0.017
65205	MN4	102.8	0.025
65205	S6	141.7	0.012
65205	2N2	334.2	0.079
65205	OO1	203.6	0.06
65205	M1	45.2	0.047
65205	J1	101.7	0.103
65205	Q1	24.8	0.084
65205	2Q1	328.1	0.073
65205	P1	96.5	0.276
65205	2SM2	54.2	0.013
65205	M3	207.5	0.036
65205	L2	87.5	0.067
65205	2MK3	350.3	0.029
65205	K2	105.4	0.154
65205	M8	263.3	0.023
65205	MS4	234.8	0.033
65206	M2	64.5	1.365
65206	S2	119.8	0.342
65206	N2	44.2	0.277
65206	K1	73.1	0.806
65206	M4	115.8	0.131
65206	O1	38.3	0.317
65206	M6	310.9	0.072
65206	MK3	131.2	0.145
65206	S4	120.6	0.037
65206	MN4	72.3	0.064
65206	S6	191	0.015
65206	2N2	154.7	0.01
65206	OO1	20.3	0.063
65206	M1	248.8	0.024
65206	J1	94.9	0.028
65206	Q1	347.3	0.101
65206	2Q1	291.7	0.1
65206	P1	85.6	0.172
65206	2SM2	228.7	0.012
65206	M3	183	0.1
65206	L2	81.9	0.151
65206	2MK3	200.7	0.086
65206	K2	88.9	0.223
65206	M8	240.4	0.03
65206	MS4	133	0.069
65207	M2	56.2	0.928
65207	S2	86.9	0.265
65207	N2	30	0.23
65207	K1	55.1	0.576
65207	M4	173.9	0.027
65207	O1	41.2	0.134
65207	M6	158.5	0.008
65207	MK3	117.7	0.047
65207	S4	89.4	0.008
65207	MN4	184.8	0.023
65207	S6	164.7	0.008
65207	2N2	283.5	0.07
65207	OO1	57.9	0.064
65207	M1	44	0.02
65207	J1	146.8	0.046
65207	Q1	354.2	0.021
65207	2Q1	263.1	0.035
65207	P1	47.6	0.092
65207	2SM2	347.9	0.039
65207	M3	210.3	0.015
65207	L2	138.2	0.066
65207	2MK3	310.7	0.024
65207	K2	87.3	0.121
65207	M8	110.8	0.004
65207	MS4	359.4	0.019
65208	M2	56	0.962
65208	S2	74.9	0.232
65208	N2	13.7	0.244
65208	K1	48.8	0.489
65208	M4	52.8	0.023
65208	O1	57.1	0.224
65208	M6	132.1	0.012
65208	MK3	325.9	0.103
65208	S4	119.7	0.016
65208	MN4	339	0.029
65208	S6	340.9	0.01
65208	2N2	171.5	0.028
65208	OO1	110.8	0.04
65208	M1	168	0.024
65208	J1	95.4	0.026
65208	Q1	109.7	0.036
65208	2Q1	133.5	0.045
65208	P1	222.2	0.023
65208	2SM2	219.3	0.009
65208	M3	75.4	0.047
65208	L2	134.2	0.053
65208	2MK3	326.3	0.069
65208	K2	129.6	0.095
65208	M8	26.3	0.009
65208	MS4	105.9	0.017
65209	M2	57.4	0.992
65209	S2	47.6	0.242
65209	N2	12.2	0.219
65209	K1	62.4	0.504
65209	M4	13.5	0.069
65209	O1	61.1	0.262
65209	M6	74.6	0.012
65209	MK3	330.7	0.123
65209	S4	31.5	0.014
65209	MN4	1.1	0.039
65209	2N2	161.7	0.047
65209	OO1	116.1	0.06
65209	M1	173.9	0.041
65209	J1	209	0.006
65209	Q1	114.6	0.068
65209	2Q1	143.3	0.06
65209	P1	232.9	0.035
65209	2SM2	240	0.027
65209	M3	51	0.09
65209	L2	91.3	0.058
65209	2MK3	340.6	0.049
65209	K2	184.5	0.059
65209	M8	153.7	0.009
65209	MS4	97.9	0.037
65210	M2	50.8	1.296
65210	S2	63.2	0.264
65210	N2	17.1	0.344
65210	K1	62.6	0.734
65210	M4	337.5	0.033
65210	O1	59.7	0.553
65210	M6	172.6	0.021
65210	MK3	273.6	0.113
65210	S4	347.2	0.027
65210	MN4	246.4	0.004
65210	S6	247.6	0.015
65210	2N2	294.7	0.025
65210	OO1	186.4	0.034
65210	M1	78.1	0.04
65210	J1	138.6	0.034
65210	Q1	34	0.155
65210	2Q1	200.8	0.04
65210	P1	84.6	0.197
65210	2SM2	179.8	0.026
65210	M3	342.4	0.025
65210	L2	105	0.065
65210	2MK3	275	0.039
65210	K2	73.4	0.067
65210	M8	28.3	0.01
65210	MS4	1.5	0.089
65211	M2	56.8	1.553
65211	S2	88	0.291
65211	N2	29.9	0.428
65211	K1	73.2	0.948
65211	M4	305.8	0.047
65211	O1	67.7	0.731
65211	M6	28.4	0.01
65211	MK3	287.2	0.16
65211	S4	206.3	0.011
65211	MN4	290	0.023
65211	S6	269.4	0.01
65211	2N2	213.4	0.038
65211	OO1	163.4	0.087
65211	M1	355.1	0.021
65211	J1	142.6	0.02
65211	Q1	26.3	0.189
65211	2Q1	207.8	0.011
65211	P1	86.2	0.3
65211	2SM2	215.5	0.022
65211	M3	249.2	0.047
65211	L2	125.9	0.067
65211	2MK3	283.1	0.073
65211	K2	96.9	0.192
65211	M8	88.5	0.005
65211	MS4	327.6	0.156
65212	M2	58.7	1.577
65212	S2	94.4	0.304
65212	N2	33.4	0.445
65212	K1	76.5	0.997
65212	M4	297.6	0.067
65212	O1	70.4	0.757
65212	M6	9.5	0.032
65212	MK3	292.4	0.183
65212	S4	200.9	0.022
65212	MN4	294	0.028
65212	S6	267.1	0.012
65212	2N2	224	0.044
65212	OO1	160.9	0.099
65212	M1	333.5	0.036
65212	J1	132.4	0.011
65212	Q1	24.6	0.207
65212	2Q1	335.1	0.016
65212	P1	88.5	0.317
65212	2SM2	229.7	0.022
65212	M3	238.1	0.073
65212	L2	142.9	0.058
65212	2MK3	292.6	0.065
65212	K2	102.1	0.223
65212	M8	73.9	0.009
65212	MS4	319.4	0.172
65213	M2	63.8	1.234
65213	S2	87.6	0.306
65213	N2	46.5	0.254
65213	K1	82.1	0.878
65213	M4	41.6	0.061
65213	O1	73.1	0.468
65213	M6	73.4	0.029
65213	MK3	11.5	0.074
65213	S4	223.4	0.011
65213	MN4	0.7	0.011
65213	NU2	59.7	0.055
65213	S6	296.4	0.01
65213	MU2	341.9	0.028
65213	2N2	353.4	0.021
65213	OO1	89.8	0.047
65213	LDA2	72.9	0.024
65213	M1	102.8	0.05
65213	J1	126.8	0.057
65213	RHO1	346.5	0.024
65213	Q1	67.7	0.075
65213	2Q1	66.8	0.021
65213	P1	84.6	0.299
65213	2SM2	246.9	0.019
65213	M3	61.4	0.01
65213	L2	73.1	0.053
65213	2MK3	281.7	0.04
65213	K2	88.1	0.051
65213	M8	168.5	0.009
65213	MS4	89.5	0.065
65214	M2	69.2	1.521
65214	S2	87.1	0.395
65214	N2	41	0.321
65214	K1	84.6	0.887
65214	M4	141.8	0.041
65214	O1	76	0.409
65214	M6	143.6	0.018
65214	MK3	103.3	0.155
65214	S4	299.2	0.018
65214	MN4	112.9	0.017
65214	NU2	33.5	0.058
65214	MU2	327.2	0.045
65214	2N2	349.4	0.012
65214	OO1	107.6	0.091
65214	LDA2	102.6	0.02
65214	M1	96	0.033
65214	J1	98.1	0.05
65214	RHO1	331.6	0.007
65214	Q1	66.7	0.068
65214	2Q1	258.5	0.022
65214	P1	80.1	0.255
65214	2SM2	326.8	0.016
65214	M3	135.7	0.008
65214	L2	140.8	0.043
65214	2MK3	37.5	0.048
65214	K2	117.4	0.083
65214	M8	9.2	0.002
65214	MS4	159	0.032
65215	M2	64.6	1.247
65215	S2	85	0.275
65215	N2	37.7	0.258
65215	K1	84.5	0.706
65215	M4	318.2	0.015
65215	O1	68.5	0.371
65215	M6	206.4	0.02
65215	MK3	235.4	0.023
65215	S4	102.1	0.012
65215	MN4	139.7	0.018
65215	NU2	45	0.046
65215	MU2	292.2	0.038
65215	2N2	73.8	0.04
65215	OO1	189.2	0.085
65215	LDA2	319.4	0.005
65215	M1	147.8	0.023
65215	J1	104.1	0.03
65215	RHO1	85.4	0.021
65215	Q1	60.4	0.043
65215	2Q1	161.3	0.01
65215	P1	87.9	0.193
65215	2SM2	115.1	0.003
65215	M3	134.3	0.011
65215	L2	114.6	0.046
65215	2MK3	119.8	0.056
65215	K2	85	0.142
65215	M8	52.2	0.023
65215	MS4	320	0.009
65216	M2	73.7	0.999
65216	S2	92.8	0.235
65216	N2	42.8	0.258
65216	K1	69.1	0.495
65216	M4	155.2	0.033
65216	O1	59.6	0.205
65216	M6	150.4	0.011
65216	MK3	64	0.048
65216	S4	14.7	0.009
65216	MN4	121.1	0.02
65216	S6	7.4	0.007
65216	2N2	299.2	0.017
65216	OO1	276.7	0.037
65216	M1	70.2	0.011
65216	J1	102.5	0.047
65216	Q1	51.2	0.019
65216	2Q1	187.5	0.021
65216	P1	75.9	0.175
65216	2SM2	1	0.025
65216	M3	144.9	0.01
65216	L2	114.3	0.057
65216	2MK3	341.1	0.013
65216	K2	116.6	0.048
65216	M8	292.3	0.005
65216	MS4	151.7	0.004
65217	M2	51.9	0.968
65217	S2	91.2	0.159
65217	N2	20.8	0.203
65217	K1	73.3	0.511
65217	M4	321.1	0.019
65217	O1	61.6	0.353
65217	M6	24	0.018
65217	MK3	251.2	0.171
65217	S4	8.3	0.027
65217	MN4	297.5	0.022
65217	S6	12.3	0.005
65217	2N2	169.9	0.022
65217	OO1	111.1	0.032
65217	M1	94.2	0.032
65217	J1	173.3	0.012
65217	Q1	61.4	0.072
65217	2Q1	348.4	0.026
65217	P1	88	0.105
65217	2SM2	307.9	0.012
65217	M3	300.6	0.055
65217	L2	104.7	0.07
65217	2MK3	250.2	0.074
65217	K2	113.6	0.144
65217	M8	141.3	0.005
65217	MS4	321	0.017
65218	M2	53.5	0.657
65218	S2	91.1	0.126
65218	N2	11.2	0.171
65218	K1	38.8	0.355
65218	M4	70.9	0.078
65218	O1	17.3	0.316
65218	M6	213.5	0.006
65218	MK3	180.7	0.173
65218	S4	273.1	0.031
65218	MN4	46.8	0.048
65218	S6	135.2	0.008
65218	2N2	295.9	0.028
65218	OO1	241.9	0.096
65218	M1	353.4	0.049
65218	J1	102.8	0.051
65218	Q1	338	0.064
65218	2Q1	78.4	0.031
65218	P1	5.6	0.01
65218	2SM2	110.3	0.006
65218	M3	79.9	0.003
65218	L2	51.4	0.022
65218	2MK3	169.2	0.081
65218	K2	303.7	0.007
65218	M8	225.9	0.006
65218	MS4	139	0.05
65219	M2	50.5	0.839
65219	S2	78.3	0.197
65219	N2	27.8	0.178
65219	K1	73.9	0.539
65219	M4	230.3	0.021
65219	O1	53.3	0.302
65219	M6	91	0.012
65219	MK3	311	0.026
65219	S4	206.4	0.005
65219	MN4	200.3	0.01
65219	NU2	44.1	0.033
65219	S6	284.8	0.002
65219	MU2	299.8	0.025
65219	2N2	349.9	0.024
65219	OO1	131.3	0.035
65219	LDA2	123.5	0.009
65219	M1	86.3	0.036
65219	J1	117	0.041
65219	RHO1	40.1	0.011
65219	Q1	49.2	0.056
65219	2Q1	14	0.011
65219	P1	80.8	0.184
65219	2SM2	311.1	0.009
65219	M3	342.2	0.004
65219	L2	74.7	0.029
65219	2MK3	264.1	0.019
65219	K2	43.7	0.043
65219	M8	8.2	0.002
65219	MS4	257.4	0.016
65220	M2	56.5	0.85
65220	S2	76.5	0.23
65220	N2	36	0.19
65220	K1	71.7	0.604
65220	M4	235.5	0.014
65220	O1	53.1	0.365
65220	M6	67.7	0.006
65220	MK3	145.2	0.015
65220	S4	187.7	0.007
65220	MN4	172.8	0.005
65220	NU2	31	0.03
65220	S6	256.9	0.005
65220	MU2	338.8	0.019
65220	2N2	24.2	0.01
65220	OO1	35.2	0.013
65220	LDA2	337.3	0.01
65220	M1	78.1	0.03
65220	J1	108.5	0.057
65220	RHO1	21.1	0.01
65220	Q1	40.6	0.054
65220	2Q1	15.9	0.027
65220	P1	69.7	0.21
65220	2SM2	349.4	0.004
65220	M3	262.8	0.004
65220	L2	106.2	0.014
65220	2MK3	138.4	0.014
65220	K2	101.3	0.049
65220	MS4	234.6	0.014
65221	M2	51	0.867
65221	S2	71.7	0.193
65221	N2	19.4	0.152
65221	K1	79.6	0.498
65221	M4	185	0.055
65221	O1	71.4	0.206
65221	M6	154.6	0.009
65221	MK3	241.9	0.03
65221	S4	36.3	0.013
65221	MN4	130.4	0.02
65221	NU2	13.4	0.029
65221	S6	92.7	0.009
65221	MU2	5.8	0.018
65221	2N2	51	0.011
65221	OO1	349	0.025
65221	LDA2	81.3	0.023
65221	M1	154.8	0.012
65221	J1	89.9	0.023
65221	RHO1	347.2	0.028
65221	Q1	77.5	0.034
65221	2Q1	175.7	0.015
65221	P1	76.9	0.141
65221	2SM2	47.6	0.005
65221	M3	222.7	0.009
65221	L2	97.8	0.074
65221	2MK3	254.5	0.015
65221	K2	78.5	0.076
65221	M8	235.3	0.001
65221	MS4	159	0.017
65222	M2	52	0.761
65222	S2	78.6	0.155
65222	N2	19.1	0.115
65222	K1	78.8	0.416
65222	M4	133.5	0.038
65222	O1	58.8	0.14
65222	M6	251.4	0.018
65222	MK3	187	0.044
65222	S4	55.8	0.031
65222	MN4	93	0.021
65222	NU2	349	0.024
65222	S6	110.8	0.005
65222	MU2	176.1	0.008
65222	2N2	118.2	0.029
65222	OO1	55.2	0.057
65222	LDA2	68.1	0.029
65222	M1	206.1	0.026
65222	J1	338.8	0.013
65222	RHO1	2.7	0.028
65222	Q1	115.6	0.01
65222	2Q1	171.5	0.038
65222	P1	65	0.13
65222	2SM2	259.3	0.009
65222	M3	185.6	0.023
65222	L2	86.6	0.091
65222	2MK3	168.2	0.04
65222	K2	58.3	0.083
65222	M8	126.7	0.004
65222	MS4	76.7	0.044
65223	M2	9.3	5.418
65223	S2	11.6	1.102
65223	N2	351.9	1.082
65223	K1	24	1.046
65223	M4	88.3	0.127
65223	O1	16.7	0.371
65223	M6	226.6	0.399
65223	MK3	179.4	0.141
65223	S4	4.6	0.024
65223	MN4	83.8	0.066
65223	2N2	269.2	0.187
65223	OO1	246.1	0.155
65223	M1	68	0.165
65223	J1	80.2	0.089
65223	Q1	53.9	0.091
65223	2Q1	120.7	0.057
65223	P1	72.5	0.332
65223	2SM2	221.7	0.123
65223	M3	101.9	0.089
65223	L2	26.6	0.452
65223	2MK3	208.4	0.259
65223	M8	347.6	0.053
65223	MS4	71.7	0.059
65224	M2	9.4	5.438
65224	S2	11.9	1.082
65224	N2	351.2	1.074
65224	K1	25.4	1.031
65224	M4	99.8	0.11
65224	O1	13.7	0.364
65224	M6	226.4	0.389
65224	MK3	182	0.178
65224	S4	346.9	0.026
65224	MN4	94.5	0.073
65224	2N2	269.4	0.212
65224	OO1	245.9	0.178
65224	M1	69.3	0.164
65224	J1	75.9	0.085
65224	Q1	56.9	0.083
65224	2Q1	124.6	0.054
65224	P1	69.8	0.344
65224	2SM2	215.4	0.123
65224	M3	99.2	0.095
65224	L2	24.2	0.456
65224	2MK3	210.4	0.284
65224	M8	345.3	0.048
65224	MS4	75	0.042
65225	M2	9.3	5.21
65225	S2	13	0.964
65225	N2	354.1	0.981
65225	K1	24.7	1.05
65225	M4	121.5	0.124
65225	O1	19	0.314
65225	M6	234.4	0.363
65225	MK3	175	0.24
65225	S4	335.3	0.026
65225	MN4	125.5	0.066
65225	S6	270.9	0.029
65225	2N2	261.2	0.254
65225	OO1	239.9	0.179
65225	M1	81.8	0.158
65225	J1	37.9	0.05
65225	Q1	51	0.092
65225	2Q1	142.5	0.052
65225	P1	60.8	0.225
65225	2SM2	214.9	0.116
65225	M3	96	0.096
65225	L2	23.8	0.496
65225	2MK3	213.8	0.3
65225	M8	331	0.022
65225	MS4	114.5	0.031
65226	M2	87.8	1.38
65226	S2	110.8	0.342
65226	N2	61.8	0.281
65226	K1	81.1	0.927
65226	M4	48.4	0.061
65226	O1	71.7	0.42
65226	M6	105.6	0.024
65226	MK3	71	0.179
65226	S4	113.3	0.005
65226	MN4	48.6	0.021
65226	NU2	62.6	0.051
65226	S6	2.7	0.004
65226	MU2	350.9	0.051
65226	2N2	11.6	0.057
65226	OO1	82.7	0.07
65226	LDA2	192.5	0.016
65226	M1	135.3	0.069
65226	J1	164.6	0.042
65226	RHO1	235.6	0.004
65226	Q1	82.2	0.09
65226	2Q1	331.7	0.039
65226	P1	86.9	0.195
65226	2SM2	357.7	0.004
65226	M3	60.9	0.037
65226	L2	124.1	0.058
65226	2MK3	29.2	0.09
65226	K2	155.4	0.092
65226	M8	67.2	0.03
65226	MS4	50.2	0.072
65227	M2	87.7	1.41
65227	S2	109.4	0.354
65227	N2	61.5	0.3
65227	K1	83.9	0.972
65227	M4	64.6	0.061
65227	O1	74.5	0.453
65227	M6	98	0.018
65227	MK3	76.3	0.185
65227	S4	102.8	0.004
65227	MN4	59.9	0.022
65227	NU2	66	0.049
65227	S6	347	0.004
65227	MU2	5.4	0.059
65227	2N2	2.7	0.054
65227	OO1	94.4	0.074
65227	LDA2	182.8	0.01
65227	M1	134.2	0.053
65227	J1	153.2	0.042
65227	RHO1	220.4	0.006
65227	Q1	79.1	0.088
65227	2Q1	330.2	0.037
65227	P1	87.1	0.215
65227	2SM2	66.8	0.006
65227	M3	56.8	0.041
65227	L2	134.3	0.053
65227	2MK3	41.7	0.089
65227	K2	156.6	0.093
65227	M8	70.3	0.028
65227	MS4	56.4	0.062
65228	M2	87.5	1.421
65228	S2	108.2	0.366
65228	N2	61	0.316
65228	K1	86.7	0.993
65228	M4	78.1	0.061
65228	O1	77.3	0.477
65228	M6	78.8	0.011
65228	MK3	81.6	0.186
65228	MN4	63.6	0.024
65228	NU2	65.7	0.048
65228	S6	329.9	0.006
65228	MU2	17.2	0.065
65228	2N2	356.2	0.052
65228	OO1	106.1	0.073
65228	LDA2	179.1	0.01
65228	M1	129.8	0.041
65228	J1	139.6	0.047
65228	RHO1	233.8	0.007
65228	Q1	80	0.085
65228	2Q1	326.1	0.039
65228	P1	89.3	0.235
65228	2SM2	85.7	0.01
65228	M3	55.3	0.045
65228	L2	140	0.048
65228	2MK3	52.4	0.086
65228	K2	159	0.092
65228	M8	70.2	0.025
65228	MS4	60.1	0.046
65229	M2	87.5	1.432
65229	S2	107.4	0.378
65229	N2	60.6	0.329
65229	K1	88.9	1.011
65229	M4	88.8	0.062
65229	O1	79.1	0.498
65229	M6	48.6	0.006
65229	MK3	86.1	0.185
65229	MN4	67.9	0.025
65229	NU2	64.4	0.046
65229	S6	320.5	0.006
65229	MU2	24.5	0.07
65229	2N2	350.8	0.049
65229	OO1	116.2	0.074
65229	LDA2	179.1	0.013
65229	M1	124.1	0.034
65229	J1	128.2	0.054
65229	RHO1	236	0.009
65229	Q1	80.4	0.083
65229	2Q1	318.7	0.04
65229	P1	91.5	0.255
65229	2SM2	94.1	0.012
65229	M3	54.4	0.046
65229	L2	142.8	0.043
65229	2MK3	60.8	0.082
65229	K2	162.3	0.094
65229	M8	66.5	0.021
65229	MS4	62.6	0.031
65230	M2	87.8	1.45
65230	S2	107.3	0.389
65230	N2	60.5	0.34
65230	K1	90.9	1.031
65230	M4	96.7	0.063
65230	O1	79.9	0.517
65230	M6	30.2	0.004
65230	MK3	89.8	0.181
65230	S4	252.7	0.004
65230	MN4	72.2	0.025
65230	NU2	63.2	0.044
65230	S6	313.5	0.007
65230	MU2	29.2	0.074
65230	2N2	344.3	0.048
65230	OO1	122.7	0.078
65230	LDA2	176.8	0.019
65230	M1	120.4	0.029
65230	J1	120.1	0.061
65230	RHO1	223.5	0.011
65230	Q1	78.9	0.082
65230	2Q1	307.5	0.038
65230	P1	92.7	0.275
65230	2SM2	100.8	0.014
65230	M3	52.3	0.046
65230	L2	142.8	0.04
65230	2MK3	67.4	0.08
65230	K2	164.3	0.097
65230	M8	60	0.019
65230	MS4	69	0.018
65231	M2	88.2	1.473
65231	S2	107.7	0.4
65231	N2	60.6	0.349
65231	K1	92.5	1.055
65231	M4	103.6	0.061
65231	O1	80.2	0.535
65231	MK3	93.1	0.172
65231	S4	268	0.006
65231	MN4	74.1	0.024
65231	NU2	61.9	0.043
65231	S6	310.1	0.008
65231	MU2	32	0.075
65231	2N2	339.5	0.05
65231	OO1	126.5	0.082
65231	LDA2	179.1	0.025
65231	M1	117.6	0.026
65231	J1	114	0.067
65231	RHO1	206.9	0.012
65231	Q1	75.2	0.08
65231	2Q1	294.3	0.035
65231	P1	93.4	0.296
65231	2SM2	103	0.014
65231	M3	48.6	0.046
65231	L2	141	0.039
65231	2MK3	73.1	0.078
65231	K2	165.3	0.101
65231	M8	56	0.017
65231	MS4	86.1	0.007
65232	M2	88.7	1.501
65232	S2	108.4	0.412
65232	N2	61.1	0.355
65232	K1	93.9	1.081
65232	M4	110.2	0.058
65232	O1	80.3	0.55
65232	M6	219.7	0.004
65232	MK3	95.9	0.163
65232	S4	273.9	0.007
65232	MN4	74.2	0.023
65232	NU2	60.1	0.042
65232	S6	319.2	0.007
65232	MU2	33.6	0.073
65232	2N2	335.6	0.053
65232	OO1	129.9	0.087
65232	LDA2	180	0.031
65232	M1	114.4	0.023
65232	J1	109.2	0.072
65232	RHO1	196.5	0.014
65232	Q1	71.7	0.081
65232	2Q1	280	0.033
65232	P1	93.9	0.317
65232	2SM2	100.8	0.013
65232	M3	45	0.045
65232	L2	138.3	0.04
65232	2MK3	77.2	0.078
65232	K2	165.2	0.107
65232	M8	53.8	0.016
65232	MS4	207	0.006
65233	M2	89.3	1.531
65233	S2	109	0.423
65233	N2	61.7	0.36
65233	K1	95.1	1.106
65233	M4	118.1	0.055
65233	O1	80.1	0.564
65233	M6	215	0.008
65233	MK3	97.9	0.154
65233	S4	272.6	0.007
65233	MN4	75.1	0.022
65233	NU2	61	0.041
65233	S6	326.7	0.006
65233	MU2	33.5	0.07
65233	2N2	333.1	0.056
65233	OO1	133.1	0.089
65233	LDA2	180.7	0.036
65233	M1	110	0.021
65233	J1	104.3	0.076
65233	RHO1	192	0.014
65233	Q1	68.8	0.081
65233	2Q1	265.8	0.03
65233	P1	94.2	0.339
65233	2SM2	93.2	0.011
65233	M3	40.4	0.043
65233	L2	134.6	0.042
65233	2MK3	80.7	0.079
65233	K2	165.4	0.112
65233	M8	47.5	0.015
65233	MS4	231.5	0.016
65234	M2	89.7	1.562
65234	S2	109.6	0.431
65234	N2	62.6	0.363
65234	K1	96.1	1.13
65234	M4	126.5	0.053
65234	O1	79.9	0.576
65234	M6	213.9	0.011
65234	MK3	99	0.148
65234	S4	262.9	0.006
65234	MN4	77.3	0.02
65234	NU2	62.6	0.039
65234	S6	335.9	0.006
65234	MU2	31.5	0.067
65234	2N2	331.5	0.058
65234	OO1	135.8	0.09
65234	LDA2	181.9	0.041
65234	M1	102.9	0.019
65234	J1	99.2	0.079
65234	RHO1	192.5	0.013
65234	Q1	66.5	0.082
65234	2Q1	250.8	0.029
65234	P1	94.1	0.36
65234	2SM2	80.6	0.009
65234	M3	33.7	0.041
65234	L2	130.8	0.045
65234	2MK3	83.1	0.08
65234	K2	166.5	0.116
65234	M8	36	0.013
65234	MS4	237.2	0.026
65235	M2	90.1	1.59
65235	S2	110.2	0.438
65235	N2	63.6	0.365
65235	K1	96.9	1.153
65235	M4	133.8	0.052
65235	O1	79.7	0.587
65235	M6	213.9	0.013
65235	MK3	99.2	0.142
65235	S4	244.5	0.006
65235	MN4	81.7	0.019
65235	NU2	64.6	0.039
65235	S6	345.1	0.005
65235	MU2	27.2	0.066
65235	2N2	329.6	0.058
65235	OO1	137.3	0.09
65235	LDA2	181.8	0.045
65235	M1	92.1	0.016
65235	J1	93.4	0.08
65235	RHO1	198	0.013
65235	Q1	64.5	0.084
65235	2Q1	235.5	0.028
65235	P1	93.7	0.379
65235	2SM2	63.6	0.008
65235	M3	26.9	0.038
65235	L2	126	0.047
65235	2MK3	82.9	0.079
65235	K2	167.7	0.122
65235	M8	19.6	0.012
65235	MS4	238.9	0.036
65236	M2	90.5	1.615
65236	S2	110.5	0.442
65236	N2	64.8	0.365
65236	K1	97.6	1.176
65236	M4	139.4	0.052
65236	O1	79.8	0.596
65236	M6	214.2	0.014
65236	MK3	97.7	0.136
65236	S4	216	0.006
65236	MN4	85.7	0.018
65236	NU2	65.8	0.041
65236	S6	3.3	0.003
65236	MU2	21.9	0.066
65236	2N2	328.2	0.056
65236	OO1	137.6	0.088
65236	LDA2	181	0.046
65236	M1	72.5	0.013
65236	J1	86.7	0.083
65236	RHO1	200.7	0.015
65236	Q1	61.7	0.086
65236	2Q1	220.3	0.028
65236	P1	93	0.395
65236	2SM2	50.8	0.008
65236	M3	21.3	0.036
65236	L2	122.2	0.05
65236	2MK3	81.6	0.076
65236	K2	169.3	0.128
65236	M8	4.6	0.012
65236	MS4	238.9	0.045
65237	M2	90.7	1.635
65237	S2	110.7	0.444
65237	N2	65.9	0.365
65237	K1	98.2	1.196
65237	M4	144.9	0.051
65237	O1	80	0.604
65237	M6	213.7	0.015
65237	MK3	94.8	0.127
65237	S4	197.4	0.008
65237	MN4	86.8	0.018
65237	NU2	68.9	0.043
65237	MU2	17.7	0.067
65237	2N2	326.2	0.055
65237	OO1	138.8	0.085
65237	LDA2	180.7	0.046
65237	M1	42.6	0.012
65237	J1	80.7	0.086
65237	RHO1	198.5	0.015
65237	Q1	59.7	0.086
65237	2Q1	204.1	0.028
65237	P1	92.3	0.409
65237	2SM2	38.8	0.008
65237	M3	17	0.036
65237	L2	119	0.052
65237	2MK3	79.2	0.074
65237	K2	169.5	0.134
65237	M8	350.8	0.012
65237	MS4	238.3	0.051
65238	M2	91	1.646
65238	S2	110.8	0.445
65238	N2	66.9	0.364
65238	K1	98.8	1.212
65238	M4	149.8	0.05
65238	O1	80.3	0.612
65238	M6	213.1	0.017
65238	MK3	90.5	0.116
65238	S4	194.3	0.01
65238	MN4	89.6	0.019
65238	NU2	73.4	0.045
65238	MU2	14.8	0.069
65238	2N2	324.5	0.055
65238	OO1	140.9	0.081
65238	LDA2	179.8	0.046
65238	M1	16.3	0.014
65238	J1	76.3	0.09
65238	RHO1	189.7	0.012
65238	Q1	57.4	0.085
65238	2Q1	187.3	0.028
65238	P1	91.9	0.421
65238	2SM2	34.1	0.01
65238	M3	13.4	0.037
65238	L2	116.5	0.053
65238	2MK3	75.9	0.073
65238	K2	168.6	0.138
65238	M8	337.6	0.013
65238	MS4	238.4	0.056
65239	M2	91.3	1.649
65239	S2	110.7	0.446
65239	N2	67.8	0.363
65239	K1	99.5	1.222
65239	M4	154.6	0.048
65239	O1	80.7	0.62
65239	M6	214.1	0.019
65239	MK3	85.4	0.104
65239	S4	197.7	0.012
65239	MN4	91	0.019
65239	NU2	78.4	0.047
65239	S6	129.8	0.003
65239	MU2	13.7	0.07
65239	2N2	322.9	0.057
65239	OO1	143.9	0.075
65239	LDA2	178.6	0.047
65239	M1	2.5	0.018
65239	J1	73.9	0.095
65239	RHO1	180.5	0.01
65239	Q1	55.1	0.084
65239	2Q1	173.7	0.031
65239	P1	91.7	0.43
65239	2SM2	34.4	0.011
65239	M3	9.6	0.037
65239	L2	115	0.052
65239	2MK3	71.5	0.074
65239	K2	166.9	0.141
65239	M8	324.6	0.014
65239	MS4	238.8	0.059
65240	M2	91.6	1.645
65240	S2	110.4	0.446
65240	N2	68.6	0.363
65240	K1	100.1	1.229
65240	M4	159.5	0.046
65240	O1	81.1	0.627
65240	M6	218.6	0.02
65240	MK3	79.5	0.091
65240	S4	205.9	0.014
65240	MN4	90.4	0.018
65240	NU2	83.1	0.048
65240	S6	143.7	0.003
65240	MU2	13	0.07
65240	2N2	322.8	0.061
65240	OO1	148.7	0.07
65240	LDA2	177.6	0.047
65240	M1	354.8	0.023
65240	J1	72.8	0.097
65240	RHO1	157.5	0.009
65240	Q1	52.3	0.082
65240	2Q1	165.1	0.035
65240	P1	91.9	0.438
65240	2SM2	36.7	0.013
65240	M3	6.7	0.036
65240	L2	114.8	0.05
65240	2MK3	68.3	0.076
65240	K2	166	0.142
65240	M8	312.1	0.016
65240	MS4	238.4	0.059
65241	M2	91.8	1.633
65241	S2	110	0.445
65241	N2	69.3	0.361
65241	K1	100.8	1.233
65241	M4	165	0.043
65241	O1	81.6	0.633
65241	M6	226.9	0.022
65241	MK3	72.1	0.078
65241	S4	211.9	0.016
65241	MN4	86.7	0.016
65241	NU2	86.3	0.049
65241	MU2	12.5	0.067
65241	2N2	324.4	0.062
65241	OO1	156.1	0.066
65241	LDA2	176.4	0.046
65241	M1	352.9	0.026
65241	J1	72.5	0.097
65241	RHO1	128.2	0.008
65241	Q1	50.2	0.08
65241	2Q1	159.7	0.037
65241	P1	92.1	0.445
65241	2SM2	39.6	0.015
65241	M3	3.7	0.034
65241	L2	116	0.046
65241	2MK3	66.1	0.078
65241	K2	165.3	0.14
65241	M8	303.5	0.019
65241	MS4	237.2	0.058
65242	M2	92	1.61
65242	S2	109.8	0.438
65242	N2	70.3	0.355
65242	K1	101.2	1.237
65242	M4	170.8	0.04
65242	O1	81.8	0.633
65242	M6	232.3	0.021
65242	MK3	61.5	0.062
65242	S4	212.6	0.019
65242	MN4	94.1	0.016
65242	NU2	83.2	0.048
65242	MU2	7.8	0.061
65242	2N2	328.8	0.059
65242	OO1	166	0.066
65242	LDA2	171.2	0.042
65242	M1	343.7	0.031
65242	J1	71.1	0.099
65242	RHO1	69.1	0.008
65242	Q1	50.5	0.072
65242	2Q1	155.9	0.037
65242	P1	92.4	0.447
65242	2SM2	38.9	0.016
65242	M3	356.8	0.028
65242	L2	121.5	0.045
65242	2MK3	66.6	0.075
65242	K2	165.1	0.14
65242	M8	302	0.022
65242	MS4	233.7	0.058
65243	M2	56.1	3.024
65243	S2	68.9	0.606
65243	N2	31.3	0.724
65243	K1	53	1.378
65243	M4	154.1	0.173
65243	O1	38.6	0.877
65243	M6	351.6	0.007
65243	MK3	152	0.145
65243	S4	277.7	0.012
65243	MN4	123.3	0.077
65243	2N2	322.7	0.115
65243	OO1	308.6	0.089
65243	M1	147	0.115
65243	J1	88.2	0.047
65243	Q1	43.1	0.132
65243	2Q1	193	0.021
65243	P1	60.2	0.371
65243	2SM2	324.8	0.019
65243	M3	171.2	0.04
65243	L2	82.9	0.15
65243	2MK3	294.6	0.037
65243	M8	267.5	0.013
65243	MS4	141	0.073
65244	M2	56	3.023
65244	S2	68.8	0.601
65244	N2	30.7	0.717
65244	K1	53.3	1.365
65244	M4	154.9	0.175
65244	O1	37.5	0.859
65244	M6	44.6	0.01
65244	MK3	155.7	0.134
65244	S4	235.7	0.011
65244	MN4	125	0.077
65244	S6	223.9	0.004
65244	2N2	319.4	0.114
65244	OO1	307.1	0.104
65244	M1	145.4	0.111
65244	J1	84.6	0.047
65244	Q1	40.3	0.118
65244	2Q1	201.5	0.017
65244	P1	58.5	0.369
65244	2SM2	333.4	0.022
65244	M3	166.2	0.047
65244	L2	83.9	0.16
65244	2MK3	286.7	0.052
65244	M8	241.6	0.017
65244	MS4	147.8	0.075
65245	M2	56.4	2.847
65245	S2	70.1	0.532
65245	N2	30.2	0.663
65245	K1	52.8	1.244
65245	M4	145.3	0.166
65245	O1	33.4	0.783
65245	M6	329.5	0.029
65245	MK3	162.1	0.164
65245	S4	189.8	0.01
65245	MN4	123.5	0.072
65245	S6	270.4	0.004
65245	2N2	303.8	0.102
65245	OO1	307.9	0.106
65245	M1	155.1	0.105
65245	J1	80.4	0.036
65245	Q1	38.9	0.093
65245	2Q1	222.4	0.037
65245	P1	52.9	0.344
65245	2SM2	331.2	0.031
65245	M3	163.7	0.054
65245	L2	81	0.177
65245	2MK3	243	0.079
65245	M8	219.3	0.031
65245	MS4	134	0.087
65246	M2	51.7	1.569
65246	S2	72.4	0.327
65246	N2	33.7	0.346
65246	K1	66.8	0.651
65246	M4	60.9	0.099
65246	O1	58.9	0.235
65246	M6	358	0.076
65246	MK3	71.2	0.101
65246	S4	347.3	0.015
65246	MN4	64	0.03
65246	S6	168.9	0.008
65246	2N2	318	0.018
65246	OO1	308.1	0.028
65246	M1	76.2	0.025
65246	J1	76	0.045
65246	Q1	49.3	0.056
65246	2Q1	98	0.018
65246	P1	77.5	0.164
65246	2SM2	244	0.011
65246	M3	59.8	0.061
65246	L2	60.4	0.086
65246	2MK3	230.3	0.058
65246	K2	88.3	0.055
65246	M8	345.8	0.011
65246	MS4	65.7	0.104
65247	M2	51.6	1.961
65247	S2	72	0.4
65247	N2	31.8	0.431
65247	K1	68.3	0.872
65247	M4	69.4	0.088
65247	O1	61.2	0.319
65247	M6	353	0.094
65247	MK3	67.7	0.093
65247	S4	335.9	0.011
65247	MN4	57.7	0.021
65247	S6	144.7	0.011
65247	2N2	333.2	0.023
65247	OO1	283	0.038
65247	M1	76	0.034
65247	J1	74.1	0.035
65247	Q1	59.4	0.068
65247	2Q1	87.6	0.037
65247	P1	67.2	0.228
65247	2SM2	216.1	0.011
65247	M3	56.1	0.061
65247	L2	58.9	0.097
65247	2MK3	222.3	0.078
65247	K2	94.2	0.062
65247	M8	320	0.008
65247	MS4	63.3	0.111
65248	M2	51.7	1.919
65248	S2	71.5	0.386
65248	N2	31.1	0.414
65248	K1	68.2	0.886
65248	M4	80.9	0.071
65248	O1	61	0.328
65248	M6	351.4	0.098
65248	MK3	68.2	0.079
65248	S4	306.8	0.008
65248	MN4	63.8	0.014
65248	S6	149.2	0.012
65248	2N2	328.9	0.026
65248	OO1	265.3	0.032
65248	M1	68.6	0.026
65248	J1	50.7	0.02
65248	Q1	59.6	0.058
65248	2Q1	78.7	0.042
65248	P1	60.1	0.23
65248	2SM2	200.2	0.007
65248	M3	55.2	0.05
65248	L2	61.9	0.094
65248	2MK3	215.1	0.087
65248	K2	101.6	0.061
65248	M8	318.8	0.01
65248	MS4	63	0.1
65249	M2	46.5	1.038
65249	S2	57.6	0.205
65249	N2	31.6	0.223
65249	K1	66.6	0.456
65249	M4	97.1	0.088
65249	O1	50	0.205
65249	M6	354.8	0.051
65249	MK3	96.2	0.114
65249	S4	38.2	0.018
65249	MN4	79.2	0.04
65249	S6	190.3	0.007
65249	2N2	155.9	0.012
65249	OO1	256.9	0.037
65249	M1	72.4	0.032
65249	J1	53.9	0.025
65249	Q1	47.9	0.055
65249	2Q1	67	0.011
65249	P1	62.8	0.121
65249	2SM2	263.8	0.011
65249	M3	59.8	0.039
65249	L2	47.8	0.067
65249	2MK3	222.4	0.042
65249	K2	267.7	0.026
65249	M8	4	0.004
65249	MS4	78.3	0.099
65250	M2	46.8	1.312
65250	S2	59.5	0.241
65250	N2	31.3	0.284
65250	K1	68.1	0.608
65250	M4	95.9	0.127
65250	O1	51.4	0.257
65250	M6	348.3	0.07
65250	MK3	84.7	0.111
65250	S4	59.5	0.02
65250	MN4	78.2	0.045
65250	S6	167.9	0.01
65250	2N2	139.8	0.021
65250	OO1	270.1	0.044
65250	M1	81.8	0.04
65250	J1	45.2	0.021
65250	Q1	47.7	0.073
65250	2Q1	65.1	0.023
65250	P1	52.2	0.166
65250	2SM2	249.1	0.013
65250	M3	63.9	0.049
65250	L2	46.7	0.078
65250	2MK3	235.9	0.076
65250	K2	147.6	0.014
65250	M8	343.3	0.009
65250	MS4	80	0.126
65251	M2	46.5	1.314
65251	S2	60.1	0.24
65251	N2	30.2	0.28
65251	K1	67.2	0.623
65251	M4	100.2	0.135
65251	O1	48.3	0.268
65251	M6	353.7	0.064
65251	MK3	87.1	0.102
65251	S4	55.3	0.02
65251	MN4	92.6	0.047
65251	S6	175.7	0.013
65251	2N2	160.1	0.023
65251	OO1	273.7	0.031
65251	M1	77.9	0.03
65251	J1	11.6	0.021
65251	Q1	42.4	0.074
65251	2Q1	57.2	0.019
65251	P1	48.4	0.174
65251	2SM2	258.1	0.012
65251	M3	69.9	0.041
65251	L2	51.7	0.081
65251	2MK3	235.9	0.091
65251	K2	107.3	0.029
65251	M8	11.4	0.013
65251	MS4	81.5	0.12
65252	M2	94.3	1.207
65252	S2	115.2	0.335
65252	N2	68.4	0.292
65252	K1	100.7	0.916
65252	M4	302.1	0.034
65252	O1	78.9	0.477
65252	M6	28.5	0.025
65252	MK3	349.2	0.052
65252	S4	354.5	0.016
65252	MN4	32.5	0.01
65252	NU2	79.6	0.054
65252	S6	85.9	0.006
65252	MU2	12.7	0.038
65252	2N2	60.3	0.043
65252	OO1	4.4	0.014
65252	LDA2	194.5	0.004
65252	M1	44.6	0.071
65252	J1	97.7	0.094
65252	RHO1	334.7	0.031
65252	Q1	63.2	0.071
65252	2Q1	266.8	0.031
65252	P1	99.9	0.381
65252	2SM2	102.1	0.005
65252	M3	320.5	0.002
65252	L2	159.6	0.009
65252	2MK3	222.2	0.04
65252	K2	131.3	0.106
65252	M8	168.6	0.012
65252	MS4	320.6	0.036
65253	M2	94.5	1.291
65253	S2	115.5	0.36
65253	N2	68.6	0.311
65253	K1	99.6	0.982
65253	M4	289.8	0.039
65253	O1	76.8	0.515
65253	M6	31.4	0.022
65253	MK3	331.3	0.034
65253	S4	351.4	0.015
65253	NU2	88.7	0.057
65253	S6	92.2	0.009
65253	MU2	6.6	0.048
65253	2N2	62.8	0.04
65253	OO1	34.6	0.005
65253	LDA2	188.3	0.006
65253	M1	44.4	0.061
65253	J1	99.7	0.092
65253	RHO1	338.1	0.033
65253	Q1	57.5	0.073
65253	2Q1	274.8	0.03
65253	P1	97.6	0.386
65253	2SM2	82.6	0.007
65253	M3	322.3	0.008
65253	L2	172.2	0.013
65253	2MK3	211.2	0.039
65253	K2	134.3	0.113
65253	M8	186.1	0.013
65253	MS4	308.1	0.039
65254	M2	94.5	1.359
65254	S2	115.5	0.382
65254	N2	69.2	0.324
65254	K1	98.4	1.036
65254	M4	282.2	0.044
65254	O1	75.6	0.547
65254	M6	31.4	0.021
65254	MK3	299.4	0.023
65254	S4	345.2	0.015
65254	MN4	243	0.01
65254	NU2	92.9	0.059
65254	S6	96	0.011
65254	MU2	6.1	0.056
65254	2N2	57	0.039
65254	OO1	129	0.013
65254	LDA2	187.5	0.006
65254	M1	42.6	0.055
65254	J1	101.8	0.091
65254	RHO1	338.1	0.033
65254	Q1	52.5	0.078
65254	2Q1	279.4	0.029
65254	P1	95.2	0.385
65254	2SM2	70.5	0.008
65254	M3	332	0.012
65254	L2	172.2	0.016
65254	2MK3	197.5	0.038
65254	K2	136.5	0.118
65254	M8	201.8	0.014
65254	MS4	299.7	0.047
65255	M2	94.4	1.417
65255	S2	115.1	0.401
65255	N2	69.8	0.334
65255	K1	97.1	1.08
65255	M4	277.7	0.049
65255	O1	74.6	0.574
65255	M6	31.1	0.021
65255	MK3	251.6	0.022
65255	S4	338.7	0.014
65255	MN4	246.2	0.019
65255	NU2	94.4	0.06
65255	S6	100.6	0.012
65255	MU2	8.4	0.062
65255	2N2	44.7	0.04
65255	OO1	137.4	0.029
65255	LDA2	182.9	0.005
65255	M1	41.6	0.051
65255	J1	103.1	0.092
65255	RHO1	335.1	0.031
65255	Q1	50	0.086
65255	2Q1	279.9	0.027
65255	P1	92.8	0.382
65255	2SM2	59.1	0.008
65255	M3	337.4	0.015
65255	L2	169.4	0.018
65255	2MK3	180	0.039
65255	K2	137.8	0.12
65255	M8	211.5	0.016
65255	MS4	294.9	0.056
65256	M2	94.3	1.467
65256	S2	114.6	0.418
65256	N2	70.1	0.34
65256	K1	95.8	1.117
65256	M4	273	0.053
65256	O1	73.4	0.596
65256	M6	28.1	0.021
65256	MK3	217	0.031
65256	S4	335.1	0.013
65256	MN4	250	0.026
65256	NU2	94	0.062
65256	S6	109.1	0.013
65256	MU2	11.8	0.067
65256	2N2	31.3	0.045
65256	OO1	139	0.045
65256	LDA2	169.1	0.004
65256	M1	42.8	0.05
65256	J1	103.9	0.093
65256	RHO1	331.2	0.029
65256	Q1	50.1	0.096
65256	2Q1	278.5	0.026
65256	P1	90.5	0.378
65256	2SM2	49.3	0.009
65256	M3	340.2	0.017
65256	L2	165.2	0.02
65256	2MK3	162.3	0.045
65256	K2	138.8	0.122
65256	M8	214.9	0.018
65256	MS4	291.8	0.064
65257	M2	94.1	1.51
65257	S2	114	0.431
65257	N2	70.3	0.343
65257	K1	94.5	1.145
65257	M4	268.6	0.058
65257	O1	72.2	0.615
65257	M6	23.5	0.022
65257	MK3	198.7	0.044
65257	S4	337.3	0.012
65257	MN4	252.9	0.03
65257	NU2	91.9	0.065
65257	S6	115.1	0.013
65257	MU2	14.2	0.071
65257	2N2	21.8	0.052
65257	OO1	140.4	0.06
65257	LDA2	166.4	0.004
65257	M1	44.7	0.051
65257	J1	103.9	0.093
65257	RHO1	329	0.027
65257	Q1	51.3	0.105
65257	2Q1	274.6	0.026
65257	P1	88.6	0.37
65257	2SM2	45.2	0.009
65257	M3	343.9	0.02
65257	L2	159.2	0.021
65257	2MK3	149.2	0.056
65257	K2	140.3	0.123
65257	M8	215.7	0.019
65257	MS4	288.6	0.071
65258	M2	94	1.548
65258	S2	113.5	0.442
65258	N2	70.6	0.344
65258	K1	93.1	1.164
65258	M4	264	0.063
65258	O1	70.9	0.63
65258	M6	18.1	0.024
65258	MK3	189.8	0.059
65258	S4	338.6	0.011
65258	MN4	254.5	0.031
65258	NU2	88.9	0.066
65258	S6	118.2	0.011
65258	MU2	16.2	0.075
65258	2N2	15.3	0.059
65258	OO1	140.8	0.072
65258	LDA2	187.4	0.004
65258	M1	46.1	0.052
65258	J1	103.5	0.094
65258	RHO1	329.8	0.025
65258	Q1	52.5	0.115
65258	2Q1	270.6	0.027
65258	P1	87.2	0.362
65258	2SM2	37.4	0.01
65258	M3	346.3	0.021
65258	L2	149.9	0.022
65258	2MK3	141.4	0.07
65258	K2	142.5	0.125
65258	M8	214.6	0.018
65258	MS4	285.3	0.077
65259	M2	93.9	1.581
65259	S2	113.3	0.45
65259	N2	70.9	0.345
65259	K1	91.9	1.177
65259	M4	260.2	0.069
65259	O1	69.7	0.641
65259	M6	12.8	0.027
65259	MK3	184.4	0.074
65259	S4	334.1	0.009
65259	MN4	254.3	0.031
65259	NU2	85.5	0.066
65259	S6	127.8	0.009
65259	MU2	18.4	0.079
65259	2N2	9.1	0.066
65259	OO1	141.1	0.082
65259	LDA2	198.3	0.006
65259	M1	44.4	0.053
65259	J1	103.1	0.092
65259	RHO1	333.8	0.02
65259	Q1	52.8	0.123
65259	2Q1	266.6	0.026
65259	P1	86.2	0.354
65259	2SM2	32.1	0.011
65259	M3	347.8	0.021
65259	L2	140.6	0.023
65259	2MK3	136	0.083
65259	K2	144.6	0.129
65259	M8	215.8	0.017
65259	MS4	282.4	0.084
65260	M2	93.9	1.612
65260	S2	113	0.458
65260	N2	71.1	0.347
65260	K1	90.8	1.185
65260	M4	257.6	0.076
65260	O1	68.7	0.649
65260	M6	7.3	0.031
65260	MK3	181	0.086
65260	S4	334.8	0.006
65260	MN4	253	0.03
65260	NU2	82.8	0.064
65260	S6	149.3	0.007
65260	MU2	20.1	0.084
65260	2N2	4.4	0.072
65260	OO1	141.6	0.093
65260	LDA2	196	0.009
65260	M1	40.3	0.054
65260	J1	103.1	0.089
65260	RHO1	339.6	0.016
65260	Q1	53	0.129
65260	2Q1	261.9	0.026
65260	P1	85.5	0.347
65260	2SM2	24.8	0.013
65260	M3	345.5	0.019
65260	L2	135.9	0.025
65260	2MK3	130.7	0.095
65260	K2	145.8	0.133
65260	M8	220.9	0.015
65260	MS4	279.7	0.091
65261	M2	94	1.643
65261	S2	112.7	0.466
65261	N2	71	0.351
65261	K1	89.8	1.191
65261	M4	256.4	0.083
65261	O1	67.8	0.655
65261	M6	3.5	0.034
65261	MK3	179.3	0.096
65261	S4	337.9	0.003
65261	MN4	248.7	0.029
65261	NU2	80.7	0.062
65261	S6	174	0.007
65261	MU2	21.1	0.09
65261	2N2	0.8	0.077
65261	OO1	140.9	0.105
65261	LDA2	191	0.012
65261	M1	34.2	0.055
65261	J1	101.9	0.087
65261	RHO1	349.6	0.014
65261	Q1	53.9	0.132
65261	2Q1	257.3	0.027
65261	P1	84.9	0.341
65261	2SM2	19.9	0.016
65261	M3	339.8	0.017
65261	L2	135.5	0.028
65261	2MK3	125.5	0.107
65261	K2	146.6	0.134
65261	M8	229.3	0.013
65261	MS4	277	0.098
65262	M2	94.2	1.67
65262	S2	112.8	0.468
65262	N2	71.2	0.35
65262	K1	88.5	1.196
65262	M4	256.7	0.091
65262	O1	66.5	0.656
65262	M6	2.2	0.036
65262	MK3	179.1	0.102
65262	MN4	240.7	0.028
65262	NU2	75.4	0.064
65262	S6	178.6	0.008
65262	MU2	18.5	0.099
65262	2N2	359	0.076
65262	OO1	140.1	0.117
65262	LDA2	182.2	0.012
65262	M1	22.6	0.057
65262	J1	96.3	0.084
65262	RHO1	5.9	0.018
65262	Q1	56.3	0.128
65262	2Q1	250.3	0.028
65262	P1	84.8	0.332
65262	2SM2	17.8	0.019
65262	M3	319.2	0.015
65262	L2	142.7	0.038
65262	2MK3	120.7	0.119
65262	K2	149.3	0.135
65262	M8	245.7	0.012
65262	MS4	274.5	0.102
65263	M2	84.5	0.462
65263	S2	93.5	0.146
65263	N2	63.7	0.123
65263	K1	92.1	0.263
65263	M4	125.1	0.022
65263	O1	87.6	0.057
65263	M6	293.3	0.007
65263	MK3	100.5	0.073
65263	S4	141	0.004
65263	MN4	150.9	0.015
65263	S6	262.9	0.004
65263	2N2	9.1	0.011
65263	OO1	158.1	0.027
65263	M1	255.5	0.009
65263	J1	222.2	0.012
65263	Q1	322.3	0.025
65263	2Q1	316.9	0.021
65263	P1	75.6	0.058
65263	2SM2	357.7	0.01
65263	M3	97.2	0.019
65263	L2	139.3	0.018
65263	2MK3	92	0.028
65263	K2	187.7	0.02
65263	M8	56.6	0.008
65263	MS4	127.8	0.03
65264	M2	95.2	0.505
65264	S2	125.2	0.128
65264	N2	68.9	0.137
65264	K1	98.4	0.288
65264	M4	113.9	0.022
65264	O1	81	0.109
65264	M6	274.1	0.018
65264	MK3	97.6	0.046
65264	S4	114.2	0.003
65264	MN4	86.2	0.005
65264	S6	326.7	0.008
65264	2N2	28.5	0.016
65264	OO1	59.1	0.007
65264	M1	313.7	0.004
65264	J1	219.5	0.012
65264	Q1	315.9	0.029
65264	2Q1	340.6	0.026
65264	P1	98.4	0.078
65264	2SM2	346.5	0.025
65264	M3	70.4	0.008
65264	L2	154.3	0.029
65264	2MK3	104	0.038
65264	K2	163.9	0.086
65264	M8	198.7	0.001
65264	MS4	134.5	0.027
65265	M2	99.6	0.501
65265	S2	144	0.168
65265	N2	74.6	0.116
65265	K1	114.1	0.303
65265	M4	107.1	0.037
65265	O1	82.2	0.099
65265	M6	298.8	0.007
65265	MK3	77.5	0.06
65265	S4	63.1	0.008
65265	MN4	105.3	0.024
65265	S6	353.4	0.008
65265	2N2	48.1	0.008
65265	OO1	61.6	0.018
65265	M1	336.6	0.014
65265	J1	57.1	0.054
65265	Q1	264.2	0.019
65265	2Q1	281.5	0.043
65265	P1	92.5	0.142
65265	2SM2	274.7	0.006
65265	M3	104	0.019
65265	L2	186.9	0.023
65265	2MK3	57.7	0.04
65265	K2	132.3	0.073
65265	M8	212.6	0.009
65265	MS4	172.7	0.038
65266	M2	99	1.02
65266	S2	117.7	0.257
65266	N2	75.3	0.228
65266	K1	95.8	0.754
65266	M4	230.5	0.043
65266	O1	63.2	0.505
65266	M6	94.2	0.026
65266	MK3	236.6	0.1
65266	S4	308.1	0.019
65266	MN4	217.3	0.02
65266	NU2	88.7	0.063
65266	S6	90.2	0.008
65266	MU2	339.9	0.031
65266	2N2	62.6	0.036
65266	OO1	157.6	0.022
65266	LDA2	272.6	0.012
65266	M1	282.7	0.018
65266	J1	82.1	0.049
65266	RHO1	15.1	0.027
65266	Q1	30.5	0.084
65266	2Q1	201.2	0.02
65266	P1	93.8	0.271
65266	2SM2	55	0.014
65266	M3	88.9	0.016
65266	L2	146.9	0.03
65266	2MK3	174.7	0.064
65266	K2	158.3	0.061
65266	M8	198.2	0.01
65266	MS4	339.9	0.034
65267	M2	100.1	1.068
65267	S2	118.4	0.276
65267	N2	76.7	0.234
65267	K1	97	0.789
65267	M4	236.3	0.04
65267	O1	65.7	0.511
65267	M6	104	0.026
65267	MK3	229.5	0.084
65267	S4	312.8	0.02
65267	MN4	214.8	0.02
65267	NU2	90.8	0.062
65267	S6	97.5	0.007
65267	MU2	358.7	0.033
65267	2N2	48.3	0.038
65267	OO1	166.1	0.031
65267	LDA2	277.7	0.01
65267	M1	299.3	0.021
65267	J1	83.1	0.052
65267	RHO1	4.8	0.033
65267	Q1	34.7	0.079
65267	2Q1	224.6	0.024
65267	P1	94.9	0.284
65267	2SM2	55.2	0.015
65267	M3	72.3	0.014
65267	L2	150.3	0.033
65267	2MK3	165.1	0.063
65267	K2	158.9	0.059
65267	M8	193.1	0.009
65267	MS4	340.5	0.04
65268	M2	101.1	1.103
65268	S2	118.9	0.293
65268	N2	77.7	0.241
65268	K1	98.2	0.815
65268	M4	240.8	0.034
65268	O1	68	0.514
65268	M6	106.4	0.023
65268	MK3	213.9	0.072
65268	S4	314.7	0.021
65268	MN4	213.2	0.021
65268	NU2	91.8	0.058
65268	S6	91.9	0.005
65268	MU2	14.8	0.037
65268	2N2	38.4	0.042
65268	OO1	170	0.039
65268	LDA2	281.5	0.01
65268	M1	313.6	0.025
65268	J1	84.5	0.056
65268	RHO1	357.9	0.04
65268	Q1	40.6	0.073
65268	2Q1	238.4	0.03
65268	P1	95.7	0.295
65268	2SM2	53.9	0.014
65268	M3	53	0.015
65268	L2	154.8	0.035
65268	2MK3	155.8	0.068
65268	K2	158.5	0.053
65268	M8	183.9	0.007
65268	MS4	346.4	0.043
65269	M2	101.9	1.129
65269	S2	119.7	0.309
65269	N2	78.2	0.249
65269	K1	99.3	0.835
65269	M4	241.8	0.029
65269	O1	70	0.521
65269	M6	101.3	0.019
65269	MK3	194.6	0.07
65269	S4	313.2	0.021
65269	MN4	213	0.021
65269	NU2	93.6	0.052
65269	S6	82.4	0.004
65269	MU2	23.2	0.045
65269	2N2	33	0.046
65269	OO1	173.6	0.047
65269	LDA2	278	0.011
65269	M1	321.6	0.03
65269	J1	86.6	0.06
65269	RHO1	355.8	0.045
65269	Q1	47.5	0.066
65269	2Q1	246.4	0.037
65269	P1	96.3	0.302
65269	2SM2	57.3	0.01
65269	M3	43.9	0.018
65269	L2	158.2	0.037
65269	2MK3	149.7	0.075
65269	K2	156.5	0.045
65269	M8	160.2	0.005
65269	MS4	354.2	0.044
65270	M2	102.4	1.148
65270	S2	120.7	0.322
65270	N2	78.5	0.255
65270	K1	100.1	0.849
65270	M4	237.7	0.028
65270	O1	71.8	0.529
65270	M6	94.3	0.015
65270	MK3	179.3	0.077
65270	S4	311.8	0.019
65270	MN4	216.2	0.02
65270	NU2	93.2	0.047
65270	S6	72.7	0.004
65270	MU2	27.4	0.051
65270	2N2	28.5	0.051
65270	OO1	178.3	0.054
65270	LDA2	272.4	0.012
65270	M1	325.8	0.034
65270	J1	87.5	0.065
65270	RHO1	355	0.049
65270	Q1	54.7	0.062
65270	2Q1	249.5	0.042
65270	P1	96.4	0.306
65270	2SM2	59.2	0.005
65270	M3	43.8	0.02
65270	L2	163.4	0.039
65270	2MK3	146.3	0.081
65270	K2	153.8	0.036
65270	M8	122.9	0.005
65270	MS4	1.9	0.041
65271	M2	102.8	1.16
65271	S2	122	0.332
65271	N2	78.5	0.258
65271	K1	100.6	0.858
65271	M4	230.5	0.029
65271	O1	73.4	0.536
65271	M6	87.3	0.012
65271	MK3	170.1	0.085
65271	S4	311.3	0.017
65271	MN4	221.5	0.018
65271	NU2	88.9	0.043
65271	S6	68.8	0.002
65271	MU2	30.1	0.056
65271	2N2	25.2	0.057
65271	OO1	178.3	0.063
65271	LDA2	259.2	0.014
65271	M1	326.7	0.037
65271	J1	86.3	0.069
65271	RHO1	357.3	0.05
65271	Q1	59.1	0.062
65271	2Q1	251.3	0.046
65271	P1	96	0.306
65271	M3	46.6	0.019
65271	L2	169.8	0.038
65271	2MK3	145.5	0.086
65271	K2	149.4	0.029
65271	M8	100.8	0.007
65271	MS4	7.4	0.035
65272	M2	103	1.169
65272	S2	123.2	0.339
65272	N2	78.4	0.259
65272	K1	100.8	0.863
65272	M4	224.4	0.03
65272	O1	74.4	0.544
65272	M6	77.2	0.011
65272	MK3	164.3	0.093
65272	S4	310	0.014
65272	MN4	225.6	0.017
65272	NU2	82.3	0.042
65272	MU2	32.4	0.057
65272	2N2	22.7	0.061
65272	OO1	176.7	0.071
65272	LDA2	248.3	0.017
65272	M1	325.4	0.038
65272	J1	84.1	0.073
65272	RHO1	0.5	0.049
65272	Q1	62.7	0.062
65272	2Q1	252.4	0.049
65272	P1	95.3	0.303
65272	M3	49.5	0.016
65272	L2	178.5	0.037
65272	2MK3	146.3	0.09
65272	K2	141.3	0.027
65272	M8	97.4	0.009
65272	MS4	10.6	0.027
65273	M2	103	1.173
65273	S2	124.2	0.344
65273	N2	78.1	0.259
65273	K1	100.7	0.865
65273	M4	220.5	0.032
65273	O1	75.2	0.551
65273	M6	64	0.012
65273	MK3	160.7	0.098
65273	S4	306.2	0.01
65273	MN4	228.5	0.015
65273	NU2	75.6	0.042
65273	MU2	34	0.058
65273	2N2	21.2	0.065
65273	OO1	175.1	0.079
65273	LDA2	239.6	0.019
65273	M1	325.7	0.039
65273	J1	82.2	0.077
65273	RHO1	3.9	0.045
65273	Q1	64.4	0.061
65273	2Q1	253.4	0.053
65273	P1	94.6	0.299
65273	M3	53.1	0.013
65273	L2	189.1	0.037
65273	2MK3	147.3	0.094
65273	K2	130	0.027
65273	M8	95.1	0.009
65273	MS4	9.6	0.018
65274	M2	102.9	1.176
65274	S2	124.8	0.345
65274	N2	77.6	0.258
65274	K1	100.2	0.866
65274	M4	215.6	0.033
65274	O1	75.9	0.558
65274	M6	50.1	0.014
65274	MK3	158.6	0.099
65274	S4	300.5	0.008
65274	MN4	230.8	0.014
65274	NU2	69.9	0.043
65274	S6	254.6	0.003
65274	MU2	35.6	0.058
65274	2N2	19.2	0.069
65274	OO1	173.6	0.086
65274	LDA2	236.9	0.022
65274	M1	327.3	0.041
65274	J1	79.4	0.08
65274	RHO1	8.4	0.04
65274	Q1	65.9	0.06
65274	2Q1	253.6	0.054
65274	P1	93.7	0.294
65274	2SM2	159.2	0.003
65274	M3	63.2	0.01
65274	L2	196.7	0.037
65274	2MK3	148.6	0.097
65274	K2	126.2	0.028
65274	M8	96.1	0.009
65274	MS4	4.9	0.011
65275	M2	102.8	1.179
65275	S2	125	0.343
65275	N2	77	0.258
65275	K1	99.7	0.866
65275	M4	210.4	0.035
65275	O1	76.3	0.564
65275	M6	40.3	0.017
65275	MK3	157.8	0.101
65275	S4	292.7	0.007
65275	MN4	230.7	0.012
65275	NU2	67.1	0.045
65275	S6	266.2	0.004
65275	MU2	37.4	0.059
65275	2N2	16.9	0.072
65275	OO1	172.1	0.09
65275	LDA2	235.8	0.025
65275	M1	329.3	0.043
65275	J1	76.3	0.081
65275	RHO1	14.9	0.035
65275	Q1	66.3	0.058
65275	2Q1	254.4	0.056
65275	P1	92.7	0.29
65275	2SM2	157.4	0.004
65275	M3	73.5	0.009
65275	L2	200.8	0.038
65275	2MK3	149.1	0.098
65275	K2	130.7	0.03
65275	M8	97.9	0.007
65275	MS4	350.9	0.006
65276	M2	102.8	1.183
65276	S2	124.8	0.34
65276	N2	76.7	0.257
65276	K1	99.1	0.866
65276	M4	204.9	0.035
65276	O1	76.7	0.568
65276	M6	36.4	0.02
65276	MK3	157.5	0.1
65276	S4	287.8	0.008
65276	MN4	222.6	0.012
65276	NU2	65.9	0.047
65276	S6	275.8	0.005
65276	MU2	40.6	0.059
65276	2N2	14.8	0.076
65276	OO1	170.1	0.091
65276	LDA2	237.5	0.027
65276	M1	329.8	0.047
65276	J1	72.9	0.081
65276	RHO1	20.8	0.031
65276	Q1	65.4	0.058
65276	2Q1	255.1	0.057
65276	P1	91.4	0.286
65276	2SM2	161.6	0.006
65276	M3	85.4	0.01
65276	L2	201.3	0.041
65276	2MK3	148.4	0.096
65276	K2	136	0.029
65276	M8	97.2	0.006
65276	MS4	317.7	0.005
65277	M2	102.9	1.188
65277	S2	124.4	0.335
65277	N2	76.4	0.253
65277	K1	98.5	0.867
65277	M4	201.6	0.034
65277	O1	77	0.571
65277	M6	33.6	0.022
65277	MK3	157.6	0.096
65277	S4	288.6	0.009
65277	MN4	211.4	0.014
65277	NU2	66.3	0.05
65277	S6	270	0.006
65277	MU2	45.2	0.057
65277	2N2	12.9	0.083
65277	OO1	169.3	0.091
65277	LDA2	245.8	0.028
65277	M1	329.1	0.051
65277	J1	69.1	0.079
65277	RHO1	26.3	0.029
65277	Q1	65.4	0.056
65277	2Q1	256.6	0.057
65277	P1	89.9	0.281
65277	2SM2	163.6	0.007
65277	M3	102.2	0.012
65277	L2	201.5	0.046
65277	2MK3	147	0.092
65277	K2	141.3	0.027
65277	M8	91.1	0.006
65277	MS4	281	0.008
65278	M2	103	1.192
65278	S2	123.9	0.332
65278	N2	76.3	0.251
65278	K1	98	0.87
65278	M4	201.8	0.032
65278	O1	77.1	0.574
65278	M6	30	0.023
65278	MK3	157.6	0.09
65278	S4	284.9	0.011
65278	MN4	207.3	0.017
65278	NU2	66.8	0.052
65278	S6	252.1	0.005
65278	MU2	50.2	0.057
65278	2N2	11.9	0.089
65278	OO1	169.6	0.09
65278	LDA2	253.6	0.029
65278	M1	326.5	0.054
65278	J1	64.8	0.075
65278	RHO1	28.4	0.028
65278	Q1	66.2	0.056
65278	2Q1	258.8	0.059
65278	P1	88.8	0.276
65278	2SM2	158.8	0.009
65278	M3	116.9	0.014
65278	L2	202.7	0.05
65278	2MK3	145.2	0.087
65278	K2	148.1	0.026
65278	M8	73.5	0.004
65278	MS4	266.2	0.015
65279	M2	102.9	1.194
65279	S2	123.4	0.332
65279	N2	76	0.251
65279	K1	97.8	0.873
65279	M4	209.2	0.031
65279	O1	76.9	0.575
65279	M6	22.6	0.024
65279	MK3	157.6	0.084
65279	S4	276.6	0.011
65279	MN4	206.6	0.019
65279	NU2	69	0.052
65279	S6	224.2	0.005
65279	MU2	54.4	0.06
65279	2N2	11	0.092
65279	OO1	169.7	0.091
65279	LDA2	259.4	0.03
65279	M1	321	0.055
65279	J1	62	0.072
65279	RHO1	25.9	0.027
65279	Q1	69.1	0.056
65279	2Q1	258.2	0.062
65279	P1	88	0.271
65279	2SM2	149	0.01
65279	M3	129.3	0.016
65279	L2	206.5	0.052
65279	2MK3	143.6	0.08
65279	K2	151.1	0.027
65279	M8	31.7	0.003
65279	MS4	258.8	0.025
65280	M2	102.8	1.194
65280	S2	122.5	0.333
65280	N2	76	0.255
65280	K1	97.8	0.877
65280	M4	224.5	0.033
65280	O1	76.4	0.574
65280	M6	10.5	0.024
65280	MK3	156.7	0.078
65280	S4	265.4	0.011
65280	MN4	203.7	0.022
65280	NU2	71.3	0.053
65280	S6	201.3	0.005
65280	MU2	56.6	0.065
65280	2N2	9.7	0.093
65280	OO1	168.8	0.094
65280	LDA2	265.8	0.03
65280	M1	313.5	0.055
65280	J1	62.4	0.069
65280	RHO1	20.4	0.027
65280	Q1	74.2	0.059
65280	2Q1	255.2	0.066
65280	P1	88.2	0.267
65280	2SM2	136.3	0.009
65280	M3	145	0.019
65280	L2	209.4	0.056
65280	2MK3	143.2	0.074
65280	K2	151.7	0.025
65280	M8	337	0.004
65280	MS4	252.2	0.035
65281	M2	103.1	1.149
65281	S2	124.2	0.32
65281	N2	77.2	0.243
65281	K1	95.3	0.857
65281	M4	226.3	0.062
65281	O1	72	0.552
65281	M6	12.4	0.026
65281	MK3	183.8	0.076
65281	S4	248.4	0.013
65281	MN4	195.5	0.036
65281	NU2	63.9	0.057
65281	S6	184.8	0.005
65281	MU2	47.9	0.065
65281	2N2	5.4	0.077
65281	OO1	162.7	0.108
65281	LDA2	284.9	0.024
65281	M1	298.5	0.07
65281	J1	58.5	0.066
65281	RHO1	4.9	0.041
65281	Q1	83	0.055
65281	2Q1	254.5	0.074
65281	P1	90	0.235
65281	2SM2	97.1	0.004
65281	M3	194.7	0.03
65281	L2	201	0.06
65281	2MK3	166.5	0.075
65281	K2	142.5	0.039
65281	M8	6.4	0.007
65281	MS4	236.2	0.056
65282	M2	116.2	0.914
65282	S2	137.6	0.246
65282	N2	90.7	0.246
65282	K1	95.2	0.691
65282	M4	267	0.067
65282	O1	68.3	0.497
65282	M6	326.3	0.022
65282	MK3	213.6	0.12
65282	S4	239.1	0.017
65282	MN4	260	0.038
65282	S6	38.2	0.011
65282	2N2	64.1	0.065
65282	OO1	154.5	0.144
65282	M1	297.1	0.026
65282	J1	48	0.032
65282	Q1	38.7	0.073
65282	2Q1	351.8	0.026
65282	P1	106	0.232
65282	2SM2	101.9	0.028
65282	M3	309.6	0.012
65282	L2	237.6	0.068
65282	2MK3	200.5	0.083
65282	M8	30	0.01
65282	MS4	272	0.049
65283	M2	105.8	0.896
65283	S2	109.3	0.197
65283	N2	85.8	0.252
65283	K1	101.7	0.553
65283	M4	284.5	0.037
65283	O1	78.7	0.544
65283	M6	310.9	0.033
65283	MK3	267.9	0.072
65283	S4	14.8	0.01
65283	MN4	307.2	0.013
65283	S6	20.2	0.004
65283	2N2	48.4	0.053
65283	OO1	188.1	0.103
65283	M1	357.7	0.034
65283	J1	61.6	0.08
65283	Q1	32.1	0.084
65283	2Q1	261.5	0.051
65283	P1	117.8	0.378
65283	2SM2	183.6	0.014
65283	M3	229.6	0.008
65283	L2	259.7	0.022
65283	2MK3	188.5	0.062
65283	M8	68.4	0.012
65283	MS4	293.1	0.035
65284	M2	105.5	0.871
65284	S2	106.1	0.18
65284	N2	84.9	0.245
65284	K1	100.5	0.53
65284	M4	287.1	0.032
65284	O1	78	0.535
65284	M6	324.7	0.029
65284	MK3	257	0.098
65284	S4	336.7	0.027
65284	MN4	307.5	0.019
65284	S6	354.6	0.005
65284	2N2	42.9	0.041
65284	OO1	182.5	0.087
65284	M1	335.6	0.024
65284	J1	64	0.079
65284	Q1	29.2	0.092
65284	2Q1	250.9	0.051
65284	P1	120.1	0.365
65284	2SM2	164.9	0.018
65284	M3	169.7	0.02
65284	L2	251.1	0.02
65284	2MK3	209	0.07
65284	M8	66.6	0.019
65284	MS4	295.1	0.057
65285	M2	75.1	0.834
65285	S2	86.7	0.225
65285	N2	54.2	0.22
65285	K1	62.6	0.44
65285	M4	9.8	0.031
65285	O1	42.5	0.3
65285	M6	305.5	0.021
65285	MK3	273.8	0.13
65285	S4	298.4	0.008
65285	MN4	311.6	0.016
65285	S6	70.4	0.011
65285	2N2	217.7	0.017
65285	OO1	0.1	0.038
65285	M1	131.1	0.022
65285	J1	83.7	0.034
65285	Q1	36.5	0.044
65285	2Q1	135	0.013
65285	P1	79	0.128
65285	2SM2	7.5	0.01
65285	M3	281.2	0.019
65285	L2	109.8	0.043
65285	2MK3	286.3	0.08
65285	K2	96	0.123
65285	M8	56.3	0.004
65285	MS4	208.8	0.011
65286	M2	78.5	0.993
65286	S2	92.1	0.27
65286	N2	55.8	0.246
65286	K1	66.7	0.516
65286	M4	30.6	0.014
65286	O1	45.2	0.367
65286	M6	302.3	0.01
65286	MK3	282.8	0.106
65286	S4	342.6	0.006
65286	MN4	284.9	0.008
65286	S6	147.9	0.002
65286	2N2	307.7	0.021
65286	OO1	20.9	0.043
65286	M1	197.2	0.023
65286	J1	62	0.04
65286	Q1	54.6	0.053
65286	2Q1	121.5	0.013
65286	P1	69.9	0.174
65286	2SM2	22	0.013
65286	M3	272.9	0.021
65286	L2	117.5	0.054
65286	2MK3	311.1	0.066
65286	K2	93.7	0.141
65286	M8	167.4	0.002
65286	MS4	158.9	0.018
65287	M2	79.2	1.049
65287	S2	100.9	0.304
65287	N2	56	0.256
65287	K1	69.6	0.553
65287	M4	201.6	0.029
65287	O1	44.2	0.414
65287	M6	63.4	0.004
65287	MK3	229.5	0.057
65287	S4	139.4	0.015
65287	MN4	157.8	0.012
65287	S6	221.1	0.011
65287	2N2	320.2	0.055
65287	OO1	40.2	0.056
65287	M1	202.3	0.033
65287	J1	67.2	0.06
65287	Q1	58.9	0.058
65287	2Q1	121	0.02
65287	P1	64	0.24
65287	2SM2	46.1	0.011
65287	M3	280.2	0.027
65287	L2	109.1	0.06
65287	2MK3	17.2	0.02
65287	K2	87.5	0.174
65287	M8	296.7	0.003
65287	MS4	186.7	0.049
65288	M2	109.7	0.761
65288	S2	120.1	0.207
65288	N2	93.5	0.178
65288	K1	80.9	0.711
65288	M4	2.9	0.036
65288	O1	57.3	0.298
65288	M6	330.2	0.028
65288	MK3	275.7	0.034
65288	S4	256	0.027
65288	MN4	258	0.021
65288	S6	207.5	0.003
65288	2N2	53.4	0.067
65288	OO1	106.6	0.137
65288	M1	58	0.012
65288	J1	94.5	0.031
65288	Q1	20.6	0.102
65288	2Q1	262.7	0.041
65288	P1	23	0.107
65288	2SM2	107.2	0.014
65288	M3	37.4	0.032
65288	L2	179.4	0.082
65288	2MK3	170	0.043
65288	M8	294.3	0.004
65288	MS4	324.8	0.025
65289	M2	89.7	0.693
65289	S2	107.8	0.218
65289	N2	82.2	0.191
65289	K1	107.3	0.419
65289	M4	230.5	0.015
65289	O1	91.9	0.231
65289	M6	93.7	0.008
65289	MK3	62.1	0.065
65289	S4	12.9	0.014
65289	MN4	296.8	0.004
65289	S6	18.5	0.014
65289	2N2	321.1	0.023
65289	OO1	186.3	0.013
65289	M1	28.1	0.01
65289	J1	43.1	0.025
65289	Q1	75.7	0.047
65289	2Q1	13.6	0.019
65289	P1	101.2	0.163
65289	2SM2	114.3	0.006
65289	M3	109.7	0.015
65289	L2	51.6	0.02
65289	2MK3	71.5	0.028
65289	M8	125.4	0.017
65289	MS4	92.1	0.026
65290	M2	84.4	0.704
65290	S2	104.2	0.22
65290	N2	78.4	0.178
65290	K1	104.2	0.349
65290	M4	205	0.023
65290	O1	95.7	0.222
65290	M6	150.8	0.002
65290	MK3	59.6	0.037
65290	S4	2.6	0.01
65290	MN4	129.4	0.003
65290	S6	4.8	0.009
65290	2N2	307.3	0.03
65290	OO1	235.2	0.031
65290	M1	95.7	0.027
65290	J1	144.4	0.023
65290	Q1	84.5	0.045
65290	2Q1	33.4	0.022
65290	P1	109	0.185
65290	2SM2	78.8	0.015
65290	M3	112.6	0.021
65290	L2	58.7	0.045
65290	2MK3	69.7	0.025
65290	M8	100.2	0.017
65290	MS4	109.4	0.022
65291	M2	113.5	0.774
65291	S2	119.2	0.228
65291	N2	106.8	0.177
65291	K1	101.4	0.497
65291	M4	129.4	0.016
65291	O1	87.4	0.262
65291	M6	248.2	0.02
65291	MK3	44.3	0.049
65291	S4	221.7	0.009
65291	MN4	216.4	0.028
65291	S6	353.3	0.006
65291	2N2	121.5	0.018
65291	OO1	307.3	0.024
65291	M1	82.8	0.044
65291	J1	108.8	0.054
65291	Q1	70.1	0.045
65291	2Q1	288.5	0.016
65291	P1	118.5	0.141
65291	2SM2	342.7	0.007
65291	M3	228.9	0.018
65291	L2	155.4	0.052
65291	2MK3	27.4	0.082
65291	M8	300	0.014
65291	MS4	264.5	0.037
65292	M2	113.8	0.796
65292	S2	118.8	0.234
65292	N2	106.3	0.179
65292	K1	100.5	0.509
65292	M4	131.3	0.019
65292	O1	86.4	0.272
65292	M6	254.1	0.022
65292	MK3	42.6	0.052
65292	S4	216.7	0.01
65292	MN4	212.5	0.025
65292	S6	342.7	0.007
65292	2N2	119.3	0.02
65292	OO1	300.2	0.026
65292	M1	84.7	0.045
65292	J1	107.2	0.054
65292	Q1	72.3	0.047
65292	2Q1	289.8	0.017
65292	P1	121.2	0.139
65292	2SM2	345	0.008
65292	M3	225.8	0.02
65292	L2	158.4	0.054
65292	2MK3	28.3	0.084
65292	M8	296.5	0.014
65292	MS4	262.1	0.038
65293	M2	114	0.814
65293	S2	118.5	0.239
65293	N2	105.6	0.179
65293	K1	99.6	0.518
65293	M4	131.9	0.02
65293	O1	85.6	0.281
65293	M6	258.8	0.025
65293	MK3	40.8	0.055
65293	S4	218.4	0.011
65293	MN4	207.4	0.023
65293	S6	333.8	0.008
65293	2N2	118.8	0.022
65293	OO1	296.4	0.027
65293	M1	85.9	0.046
65293	J1	106	0.055
65293	Q1	73.6	0.05
65293	2Q1	294.9	0.017
65293	P1	123.6	0.137
65293	2SM2	350.8	0.009
65293	M3	220.7	0.023
65293	L2	160.7	0.056
65293	2MK3	28.4	0.085
65293	M8	296.6	0.012
65293	MS4	260.1	0.039
65294	M2	114.2	0.832
65294	S2	118.3	0.243
65294	N2	105.1	0.179
65294	K1	98.6	0.527
65294	M4	132.5	0.021
65294	O1	84.9	0.29
65294	M6	262.8	0.027
65294	MK3	40.2	0.058
65294	S4	219.5	0.011
65294	MN4	203.2	0.019
65294	S6	329.6	0.008
65294	2N2	115.9	0.024
65294	OO1	292.1	0.028
65294	M1	85.3	0.046
65294	J1	104.4	0.056
65294	Q1	74.2	0.053
65294	2Q1	301.8	0.018
65294	P1	125.8	0.134
65294	2SM2	354.5	0.011
65294	M3	213.8	0.027
65294	L2	162.7	0.057
65294	2MK3	28.6	0.086
65294	M8	299.9	0.011
65294	MS4	257	0.039
65295	M2	114.4	0.847
65295	S2	118.1	0.247
65295	N2	104.7	0.179
65295	K1	97.7	0.539
65295	M4	130.6	0.021
65295	O1	84.6	0.299
65295	M6	266.5	0.029
65295	MK3	39.7	0.061
65295	S4	217.8	0.012
65295	MN4	195.6	0.016
65295	S6	325.2	0.008
65295	2N2	114.2	0.026
65295	OO1	291.7	0.028
65295	M1	83.6	0.046
65295	J1	103.6	0.057
65295	Q1	75.2	0.056
65295	2Q1	307.2	0.019
65295	P1	127.4	0.13
65295	2SM2	355.1	0.012
65295	M3	208.4	0.029
65295	L2	164.8	0.058
65295	2MK3	28.9	0.088
65295	M8	302.6	0.009
65295	MS4	254.7	0.039
65296	M2	114.5	0.861
65296	S2	118.1	0.25
65296	N2	104.1	0.18
65296	K1	97	0.549
65296	M4	131.6	0.02
65296	O1	84.4	0.309
65296	M6	270.2	0.031
65296	MK3	39.6	0.064
65296	S4	212.5	0.012
65296	MN4	187.2	0.012
65296	S6	324.1	0.008
65296	2N2	110.2	0.027
65296	OO1	289.9	0.029
65296	M1	80.5	0.047
65296	J1	102.8	0.058
65296	Q1	76.1	0.059
65296	2Q1	312.8	0.018
65296	P1	128.7	0.128
65296	2SM2	357.7	0.013
65296	M3	202.6	0.032
65296	L2	166.4	0.059
65296	2MK3	28.8	0.09
65296	M8	301.9	0.009
65296	MS4	251.4	0.039
65297	M2	114.6	0.875
65297	S2	118	0.251
65297	N2	103.7	0.181
65297	K1	96.5	0.56
65297	M4	129.8	0.019
65297	O1	84.4	0.32
65297	M6	275.1	0.033
65297	MK3	38.3	0.068
65297	S4	210.9	0.013
65297	MN4	177.3	0.009
65297	S6	319.1	0.008
65297	2N2	107.7	0.028
65297	OO1	288.7	0.029
65297	M1	78.4	0.049
65297	J1	101.6	0.06
65297	Q1	76.9	0.063
65297	2Q1	317.3	0.018
65297	P1	130	0.126
65297	2SM2	358.1	0.015
65297	M3	197.8	0.034
65297	L2	168.8	0.061
65297	2MK3	28.4	0.091
65297	M8	301.7	0.007
65297	MS4	248.1	0.04
65298	M2	114.7	0.889
65298	S2	118.2	0.252
65298	N2	103.4	0.183
65298	K1	96.3	0.569
65298	M4	129.6	0.018
65298	O1	84.8	0.331
65298	M6	278	0.035
65298	MK3	37.3	0.071
65298	S4	204.7	0.014
65298	MN4	170.3	0.005
65298	S6	319.7	0.008
65298	2N2	104.7	0.03
65298	OO1	288.4	0.03
65298	M1	76.3	0.05
65298	J1	101.3	0.061
65298	Q1	76.1	0.064
65298	2Q1	325.4	0.017
65298	P1	131.3	0.128
65298	2SM2	353.7	0.015
65298	M3	193.3	0.037
65298	L2	171.2	0.063
65298	2MK3	28.2	0.091
65298	M8	297.8	0.006
65298	MS4	243.5	0.041
65299	M2	114.7	0.903
65299	S2	118.2	0.252
65299	N2	103.3	0.187
65299	K1	96.1	0.576
65299	M4	127.3	0.017
65299	O1	85.1	0.341
65299	M6	280.4	0.037
65299	MK3	35.7	0.075
65299	S4	199.2	0.014
65299	MN4	179.4	0.002
65299	S6	315.2	0.008
65299	2N2	99.4	0.032
65299	OO1	289	0.03
65299	M1	72.7	0.052
65299	J1	100.8	0.062
65299	Q1	75.7	0.067
65299	2Q1	335	0.016
65299	P1	133.5	0.13
65299	2SM2	353.6	0.017
65299	M3	188	0.038
65299	L2	172.4	0.065
65299	2MK3	28.3	0.089
65299	M8	299.7	0.006
65299	MS4	240.2	0.041
65300	M2	114.6	0.917
65300	S2	118.4	0.253
65300	N2	103	0.191
65300	K1	96.1	0.581
65300	M4	125.4	0.015
65300	O1	85.3	0.351
65300	M6	281.6	0.038
65300	MK3	33.6	0.078
65300	S4	193.4	0.013
65300	MN4	297.6	0.002
65300	S6	309.7	0.007
65300	2N2	94	0.034
65300	OO1	292.8	0.028
65300	M1	68.8	0.054
65300	J1	101.3	0.063
65300	Q1	74.6	0.069
65300	2Q1	346	0.016
65300	P1	136.3	0.133
65300	2SM2	352.9	0.018
65300	M3	183.8	0.041
65300	L2	173.6	0.068
65300	2MK3	28.3	0.087
65300	M8	308.9	0.006
65300	MS4	238.1	0.041
65301	M2	114.5	0.931
65301	S2	118.6	0.254
65301	N2	103	0.197
65301	K1	96.3	0.586
65301	M4	121.3	0.015
65301	O1	85.8	0.359
65301	M6	281.9	0.039
65301	MK3	32	0.082
65301	S4	187.5	0.012
65301	MN4	308.8	0.005
65301	S6	303.9	0.006
65301	2N2	88.8	0.037
65301	OO1	293.7	0.026
65301	M1	64.7	0.056
65301	J1	101.6	0.065
65301	Q1	73.8	0.071
65301	2Q1	356.9	0.015
65301	P1	138.9	0.138
65301	2SM2	351.6	0.019
65301	M3	178.8	0.043
65301	L2	174.2	0.07
65301	2MK3	27.9	0.084
65301	M8	319.3	0.005
65301	MS4	236.6	0.04
65302	M2	114.4	0.946
65302	S2	118.8	0.255
65302	N2	103.3	0.202
65302	K1	96.6	0.591
65302	M4	122.1	0.014
65302	O1	86.4	0.366
65302	M6	281.1	0.041
65302	MK3	30.6	0.085
65302	S4	176.8	0.011
65302	MN4	314	0.007
65302	S6	287.5	0.005
65302	2N2	83	0.04
65302	OO1	294.3	0.026
65302	M1	62.1	0.06
65302	J1	102	0.066
65302	Q1	72.5	0.074
65302	2Q1	11.1	0.015
65302	P1	141.2	0.144
65302	2SM2	349.3	0.019
65302	M3	174.2	0.044
65302	L2	173.5	0.071
65302	2MK3	27.9	0.082
65302	M8	324.6	0.005
65302	MS4	234.9	0.039
65303	M2	114.2	0.961
65303	S2	118.7	0.256
65303	N2	103.5	0.209
65303	K1	96.8	0.597
65303	M4	121.5	0.013
65303	O1	87	0.374
65303	M6	279.4	0.042
65303	MK3	28.8	0.086
65303	S4	163.8	0.011
65303	MN4	315.6	0.01
65303	S6	264.1	0.004
65303	2N2	77.8	0.044
65303	OO1	294.2	0.028
65303	M1	59.6	0.064
65303	J1	101.9	0.067
65303	Q1	71.2	0.076
65303	2Q1	20.6	0.016
65303	P1	143.5	0.147
65303	2SM2	345.8	0.019
65303	M3	170.6	0.045
65303	L2	172.5	0.07
65303	2MK3	28.6	0.08
65303	M8	330.2	0.006
65303	MS4	232.5	0.038
65304	M2	114.1	0.975
65304	S2	118.6	0.256
65304	N2	103.8	0.214
65304	K1	97.1	0.607
65304	M4	123.9	0.012
65304	O1	87.7	0.38
65304	M6	277.5	0.042
65304	MK3	27.6	0.087
65304	S4	147.5	0.01
65304	MN4	314.2	0.012
65304	S6	217.8	0.005
65304	2N2	73.2	0.048
65304	OO1	295.6	0.03
65304	M1	57.4	0.068
65304	J1	102.2	0.065
65304	Q1	70.1	0.078
65304	2Q1	33	0.018
65304	P1	145.3	0.149
65304	2SM2	342.9	0.019
65304	M3	166.6	0.045
65304	L2	170.7	0.069
65304	2MK3	29.9	0.077
65304	M8	329.8	0.005
65304	MS4	229.3	0.036
65305	M2	113.9	0.989
65305	S2	118.4	0.257
65305	N2	103.8	0.22
65305	K1	97.6	0.616
65305	M4	123.2	0.012
65305	O1	88.3	0.386
65305	M6	275.5	0.042
65305	MK3	26.3	0.088
65305	S4	132.4	0.011
65305	MN4	313.9	0.013
65305	S6	193.5	0.007
65305	2N2	69.8	0.052
65305	OO1	295.2	0.03
65305	M1	56.3	0.072
65305	J1	102.6	0.065
65305	Q1	68.9	0.081
65305	2Q1	42.1	0.02
65305	P1	146.6	0.153
65305	2SM2	340.3	0.018
65305	M3	161.5	0.044
65305	L2	168.6	0.067
65305	2MK3	33.1	0.075
65305	M8	318.2	0.005
65305	MS4	225.2	0.034
65306	M2	113.8	1.003
65306	S2	118	0.258
65306	N2	103.9	0.225
65306	K1	98	0.626
65306	M4	129.5	0.013
65306	O1	88.8	0.392
65306	M6	273.7	0.041
65306	MK3	25.4	0.089
65306	S4	122.9	0.013
65306	MN4	312.1	0.012
65306	S6	182	0.009
65306	2N2	67.3	0.056
65306	OO1	294.5	0.03
65306	M1	54.5	0.074
65306	J1	102.9	0.064
65306	Q1	68.1	0.084
65306	2Q1	45.3	0.024
65306	P1	147.8	0.156
65306	2SM2	338.1	0.017
65306	M3	156.4	0.041
65306	L2	165.5	0.063
65306	2MK3	37.1	0.074
65306	M8	304.2	0.005
65306	MS4	221.5	0.033
65307	M2	113.8	1.016
65307	S2	117.4	0.26
65307	N2	103.9	0.229
65307	K1	98.5	0.642
65307	M4	133.1	0.015
65307	O1	89.2	0.399
65307	M6	271.9	0.041
65307	MK3	25	0.089
65307	S4	117.1	0.015
65307	MN4	306.3	0.011
65307	S6	169.9	0.011
65307	2N2	65.5	0.06
65307	OO1	294.1	0.029
65307	M1	53.7	0.077
65307	J1	103	0.061
65307	Q1	67.1	0.087
65307	2Q1	48.9	0.028
65307	P1	147.6	0.157
65307	2SM2	337.2	0.017
65307	M3	150.6	0.039
65307	L2	161.4	0.06
65307	2MK3	42.5	0.073
65307	M8	294	0.004
65307	MS4	217.9	0.032
65308	M2	113.8	1.027
65308	S2	116.6	0.261
65308	N2	103.6	0.233
65308	K1	98.8	0.662
65308	M4	135.1	0.018
65308	O1	89.6	0.408
65308	M6	269.7	0.04
65308	MK3	25.6	0.089
65308	S4	113.4	0.018
65308	MN4	298	0.01
65308	S6	161.4	0.013
65308	2N2	63.1	0.063
65308	OO1	293.2	0.023
65308	M1	51.9	0.081
65308	J1	101.6	0.058
65308	Q1	66.4	0.091
65308	2Q1	52.4	0.034
65308	P1	146.8	0.153
65308	2SM2	336.4	0.017
65308	M3	143.6	0.036
65308	L2	155	0.056
65308	2MK3	48.5	0.074
65308	M8	297.9	0.004
65308	MS4	215.8	0.03
65309	M2	113.7	1.037
65309	S2	115.7	0.262
65309	N2	103.1	0.237
65309	K1	98.8	0.685
65309	M4	137	0.021
65309	O1	90	0.418
65309	M6	267.5	0.039
65309	MK3	27	0.087
65309	S4	110.4	0.02
65309	MN4	290.2	0.009
65309	S6	150.6	0.014
65309	2N2	61.2	0.067
65309	OO1	284.3	0.014
65309	M1	50	0.085
65309	J1	100.8	0.053
65309	Q1	65.8	0.094
65309	2Q1	52.6	0.041
65309	P1	145.4	0.144
65309	2SM2	334.3	0.016
65309	M3	134.9	0.033
65309	L2	147.1	0.053
65309	2MK3	55.1	0.075
65309	M8	310.6	0.004
65309	MS4	213.5	0.027
65310	M2	113.6	1.045
65310	S2	114.7	0.262
65310	N2	102.6	0.241
65310	K1	98.7	0.71
65310	M4	136.6	0.023
65310	O1	90.7	0.428
65310	M6	265.8	0.038
65310	MK3	29.8	0.084
65310	S4	106.5	0.021
65310	MN4	282.1	0.008
65310	S6	140	0.015
65310	2N2	59	0.071
65310	OO1	221.4	0.005
65310	M1	49	0.091
65310	J1	101.5	0.049
65310	Q1	64.2	0.095
65310	2Q1	53.4	0.049
65310	P1	143.5	0.136
65310	2SM2	332.6	0.014
65310	M3	122.3	0.029
65310	L2	137.7	0.052
65310	2MK3	61.8	0.075
65310	M8	324.2	0.004
65310	MS4	209.6	0.022
65311	M2	113.5	1.05
65311	S2	113.7	0.261
65311	N2	101.7	0.243
65311	K1	98.5	0.731
65311	M4	133.8	0.026
65311	O1	91.7	0.438
65311	M6	263.4	0.036
65311	MK3	33.2	0.082
65311	S4	103	0.022
65311	MN4	274.8	0.007
65311	S6	129.7	0.015
65311	2N2	57.3	0.077
65311	OO1	160.3	0.012
65311	M1	49.2	0.096
65311	J1	104.9	0.047
65311	Q1	62.3	0.095
65311	2Q1	52.1	0.056
65311	P1	141.6	0.13
65311	2SM2	332.1	0.011
65311	M3	105.6	0.027
65311	L2	128.4	0.053
65311	2MK3	68.6	0.075
65311	M8	329.5	0.004
65311	MS4	204.2	0.017
65312	M2	113.3	1.054
65312	S2	112.7	0.26
65312	N2	100.8	0.245
65312	K1	98.4	0.751
65312	M4	132.7	0.028
65312	O1	92.4	0.449
65312	M6	259.2	0.034
65312	MK3	37.6	0.078
65312	S4	99.8	0.022
65312	MN4	269	0.006
65312	S6	123.2	0.015
65312	2N2	55.5	0.082
65312	OO1	145.6	0.02
65312	M1	50.7	0.101
65312	J1	110.5	0.044
65312	Q1	58.5	0.094
65312	2Q1	52.2	0.062
65312	P1	139.1	0.125
65312	2SM2	335.3	0.007
65312	M3	86.8	0.028
65312	L2	120.9	0.054
65312	2MK3	76.6	0.075
65312	M8	326.3	0.005
65312	MS4	195.6	0.012
65313	M2	113.2	1.058
65313	S2	111.9	0.258
65313	N2	100.2	0.245
65313	K1	98.1	0.771
65313	M4	132.1	0.029
65313	O1	93.1	0.457
65313	M6	256.3	0.032
65313	MK3	41.7	0.075
65313	S4	98.9	0.023
65313	MN4	275.7	0.006
65313	S6	115.4	0.013
65313	2N2	53.9	0.087
65313	OO1	146.2	0.026
65313	M1	52.7	0.108
65313	J1	118.4	0.043
65313	Q1	54.3	0.093
65313	2Q1	51.1	0.069
65313	P1	135.6	0.118
65313	2SM2	337.5	0.003
65313	M3	68.7	0.032
65313	L2	115.4	0.057
65313	2MK3	84.6	0.074
65313	M8	324.6	0.006
65313	MS4	184.6	0.008
65314	M2	113.1	1.06
65314	S2	111.8	0.258
65314	N2	99.5	0.244
65314	K1	98.2	0.789
65314	M4	132.5	0.029
65314	O1	93.8	0.465
65314	M6	255.7	0.03
65314	MK3	46.3	0.074
65314	S4	91.4	0.022
65314	MN4	266.1	0.006
65314	S6	106.4	0.012
65314	2N2	52.5	0.092
65314	OO1	148.2	0.03
65314	M1	55.7	0.116
65314	J1	124.4	0.047
65314	Q1	50.8	0.092
65314	2Q1	50.7	0.076
65314	P1	130.4	0.114
65314	M3	54.5	0.036
65314	L2	110.3	0.058
65314	2MK3	92	0.074
65314	M8	328.1	0.007
65314	MS4	156.7	0.004
65315	M2	113	1.057
65315	S2	111.8	0.253
65315	N2	99	0.239
65315	K1	98.1	0.807
65315	M4	135.2	0.03
65315	O1	93.7	0.471
65315	M6	258.6	0.025
65315	MK3	53.7	0.071
65315	S4	74.4	0.018
65315	MN4	230	0.01
65315	S6	98	0.008
65315	2N2	50.7	0.093
65315	OO1	145.6	0.032
65315	M1	58.7	0.125
65315	J1	127.5	0.05
65315	Q1	47.3	0.087
65315	2Q1	48.4	0.078
65315	P1	122.2	0.11
65315	2SM2	136.5	0.005
65315	M3	39.9	0.037
65315	L2	106.2	0.061
65315	2MK3	100.4	0.071
65315	M8	326.3	0.01
65315	MS4	54.8	0.002
65316	M2	112.2	1.003
65316	S2	105	0.238
65316	N2	99.8	0.218
65316	K1	94.7	0.792
65316	M4	192.6	0.025
65316	O1	88	0.46
65316	M6	238.5	0.028
65316	MK3	19.7	0.038
65316	S4	36.5	0.017
65316	MN4	218.3	0.027
65316	S6	353.3	0.002
65316	2N2	41.4	0.076
65316	OO1	123.9	0.052
65316	M1	55.3	0.127
65316	J1	116.4	0.047
65316	Q1	31.8	0.08
65316	2Q1	41.1	0.072
65316	P1	114.4	0.092
65316	2SM2	129.8	0.012
65316	M3	10	0.035
65316	L2	106.9	0.07
65316	2MK3	106.8	0.038
65316	M8	294	0.007
65316	MS4	325.5	0.028
65317	M2	78.9	1.259
65317	S2	98.5	0.263
65317	N2	62.2	0.297
65317	K1	85.8	0.589
65317	M4	49.1	0.089
65317	O1	85.9	0.237
65317	M6	196.8	0.02
65317	MK3	3.2	0.056
65317	S4	47.6	0.013
65317	MN4	9.9	0.053
65317	S6	72.7	0.007
65317	2N2	13.8	0.08
65317	OO1	120.1	0.043
65317	M1	355.6	0.039
65317	J1	91.1	0.069
65317	Q1	125.9	0.018
65317	2Q1	113.7	0.025
65317	P1	92.6	0.199
65317	2SM2	7.7	0.024
65317	M3	72.8	0.018
65317	L2	105.7	0.078
65317	2MK3	25.7	0.062
65317	K2	148.5	0.132
65317	M8	43.8	0.011
65317	MS4	80.7	0.021
65318	M2	79.2	1.315
65318	S2	93.7	0.254
65318	N2	63.3	0.295
65318	K1	84.3	0.654
65318	M4	34.6	0.067
65318	O1	83.1	0.305
65318	M6	167.9	0.021
65318	MK3	354.9	0.037
65318	S4	66.3	0.008
65318	MN4	4.4	0.041
65318	S6	140.3	0.006
65318	2N2	12.2	0.072
65318	OO1	110.3	0.027
65318	M1	346.9	0.046
65318	J1	79.2	0.053
65318	Q1	132	0.036
65318	2Q1	122.9	0.018
65318	P1	73.4	0.188
65318	2SM2	347.7	0.036
65318	M3	94	0.028
65318	L2	108.6	0.093
65318	2MK3	28.2	0.048
65318	K2	147.3	0.113
65318	M8	45.4	0.012
65318	MS4	78.2	0.02
65319	M2	78.9	1.317
65319	S2	80.6	0.217
65319	N2	66.1	0.279
65319	K1	84.1	0.699
65319	M4	23.4	0.055
65319	O1	84	0.337
65319	M6	154	0.026
65319	MK3	321.2	0.018
65319	MN4	17.7	0.031
65319	S6	191.7	0.014
65319	2N2	0.9	0.065
65319	OO1	127	0.042
65319	M1	327.3	0.065
65319	J1	51.3	0.035
65319	Q1	137.3	0.04
65319	2Q1	110.2	0.005
65319	P1	58.7	0.19
65319	2SM2	1.2	0.029
65319	M3	102.4	0.031
65319	L2	108.4	0.1
65319	2MK3	28.5	0.018
65319	K2	176.1	0.115
65319	M8	29.3	0.008
65319	MS4	82	0.013
65320	M2	85.8	1.403
65320	S2	110.1	0.426
65320	N2	75.2	0.345
65320	K1	84.4	0.736
65320	M4	22.4	0.12
65320	O1	114.5	0.388
65320	M6	292.7	0.041
65320	MK3	311.2	0.071
65320	S4	236.9	0.021
65320	MN4	340.9	0.093
65320	S6	265.2	0.02
65320	2N2	17.2	0.112
65320	OO1	265.9	0.057
65320	M1	22.6	0.089
65320	J1	116.9	0.084
65320	Q1	101.4	0.087
65320	2Q1	13.5	0.105
65320	P1	96.5	0.196
65320	2SM2	51.8	0.028
65320	M3	121	0.032
65320	L2	91.3	0.064
65320	2MK3	256.2	0.054
65320	K2	62	0.149
65320	M8	214.5	0.019
65320	MS4	261.3	0.048
65321	M2	86.4	1.556
65321	S2	108.6	0.453
65321	N2	74.1	0.414
65321	K1	78	0.789
65321	M4	334.6	0.075
65321	O1	100.1	0.433
65321	M6	256.4	0.036
65321	MK3	251.8	0.082
65321	S4	256	0.027
65321	MN4	296	0.053
65321	S6	234.7	0.018
65321	2N2	5.6	0.102
65321	OO1	259.9	0.049
65321	M1	21.7	0.086
65321	J1	92	0.083
65321	Q1	82.3	0.07
65321	2Q1	26.6	0.079
65321	P1	102.7	0.137
65321	2SM2	87.1	0.014
65321	M3	99.5	0.019
65321	L2	96.1	0.06
65321	2MK3	202.3	0.061
65321	K2	49	0.071
65321	M8	171.3	0.005
65321	MS4	233.8	0.05
65322	M2	83.6	1.492
65322	S2	112.6	0.399
65322	N2	71.9	0.38
65322	K1	74.7	0.746
65322	M4	272	0.088
65322	O1	90.8	0.386
65322	M6	218.4	0.016
65322	MK3	229.2	0.15
65322	S4	224.3	0.028
65322	MN4	248	0.056
65322	S6	201.2	0.011
65322	2N2	8.8	0.079
65322	OO1	292	0.053
65322	M1	25.6	0.072
65322	J1	71.5	0.069
65322	Q1	58.1	0.072
65322	2Q1	50.2	0.047
65322	P1	106.4	0.109
65322	2SM2	75.7	0.025
65322	M3	230.5	0.016
65322	L2	88.2	0.081
65322	2MK3	235.7	0.085
65322	K2	105.5	0.121
65322	M8	353.2	0.016
65322	MS4	226.3	0.061
65323	M2	88.8	1.138
65323	S2	96	0.318
65323	N2	71.8	0.266
65323	K1	103.1	0.722
65323	M4	89.4	0.062
65323	O1	99.8	0.28
65323	M6	17.2	0.011
65323	MK3	45.5	0.073
65323	S4	337.6	0.027
65323	MN4	87.1	0.018
65323	S6	62.5	0.008
65323	2N2	53.8	0.049
65323	OO1	79.8	0.033
65323	M1	55.1	0.022
65323	J1	110.3	0.047
65323	Q1	62.6	0.037
65323	2Q1	178.9	0.027
65323	P1	105.3	0.285
65323	2SM2	309.3	0.018
65323	M3	173.7	0.026
65323	L2	134.4	0.027
65323	2MK3	32.1	0.018
65323	M8	111.8	0.004
65323	MS4	39.3	0.036
65324	M2	93.5	1.169
65324	S2	100.1	0.331
65324	N2	72.6	0.255
65324	K1	97.7	0.683
65324	M4	122	0.052
65324	O1	87.1	0.341
65324	M6	197.8	0.009
65324	MK3	71.9	0.039
65324	S4	174	0.013
65324	MN4	121.4	0.053
65324	S6	143.2	0.013
65324	2N2	297.6	0.012
65324	OO1	45.9	0.04
65324	M1	328.4	0.034
65324	J1	122	0.042
65324	Q1	43.1	0.039
65324	2Q1	206.7	0.032
65324	P1	114.1	0.288
65324	2SM2	339	0.023
65324	M3	190.1	0.065
65324	L2	145.4	0.056
65324	2MK3	337	0.04
65324	M8	294.7	0.015
65324	MS4	137	0.012
65325	M2	94.2	1.134
65325	S2	97.7	0.291
65325	N2	76.5	0.228
65325	K1	88	0.651
65325	M4	174.5	0.058
65325	O1	72.9	0.37
65325	M6	112.2	0.013
65325	MK3	162.9	0.024
65325	S4	176	0.019
65325	MN4	139.7	0.052
65325	S6	166.1	0.021
65325	2N2	247.2	0.04
65325	OO1	35.8	0.088
65325	M1	297.1	0.044
65325	J1	118.3	0.028
65325	Q1	29	0.054
65325	2Q1	245.1	0.03
65325	P1	119.6	0.24
65325	2SM2	3.9	0.039
65325	M3	191	0.073
65325	L2	129.1	0.076
65325	2MK3	291.6	0.042
65325	M8	348.8	0.017
65325	MS4	228.4	0.034
65326	M2	31.8	0.986
65326	S2	68.8	0.264
65326	N2	13.9	0.23
65326	K1	10.3	0.342
65326	M4	162.3	0.049
65326	O1	31.4	0.198
65326	M6	319.5	0.022
65326	MK3	166.7	0.071
65326	S4	122.2	0.008
65326	MN4	113.4	0.026
65326	S6	16.4	0.009
65326	2N2	333.5	0.025
65326	OO1	249.4	0.074
65326	M1	173	0.037
65326	J1	224.2	0.012
65326	Q1	281.2	0.014
65326	2Q1	280.2	0.044
65326	P1	329.9	0.091
65326	2SM2	259.4	0.026
65326	M3	91.9	0.054
65326	L2	67.3	0.065
65326	2MK3	291.7	0.07
65326	K2	40.6	0.21
65326	M8	229.7	0.015
65326	MS4	175.6	0.048
65327	M2	34.2	1.019
65327	S2	51.8	0.28
65327	N2	16.8	0.257
65327	K1	20.9	0.287
65327	M4	132.5	0.044
65327	O1	52.7	0.132
65327	M6	205.1	0.011
65327	MK3	107.7	0.096
65327	S4	105	0.026
65327	MN4	128.2	0.034
65327	S6	75.1	0.012
65327	2N2	319.9	0.079
65327	OO1	246.5	0.075
65327	M1	130.2	0.055
65327	J1	166.5	0.068
65327	Q1	115.2	0.073
65327	2Q1	343.3	0.056
65327	P1	337.4	0.048
65327	2SM2	251.3	0.035
65327	M3	78.5	0.037
65327	L2	1	0.041
65327	2MK3	286.8	0.046
65327	K2	27.2	0.14
65327	M8	188.9	0.015
65327	MS4	142.1	0.087
65328	M2	47.8	1.018
65328	S2	51.7	0.361
65328	N2	22.3	0.255
65328	K1	78.2	0.156
65328	M4	124.2	0.02
65328	O1	118.3	0.141
65328	M6	189.4	0.037
65328	MK3	49.1	0.191
65328	S4	109.5	0.042
65328	MN4	144.6	0.017
65328	S6	121.8	0.014
65328	2N2	306.8	0.123
65328	OO1	177.7	0.023
65328	M1	121.7	0.054
65328	J1	140.9	0.104
65328	Q1	116.6	0.1
65328	2Q1	8.7	0.062
65328	P1	98.5	0.154
65328	2SM2	42.5	0.037
65328	M3	344.5	0.022
65328	L2	143.2	0.034
65328	2MK3	17.4	0.08
65328	K2	307.8	0.097
65328	M8	237.9	0.007
65328	MS4	149.6	0.112
65329	M2	64.5	1.517
65329	S2	96.2	0.356
65329	N2	59.8	0.42
65329	K1	86.3	0.6
65329	M4	284.9	0.101
65329	O1	65.6	0.73
65329	M6	114.1	0.076
65329	MK3	253.7	0.283
65329	S4	194.1	0.035
65329	MN4	285.6	0.018
65329	S6	33	0.021
65329	2N2	34.3	0.067
65329	OO1	232.2	0.083
65329	M1	82.8	0.106
65329	J1	92.3	0.184
65329	Q1	67.7	0.14
65329	2Q1	12.3	0.02
65329	P1	123.9	0.343
65329	2SM2	218.1	0.05
65329	M3	75.2	0.06
65329	L2	324.5	0.12
65329	2MK3	264.5	0.236
65329	K2	81.3	0.331
65329	M8	33.9	0.04
65329	MS4	307.1	0.059
65330	M2	63.1	1.545
65330	S2	90.4	0.346
65330	N2	58.3	0.424
65330	K1	87.6	0.651
65330	M4	292.9	0.094
65330	O1	65.6	0.723
65330	M6	114.1	0.07
65330	MK3	244.7	0.269
65330	S4	184.9	0.036
65330	MN4	297.2	0.029
65330	S6	15.5	0.021
65330	2N2	48.8	0.093
65330	OO1	230.7	0.091
65330	M1	98.8	0.115
65330	J1	92.3	0.174
65330	Q1	75.9	0.13
65330	2Q1	167.3	0.007
65330	P1	116.8	0.362
65330	2SM2	215.4	0.053
65330	M3	54.6	0.075
65330	L2	319.6	0.14
65330	2MK3	254	0.217
65330	K2	78.6	0.277
65330	M8	40.2	0.04
65330	MS4	319.7	0.05
65331	M2	63.4	1.63
65331	S2	85.6	0.431
65331	N2	52.9	0.437
65331	K1	86.8	0.771
65331	M4	307.5	0.064
65331	O1	65.3	0.716
65331	M6	105.7	0.058
65331	MK3	233.2	0.247
65331	S4	210.9	0.014
65331	MN4	299.6	0.038
65331	S6	350.2	0.019
65331	2N2	53.3	0.143
65331	OO1	223.7	0.135
65331	M1	105.9	0.111
65331	J1	90.8	0.174
65331	Q1	82.5	0.114
65331	2Q1	170.1	0.052
65331	P1	108.7	0.378
65331	2SM2	190.9	0.049
65331	M3	34.1	0.064
65331	L2	321.5	0.155
65331	2MK3	236.4	0.204
65331	K2	49.8	0.244
65331	M8	37.6	0.014
65331	MS4	358.6	0.073
65332	M2	87.8	1.262
65332	S2	126.5	0.379
65332	N2	67.2	0.355
65332	K1	101.5	0.951
65332	M4	33.1	0.039
65332	O1	86.4	0.656
65332	M6	298.2	0.032
65332	MK3	164.5	0.034
65332	S4	42	0.005
65332	MN4	18.8	0.03
65332	S6	138.4	0.012
65332	2N2	36.9	0.083
65332	OO1	190.2	0.08
65332	M1	65.5	0.028
65332	J1	76.2	0.068
65332	Q1	69.9	0.121
65332	2Q1	242	0.016
65332	P1	121.5	0.282
65332	2SM2	225.9	0.019
65332	M3	76.4	0.041
65332	L2	187.8	0.032
65332	2MK3	145.6	0.048
65332	K2	103.1	0.175
65332	M8	304.6	0.012
65332	MS4	208.7	0.014
65333	M2	89.7	1.054
65333	S2	125.7	0.292
65333	N2	64.4	0.263
65333	K1	114.9	0.808
65333	M4	13.3	0.105
65333	O1	84.3	0.577
65333	M6	66.7	0.016
65333	MK3	236.8	0.166
65333	S4	129.7	0.029
65333	MN4	37.6	0.024
65333	S6	351.2	0.013
65333	2N2	328.2	0.024
65333	OO1	87.4	0.036
65333	M1	259.2	0.074
65333	J1	63.2	0.049
65333	Q1	34.6	0.101
65333	2Q1	296.6	0.027
65333	P1	116.9	0.308
65333	2SM2	42	0.014
65333	M3	126.7	0.021
65333	L2	108.4	0.066
65333	2MK3	251.4	0.117
65333	K2	81.8	0.219
65333	M8	359.7	0.026
65333	MS4	103.6	0.052
65334	M2	88.2	0.885
65334	S2	134.2	0.193
65334	N2	71.5	0.203
65334	K1	116.3	0.675
65334	M4	10.1	0.112
65334	O1	78.9	0.551
65334	M6	202.6	0.018
65334	MK3	244.7	0.142
65334	S4	174.5	0.037
65334	MN4	24.9	0.045
65334	S6	167.8	0.002
65334	2N2	314.1	0.049
65334	OO1	106	0.067
65334	M1	247.4	0.081
65334	J1	90.6	0.059
65334	Q1	41.8	0.073
65334	2Q1	278.9	0.042
65334	P1	105.1	0.287
65334	2SM2	339.7	0.019
65334	M3	103	0.047
65334	L2	104	0.067
65334	2MK3	254.7	0.149
65334	K2	109.7	0.16
65334	M8	39.6	0.037
65334	MS4	124.5	0.075
65335	M2	57.9	2.297
65335	S2	83.8	0.51
65335	N2	41.1	0.567
65335	K1	81.5	0.699
65335	M4	115.7	0.113
65335	O1	73.5	0.361
65335	M6	60.4	0.06
65335	MK3	53.1	0.092
65335	S4	95.1	0.022
65335	MN4	108.3	0.031
65335	S6	329.5	0.01
65335	2N2	29.6	0.104
65335	OO1	186.7	0.091
65335	M1	343.9	0.048
65335	J1	65.6	0.081
65335	Q1	86.1	0.051
65335	2Q1	233.7	0.036
65335	P1	106.6	0.366
65335	2SM2	324	0.007
65335	M3	125.2	0.077
65335	L2	43.5	0.07
65335	2MK3	268.3	0.108
65335	K2	98.1	0.234
65335	M8	130.4	0.016
65335	MS4	124.9	0.088
65336	M2	60.9	2.111
65336	S2	102.3	0.569
65336	N2	36.9	0.568
65336	K1	84.3	0.738
65336	M4	160.3	0.134
65336	O1	73.8	0.411
65336	M6	36.9	0.019
65336	MK3	106.8	0.155
65336	S4	131.2	0.011
65336	MN4	119.6	0.052
65336	2N2	16.4	0.115
65336	OO1	152.6	0.097
65336	M1	320.4	0.053
65336	J1	84.4	0.111
65336	Q1	82	0.03
65336	2Q1	162	0.045
65336	P1	108	0.411
65336	2SM2	305.8	0.023
65336	M3	83.9	0.053
65336	L2	358.9	0.056
65336	2MK3	193.2	0.035
65336	K2	89.2	0.378
65336	M8	172.1	0.019
65336	MS4	156	0.129
65337	M2	61.4	2.098
65337	S2	102.6	0.573
65337	N2	36.6	0.564
65337	K1	84.3	0.74
65337	M4	164	0.138
65337	O1	74.8	0.419
65337	M6	50.1	0.015
65337	MK3	107	0.163
65337	S4	124.5	0.014
65337	MN4	116.4	0.056
65337	S6	35	0.004
65337	2N2	15.8	0.12
65337	OO1	151.6	0.09
65337	M1	315.5	0.055
65337	J1	86.5	0.107
65337	Q1	83.9	0.025
65337	2Q1	161.4	0.044
65337	P1	108.6	0.411
65337	2SM2	307.4	0.022
65337	M3	80.4	0.055
65337	L2	0.4	0.051
65337	2MK3	181.2	0.036
65337	K2	89.3	0.37
65337	M8	171.9	0.018
65337	MS4	155.3	0.129
65338	M2	30.4	0.915
65338	S2	46.7	0.183
65338	N2	12.5	0.19
65338	K1	25.5	0.253
65338	M4	321.3	0.024
65338	O1	339.5	0.121
65338	M6	312.1	0.039
65338	MK3	292.9	0.1
65338	S4	83.7	0.012
65338	MN4	302.4	0.027
65338	S6	202.3	0.009
65338	2N2	299.9	0.042
65338	OO1	306.9	0.053
65338	M1	135.7	0.037
65338	J1	230.8	0.029
65338	Q1	143.5	0.027
65338	2Q1	116.9	0.017
65338	P1	358.2	0.097
65338	2SM2	280.2	0.021
65338	M3	42.1	0.021
65338	L2	33.5	0.104
65338	2MK3	273.6	0.071
65338	K2	89	0.109
65338	M8	23.7	0.002
65338	MS4	347.8	0.018
65339	M2	32.9	0.928
65339	S2	49	0.174
65339	N2	13.4	0.192
65339	K1	39.2	0.221
65339	M4	317.7	0.047
65339	O1	323.1	0.074
65339	M6	316.7	0.039
65339	MK3	314.4	0.104
65339	S4	69	0.005
65339	MN4	321.1	0.037
65339	S6	179.1	0.019
65339	2N2	329.2	0.035
65339	OO1	282.6	0.068
65339	M1	120	0.056
65339	J1	216.5	0.029
65339	Q1	149.6	0.046
65339	2Q1	108.4	0.032
65339	P1	26.4	0.102
65339	2SM2	291.8	0.022
65339	M3	32.3	0.022
65339	L2	37.5	0.1
65339	2MK3	272.5	0.058
65339	K2	90	0.108
65339	M8	267.3	0.002
65339	MS4	7.4	0.035
65340	M2	35	0.923
65340	S2	49.8	0.188
65340	N2	16.5	0.183
65340	K1	54.5	0.203
65340	M4	327.8	0.053
65340	O1	295.3	0.045
65340	M6	326.4	0.037
65340	MK3	325.9	0.106
65340	MN4	340	0.039
65340	S6	190.3	0.014
65340	2N2	327.1	0.026
65340	OO1	282.4	0.084
65340	M1	117.5	0.062
65340	J1	227	0.031
65340	Q1	154.2	0.056
65340	2Q1	112.7	0.043
65340	P1	41	0.125
65340	2SM2	309.3	0.022
65340	M3	42.5	0.021
65340	L2	42.4	0.095
65340	2MK3	269.4	0.058
65340	K2	81.5	0.09
65340	M8	278.5	0.006
65340	MS4	14.1	0.044
65341	M2	59.7	1.607
65341	S2	81.8	0.344
65341	N2	44	0.387
65341	K1	58.4	0.672
65341	M4	84.2	0.043
65341	O1	50.9	0.412
65341	M6	2.9	0.033
65341	MK3	191.6	0.059
65341	S4	20.3	0.006
65341	MN4	46.7	0.027
65341	S6	134.5	0.003
65341	2N2	20.1	0.025
65341	OO1	314.4	0.056
65341	M1	91.1	0.051
65341	J1	114.8	0.044
65341	Q1	45.8	0.076
65341	2Q1	85.2	0.015
65341	P1	87.4	0.157
65341	2SM2	289.4	0.013
65341	M3	196.9	0.006
65341	L2	67.9	0.124
65341	2MK3	282.7	0.07
65341	K2	86.4	0.138
65341	M8	339.8	0.01
65341	MS4	112.5	0.065
65342	M2	59.7	1.625
65342	S2	81.5	0.348
65342	N2	44	0.392
65342	K1	58.4	0.68
65342	M4	84.6	0.044
65342	O1	50.9	0.416
65342	M6	2.3	0.034
65342	MK3	191.3	0.059
65342	S4	21.6	0.006
65342	MN4	47.2	0.027
65342	S6	138.6	0.004
65342	2N2	21.2	0.026
65342	OO1	313.6	0.057
65342	M1	90.4	0.052
65342	J1	114.5	0.045
65342	Q1	45.5	0.077
65342	2Q1	85.1	0.014
65342	P1	87	0.159
65342	2SM2	288.6	0.013
65342	M3	195.7	0.005
65342	L2	67.8	0.126
65342	2MK3	283.2	0.071
65342	K2	86	0.138
65342	M8	339.6	0.01
65342	MS4	112.5	0.066
65343	M2	59.7	1.637
65343	S2	81.4	0.351
65343	N2	44	0.395
65343	K1	58.5	0.684
65343	M4	83.5	0.044
65343	O1	51	0.418
65343	M6	1.5	0.034
65343	MK3	191.7	0.059
65343	S4	20.7	0.006
65343	MN4	46.5	0.027
65343	S6	139.6	0.004
65343	2N2	21	0.026
65343	OO1	313.1	0.058
65343	M1	90	0.052
65343	J1	114	0.046
65343	Q1	45.5	0.078
65343	2Q1	84.9	0.015
65343	P1	86.6	0.16
65343	2SM2	286.2	0.013
65343	M3	201	0.005
65343	L2	67.5	0.126
65343	2MK3	282.9	0.072
65343	K2	86.2	0.139
65343	M8	338.8	0.01
65343	MS4	112.6	0.065
65344	M2	59.7	1.647
65344	S2	81.4	0.353
65344	N2	44	0.398
65344	K1	58.6	0.688
65344	M4	83.1	0.043
65344	O1	51.2	0.42
65344	M6	1	0.034
65344	MK3	192.8	0.059
65344	S4	22.8	0.006
65344	MN4	45.4	0.027
65344	S6	145.5	0.004
65344	2N2	20.8	0.026
65344	OO1	312.8	0.058
65344	M1	89.6	0.053
65344	J1	113.3	0.046
65344	Q1	45.7	0.078
65344	2Q1	85	0.014
65344	P1	86	0.162
65344	2SM2	285.6	0.013
65344	M3	201.9	0.005
65344	L2	67.2	0.127
65344	2MK3	282.9	0.073
65344	K2	85.9	0.14
65344	M8	336.6	0.01
65344	MS4	112.7	0.065
65345	M2	59.6	1.654
65345	S2	81.3	0.354
65345	N2	44	0.4
65345	K1	58.7	0.692
65345	M4	81.7	0.042
65345	O1	51.3	0.42
65345	M6	0.1	0.035
65345	MK3	193.6	0.058
65345	S4	23.9	0.006
65345	MN4	42.7	0.026
65345	S6	147.4	0.003
65345	2N2	19.6	0.026
65345	OO1	312.7	0.059
65345	M1	89.5	0.052
65345	J1	112.7	0.047
65345	Q1	45.7	0.079
65345	2Q1	81.7	0.015
65345	P1	85.4	0.162
65345	2SM2	285	0.013
65345	M3	208.4	0.004
65345	L2	67	0.128
65345	2MK3	283.2	0.075
65345	K2	85.8	0.14
65345	M8	336.7	0.011
65345	MS4	112.5	0.064
65346	M2	59.6	1.66
65346	S2	81.5	0.356
65346	N2	44	0.402
65346	K1	58.8	0.696
65346	M4	80.8	0.042
65346	O1	51.4	0.421
65346	M6	359.7	0.035
65346	MK3	194.9	0.058
65346	S4	27.7	0.005
65346	MN4	40	0.026
65346	S6	152.3	0.004
65346	2N2	18.4	0.026
65346	OO1	312.4	0.06
65346	M1	89.2	0.052
65346	J1	111.9	0.048
65346	Q1	46.1	0.079
65346	2Q1	79.4	0.015
65346	P1	84.7	0.162
65346	2SM2	284.4	0.012
65346	M3	216.6	0.004
65346	L2	66.4	0.129
65346	2MK3	283.5	0.077
65346	K2	85.6	0.142
65346	M8	336.9	0.011
65346	MS4	112.1	0.063
65347	M2	59.6	1.666
65347	S2	81.7	0.356
65347	N2	44	0.403
65347	K1	58.8	0.699
65347	M4	78.9	0.04
65347	O1	51.5	0.422
65347	M6	359.9	0.036
65347	MK3	196.5	0.059
65347	S4	27.2	0.005
65347	MN4	37	0.026
65347	S6	148.8	0.004
65347	2N2	17.6	0.026
65347	OO1	311.6	0.06
65347	M1	89.1	0.052
65347	J1	111.8	0.048
65347	Q1	46.3	0.079
65347	2Q1	77.3	0.016
65347	P1	83.8	0.162
65347	2SM2	284	0.012
65347	M3	230.2	0.004
65347	L2	66.2	0.129
65347	2MK3	283.7	0.078
65347	K2	86.1	0.145
65347	M8	335.4	0.011
65347	MS4	112.2	0.062
65348	M2	59.6	1.67
65348	S2	81.9	0.355
65348	N2	44	0.405
65348	K1	58.9	0.702
65348	M4	77.5	0.039
65348	O1	51.7	0.421
65348	M6	358.9	0.036
65348	MK3	198.2	0.059
65348	S4	26.1	0.005
65348	MN4	34.1	0.026
65348	S6	152.2	0.004
65348	2N2	15.5	0.026
65348	OO1	311.8	0.061
65348	M1	89.4	0.053
65348	J1	111.3	0.048
65348	Q1	46.5	0.078
65348	2Q1	75.5	0.016
65348	P1	82.7	0.162
65348	2SM2	284	0.012
65348	M3	241.4	0.004
65348	L2	65.9	0.129
65348	2MK3	283.8	0.079
65348	K2	86.1	0.147
65348	M8	334.3	0.012
65348	MS4	112	0.061
65349	M2	59.6	1.674
65349	S2	82.1	0.356
65349	N2	44	0.406
65349	K1	59	0.705
65349	M4	75.8	0.039
65349	O1	51.8	0.421
65349	M6	357.7	0.036
65349	MK3	199.2	0.059
65349	S4	23.8	0.005
65349	MN4	31.3	0.026
65349	S6	161.1	0.004
65349	2N2	13.3	0.025
65349	OO1	311.1	0.062
65349	M1	89.6	0.053
65349	J1	110.5	0.048
65349	Q1	47.3	0.078
65349	2Q1	74.1	0.017
65349	P1	81.9	0.162
65349	2SM2	285.9	0.012
65349	M3	248	0.004
65349	L2	65.6	0.13
65349	2MK3	283.6	0.081
65349	K2	85.9	0.149
65349	M8	334.4	0.012
65349	MS4	111.8	0.06
65350	M2	59.6	1.677
65350	S2	82.3	0.355
65350	N2	44.1	0.406
65350	K1	59	0.706
65350	M4	73.8	0.038
65350	O1	51.9	0.42
65350	M6	357.3	0.037
65350	MK3	200.3	0.059
65350	S4	21.8	0.005
65350	MN4	28.8	0.026
65350	S6	162.2	0.004
65350	2N2	12	0.025
65350	OO1	310.8	0.063
65350	M1	89.9	0.052
65350	J1	110.1	0.049
65350	Q1	47.6	0.078
65350	2Q1	73.3	0.017
65350	P1	81.5	0.161
65350	2SM2	286.2	0.012
65350	M3	254.9	0.004
65350	L2	65.4	0.131
65350	2MK3	283.8	0.082
65350	K2	86.3	0.151
65350	M8	334.4	0.012
65350	MS4	111.5	0.059
65351	M2	59.6	1.68
65351	S2	82.4	0.354
65351	N2	44.1	0.407
65351	K1	59	0.706
65351	M4	71.2	0.037
65351	O1	51.9	0.419
65351	M6	356.6	0.037
65351	MK3	201.4	0.06
65351	S4	17.2	0.006
65351	MN4	25	0.026
65351	S6	169.6	0.004
65351	2N2	10.2	0.025
65351	OO1	310.7	0.064
65351	M1	90.2	0.052
65351	J1	109.2	0.049
65351	Q1	47.9	0.077
65351	2Q1	73.5	0.018
65351	P1	80.9	0.161
65351	2SM2	288.5	0.012
65351	M3	267.3	0.004
65351	L2	65.3	0.132
65351	2MK3	283.5	0.084
65351	K2	86.7	0.153
65351	M8	332.9	0.012
65351	MS4	111.1	0.058
65352	M2	59.5	1.682
65352	S2	82.5	0.354
65352	N2	44.2	0.407
65352	K1	59.1	0.707
65352	M4	69.1	0.036
65352	O1	51.9	0.418
65352	M6	356	0.038
65352	MK3	201.7	0.061
65352	S4	13.3	0.006
65352	MN4	22.6	0.026
65352	S6	178.1	0.004
65352	2N2	8.7	0.026
65352	OO1	310.9	0.065
65352	M1	90.3	0.053
65352	J1	109.2	0.05
65352	Q1	47.5	0.077
65352	2Q1	73.5	0.018
65352	P1	80.6	0.161
65352	2SM2	291.4	0.011
65352	M3	268.4	0.005
65352	L2	65.2	0.133
65352	2MK3	283.7	0.084
65352	K2	86.8	0.154
65352	M8	333.7	0.013
65352	MS4	111.4	0.057
65353	M2	59.5	1.684
65353	S2	82.5	0.353
65353	N2	44.2	0.407
65353	K1	59	0.707
65353	M4	67	0.036
65353	O1	51.9	0.418
65353	M6	356	0.039
65353	MK3	201.3	0.063
65353	S4	13.9	0.006
65353	MN4	20.1	0.026
65353	S6	187.8	0.003
65353	2N2	7.9	0.026
65353	OO1	310.9	0.066
65353	M1	90.4	0.053
65353	J1	108.5	0.051
65353	Q1	47.8	0.077
65353	2Q1	73.4	0.018
65353	P1	80.2	0.16
65353	2SM2	293.4	0.011
65353	M3	269.9	0.005
65353	L2	65.5	0.133
65353	2MK3	283.7	0.086
65353	K2	87.1	0.154
65353	M8	334.3	0.014
65353	MS4	111.4	0.056
65354	M2	59.5	1.685
65354	S2	82.5	0.352
65354	N2	44.3	0.406
65354	K1	59	0.706
65354	M4	65	0.036
65354	O1	51.9	0.417
65354	M6	356	0.04
65354	MK3	200.7	0.064
65354	S4	10.8	0.006
65354	MN4	18.2	0.025
65354	S6	187.6	0.003
65354	2N2	7.5	0.026
65354	OO1	310.9	0.067
65354	M1	90.6	0.052
65354	J1	108.8	0.052
65354	Q1	47.6	0.077
65354	2Q1	73.5	0.018
65354	P1	79.9	0.158
65354	2SM2	296.2	0.011
65354	M3	273.4	0.005
65354	L2	65.6	0.134
65354	2MK3	283.6	0.087
65354	K2	87.2	0.155
65354	M8	334.8	0.014
65354	MS4	111.8	0.056
65355	M2	59.4	1.686
65355	S2	82.5	0.351
65355	N2	44.3	0.406
65355	K1	59	0.706
65355	M4	63.5	0.035
65355	O1	51.8	0.415
65355	M6	355.7	0.04
65355	MK3	200.5	0.065
65355	S4	11.9	0.005
65355	MN4	16.1	0.025
65355	S6	199.5	0.003
65355	2N2	8	0.026
65355	OO1	310.9	0.068
65355	M1	90.1	0.052
65355	J1	109.1	0.052
65355	Q1	47.4	0.077
65355	2Q1	73.2	0.019
65355	P1	79.6	0.158
65355	2SM2	298.3	0.01
65355	M3	274.9	0.005
65355	L2	65.7	0.134
65355	2MK3	283.1	0.087
65355	K2	87.3	0.155
65355	M8	335.3	0.015
65355	MS4	111.7	0.056
65356	M2	59.4	1.687
65356	S2	82.4	0.351
65356	N2	44.2	0.405
65356	K1	58.9	0.704
65356	M4	63	0.035
65356	O1	51.8	0.414
65356	M6	355.6	0.041
65356	MK3	199.4	0.065
65356	S4	9	0.005
65356	MN4	14.7	0.025
65356	S6	210.2	0.003
65356	2N2	7.7	0.026
65356	OO1	310.8	0.069
65356	M1	89.9	0.052
65356	J1	109.2	0.052
65356	Q1	46.8	0.077
65356	2Q1	73.7	0.019
65356	P1	79.5	0.157
65356	2SM2	301	0.01
65356	M3	270.1	0.006
65356	L2	65.7	0.135
65356	2MK3	282.6	0.088
65356	K2	87.3	0.155
65356	M8	336.3	0.016
65356	MS4	112.3	0.056
65357	M2	59.3	1.682
65357	S2	82.3	0.345
65357	N2	44.2	0.402
65357	K1	58.8	0.706
65357	M4	70.8	0.033
65357	O1	51.4	0.41
65357	M6	0.3	0.04
65357	MK3	199	0.071
65357	S4	1.5	0.007
65357	MN4	13.9	0.021
65357	2N2	6.7	0.023
65357	OO1	312	0.07
65357	M1	89.8	0.05
65357	J1	108.9	0.05
65357	Q1	45.9	0.076
65357	2Q1	73.1	0.018
65357	P1	78	0.153
65357	2SM2	310	0.01
65357	M3	253.9	0.009
65357	L2	66	0.137
65357	2MK3	279.2	0.09
65357	K2	88.5	0.157
65357	M8	345.2	0.017
65357	MS4	116.1	0.053
65358	M2	53.7	0.713
65358	S2	77.3	0.177
65358	N2	39.2	0.175
65358	K1	53.9	0.332
65358	M4	346.3	0.008
65358	O1	55.2	0.176
65358	M6	300	0.011
65358	MK3	248.3	0.019
65358	MN4	351	0.016
65358	S6	120.9	0.004
65358	2N2	345	0.025
65358	OO1	323.3	0.021
65358	M1	55.3	0.029
65358	J1	110.5	0.037
65358	Q1	28.1	0.03
65358	2Q1	7.7	0.017
65358	P1	82.4	0.05
65358	2SM2	288.9	0.008
65358	M3	73.9	0.006
65358	L2	61.9	0.057
65358	2MK3	274.5	0.025
65358	K2	66	0.065
65358	M8	247.1	0.003
65358	MS4	118.5	0.014
65359	M2	53.9	0.762
65359	S2	77.7	0.189
65359	N2	39.6	0.187
65359	K1	54	0.355
65359	M4	352.3	0.006
65359	O1	54.7	0.19
65359	M6	302.1	0.012
65359	MK3	246.3	0.019
65359	MN4	353.3	0.017
65359	S6	124.3	0.004
65359	2N2	344.2	0.027
65359	OO1	320	0.02
65359	M1	57.8	0.031
65359	J1	111.3	0.04
65359	Q1	27.1	0.032
65359	2Q1	6.5	0.017
65359	P1	82.8	0.055
65359	2SM2	290.1	0.009
65359	M3	77.9	0.006
65359	L2	62.5	0.061
65359	2MK3	276.3	0.026
65359	K2	66.3	0.07
65359	M8	244.2	0.003
65359	MS4	121.8	0.016
65360	M2	54.2	0.795
65360	S2	77.5	0.197
65360	N2	39.9	0.195
65360	K1	54.2	0.37
65360	M4	357.6	0.004
65360	O1	54.3	0.201
65360	M6	302.1	0.012
65360	MK3	243.2	0.019
65360	MN4	356.9	0.016
65360	S6	124.5	0.005
65360	2N2	343	0.027
65360	OO1	318.9	0.02
65360	M1	58.6	0.032
65360	J1	111.4	0.04
65360	Q1	26.6	0.033
65360	2Q1	5.1	0.016
65360	P1	82.3	0.058
65360	2SM2	291.1	0.009
65360	M3	86.5	0.006
65360	L2	62.9	0.063
65360	2MK3	278.7	0.027
65360	K2	65.8	0.072
65360	M8	241.7	0.003
65360	MS4	125	0.018
65361	M2	54.4	0.822
65361	S2	77.8	0.203
65361	N2	40.2	0.202
65361	K1	54.5	0.383
65361	M4	12.8	0.003
65361	O1	54.2	0.209
65361	M6	303.4	0.012
65361	MK3	240.4	0.018
65361	MN4	0	0.016
65361	S6	124.1	0.004
65361	2N2	341	0.027
65361	OO1	317.2	0.02
65361	M1	60.2	0.033
65361	J1	111.9	0.04
65361	Q1	27.6	0.034
65361	2Q1	3.4	0.015
65361	P1	81.1	0.061
65361	2SM2	291.4	0.009
65361	M3	95.1	0.006
65361	L2	63.3	0.066
65361	2MK3	280.6	0.028
65361	K2	66.8	0.074
65361	M8	235.3	0.002
65361	MS4	127.8	0.019
65362	M2	54.6	0.845
65362	S2	77.8	0.206
65362	N2	40.6	0.207
65362	K1	54.7	0.394
65362	M4	30.5	0.002
65362	O1	53.8	0.216
65362	M6	306.1	0.012
65362	MK3	237.1	0.018
65362	S4	245.1	0.001
65362	MN4	0.8	0.015
65362	S6	125.8	0.004
65362	2N2	338.4	0.027
65362	OO1	317.1	0.021
65362	M1	61.4	0.033
65362	J1	111.6	0.04
65362	Q1	29.7	0.035
65362	2Q1	359	0.014
65362	P1	81.3	0.064
65362	2SM2	289	0.009
65362	M3	101.1	0.005
65362	L2	63.7	0.067
65362	2MK3	282.8	0.029
65362	K2	67.8	0.076
65362	M8	230.3	0.002
65362	MS4	130.1	0.019
65363	M2	54.8	0.862
65363	S2	78	0.209
65363	N2	40.8	0.211
65363	K1	55	0.402
65363	M4	43.4	0.002
65363	O1	53.8	0.221
65363	M6	307.4	0.012
65363	MK3	235.8	0.018
65363	S4	255.1	0.002
65363	MN4	1	0.014
65363	S6	125.6	0.003
65363	2N2	337.4	0.027
65363	OO1	317.7	0.022
65363	M1	63.2	0.033
65363	J1	111.4	0.039
65363	Q1	32.3	0.035
65363	2Q1	355.6	0.013
65363	P1	81.4	0.066
65363	2SM2	287.4	0.009
65363	M3	112.2	0.004
65363	L2	64	0.069
65363	2MK3	284.8	0.03
65363	K2	69.7	0.078
65363	M8	229.7	0.001
65363	MS4	130.8	0.019
65364	M2	54.9	0.876
65364	S2	78.1	0.211
65364	N2	41	0.215
65364	K1	55.3	0.409
65364	M4	35.8	0.001
65364	O1	53.9	0.225
65364	M6	310.7	0.012
65364	MK3	235.4	0.018
65364	S4	257.7	0.003
65364	MN4	359.7	0.013
65364	S6	128.3	0.003
65364	2N2	335.5	0.027
65364	OO1	316.7	0.023
65364	M1	65	0.033
65364	J1	110.7	0.039
65364	Q1	35	0.036
65364	2Q1	354.7	0.012
65364	P1	81.6	0.067
65364	2SM2	285.8	0.009
65364	M3	125.2	0.003
65364	L2	64.1	0.069
65364	2MK3	286.2	0.031
65364	K2	71.4	0.079
65364	MS4	130.6	0.018
65365	M2	55.1	0.888
65365	S2	78.3	0.212
65365	N2	41	0.218
65365	K1	55.6	0.416
65365	M4	2.9	0.001
65365	O1	53.9	0.228
65365	M6	313.8	0.012
65365	MK3	236.1	0.019
65365	S4	263.5	0.004
65365	MN4	355.2	0.012
65365	S6	134.3	0.003
65365	2N2	334.7	0.027
65365	OO1	315.4	0.024
65365	M1	66.4	0.033
65365	J1	110.1	0.038
65365	Q1	37.2	0.037
65365	2Q1	351	0.011
65365	P1	81.9	0.068
65365	2SM2	283.9	0.01
65365	M3	148.1	0.002
65365	L2	64.3	0.07
65365	2MK3	286	0.032
65365	K2	73.2	0.081
65365	MS4	130.8	0.017
65366	M2	55.2	0.898
65366	S2	78.7	0.213
65366	N2	41.1	0.221
65366	K1	56	0.421
65366	M4	330.8	0.001
65366	O1	54.1	0.231
65366	M6	315.1	0.012
65366	MK3	237.3	0.02
65366	S4	258.7	0.004
65366	MN4	351	0.011
65366	S6	130.8	0.003
65366	2N2	335	0.028
65366	OO1	315.3	0.026
65366	M1	67.4	0.032
65366	J1	110	0.037
65366	Q1	38.7	0.038
65366	2Q1	352.1	0.01
65366	P1	82	0.07
65366	2SM2	283	0.01
65366	M3	173.5	0.002
65366	L2	64	0.07
65366	2MK3	286	0.033
65366	K2	75.8	0.083
65366	MS4	131.3	0.016
65367	M2	55.3	0.906
65367	S2	78.8	0.213
65367	N2	41.2	0.223
65367	K1	56.4	0.427
65367	M4	325.2	0.002
65367	O1	54.3	0.234
65367	M6	318	0.013
65367	MK3	238.4	0.022
65367	S4	257.8	0.004
65367	MN4	345.6	0.01
65367	S6	120.3	0.003
65367	2N2	335.5	0.028
65367	OO1	316.6	0.026
65367	M1	69.4	0.031
65367	J1	109.2	0.036
65367	Q1	41	0.039
65367	2Q1	352.1	0.009
65367	P1	81.7	0.072
65367	2SM2	285.2	0.01
65367	M3	194	0.002
65367	L2	63.8	0.07
65367	2MK3	286.4	0.034
65367	K2	77.3	0.084
65367	MS4	130.5	0.014
65368	M2	55.3	0.914
65368	S2	79.1	0.213
65368	N2	41.2	0.225
65368	K1	56.8	0.432
65368	M4	317.2	0.003
65368	O1	54.4	0.237
65368	M6	321.4	0.012
65368	MK3	239.3	0.023
65368	S4	256.6	0.004
65368	MN4	340.2	0.01
65368	S6	119.8	0.003
65368	2N2	335.5	0.028
65368	OO1	316.1	0.027
65368	M1	70.1	0.031
65368	J1	107.5	0.035
65368	Q1	42.3	0.04
65368	2Q1	353.7	0.008
65368	P1	80.7	0.072
65368	2SM2	285.6	0.009
65368	M3	208.8	0.002
65368	L2	63.5	0.07
65368	2MK3	286.4	0.035
65368	K2	79.6	0.086
65368	MS4	129	0.013
65369	M2	55.4	0.92
65369	S2	79.2	0.213
65369	N2	41.2	0.226
65369	K1	57.3	0.437
65369	M4	318.5	0.004
65369	O1	54.6	0.24
65369	M6	323	0.012
65369	MK3	239.7	0.024
65369	S4	255.6	0.004
65369	MN4	334	0.009
65369	S6	118	0.003
65369	2N2	336.3	0.029
65369	OO1	316.7	0.028
65369	M1	72.2	0.03
65369	J1	106.1	0.034
65369	Q1	44	0.041
65369	2Q1	356.7	0.008
65369	P1	80	0.074
65369	2SM2	290	0.009
65369	M3	234	0.003
65369	L2	63	0.07
65369	2MK3	286.2	0.036
65369	K2	80.7	0.087
65369	M8	319.5	0.001
65369	MS4	129.7	0.012
65370	M2	55.5	0.925
65370	S2	79.2	0.213
65370	N2	41.2	0.227
65370	K1	57.7	0.441
65370	M4	322.3	0.006
65370	O1	54.7	0.242
65370	M6	324.7	0.012
65370	MK3	239.8	0.025
65370	S4	255.4	0.004
65370	MN4	325.5	0.008
65370	S6	120.6	0.003
65370	2N2	336.2	0.029
65370	OO1	317.7	0.028
65370	M1	74.4	0.029
65370	J1	105.1	0.033
65370	Q1	45.6	0.042
65370	2Q1	354.8	0.007
65370	P1	79.8	0.076
65370	2SM2	294.2	0.009
65370	M3	241	0.003
65370	L2	62.8	0.07
65370	2MK3	285.9	0.037
65370	K2	82	0.089
65370	M8	326.6	0.001
65370	MS4	128.5	0.01
65371	M2	55.6	0.929
65371	S2	79.3	0.211
65371	N2	41.2	0.228
65371	K1	58	0.444
65371	M4	323.8	0.007
65371	O1	54.9	0.244
65371	M6	325.5	0.012
65371	MK3	239.2	0.027
65371	S4	257.5	0.004
65371	MN4	319.7	0.008
65371	S6	112.5	0.003
65371	2N2	338.1	0.029
65371	OO1	317.1	0.028
65371	M1	75.9	0.028
65371	J1	103.5	0.033
65371	Q1	46.3	0.042
65371	2Q1	356.8	0.007
65371	P1	79.7	0.078
65371	2SM2	298.3	0.008
65371	M3	254.9	0.003
65371	L2	62.7	0.07
65371	2MK3	285.1	0.037
65371	K2	84.1	0.09
65371	M8	329.6	0.002
65371	MS4	127.3	0.009
65372	M2	55.6	0.933
65372	S2	79.3	0.21
65372	N2	41.3	0.229
65372	K1	58.5	0.447
65372	M4	327.2	0.008
65372	O1	55	0.245
65372	M6	326.4	0.012
65372	MK3	238.5	0.028
65372	S4	265.2	0.004
65372	MN4	310.5	0.008
65372	S6	117.6	0.003
65372	2N2	339	0.029
65372	OO1	315.6	0.028
65372	M1	77.2	0.028
65372	J1	102.4	0.032
65372	Q1	47.7	0.043
65372	2Q1	357.3	0.007
65372	P1	79	0.081
65372	2SM2	303.5	0.009
65372	M3	260.5	0.004
65372	L2	62.8	0.07
65372	2MK3	284.4	0.038
65372	K2	85.1	0.091
65372	M8	338.3	0.002
65372	MS4	125.1	0.008
65373	M2	55.6	0.936
65373	S2	79.4	0.209
65373	N2	41.3	0.23
65373	K1	58.8	0.449
65373	M4	330	0.009
65373	O1	55.1	0.246
65373	M6	328.5	0.012
65373	MK3	236.5	0.03
65373	S4	261.3	0.003
65373	MN4	304.8	0.008
65373	S6	121	0.003
65373	2N2	340.2	0.028
65373	OO1	315.1	0.029
65373	M1	78.5	0.027
65373	J1	100.8	0.032
65373	Q1	48.7	0.043
65373	2Q1	358.9	0.007
65373	P1	79	0.083
65373	2SM2	309.6	0.008
65373	M3	269.9	0.004
65373	L2	63.3	0.07
65373	2MK3	283	0.039
65373	K2	86	0.092
65373	M8	345.6	0.002
65373	MS4	123	0.008
65374	M2	55.7	0.938
65374	S2	79.4	0.208
65374	N2	41.2	0.231
65374	K1	59.1	0.449
65374	M4	331.5	0.011
65374	O1	55.2	0.248
65374	M6	332.5	0.012
65374	MK3	235.5	0.031
65374	S4	273.3	0.004
65374	MN4	299.3	0.008
65374	S6	121.1	0.003
65374	2N2	341.9	0.028
65374	OO1	313.8	0.029
65374	M1	79.9	0.027
65374	J1	99.9	0.032
65374	Q1	49.1	0.043
65374	2Q1	4.8	0.007
65374	P1	79.4	0.086
65374	2SM2	310	0.009
65374	M3	263.6	0.005
65374	L2	63.6	0.07
65374	2MK3	282.6	0.039
65374	K2	86.6	0.093
65374	M8	352.9	0.003
65374	MS4	119.5	0.008
65375	M2	55.7	0.94
65375	S2	79.7	0.207
65375	N2	41.2	0.231
65375	K1	59.4	0.45
65375	M4	334.5	0.012
65375	O1	55.5	0.249
65375	M6	334	0.011
65375	MK3	234.1	0.033
65375	S4	277.7	0.004
65375	MN4	295.3	0.008
65375	S6	120.4	0.003
65375	2N2	343.7	0.028
65375	OO1	312.5	0.029
65375	M1	82	0.026
65375	J1	98.1	0.032
65375	Q1	50.6	0.044
65375	2Q1	12.5	0.007
65375	P1	79.8	0.088
65375	2SM2	312.7	0.009
65375	M3	268.9	0.005
65375	L2	63.5	0.07
65375	2MK3	281.4	0.041
65375	K2	86.4	0.094
65375	M8	350.1	0.003
65375	MS4	114	0.008
65376	M2	55.7	0.941
65376	S2	79.6	0.207
65376	N2	41.1	0.231
65376	K1	59.8	0.45
65376	M4	336.3	0.013
65376	O1	55.6	0.249
65376	M6	335.6	0.011
65376	MK3	232.6	0.035
65376	S4	283.2	0.004
65376	MN4	290.9	0.008
65376	S6	140	0.002
65376	2N2	346.3	0.027
65376	OO1	311.8	0.03
65376	M1	82.8	0.027
65376	J1	97.6	0.031
65376	Q1	51.3	0.045
65376	2Q1	20.7	0.007
65376	P1	80.1	0.092
65376	2SM2	315.9	0.009
65376	M3	267.7	0.006
65376	L2	63.8	0.069
65376	2MK3	279.8	0.042
65376	K2	86.1	0.093
65376	M8	357.7	0.004
65376	MS4	111.4	0.008
65377	M2	55.8	0.942
65377	S2	79.6	0.206
65377	N2	41.1	0.231
65377	K1	60.4	0.449
65377	M4	339	0.015
65377	O1	55.6	0.25
65377	M6	337.2	0.011
65377	MK3	231.6	0.036
65377	S4	283.7	0.003
65377	MN4	289.8	0.007
65377	S6	154.9	0.001
65377	2N2	350	0.027
65377	OO1	311.2	0.032
65377	M1	84.7	0.027
65377	J1	96.3	0.031
65377	Q1	51.7	0.045
65377	2Q1	30.8	0.007
65377	P1	80.2	0.097
65377	2SM2	314.9	0.009
65377	M3	268.5	0.006
65377	L2	63.9	0.069
65377	2MK3	278.8	0.043
65377	K2	85.8	0.094
65377	M8	357.9	0.004
65377	MS4	106.7	0.008
65378	M2	55.8	0.943
65378	S2	79.7	0.206
65378	N2	40.8	0.231
65378	K1	61	0.449
65378	M4	341.4	0.016
65378	O1	55.6	0.251
65378	M6	340	0.01
65378	MK3	230.5	0.038
65378	S4	283	0.003
65378	MN4	289.7	0.007
65378	2N2	353.5	0.026
65378	OO1	309.1	0.033
65378	M1	85.4	0.028
65378	J1	94.9	0.03
65378	Q1	52.5	0.045
65378	2Q1	40.1	0.008
65378	P1	79.8	0.101
65378	2SM2	316.7	0.009
65378	M3	268	0.008
65378	L2	63.9	0.069
65378	2MK3	277.4	0.045
65378	K2	85.3	0.095
65378	M8	5.3	0.005
65378	MS4	102.7	0.009
65379	M2	55.8	0.944
65379	S2	79.5	0.206
65379	N2	40.7	0.231
65379	K1	61.4	0.449
65379	M4	343	0.017
65379	O1	55.5	0.252
65379	M6	343.5	0.011
65379	MK3	228.7	0.04
65379	S4	277.8	0.003
65379	MN4	287.2	0.008
65379	2N2	357.7	0.025
65379	OO1	309.5	0.034
65379	M1	86.9	0.028
65379	J1	92.7	0.029
65379	Q1	54	0.046
65379	2Q1	47.9	0.009
65379	P1	80	0.105
65379	2SM2	317.6	0.009
65379	M3	269	0.009
65379	L2	63.7	0.068
65379	2MK3	277.1	0.046
65379	K2	84.3	0.094
65379	M8	8.3	0.005
65379	MS4	99.3	0.009
65380	M2	55.9	0.945
65380	S2	79.4	0.204
65380	N2	40.4	0.23
65380	K1	62.1	0.449
65380	M4	343.8	0.018
65380	O1	55.6	0.252
65380	M6	346.6	0.011
65380	MK3	227.2	0.042
65380	S4	269.1	0.002
65380	MN4	288.6	0.008
65380	2N2	1.7	0.025
65380	OO1	309	0.036
65380	M1	88.3	0.029
65380	J1	91.8	0.027
65380	Q1	55.8	0.047
65380	2Q1	55.8	0.009
65380	P1	79.3	0.109
65380	2SM2	318.2	0.009
65380	M3	268.8	0.01
65380	L2	63.5	0.068
65380	2MK3	276.6	0.049
65380	K2	84.5	0.094
65380	M8	7.1	0.006
65380	MS4	95.1	0.01
65381	M2	55.9	0.946
65381	S2	79.4	0.202
65381	N2	40.2	0.23
65381	K1	62.7	0.451
65381	M4	345.2	0.019
65381	O1	55.6	0.252
65381	M6	348.1	0.01
65381	MK3	225.6	0.044
65381	S4	263.2	0.002
65381	MN4	288.4	0.008
65381	S6	317.7	0.002
65381	2N2	8	0.024
65381	OO1	308.2	0.037
65381	M1	89.2	0.03
65381	J1	88.7	0.027
65381	Q1	57.2	0.048
65381	2Q1	62.5	0.01
65381	P1	78.6	0.114
65381	2SM2	319.8	0.009
65381	M3	269.7	0.011
65381	L2	63.5	0.067
65381	2MK3	276.8	0.051
65381	K2	85.1	0.094
65381	M8	10	0.006
65381	MS4	92.5	0.01
65382	M2	56	0.946
65382	S2	79.3	0.2
65382	N2	40	0.23
65382	K1	63.5	0.452
65382	M4	347.2	0.02
65382	O1	55.5	0.252
65382	M6	350.2	0.01
65382	MK3	224.2	0.046
65382	S4	257.6	0.002
65382	MN4	286.3	0.009
65382	S6	314.3	0.002
65382	2N2	13.1	0.023
65382	OO1	307.2	0.038
65382	M1	89.9	0.031
65382	J1	87.6	0.025
65382	Q1	58.3	0.049
65382	2Q1	69.2	0.011
65382	P1	77.9	0.119
65382	2SM2	324.5	0.008
65382	M3	270.9	0.012
65382	L2	63.3	0.067
65382	2MK3	276.3	0.054
65382	K2	85.9	0.094
65382	M8	10.1	0.007
65382	MS4	86.9	0.011
65383	M2	56.1	0.947
65383	S2	79.1	0.198
65383	N2	39.8	0.23
65383	K1	64.1	0.456
65383	M4	347.9	0.021
65383	O1	55.5	0.252
65383	M6	352.1	0.01
65383	MK3	224	0.048
65383	S4	258.8	0.001
65383	MN4	287	0.01
65383	S6	317.8	0.002
65383	2N2	18.5	0.022
65383	OO1	306.4	0.04
65383	M1	90.6	0.032
65383	J1	84.1	0.024
65383	Q1	58.8	0.05
65383	2Q1	76.6	0.013
65383	P1	76.5	0.123
65383	2SM2	329.9	0.007
65383	M3	270.4	0.012
65383	L2	63.5	0.067
65383	2MK3	276.6	0.057
65383	K2	86.8	0.093
65383	M8	13.6	0.008
65383	MS4	83.5	0.012
65384	M2	56.1	0.948
65384	S2	78.6	0.194
65384	N2	39.6	0.229
65384	K1	64.6	0.459
65384	M4	348.8	0.021
65384	O1	55.4	0.252
65384	M6	352.3	0.01
65384	MK3	224.2	0.051
65384	S4	221.2	0.001
65384	MN4	286	0.01
65384	S6	306.3	0.001
65384	2N2	26.2	0.021
65384	OO1	306	0.041
65384	M1	91	0.033
65384	J1	79.8	0.023
65384	Q1	59.6	0.051
65384	2Q1	81.7	0.015
65384	P1	75.1	0.127
65384	2SM2	338.7	0.006
65384	M3	267	0.013
65384	L2	63.9	0.066
65384	2MK3	276.1	0.061
65384	K2	89	0.092
65384	M8	14.5	0.009
65384	MS4	77.2	0.012
65385	M2	55.7	0.917
65385	S2	78.5	0.183
65385	N2	40.9	0.217
65385	K1	61.8	0.45
65385	M4	216.2	0.008
65385	O1	50.2	0.247
65385	M6	68.6	0.014
65385	MK3	216.4	0.089
65385	S4	281.6	0.002
65385	MN4	172.8	0.011
65385	S6	314.6	0.003
65385	2N2	35.9	0.012
65385	OO1	326.9	0.037
65385	M1	98.7	0.025
65385	J1	40.9	0.017
65385	Q1	54.4	0.047
65385	2Q1	71.6	0.013
65385	P1	73.6	0.116
65385	2SM2	12.7	0.008
65385	M3	217.4	0.022
65385	L2	68.2	0.074
65385	2MK3	260.4	0.078
65385	K2	86.2	0.108
65385	M8	24.8	0.014
65385	MS4	195.6	0.011
65386	M2	1.2	1.07
65386	S2	8.1	0.345
65386	N2	323.5	0.239
65386	K1	343.1	0.249
65386	M4	249.5	0.08
65386	O1	337	0.231
65386	M6	332.4	0.033
65386	MK3	224.6	0.177
65386	S4	294.3	0.01
65386	MN4	215.8	0.047
65386	S6	162.6	0.005
65386	2N2	241.9	0.102
65386	OO1	233.5	0.017
65386	M1	182.7	0.066
65386	J1	334.2	0.064
65386	Q1	43.7	0.018
65386	2Q1	223.4	0.059
65386	P1	6.5	0.19
65386	2SM2	298.2	0.01
65386	M3	154.4	0.057
65386	L2	39.5	0.048
65386	2MK3	233.7	0.155
65386	K2	334.9	0.178
65386	M8	106.3	0.005
65386	MS4	287.4	0.015
65387	M2	1.2	1.082
65387	S2	8.5	0.348
65387	N2	323.6	0.243
65387	K1	343.3	0.251
65387	M4	249.6	0.077
65387	O1	337.2	0.235
65387	M6	331.3	0.033
65387	MK3	225.4	0.177
65387	S4	296.2	0.01
65387	MN4	215.8	0.045
65387	S6	170.3	0.005
65387	2N2	242.3	0.104
65387	OO1	233.6	0.019
65387	M1	182.1	0.066
65387	J1	334.8	0.065
65387	Q1	39.5	0.019
65387	2Q1	223.6	0.059
65387	P1	6.8	0.194
65387	2SM2	295.6	0.01
65387	M3	155.7	0.059
65387	L2	40.4	0.05
65387	2MK3	233.9	0.157
65387	K2	335.5	0.181
65387	M8	116.3	0.004
65387	MS4	289.2	0.014
65388	M2	1.1	1.094
65388	S2	8.5	0.351
65388	N2	323.6	0.248
65388	K1	343.2	0.251
65388	M4	250.2	0.074
65388	O1	337.4	0.239
65388	M6	330.7	0.033
65388	MK3	226.2	0.177
65388	S4	301.1	0.01
65388	MN4	216	0.043
65388	S6	163.5	0.004
65388	2N2	242	0.106
65388	OO1	233.2	0.022
65388	M1	182.1	0.065
65388	J1	335.1	0.065
65388	Q1	38.3	0.019
65388	2Q1	223.2	0.059
65388	P1	7.2	0.197
65388	2SM2	292.4	0.009
65388	M3	156.4	0.059
65388	L2	41.5	0.051
65388	2MK3	234.2	0.16
65388	K2	335.4	0.184
65388	M8	125.4	0.003
65388	MS4	293.3	0.014
65389	M2	1.2	1.105
65389	S2	8.5	0.355
65389	N2	323.7	0.252
65389	K1	343.2	0.254
65389	M4	250.7	0.071
65389	O1	337.8	0.242
65389	M6	330.5	0.033
65389	MK3	226.8	0.178
65389	S4	299.9	0.01
65389	MN4	217.5	0.042
65389	S6	161.5	0.004
65389	2N2	242.2	0.108
65389	OO1	232.4	0.024
65389	M1	181.9	0.065
65389	J1	336	0.067
65389	Q1	38.6	0.019
65389	2Q1	223.5	0.059
65389	P1	7.2	0.199
65389	2SM2	290.3	0.009
65389	M3	157	0.06
65389	L2	42	0.053
65389	2MK3	234.6	0.162
65389	K2	335	0.187
65389	M8	157.5	0.002
65389	MS4	299.5	0.014
65390	M2	1.2	1.115
65390	S2	8.5	0.359
65390	N2	323.7	0.256
65390	K1	343	0.255
65390	M4	252	0.068
65390	O1	338.3	0.245
65390	M6	330.9	0.033
65390	MK3	227.7	0.178
65390	S4	301.4	0.011
65390	MN4	219.9	0.04
65390	S6	152.9	0.005
65390	2N2	242.3	0.11
65390	OO1	232	0.025
65390	M1	181.4	0.066
65390	J1	336.9	0.067
65390	Q1	37.2	0.019
65390	2Q1	223.5	0.059
65390	P1	7.6	0.201
65390	2SM2	288.5	0.008
65390	M3	157.5	0.062
65390	L2	42.7	0.055
65390	2MK3	235.1	0.163
65390	K2	334.6	0.19
65390	M8	197.9	0.003
65390	MS4	304.2	0.014
65391	M2	1.2	1.125
65391	S2	8.5	0.36
65391	N2	323.6	0.26
65391	K1	342.6	0.257
65391	M4	253.4	0.065
65391	O1	338.8	0.248
65391	M6	331.5	0.033
65391	MK3	228.7	0.179
65391	S4	299.7	0.011
65391	MN4	223.3	0.039
65391	S6	149.1	0.004
65391	2N2	242.4	0.113
65391	OO1	233.5	0.025
65391	M1	181.1	0.067
65391	J1	338.1	0.068
65391	Q1	35.8	0.019
65391	2Q1	224	0.06
65391	P1	7.9	0.202
65391	2SM2	287.9	0.008
65391	M3	157.3	0.064
65391	L2	42.6	0.057
65391	2MK3	235.7	0.165
65391	K2	334.8	0.193
65391	M8	219.9	0.004
65391	MS4	310.1	0.015
65392	M2	1.3	1.134
65392	S2	8.4	0.361
65392	N2	323.7	0.263
65392	K1	342.1	0.261
65392	M4	255.3	0.061
65392	O1	339.3	0.251
65392	M6	333	0.033
65392	MK3	229.7	0.179
65392	S4	294.3	0.011
65392	MN4	226.3	0.038
65392	S6	142.1	0.004
65392	2N2	242.8	0.115
65392	OO1	232	0.025
65392	M1	180.9	0.068
65392	J1	338.5	0.067
65392	Q1	35.2	0.019
65392	2Q1	224.4	0.061
65392	P1	8	0.202
65392	2SM2	287.7	0.008
65392	M3	157.4	0.065
65392	L2	42.5	0.059
65392	2MK3	236.3	0.165
65392	K2	335	0.194
65392	M8	235.9	0.005
65392	MS4	316.3	0.016
65393	M2	1.3	1.141
65393	S2	8.4	0.363
65393	N2	323.8	0.266
65393	K1	341.7	0.264
65393	M4	257.5	0.058
65393	O1	339.9	0.254
65393	M6	333.9	0.033
65393	MK3	230.7	0.179
65393	S4	292.7	0.012
65393	MN4	229.8	0.037
65393	S6	130.8	0.004
65393	2N2	243.5	0.117
65393	OO1	228.1	0.024
65393	M1	180.4	0.07
65393	J1	339.1	0.067
65393	Q1	37.1	0.019
65393	2Q1	225	0.063
65393	P1	8.1	0.201
65393	2SM2	283.2	0.008
65393	M3	157.9	0.067
65393	L2	42.7	0.06
65393	2MK3	237	0.167
65393	K2	335.5	0.197
65393	M8	244.2	0.006
65393	MS4	320.2	0.018
65394	M2	1.4	1.147
65394	S2	8.3	0.364
65394	N2	323.9	0.268
65394	K1	341.5	0.268
65394	M4	259.4	0.055
65394	O1	340.5	0.256
65394	M6	334.7	0.033
65394	MK3	231.4	0.18
65394	S4	287.1	0.013
65394	MN4	233.2	0.037
65394	S6	121.7	0.003
65394	2N2	243.8	0.118
65394	OO1	225.4	0.023
65394	M1	179.9	0.071
65394	J1	339.9	0.067
65394	Q1	39.7	0.019
65394	2Q1	224.9	0.064
65394	P1	8	0.201
65394	2SM2	279	0.008
65394	M3	158.3	0.068
65394	L2	43.2	0.062
65394	2MK3	237.5	0.168
65394	K2	335.6	0.199
65394	M8	255.9	0.006
65394	MS4	324.2	0.021
65395	M2	1.5	1.152
65395	S2	8.2	0.365
65395	N2	324.1	0.271
65395	K1	341.4	0.272
65395	M4	261.3	0.052
65395	O1	341.2	0.259
65395	M6	336.3	0.032
65395	MK3	232	0.18
65395	S4	284.5	0.013
65395	MN4	237.7	0.037
65395	S6	107.6	0.003
65395	2N2	244.2	0.118
65395	OO1	222.6	0.023
65395	M1	179.3	0.073
65395	J1	340.3	0.066
65395	Q1	40.9	0.018
65395	2Q1	225.7	0.065
65395	P1	7.6	0.2
65395	2SM2	278.1	0.007
65395	M3	158.4	0.07
65395	L2	43.9	0.063
65395	2MK3	238.2	0.169
65395	K2	335.9	0.2
65395	M8	262.1	0.007
65395	MS4	327.5	0.023
65396	M2	1.6	1.155
65396	S2	8.2	0.365
65396	N2	324.4	0.273
65396	K1	340.9	0.277
65396	M4	263.2	0.049
65396	O1	341.5	0.261
65396	M6	337.2	0.032
65396	MK3	232.5	0.18
65396	S4	280.1	0.014
65396	MN4	242	0.036
65396	S6	103.9	0.002
65396	2N2	245	0.119
65396	OO1	222.1	0.023
65396	M1	179.1	0.075
65396	J1	340.5	0.065
65396	Q1	42.7	0.018
65396	2Q1	225.6	0.067
65396	P1	7.8	0.197
65396	2SM2	265.8	0.007
65396	M3	158.7	0.071
65396	L2	44	0.066
65396	2MK3	238.8	0.17
65396	K2	336.1	0.201
65396	M8	268.9	0.007
65396	MS4	330.3	0.026
65397	M2	1.7	1.158
65397	S2	8.3	0.365
65397	N2	324.7	0.274
65397	K1	340.7	0.282
65397	M4	265.2	0.047
65397	O1	341.9	0.263
65397	M6	339.6	0.032
65397	MK3	233	0.18
65397	S4	280.7	0.014
65397	MN4	246.5	0.036
65397	S6	117.2	0.002
65397	2N2	245.9	0.119
65397	OO1	219.6	0.024
65397	M1	178.7	0.077
65397	J1	341.2	0.065
65397	Q1	41.8	0.018
65397	2Q1	225.5	0.068
65397	P1	7.5	0.194
65397	2SM2	254.1	0.006
65397	M3	158.7	0.073
65397	L2	44.6	0.067
65397	2MK3	239.3	0.171
65397	K2	336.2	0.203
65397	M8	274.3	0.007
65397	MS4	332.4	0.028
65398	M2	1.8	1.161
65398	S2	8.4	0.367
65398	N2	324.9	0.276
65398	K1	340.5	0.286
65398	M4	268.1	0.045
65398	O1	342.3	0.266
65398	M6	340.1	0.032
65398	MK3	233.2	0.18
65398	S4	277.9	0.015
65398	MN4	249.8	0.035
65398	2N2	246.8	0.119
65398	OO1	217.8	0.025
65398	M1	178.3	0.08
65398	J1	341.5	0.064
65398	Q1	41.6	0.017
65398	2Q1	225.8	0.07
65398	P1	7.5	0.191
65398	2SM2	235.6	0.007
65398	M3	158.8	0.074
65398	L2	45	0.069
65398	2MK3	239.8	0.172
65398	K2	336	0.206
65398	M8	278.8	0.007
65398	MS4	333.8	0.03
65399	M2	1.9	1.162
65399	S2	8.5	0.37
65399	N2	325.3	0.277
65399	K1	340.1	0.291
65399	M4	270.3	0.043
65399	O1	342.6	0.268
65399	M6	342.9	0.032
65399	MK3	233.4	0.18
65399	S4	273.3	0.016
65399	MN4	253.4	0.034
65399	S6	128	0.002
65399	2N2	248	0.119
65399	OO1	217.7	0.026
65399	M1	178	0.082
65399	J1	341.8	0.063
65399	Q1	40.5	0.017
65399	2Q1	226.5	0.071
65399	P1	7.5	0.187
65399	2SM2	220.6	0.008
65399	M3	159.1	0.076
65399	L2	46.1	0.071
65399	2MK3	240.1	0.174
65399	K2	335.6	0.208
65399	M8	286.5	0.007
65399	MS4	333	0.032
65400	M2	2.1	1.164
65400	S2	8.5	0.373
65400	N2	325.7	0.279
65400	K1	339.7	0.296
65400	M4	273.5	0.042
65400	O1	342.9	0.27
65400	M6	345.5	0.031
65400	MK3	233.5	0.181
65400	S4	270.3	0.015
65400	MN4	255.7	0.035
65400	S6	145.4	0.002
65400	2N2	249.2	0.119
65400	OO1	215.7	0.027
65400	M1	178.1	0.084
65400	J1	341.8	0.063
65400	Q1	37.3	0.017
65400	2Q1	226.6	0.072
65400	P1	7.6	0.184
65400	2SM2	214.1	0.009
65400	M3	158.8	0.077
65400	L2	47	0.073
65400	2MK3	240.4	0.176
65400	K2	335	0.211
65400	M8	294.8	0.006
65400	MS4	331.8	0.034
65401	M2	2.3	1.168
65401	S2	8.4	0.376
65401	N2	326	0.28
65401	K1	339.2	0.302
65401	M4	277	0.041
65401	O1	343	0.272
65401	M6	348.2	0.032
65401	MK3	233.9	0.183
65401	S4	266.5	0.016
65401	MN4	257.6	0.035
65401	S6	146.2	0.003
65401	2N2	250.3	0.119
65401	OO1	215.1	0.029
65401	M1	178	0.087
65401	J1	342	0.062
65401	Q1	33.7	0.016
65401	2Q1	227.5	0.074
65401	P1	7.7	0.179
65401	2SM2	210.4	0.01
65401	M3	158.9	0.079
65401	L2	48.2	0.075
65401	2MK3	240.8	0.179
65401	K2	334.2	0.214
65401	M8	305.3	0.006
65401	MS4	330.9	0.036
65402	M2	2.5	1.172
65402	S2	8.3	0.379
65402	N2	326.6	0.282
65402	K1	339.2	0.309
65402	M4	280.1	0.04
65402	O1	343.2	0.276
65402	M6	351.7	0.032
65402	MK3	234.4	0.185
65402	S4	258.4	0.016
65402	MN4	258	0.035
65402	S6	146.8	0.003
65402	2N2	251.3	0.118
65402	OO1	212.4	0.028
65402	M1	177.9	0.088
65402	J1	342.2	0.06
65402	Q1	31	0.016
65402	2Q1	228.4	0.076
65402	P1	7.4	0.176
65402	2SM2	210.8	0.012
65402	M3	158.7	0.081
65402	L2	48.7	0.076
65402	2MK3	241.3	0.183
65402	K2	333.4	0.216
65402	M8	311.6	0.007
65402	MS4	329.7	0.038
65403	M2	2.8	1.175
65403	S2	8.4	0.381
65403	N2	327.3	0.284
65403	K1	338.8	0.319
65403	M4	282	0.04
65403	O1	343.2	0.278
65403	M6	355.9	0.031
65403	MK3	234.4	0.19
65403	S4	255.6	0.015
65403	MN4	257.8	0.034
65403	S6	142.4	0.004
65403	2N2	251.8	0.117
65403	OO1	211.5	0.029
65403	M1	177.6	0.091
65403	J1	340.8	0.059
65403	Q1	30.9	0.017
65403	2Q1	229.6	0.077
65403	P1	7	0.169
65403	2SM2	208.5	0.012
65403	M3	158.2	0.084
65403	L2	49.3	0.078
65403	2MK3	241.6	0.188
65403	K2	332.8	0.218
65403	M8	322.9	0.007
65403	MS4	325.9	0.039
65404	M2	108.9	1.137
65404	S2	133.1	0.244
65404	N2	92.1	0.22
65404	K1	98	0.912
65404	M4	71	0.053
65404	O1	91.3	0.439
65404	M6	252.2	0.03
65404	MK3	245.5	0.091
65404	S4	124.9	0.039
65404	MN4	56.1	0.023
65404	NU2	51.2	0.058
65404	S6	114.9	0.009
65404	MU2	337.1	0.04
65404	2N2	95.8	0.036
65404	OO1	101.5	0.151
65404	LDA2	71.6	0.036
65404	M1	145.1	0.079
65404	J1	159.4	0.053
65404	RHO1	275.5	0.053
65404	Q1	87.6	0.1
65404	2Q1	61.1	0.039
65404	P1	110.9	0.243
65404	2SM2	330.5	0.014
65404	M3	16.1	0.061
65404	L2	141.6	0.071
65404	2MK3	264.1	0.063
65404	K2	108.4	0.045
65404	M8	287.3	0.017
65404	MS4	116.9	0.042
65405	M2	112.1	1.123
65405	S2	133	0.24
65405	N2	96.7	0.19
65405	K1	101.6	0.95
65405	M4	60.6	0.08
65405	O1	98.6	0.413
65405	M6	266.5	0.045
65405	MK3	277.1	0.104
65405	S4	129.3	0.026
65405	MN4	21.5	0.037
65405	NU2	43.4	0.067
65405	S6	80.6	0.013
65405	MU2	306.3	0.057
65405	2N2	169.6	0.021
65405	OO1	112.6	0.141
65405	LDA2	82	0.053
65405	M1	180	0.12
65405	J1	189.8	0.037
65405	RHO1	279.7	0.067
65405	Q1	108	0.112
65405	2Q1	84.9	0.02
65405	P1	111.3	0.219
65405	2SM2	13.7	0.029
65405	M3	356.3	0.077
65405	L2	149.6	0.098
65405	2MK3	305.6	0.1
65405	K2	98.3	0.044
65405	M8	344.3	0.02
65405	MS4	115.7	0.072
65406	M2	109.7	1.054
65406	S2	127.1	0.208
65406	N2	101	0.142
65406	K1	103.3	0.925
65406	M4	33.4	0.099
65406	O1	96.2	0.358
65406	M6	295.2	0.064
65406	MK3	309.5	0.156
65406	S4	130.4	0.012
65406	MN4	356.9	0.035
65406	NU2	59.7	0.086
65406	S6	121.2	0.01
65406	MU2	284.2	0.082
65406	2N2	237.6	0.048
65406	OO1	123.8	0.133
65406	LDA2	84.2	0.07
65406	M1	201.9	0.147
65406	J1	272.7	0.027
65406	RHO1	304.5	0.065
65406	Q1	124.7	0.113
65406	2Q1	165.3	0.016
65406	P1	105.2	0.195
65406	2SM2	17	0.054
65406	M3	348	0.091
65406	L2	157.7	0.115
65406	2MK3	328.8	0.181
65406	K2	130.2	0.035
65406	M8	333.4	0.021
65406	MS4	106.8	0.063
65407	M2	94.7	0.416
65407	S2	96.7	0.1
65407	N2	52.4	0.092
65407	K1	91.3	0.265
65407	M4	175.3	0.03
65407	O1	71	0.179
65407	M6	359.2	0.011
65407	MK3	202.1	0.054
65407	S4	338.2	0.014
65407	MN4	159.1	0.014
65407	S6	42.2	0.003
65407	2N2	319.6	0.02
65407	OO1	193.2	0.102
65407	M1	343.2	0.032
65407	J1	48.6	0.029
65407	Q1	76.6	0.013
65407	2Q1	244.9	0.033
65407	P1	70	0.14
65407	2SM2	301	0.012
65407	M3	114.8	0.013
65407	L2	212.2	0.028
65407	2MK3	163.4	0.038
65407	M8	72	0.003
65407	MS4	174.5	0.028
65408	M2	94.7	0.463
65408	S2	97.3	0.11
65408	N2	64.9	0.11
65408	K1	92.2	0.298
65408	M4	203.5	0.035
65408	O1	59	0.222
65408	M6	331.7	0.02
65408	MK3	191.1	0.055
65408	S4	225.7	0.003
65408	MN4	128.3	0.012
65408	S6	122.2	0.006
65408	2N2	308	0.017
65408	OO1	192	0.072
65408	M1	316.5	0.011
65408	J1	75.1	0.044
65408	Q1	60.2	0.027
65408	2Q1	228.8	0.044
65408	P1	64.2	0.139
65408	2SM2	226.5	0.02
65408	M3	132.8	0.022
65408	L2	211.2	0.02
65408	2MK3	158.7	0.053
65408	M8	33	0.005
65408	MS4	206.9	0.014
65409	M2	86.5	0.503
65409	S2	118.6	0.093
65409	N2	54.2	0.087
65409	K1	99.1	0.302
65409	M4	225.9	0.027
65409	O1	48.5	0.261
65409	M6	320.6	0.019
65409	MK3	148.6	0.045
65409	S4	176	0.011
65409	MN4	182.3	0.016
65409	S6	98	0.002
65409	2N2	314.6	0.036
65409	OO1	153.8	0.042
65409	M1	245.8	0.009
65409	J1	107	0.029
65409	Q1	32.5	0.048
65409	2Q1	215.1	0.031
65409	P1	31.9	0.091
65409	2SM2	169.9	0.031
65409	M3	173.5	0.013
65409	L2	121.3	0.018
65409	2MK3	122	0.058
65409	M8	32.6	0.007
65409	MS4	210	0.034
65410	M2	85.3	0.741
65410	S2	117.1	0.204
65410	N2	77.6	0.156
65410	K1	79	0.385
65410	M4	95.7	0.022
65410	O1	78.5	0.221
65410	M6	259.7	0.004
65410	MK3	79.5	0.041
65410	S4	208.5	0.008
65410	MN4	80.1	0.01
65410	S6	60.5	0.003
65410	2N2	95.1	0.019
65410	OO1	282.1	0.035
65410	M1	129.7	0.03
65410	J1	101.6	0.042
65410	Q1	81	0.035
65410	2Q1	147.2	0.022
65410	P1	112.3	0.12
65410	2SM2	105.6	0.013
65410	M3	229.1	0.007
65410	L2	92	0.008
65410	2MK3	80.4	0.023
65410	K2	149.4	0.033
65410	M8	309.1	0.001
65410	MS4	163.9	0.016
65411	M2	72.7	0.768
65411	S2	88.8	0.207
65411	N2	65.6	0.185
65411	K1	74.4	0.338
65411	M4	56.1	0.025
65411	O1	71.5	0.19
65411	M6	91.4	0.006
65411	MK3	30.2	0.035
65411	S4	80.2	0.015
65411	MN4	60.5	0.021
65411	S6	345.7	0.006
65411	2N2	123.6	0.038
65411	OO1	226.2	0.053
65411	M1	141.7	0.02
65411	J1	102.1	0.058
65411	Q1	75.5	0.041
65411	2Q1	149.6	0.014
65411	P1	125.1	0.092
65411	2SM2	287.4	0.034
65411	M3	184.8	0.009
65411	L2	82.1	0.03
65411	2MK3	17.5	0.016
65411	K2	100	0.069
65411	M8	39.1	0.003
65411	MS4	80.5	0.033
65412	M2	61.9	0.731
65412	S2	88.7	0.145
65412	N2	53.4	0.231
65412	K1	85.8	0.257
65412	M4	121.6	0.015
65412	O1	72.3	0.146
65412	M6	308.5	0.007
65412	MK3	88.1	0.021
65412	S4	28	0.01
65412	MN4	2.4	0.009
65412	S6	23.2	0.008
65412	2N2	82.6	0.018
65412	OO1	301.6	0.028
65412	M1	45.8	0.014
65412	J1	91.8	0.088
65412	Q1	5.8	0.022
65412	2Q1	143.3	0.016
65412	P1	118.1	0.146
65412	2SM2	248.8	0.032
65412	M3	37	0.022
65412	L2	10.9	0.039
65412	2MK3	168	0.005
65412	K2	117	0.165
65412	M8	1.6	0.005
65412	MS4	79.4	0.019
65413	M2	83.4	0.74
65413	S2	93.9	0.198
65413	N2	58.6	0.202
65413	K1	91.5	0.499
65413	M4	138.2	0.079
65413	O1	76.6	0.207
65413	M6	340.7	0.028
65413	MK3	187.8	0.143
65413	S4	278.7	0.004
65413	MN4	112	0.042
65413	S6	114.1	0.004
65413	2N2	5.3	0.067
65413	OO1	72.6	0.033
65413	M1	108.9	0.065
65413	J1	118.5	0.058
65413	Q1	71.3	0.08
65413	2Q1	10.9	0.053
65413	P1	87.9	0.172
65413	2SM2	73.1	0.02
65413	M3	86.8	0.059
65413	L2	301.8	0.027
65413	2MK3	101.7	0.072
65413	K2	62.2	0.084
65413	M8	328.1	0.003
65413	MS4	121.7	0.056
65414	M2	96	1.075
65414	S2	109.2	0.305
65414	N2	72.8	0.245
65414	K1	118.8	0.784
65414	M4	264.2	0.036
65414	O1	102.1	0.432
65414	M6	205.2	0.025
65414	MK3	112.2	0.114
65414	S4	34.2	0.019
65414	MN4	321.4	0.003
65414	S6	70.5	0.02
65414	2N2	310.6	0.122
65414	OO1	160.8	0.036
65414	M1	20.9	0.085
65414	J1	99	0.092
65414	Q1	50.4	0.075
65414	2Q1	259.1	0.057
65414	P1	93.5	0.268
65414	2SM2	222	0.028
65414	M3	245.1	0.019
65414	L2	156.9	0.032
65414	2MK3	49.3	0.117
65414	K2	168.1	0.06
65414	M8	301	0.011
65414	MS4	322	0.059
65415	M2	96.9	1.066
65415	S2	110.9	0.298
65415	N2	72.3	0.232
65415	K1	121.6	0.803
65415	M4	257	0.051
65415	O1	101.8	0.461
65415	M6	197	0.033
65415	MK3	114.9	0.083
65415	S4	25.2	0.02
65415	MN4	230.4	0.014
65415	S6	94.9	0.02
65415	2N2	311.8	0.125
65415	OO1	184.5	0.042
65415	M1	16.4	0.09
65415	J1	98.9	0.09
65415	Q1	40.4	0.076
65415	2Q1	249.4	0.064
65415	P1	94.2	0.269
65415	2SM2	230	0.027
65415	M3	254.1	0.022
65415	L2	153	0.047
65415	2MK3	44.6	0.1
65415	K2	183.7	0.055
65415	M8	309.2	0.008
65415	MS4	317.9	0.06
65416	M2	76.3	1.433
65416	S2	95.8	0.368
65416	N2	45.4	0.339
65416	K1	77.3	0.893
65416	M4	206.5	0.031
65416	O1	58.1	0.481
65416	M6	136.7	0.019
65416	MK3	144.9	0.063
65416	S4	21.1	0.018
65416	MN4	132.6	0.039
65416	S6	115.6	0.014
65416	2N2	306	0.085
65416	OO1	113.3	0.042
65416	M1	35.5	0.023
65416	J1	105	0.079
65416	Q1	30.7	0.067
65416	2Q1	267.2	0.055
65416	P1	78.3	0.224
65416	2SM2	98.8	0.015
65416	M3	15.3	0.011
65416	L2	142.3	0.011
65416	2MK3	118.1	0.016
65416	K2	126.8	0.121
65416	M8	37.3	0.008
65416	MS4	114.3	0.033
65417	M2	84.4	1.588
65417	S2	99.7	0.447
65417	N2	50.1	0.323
65417	K1	86.3	1.097
65417	M4	197.4	0.083
65417	O1	53.6	0.664
65417	M6	184.3	0.039
65417	MK3	167.5	0.167
65417	S4	203.5	0.008
65417	MN4	186.9	0.051
65417	S6	290.6	0.014
65417	2N2	295.5	0.128
65417	OO1	173.9	0.072
65417	M1	6.4	0.018
65417	J1	64.9	0.108
65417	Q1	22	0.105
65417	2Q1	194	0.087
65417	P1	88	0.333
65417	2SM2	350.1	0.03
65417	M3	104.4	0.035
65417	L2	173.5	0.063
65417	2MK3	76.9	0.035
65417	K2	160.2	0.106
65417	M8	246.2	0.023
65417	MS4	209.6	0.069
65418	M2	86.5	1.591
65418	S2	97.7	0.442
65418	N2	51.2	0.309
65418	K1	90.9	1.105
65418	M4	204.9	0.092
65418	O1	57.6	0.678
65418	M6	184.4	0.041
65418	MK3	164.5	0.198
65418	S4	206.5	0.009
65418	MN4	189.5	0.063
65418	S6	234.2	0.011
65418	2N2	291	0.128
65418	OO1	181	0.109
65418	M1	324.7	0.045
65418	J1	59.3	0.116
65418	Q1	14.2	0.091
65418	2Q1	191.2	0.101
65418	P1	87.2	0.357
65418	2SM2	346	0.041
65418	M3	100.9	0.034
65418	L2	164.4	0.101
65418	2MK3	66.1	0.029
65418	K2	175	0.108
65418	M8	236.6	0.022
65418	MS4	222.1	0.068
65419	M2	85.1	1.757
65419	S2	103.4	0.421
65419	N2	54.8	0.382
65419	K1	92.1	1.131
65419	M4	172.8	0.084
65419	O1	72.7	0.594
65419	M6	184.4	0.036
65419	MK3	130.7	0.082
65419	S4	106.3	0.007
65419	MN4	149.4	0.042
65419	S6	97	0.005
65419	2N2	315.4	0.101
65419	OO1	181.7	0.062
65419	M1	2.2	0.053
65419	J1	82.5	0.078
65419	Q1	48.9	0.095
65419	2Q1	228.3	0.017
65419	P1	79.4	0.311
65419	2SM2	345.9	0.017
65419	M3	349.8	0.011
65419	L2	112.2	0.034
65419	2MK3	68.4	0.041
65419	K2	103.4	0.135
65419	M8	75	0.011
65419	MS4	207.2	0.067
65420	M2	88.5	1.846
65420	S2	104.2	0.442
65420	N2	56.6	0.397
65420	K1	97.2	1.273
65420	M4	202.8	0.03
65420	O1	76.8	0.701
65420	M6	22.5	0.01
65420	MK3	23.3	0.041
65420	S4	96.4	0.008
65420	MN4	192.6	0.013
65420	S6	57.6	0.011
65420	2N2	317.7	0.102
65420	OO1	188.8	0.049
65420	M1	317.3	0.046
65420	J1	93	0.082
65420	Q1	56.2	0.075
65420	2Q1	190.4	0.046
65420	P1	83.2	0.32
65420	2SM2	75.8	0.016
65420	M3	3.5	0.02
65420	L2	139.4	0.044
65420	2MK3	26.6	0.016
65420	K2	111.6	0.128
65420	M8	75.3	0.012
65420	MS4	171	0.038
65421	M2	89.4	1.838
65421	S2	105.7	0.47
65421	N2	57.6	0.397
65421	K1	98.7	1.325
65421	M4	17.4	0.029
65421	O1	76.3	0.747
65421	M6	347.1	0.029
65421	MK3	0.9	0.116
65421	S4	105.3	0.015
65421	MN4	4.7	0.008
65421	S6	71.6	0.005
65421	2N2	303.6	0.077
65421	OO1	137.8	0.092
65421	M1	279.7	0.049
65421	J1	86.3	0.102
65421	Q1	72	0.061
65421	2Q1	178.9	0.062
65421	P1	86.1	0.327
65421	2SM2	93.3	0.019
65421	M3	322.2	0.014
65421	L2	146.5	0.052
65421	2MK3	319.4	0.018
65421	K2	131.8	0.137
65421	M8	22	0.019
65421	MS4	115.2	0.03
65422	M2	48.6	2.1
65422	S2	61.1	0.488
65422	N2	13.8	0.419
65422	K1	63.5	0.864
65422	M4	33	0.074
65422	O1	56.1	0.417
65422	M6	353.7	0.09
65422	MK3	345.8	0.07
65422	S4	213.4	0.006
65422	MN4	328.4	0.039
65422	S6	0	0.007
65422	2N2	71.7	0.004
65422	OO1	96	0.117
65422	M1	82.9	0.034
65422	J1	90.1	0.05
65422	Q1	48.3	0.055
65422	2Q1	26.5	0.045
65422	P1	56	0.256
65422	2SM2	313.9	0.029
65422	M3	4.3	0.049
65422	L2	92.5	0.099
65422	2MK3	221.6	0.121
65422	K2	62.4	0.189
65422	M8	33.7	0.024
65422	MS4	339.6	0.07
65423	M2	48.5	2.14
65423	S2	61.3	0.495
65423	N2	13.3	0.429
65423	K1	63.2	0.887
65423	M4	30.9	0.061
65423	O1	56.8	0.424
65423	M6	352.6	0.091
65423	MK3	346.1	0.07
65423	S4	194.1	0.011
65423	MN4	319.6	0.035
65423	S6	357.4	0.007
65423	2N2	344.7	0.004
65423	OO1	99.3	0.121
65423	M1	91.8	0.037
65423	J1	90.4	0.051
65423	Q1	63.7	0.053
65423	2Q1	18.5	0.044
65423	P1	55.7	0.258
65423	2SM2	309.5	0.029
65423	M3	1.7	0.054
65423	L2	92.1	0.098
65423	2MK3	220.2	0.124
65423	K2	63.9	0.192
65423	M8	32	0.025
65423	MS4	333.6	0.074
65424	M2	48.4	2.126
65424	S2	60.8	0.488
65424	N2	13.4	0.421
65424	K1	63.4	0.887
65424	M4	32.3	0.055
65424	O1	56.4	0.419
65424	M6	352.7	0.092
65424	MK3	352.6	0.07
65424	S4	185.5	0.011
65424	MN4	317.4	0.032
65424	S6	3.5	0.006
65424	2N2	326	0.01
65424	OO1	99.7	0.124
65424	M1	89.8	0.04
65424	J1	89	0.059
65424	Q1	67.2	0.052
65424	2Q1	19.1	0.043
65424	P1	57.1	0.251
65424	2SM2	303.7	0.029
65424	M3	7	0.055
65424	L2	93.4	0.1
65424	2MK3	221.2	0.124
65424	K2	63	0.19
65424	M8	40.4	0.025
65424	MS4	332.7	0.069
65425	M2	58.8	1.095
65425	S2	64.5	0.208
65425	N2	28.6	0.223
65425	K1	68.2	0.595
65425	M4	65.2	0.139
65425	O1	72.4	0.125
65425	M6	151.5	0.047
65425	MK3	44.4	0.219
65425	S4	313.2	0.007
65425	MN4	45.3	0.05
65425	S6	245.6	0.004
65425	2N2	247.9	0.08
65425	OO1	115.6	0.161
65425	M1	249.8	0.02
65425	J1	70.1	0.042
65425	Q1	307	0.012
65425	2Q1	57.6	0.042
65425	P1	100.2	0.084
65425	2SM2	251.5	0.009
65425	M3	9	0.059
65425	L2	110.6	0.084
65425	2MK3	302.5	0.163
65425	K2	125.7	0.094
65425	M8	246.5	0.026
65425	MS4	80.3	0.094
65426	M2	56	1.116
65426	S2	70.2	0.206
65426	N2	22.3	0.221
65426	K1	61.3	0.532
65426	M4	63.2	0.163
65426	O1	81.4	0.077
65426	M6	150.4	0.059
65426	MK3	45.9	0.288
65426	S4	43.3	0.004
65426	MN4	34.1	0.057
65426	S6	254.2	0.003
65426	2N2	265	0.055
65426	OO1	94.7	0.175
65426	M1	34.3	0.018
65426	J1	54.6	0.06
65426	Q1	18	0.034
65426	2Q1	80.8	0.016
65426	P1	89.9	0.105
65426	2SM2	246.9	0.014
65426	M3	17.1	0.039
65426	L2	101.1	0.091
65426	2MK3	306.5	0.184
65426	K2	125.8	0.115
65426	M8	226.3	0.025
65426	MS4	77.5	0.097
65427	M2	57.1	1.139
65427	S2	66.9	0.203
65427	N2	20.7	0.221
65427	K1	60	0.518
65427	M4	64.5	0.152
65427	O1	112.6	0.063
65427	M6	153.7	0.072
65427	MK3	44.6	0.282
65427	S4	112	0.012
65427	MN4	31.8	0.045
65427	S6	244.3	0.006
65427	2N2	254.9	0.041
65427	OO1	97	0.164
65427	M1	4.5	0.034
65427	J1	29.4	0.066
65427	Q1	15.5	0.057
65427	2Q1	170.8	0.026
65427	P1	87.5	0.133
65427	2SM2	271.7	0.02
65427	M3	25.5	0.027
65427	L2	102.9	0.117
65427	2MK3	306.5	0.2
65427	K2	115.9	0.099
65427	M8	207	0.025
65427	MS4	82.5	0.077
65428	M2	89.4	1.947
65428	S2	106.5	0.506
65428	N2	61.3	0.414
65428	K1	96.9	1.239
65428	M4	109.4	0.059
65428	O1	85.1	0.596
65428	M6	325.3	0.018
65428	MK3	100.3	0.128
65428	S4	34.6	0.016
65428	MN4	115.7	0.05
65428	S6	209.6	0.011
65428	2N2	323.1	0.16
65428	OO1	187.2	0.097
65428	M1	357.9	0.099
65428	J1	75.4	0.084
65428	Q1	50.8	0.058
65428	2Q1	230.1	0.073
65428	P1	79.4	0.41
65428	2SM2	329.2	0.017
65428	M3	94.5	0.038
65428	L2	140.7	0.032
65428	2MK3	35.4	0.045
65428	K2	149.1	0.129
65428	M8	98.7	0.018
65428	MS4	147.7	0.05
65429	M2	89.1	2.215
65429	S2	100.4	0.595
65429	N2	56.7	0.494
65429	K1	93.1	1.454
65429	M4	113.1	0.009
65429	O1	73	0.803
65429	M6	279.5	0.029
65429	MK3	63.8	0.148
65429	S4	248.5	0.016
65429	MN4	354.5	0.032
65429	S6	54.4	0.009
65429	2N2	311	0.135
65429	OO1	144.1	0.115
65429	M1	202.6	0.007
65429	J1	101.6	0.108
65429	Q1	77.4	0.101
65429	2Q1	173.4	0.025
65429	P1	86	0.42
65429	2SM2	16	0.012
65429	M3	62	0.022
65429	L2	149.9	0.056
65429	2MK3	30.8	0.131
65429	K2	144.8	0.164
65429	M8	288.9	0.013
65429	MS4	149.1	0.016
65430	M2	88.7	2.211
65430	S2	99.7	0.587
65430	N2	57.4	0.493
65430	K1	92.6	1.456
65430	M4	334.4	0.006
65430	O1	71.5	0.805
65430	M6	264	0.032
65430	MK3	61.6	0.128
65430	S4	238.1	0.018
65430	MN4	351.9	0.03
65430	S6	52.3	0.011
65430	2N2	309.7	0.136
65430	OO1	146.8	0.112
65430	M1	205.4	0.017
65430	J1	101.5	0.105
65430	Q1	78.1	0.101
65430	2Q1	168.8	0.023
65430	P1	84.7	0.413
65430	2SM2	27.5	0.011
65430	M3	39	0.017
65430	L2	144	0.054
65430	2MK3	33.2	0.123
65430	K2	142.2	0.162
65430	M8	284.4	0.011
65430	MS4	153.8	0.003
65431	M2	97.6	0.734
65431	S2	98.4	0.215
65431	N2	70	0.182
65431	K1	123.8	0.685
65431	M4	9.4	0.079
65431	O1	105.7	0.415
65431	M6	152.2	0.02
65431	MK3	40.7	0.191
65431	S4	329.5	0.01
65431	MN4	352.8	0.042
65431	S6	240.5	0.005
65431	2N2	309.6	0.105
65431	OO1	168.1	0.075
65431	M1	9.4	0.068
65431	J1	142.3	0.079
65431	Q1	94.6	0.054
65431	2Q1	293.1	0.041
65431	P1	92.6	0.157
65431	2SM2	285.2	0.022
65431	M3	335.6	0.022
65431	L2	97.2	0.016
65431	2MK3	22.6	0.141
65431	K2	174.7	0.101
65431	M8	207.7	0.013
65431	MS4	167.7	0.041
65432	M2	90.2	0.769
65432	S2	113.3	0.218
65432	N2	59.1	0.175
65432	K1	105.6	0.55
65432	M4	23.6	0.106
65432	O1	89.2	0.346
65432	M6	190.4	0.041
65432	MK3	52.8	0.144
65432	S4	131.2	0.013
65432	MN4	9.3	0.035
65432	S6	108.4	0.007
65432	2N2	354	0.096
65432	OO1	55.2	0.088
65432	M1	78.8	0.065
65432	J1	120.7	0.076
65432	Q1	91.6	0.088
65432	2Q1	305.2	0.046
65432	P1	79	0.191
65432	2SM2	148.9	0.003
65432	M3	6.6	0.021
65432	L2	23.9	0.025
65432	2MK3	356.2	0.094
65432	K2	147.3	0.115
65432	M8	162.1	0.01
65432	MS4	59.6	0.035
65433	M2	85.7	0.752
65433	S2	118.3	0.203
65433	N2	61.2	0.185
65433	K1	95.5	0.492
65433	M4	9.4	0.103
65433	O1	79.5	0.284
65433	M6	192.8	0.046
65433	MK3	70	0.15
65433	S4	142.2	0.014
65433	MN4	353	0.051
65433	S6	113.3	0.007
65433	2N2	346.1	0.086
65433	OO1	61	0.075
65433	M1	84	0.102
65433	J1	121.5	0.074
65433	Q1	81	0.117
65433	2Q1	302.5	0.077
65433	P1	76.6	0.2
65433	2SM2	158.7	0.008
65433	M3	319.1	0.034
65433	L2	12	0.05
65433	2MK3	13.1	0.091
65433	K2	157.6	0.118
65433	M8	118.3	0.009
65433	MS4	3.4	0.026
65434	M2	72.5	1.307
65434	S2	89.1	0.3
65434	N2	42.6	0.282
65434	K1	86.4	0.669
65434	M4	14.3	0.066
65434	O1	86.8	0.325
65434	M6	46.6	0.023
65434	MK3	19	0.131
65434	S4	99.7	0.014
65434	MN4	353.8	0.038
65434	S6	13.7	0.007
65434	2N2	282	0.076
65434	OO1	94.5	0.055
65434	M1	14.9	0.021
65434	J1	72.9	0.065
65434	Q1	67.7	0.071
65434	2Q1	208.4	0.044
65434	P1	79.4	0.209
65434	2SM2	192.3	0.008
65434	M3	22.5	0.018
65434	L2	115.1	0.021
65434	2MK3	341.7	0.058
65434	K2	93.2	0.108
65434	M8	252.9	0.006
65434	MS4	95.4	0.059
65435	M2	73	1.76
65435	S2	85.9	0.405
65435	N2	42.8	0.38
65435	K1	82.9	0.926
65435	M4	25.2	0.054
65435	O1	77.5	0.449
65435	M6	40.4	0.02
65435	MK3	14	0.129
65435	S4	92.1	0.003
65435	MN4	351	0.022
65435	S6	330.7	0.005
65435	2N2	273.3	0.076
65435	OO1	125.6	0.071
65435	M1	213	0.031
65435	J1	73.6	0.043
65435	Q1	79.4	0.076
65435	2Q1	193.2	0.029
65435	P1	78.4	0.249
65435	2SM2	267.6	0.008
65435	M3	46.4	0.023
65435	L2	117.2	0.044
65435	2MK3	316.3	0.087
65435	K2	99.9	0.142
65435	MS4	79.6	0.063
65436	M2	72.3	1.866
65436	S2	82.8	0.423
65436	N2	42.4	0.395
65436	K1	79.7	0.998
65436	M4	12.7	0.051
65436	O1	71.5	0.484
65436	M6	36	0.019
65436	MK3	4.4	0.107
65436	S4	198.9	0.004
65436	MN4	285	0.005
65436	2N2	269.5	0.079
65436	OO1	136	0.102
65436	M1	210.7	0.056
65436	J1	68.6	0.036
65436	Q1	84.2	0.071
65436	2Q1	154.2	0.015
65436	P1	76.3	0.258
65436	2SM2	259.4	0.018
65436	M3	45.2	0.027
65436	L2	112.7	0.062
65436	2MK3	303.4	0.099
65436	K2	100.8	0.161
65436	M8	339.7	0.005
65436	MS4	63.2	0.044
65437	M2	71.5	1.35
65437	S2	87.5	0.332
65437	N2	39.4	0.295
65437	K1	74.3	0.783
65437	M4	173.7	0.079
65437	O1	48	0.433
65437	M6	178.9	0.01
65437	MK3	176.3	0.117
65437	S4	162.9	0.006
65437	MN4	145.8	0.041
65437	S6	307.6	0.002
65437	2N2	253.2	0.041
65437	OO1	137.7	0.05
65437	M1	207.1	0.027
65437	J1	60.8	0.04
65437	Q1	33	0.061
65437	2Q1	145.7	0.015
65437	P1	74	0.197
65437	2SM2	320.3	0.01
65437	M3	85.5	0.023
65437	L2	124.7	0.032
65437	2MK3	197.4	0.007
65437	K2	90	0.11
65437	M8	223.4	0.01
65437	MS4	170.1	0.028
65438	M2	72.2	1.776
65438	S2	85.9	0.427
65438	N2	39.4	0.38
65438	K1	74	1
65438	M4	167.3	0.122
65438	O1	49.2	0.552
65438	M6	136.9	0.008
65438	MK3	162.6	0.144
65438	S4	182.3	0.004
65438	MN4	133.6	0.06
65438	S6	281.3	0.004
65438	2N2	249.5	0.044
65438	OO1	145.5	0.076
65438	M1	213.7	0.056
65438	J1	52	0.039
65438	Q1	43.2	0.058
65438	2Q1	117.3	0.014
65438	P1	73.5	0.248
65438	2SM2	287.5	0.015
65438	M3	85	0.024
65438	L2	122.8	0.053
65438	2MK3	318.1	0.008
65438	K2	89.6	0.139
65438	M8	196.2	0.014
65438	MS4	160	0.038
65439	M2	71.9	1.851
65439	S2	85.9	0.456
65439	N2	39.1	0.401
65439	K1	72.3	1.052
65439	M4	162.1	0.145
65439	O1	48	0.553
65439	M6	169.4	0.007
65439	MK3	153	0.194
65439	S4	245.3	0.005
65439	MN4	124.8	0.077
65439	S6	309.6	0.003
65439	2N2	246.8	0.042
65439	OO1	140.4	0.078
65439	M1	196.9	0.063
65439	J1	47.9	0.036
65439	Q1	45.8	0.053
65439	2Q1	83.8	0.024
65439	P1	73.2	0.272
65439	2SM2	289.8	0.026
65439	M3	54.3	0.025
65439	L2	122.7	0.045
65439	2MK3	98.7	0.029
65439	K2	90.8	0.153
65439	M8	180.7	0.018
65439	MS4	156.8	0.05
65440	M2	92	0.549
65440	S2	82.6	0.125
65440	N2	65.3	0.093
65440	K1	80.8	0.329
65440	M4	116.4	0.067
65440	O1	37.5	0.173
65440	M6	107.6	0.025
65440	MK3	123.6	0.073
65440	S4	89.3	0.008
65440	MN4	130.7	0.029
65440	S6	119.5	0.006
65440	2N2	13	0.044
65440	OO1	352.4	0.038
65440	M1	132	0.015
65440	J1	92	0.03
65440	Q1	11.7	0.037
65440	2Q1	150.4	0.007
65440	P1	93.1	0.116
65440	2SM2	270.1	0.046
65440	M3	250.8	0.021
65440	L2	94.9	0.032
65440	2MK3	71.6	0.036
65440	K2	109.9	0.049
65440	M8	162.3	0.015
65440	MS4	131.4	0.007
65441	M2	90.7	0.549
65441	S2	83.9	0.13
65441	N2	62.5	0.097
65441	K1	80.8	0.331
65441	M4	118.1	0.061
65441	O1	38	0.175
65441	M6	103.3	0.026
65441	MK3	124.4	0.073
65441	S4	78.8	0.009
65441	MN4	133.3	0.028
65441	S6	127.3	0.006
65441	2N2	12.9	0.041
65441	OO1	359.4	0.034
65441	M1	130.6	0.014
65441	J1	90.4	0.032
65441	Q1	10.6	0.038
65441	2Q1	183.8	0.009
65441	P1	92.3	0.113
65441	2SM2	268.5	0.045
65441	M3	251.3	0.022
65441	L2	91.6	0.028
65441	2MK3	76.5	0.035
65441	K2	108.8	0.051
65441	M8	163.6	0.017
65441	MS4	116.1	0.007
65442	M2	89.4	0.548
65442	S2	84.9	0.131
65442	N2	60.5	0.102
65442	K1	81	0.332
65442	M4	119.2	0.055
65442	O1	38.4	0.176
65442	M6	99.4	0.026
65442	MK3	124.2	0.072
65442	S4	73.5	0.011
65442	MN4	135.7	0.026
65442	S6	129.7	0.006
65442	2N2	12.8	0.038
65442	OO1	7.2	0.031
65442	M1	132.7	0.014
65442	J1	91.1	0.034
65442	Q1	10.7	0.038
65442	2Q1	194.2	0.013
65442	P1	91.6	0.108
65442	2SM2	266.3	0.043
65442	M3	250.2	0.022
65442	L2	88.2	0.025
65442	2MK3	80.3	0.034
65442	K2	108.5	0.051
65442	M8	165	0.019
65442	MS4	103.3	0.006
65443	M2	88.1	0.549
65443	S2	85.7	0.133
65443	N2	58.8	0.106
65443	K1	81.2	0.333
65443	M4	120.3	0.05
65443	O1	39.1	0.178
65443	M6	93.8	0.025
65443	MK3	123.7	0.071
65443	S4	71.6	0.012
65443	MN4	135.3	0.025
65443	S6	130.1	0.006
65443	2N2	12	0.035
65443	OO1	18	0.027
65443	M1	137.7	0.014
65443	J1	91.8	0.036
65443	Q1	12.1	0.037
65443	2Q1	198	0.017
65443	P1	91	0.103
65443	2SM2	264.5	0.042
65443	M3	251.2	0.023
65443	L2	85.1	0.022
65443	2MK3	84.2	0.032
65443	K2	108	0.052
65443	M8	164.5	0.02
65443	MS4	85.1	0.006
65444	M2	86.8	0.551
65444	S2	87.1	0.133
65444	N2	58	0.11
65444	K1	81.1	0.332
65444	M4	121.3	0.046
65444	O1	39.9	0.179
65444	M6	87.8	0.025
65444	MK3	123.6	0.069
65444	S4	69	0.014
65444	MN4	135.3	0.023
65444	S6	137.8	0.006
65444	2N2	11	0.031
65444	OO1	31.8	0.025
65444	M1	140.1	0.016
65444	J1	93.4	0.037
65444	Q1	14.9	0.036
65444	2Q1	201.2	0.021
65444	P1	90.3	0.1
65444	2SM2	263.2	0.04
65444	M3	250.3	0.022
65444	L2	82.6	0.02
65444	2MK3	86.8	0.03
65444	K2	109.6	0.052
65444	M8	162.9	0.019
65444	MS4	71.3	0.007
65445	M2	85.6	0.554
65445	S2	87.9	0.132
65445	N2	57.1	0.114
65445	K1	81.1	0.332
65445	M4	121.7	0.043
65445	O1	40.7	0.179
65445	M6	81.4	0.024
65445	MK3	123.1	0.068
65445	S4	67	0.015
65445	MN4	134.7	0.021
65445	S6	136.1	0.005
65445	2N2	7.9	0.027
65445	OO1	44.6	0.025
65445	M1	142.2	0.017
65445	J1	95.3	0.038
65445	Q1	18.1	0.035
65445	2Q1	204	0.024
65445	P1	89.9	0.097
65445	2SM2	260.9	0.039
65445	M3	250.1	0.021
65445	L2	81.9	0.019
65445	2MK3	89.7	0.028
65445	K2	110.4	0.052
65445	M8	160.5	0.019
65445	MS4	59.1	0.007
65446	M2	84.5	0.557
65446	S2	88.2	0.132
65446	N2	56.4	0.117
65446	K1	81.1	0.331
65446	M4	122.9	0.039
65446	O1	41.7	0.18
65446	M6	74.7	0.024
65446	MK3	122.7	0.066
65446	S4	68.5	0.016
65446	MN4	132.7	0.02
65446	S6	139.2	0.005
65446	2N2	3.1	0.022
65446	OO1	54.8	0.025
65446	M1	141.8	0.018
65446	J1	96.4	0.04
65446	Q1	21.8	0.034
65446	2Q1	207	0.026
65446	P1	89.7	0.093
65446	2SM2	259.1	0.037
65446	M3	249.8	0.02
65446	L2	81.3	0.018
65446	2MK3	91.5	0.026
65446	K2	111.4	0.053
65446	M8	157	0.018
65446	MS4	48.1	0.007
65447	M2	83.5	0.562
65447	S2	88.6	0.13
65447	N2	55.9	0.121
65447	K1	80.9	0.33
65447	M4	123.6	0.037
65447	O1	42.4	0.18
65447	M6	67	0.024
65447	MK3	122.9	0.065
65447	S4	69.5	0.016
65447	MN4	129.1	0.019
65447	S6	136	0.004
65447	2N2	354.3	0.018
65447	OO1	65.3	0.025
65447	M1	142.8	0.02
65447	J1	97.1	0.041
65447	Q1	26.9	0.032
65447	2Q1	208.4	0.028
65447	P1	89.1	0.091
65447	2SM2	258.4	0.035
65447	M3	248.9	0.018
65447	L2	81.5	0.017
65447	2MK3	94.6	0.024
65447	K2	112.5	0.053
65447	M8	151.3	0.018
65447	MS4	36.5	0.008
65448	M2	82.7	0.567
65448	S2	88.9	0.129
65448	N2	55.7	0.123
65448	K1	80.7	0.328
65448	M4	124.9	0.035
65448	O1	43	0.18
65448	M6	61.1	0.024
65448	MK3	122.8	0.064
65448	S4	69.5	0.016
65448	MN4	123.3	0.018
65448	S6	136.2	0.004
65448	2N2	342.5	0.015
65448	OO1	76.3	0.027
65448	M1	145.5	0.02
65448	J1	98.5	0.041
65448	Q1	31.6	0.031
65448	2Q1	209.6	0.029
65448	P1	89.1	0.089
65448	2SM2	258	0.034
65448	M3	249.2	0.016
65448	L2	83.4	0.018
65448	2MK3	97.7	0.022
65448	K2	114.3	0.053
65448	M8	146.6	0.018
65448	MS4	34.1	0.009
65449	M2	82.1	0.573
65449	S2	89.3	0.127
65449	N2	55.4	0.126
65449	K1	80.3	0.326
65449	M4	125.6	0.033
65449	O1	43.6	0.18
65449	M6	54.6	0.024
65449	MK3	122.8	0.062
65449	S4	72.5	0.014
65449	MN4	118.7	0.017
65449	S6	123.1	0.004
65449	2N2	321	0.012
65449	OO1	82.8	0.027
65449	M1	146.2	0.02
65449	J1	99.5	0.042
65449	Q1	36	0.029
65449	2Q1	211.9	0.03
65449	P1	88.9	0.088
65449	2SM2	257.7	0.031
65449	M3	246.9	0.013
65449	L2	85.6	0.018
65449	2MK3	104.1	0.019
65449	K2	116.2	0.052
65449	M8	141.5	0.018
65449	MS4	29.7	0.009
65450	M2	81.6	0.579
65450	S2	89.3	0.126
65450	N2	55.3	0.129
65450	K1	79.9	0.324
65450	M4	125.8	0.033
65450	O1	44.4	0.179
65450	M6	49.4	0.025
65450	MK3	123.1	0.06
65450	S4	75.9	0.013
65450	MN4	116	0.017
65450	S6	124.4	0.004
65450	2N2	295.7	0.012
65450	OO1	90.7	0.027
65450	M1	148.4	0.021
65450	J1	100.4	0.042
65450	Q1	41	0.028
65450	2Q1	213.8	0.031
65450	P1	88.5	0.088
65450	2SM2	255.9	0.029
65450	M3	247.7	0.009
65450	L2	86.5	0.018
65450	2MK3	111.7	0.017
65450	K2	118.4	0.054
65450	M8	135.4	0.018
65450	MS4	22.9	0.01
65451	M2	81.3	0.586
65451	S2	89.2	0.125
65451	N2	55.4	0.131
65451	K1	79.4	0.323
65451	M4	125.5	0.032
65451	O1	44.9	0.179
65451	M6	45.4	0.025
65451	MK3	122.6	0.058
65451	S4	75.5	0.012
65451	MN4	113.7	0.017
65451	S6	122.1	0.004
65451	2N2	274.9	0.014
65451	OO1	97.7	0.028
65451	M1	151	0.021
65451	J1	101.6	0.041
65451	Q1	46.2	0.028
65451	2Q1	216.2	0.031
65451	P1	88.4	0.087
65451	2SM2	255	0.026
65451	M3	248.3	0.006
65451	L2	90.6	0.019
65451	2MK3	119.6	0.015
65451	K2	119.9	0.055
65451	M8	130.3	0.018
65451	MS4	20.8	0.011
65452	M2	81.1	0.592
65452	S2	89.1	0.124
65452	N2	55.3	0.132
65452	K1	78.7	0.321
65452	M4	126.1	0.031
65452	O1	45.7	0.178
65452	M6	41.3	0.026
65452	MK3	122.3	0.056
65452	S4	77.6	0.011
65452	MN4	110.6	0.017
65452	S6	122.9	0.005
65452	2N2	262.5	0.017
65452	OO1	104.8	0.027
65452	M1	153.4	0.02
65452	J1	101.7	0.04
65452	Q1	52.3	0.026
65452	2Q1	219.7	0.031
65452	P1	88.2	0.088
65452	2SM2	253.4	0.024
65452	M3	238.3	0.002
65452	L2	95	0.02
65452	2MK3	133	0.013
65452	K2	121.3	0.053
65452	M8	125.4	0.018
65452	MS4	17.2	0.011
65453	M2	81.1	0.599
65453	S2	88.8	0.124
65453	N2	55.1	0.134
65453	K1	78.1	0.32
65453	M4	126	0.031
65453	O1	46.7	0.177
65453	M6	38.4	0.027
65453	MK3	121.7	0.053
65453	S4	81.8	0.01
65453	MN4	111.1	0.017
65453	S6	130.3	0.005
65453	2N2	254	0.02
65453	OO1	111.1	0.027
65453	M1	157	0.02
65453	J1	101.5	0.038
65453	Q1	56.4	0.026
65453	2Q1	223	0.031
65453	P1	87.7	0.089
65453	2SM2	250.8	0.022
65453	M3	92	0.002
65453	L2	100.6	0.021
65453	2MK3	150.7	0.011
65453	K2	122.5	0.054
65453	M8	120.8	0.018
65453	MS4	14.4	0.012
65454	M2	81.2	0.606
65454	S2	88.9	0.123
65454	N2	55	0.135
65454	K1	77.4	0.319
65454	M4	126.4	0.031
65454	O1	47.9	0.176
65454	M6	34.9	0.027
65454	MK3	120.6	0.051
65454	S4	85.4	0.009
65454	MN4	110.8	0.017
65454	S6	140	0.004
65454	2N2	248.5	0.023
65454	OO1	120.2	0.027
65454	M1	163	0.02
65454	J1	101.2	0.036
65454	Q1	61.4	0.024
65454	2Q1	226	0.029
65454	P1	87.2	0.09
65454	2SM2	247.6	0.019
65454	M3	87.9	0.006
65454	L2	104	0.022
65454	2MK3	177	0.01
65454	K2	124.3	0.052
65454	M8	118.4	0.018
65454	MS4	14.4	0.012
65455	M2	81.3	0.612
65455	S2	89.2	0.123
65455	N2	55.1	0.135
65455	K1	77.3	0.318
65455	M4	126.6	0.031
65455	O1	49.4	0.176
65455	M6	32.4	0.028
65455	MK3	118.1	0.048
65455	S4	90.3	0.008
65455	MN4	111.2	0.017
65455	S6	140.8	0.005
65455	2N2	245.7	0.026
65455	OO1	128.9	0.027
65455	M1	171	0.02
65455	J1	99.6	0.033
65455	Q1	65.6	0.023
65455	2Q1	229.4	0.028
65455	P1	86.4	0.091
65455	2SM2	242.9	0.016
65455	M3	83.6	0.009
65455	L2	108.1	0.023
65455	2MK3	200.1	0.01
65455	K2	125.3	0.05
65455	M8	115.3	0.017
65455	MS4	12.6	0.012
65456	M2	81.5	0.619
65456	S2	89.8	0.121
65456	N2	55.2	0.134
65456	K1	77.4	0.317
65456	M4	127	0.031
65456	O1	51.2	0.175
65456	M6	29.7	0.028
65456	MK3	115.4	0.045
65456	S4	95.1	0.008
65456	MN4	109.4	0.017
65456	S6	150.8	0.005
65456	2N2	243.3	0.028
65456	OO1	136.8	0.027
65456	M1	178.9	0.019
65456	J1	96.3	0.029
65456	Q1	71.1	0.021
65456	2Q1	231.6	0.026
65456	P1	84.8	0.09
65456	2SM2	236.4	0.013
65456	M3	82.2	0.013
65456	L2	111	0.025
65456	2MK3	215.4	0.011
65456	K2	126.4	0.047
65456	M8	112.4	0.017
65456	MS4	14.2	0.011
65457	M2	81.8	0.624
65457	S2	90.8	0.121
65457	N2	55	0.133
65457	K1	77.5	0.316
65457	M4	127.8	0.031
65457	O1	53.2	0.173
65457	M6	28.2	0.028
65457	MK3	111.7	0.043
65457	S4	104.8	0.007
65457	MN4	106.9	0.017
65457	S6	160.9	0.004
65457	2N2	240.7	0.031
65457	OO1	148.9	0.027
65457	M1	189.9	0.019
65457	J1	92.7	0.025
65457	Q1	76.1	0.02
65457	2Q1	235.9	0.024
65457	P1	83.5	0.089
65457	2SM2	231	0.011
65457	M3	83.3	0.016
65457	L2	113.3	0.025
65457	2MK3	230.4	0.013
65457	K2	129.7	0.044
65457	M8	111	0.018
65457	MS4	16.9	0.01
65458	M2	82.1	0.628
65458	S2	91.9	0.121
65458	N2	55.1	0.132
65458	K1	77.7	0.317
65458	M4	129.4	0.032
65458	O1	55.2	0.172
65458	M6	28.7	0.029
65458	MK3	108.2	0.042
65458	S4	109.7	0.008
65458	MN4	105.3	0.017
65458	S6	167.8	0.005
65458	2N2	238.6	0.033
65458	OO1	159.9	0.028
65458	M1	200.1	0.018
65458	J1	88.8	0.021
65458	Q1	80.6	0.019
65458	2Q1	237.3	0.023
65458	P1	82.9	0.089
65458	2SM2	220.1	0.008
65458	M3	83.1	0.017
65458	L2	118.1	0.026
65458	2MK3	242.6	0.014
65458	K2	131.6	0.041
65458	M8	108.3	0.017
65458	MS4	24.1	0.009
65459	M2	82.5	0.63
65459	S2	93.1	0.12
65459	N2	54.6	0.131
65459	K1	77.9	0.318
65459	M4	130.5	0.032
65459	O1	57.2	0.171
65459	M6	28.9	0.029
65459	MK3	105.5	0.041
65459	S4	116	0.007
65459	MN4	104.4	0.016
65459	S6	172.3	0.005
65459	2N2	237.6	0.034
65459	OO1	170.7	0.033
65459	M1	211.4	0.019
65459	J1	82.4	0.018
65459	Q1	84.2	0.017
65459	2Q1	237.5	0.021
65459	P1	82.2	0.089
65459	2SM2	208.8	0.006
65459	M3	82.7	0.019
65459	L2	121.8	0.025
65459	2MK3	250.7	0.016
65459	K2	132.6	0.036
65459	M8	106.3	0.018
65459	MS4	35.9	0.008
65460	M2	82.8	0.63
65460	S2	94.2	0.121
65460	N2	54.2	0.129
65460	K1	78.4	0.319
65460	M4	131.1	0.033
65460	O1	59.6	0.17
65460	M6	28.7	0.029
65460	MK3	101.8	0.041
65460	S4	118.8	0.006
65460	MN4	103.8	0.015
65460	S6	175	0.006
65460	2N2	238.5	0.035
65460	OO1	178.7	0.038
65460	M1	223.6	0.021
65460	J1	74.3	0.015
65460	Q1	88.1	0.016
65460	2Q1	237.4	0.02
65460	P1	80.1	0.087
65460	2SM2	179.1	0.004
65460	M3	81.5	0.02
65460	L2	127.8	0.025
65460	2MK3	257.2	0.017
65460	K2	133	0.033
65460	M8	104.7	0.018
65460	MS4	45.1	0.008
65461	M2	83.2	0.627
65461	S2	95.7	0.122
65461	N2	53.8	0.128
65461	K1	79	0.319
65461	M4	131.1	0.034
65461	O1	61.8	0.169
65461	M6	28.2	0.029
65461	MK3	98.7	0.04
65461	S4	126.2	0.005
65461	MN4	103.8	0.014
65461	S6	178.4	0.006
65461	2N2	239.3	0.036
65461	OO1	183.6	0.044
65461	M1	231.8	0.023
65461	J1	61.5	0.012
65461	Q1	91.8	0.015
65461	2Q1	234.9	0.018
65461	P1	78.4	0.086
65461	2SM2	138.9	0.004
65461	M3	80.3	0.02
65461	L2	134.7	0.025
65461	2MK3	265.5	0.018
65461	K2	133.9	0.029
65461	M8	103.4	0.019
65461	MS4	55.1	0.008
65462	M2	83.4	0.623
65462	S2	97	0.123
65462	N2	53.3	0.127
65462	K1	79.2	0.321
65462	M4	132.5	0.036
65462	O1	64.3	0.169
65462	M6	27.4	0.028
65462	MK3	96.4	0.04
65462	S4	148	0.002
65462	MN4	102.7	0.014
65462	S6	178.4	0.005
65462	2N2	241.3	0.037
65462	OO1	187.3	0.051
65462	M1	238.2	0.026
65462	J1	40.7	0.01
65462	Q1	94.9	0.015
65462	2Q1	227.5	0.016
65462	P1	77.5	0.084
65462	2SM2	106.9	0.005
65462	M3	80.1	0.021
65462	L2	141.2	0.025
65462	2MK3	272.1	0.019
65462	K2	130.1	0.026
65462	M8	103.8	0.019
65462	MS4	64.7	0.009
65463	M2	83.7	0.618
65463	S2	98.3	0.124
65463	N2	52.7	0.125
65463	K1	79.3	0.321
65463	M4	135.1	0.037
65463	O1	66.3	0.169
65463	M6	26	0.028
65463	MK3	94.4	0.04
65463	MN4	104.5	0.012
65463	S6	184.9	0.005
65463	2N2	243.8	0.038
65463	OO1	188.9	0.058
65463	M1	243.3	0.029
65463	J1	22	0.01
65463	Q1	96	0.014
65463	2Q1	220.3	0.015
65463	P1	76	0.084
65463	2SM2	92.8	0.008
65463	M3	79.1	0.021
65463	L2	148.3	0.025
65463	2MK3	279.8	0.02
65463	K2	125.2	0.024
65463	M8	106.2	0.021
65463	MS4	75.1	0.009
65464	M2	83.9	0.61
65464	S2	99.3	0.126
65464	N2	52.1	0.124
65464	K1	79.6	0.322
65464	M4	138.2	0.039
65464	O1	68	0.169
65464	M6	25.3	0.027
65464	MK3	93.3	0.038
65464	S4	295.4	0.002
65464	MN4	103.7	0.011
65464	S6	186.8	0.005
65464	2N2	246.5	0.038
65464	OO1	190.5	0.065
65464	M1	245.7	0.032
65464	J1	10.4	0.012
65464	Q1	96.9	0.013
65464	2Q1	208.3	0.014
65464	P1	74.7	0.082
65464	2SM2	88.5	0.01
65464	M3	78.1	0.022
65464	L2	154.7	0.025
65464	2MK3	285.6	0.022
65464	K2	116.4	0.023
65464	M8	109.4	0.021
65464	MS4	86.9	0.01
65465	M2	84	0.602
65465	S2	100.3	0.128
65465	N2	51.1	0.122
65465	K1	79.7	0.322
65465	M4	143.1	0.039
65465	O1	69.3	0.17
65465	M6	24.6	0.026
65465	MK3	93.1	0.035
65465	S4	311.6	0.004
65465	MN4	102.7	0.01
65465	S6	198.2	0.004
65465	2N2	250.2	0.037
65465	OO1	191.9	0.071
65465	M1	248.1	0.035
65465	J1	358.1	0.014
65465	Q1	104.3	0.014
65465	2Q1	196.3	0.014
65465	P1	73.2	0.081
65465	2SM2	85.6	0.013
65465	M3	77.3	0.023
65465	L2	160.1	0.025
65465	2MK3	289.6	0.024
65465	K2	107.3	0.023
65465	M8	112.9	0.022
65465	MS4	100.2	0.011
65466	M2	84	0.593
65466	S2	100.9	0.129
65466	N2	50.1	0.12
65466	K1	79.3	0.325
65466	M4	149.6	0.039
65466	O1	69.8	0.17
65466	M6	24.3	0.025
65466	MK3	94.5	0.031
65466	S4	319.1	0.006
65466	MN4	105.1	0.009
65466	S6	200.3	0.004
65466	2N2	253	0.038
65466	OO1	192.3	0.074
65466	M1	247.8	0.038
65466	J1	352.5	0.017
65466	Q1	109	0.014
65466	2Q1	186.3	0.014
65466	P1	73.3	0.08
65466	2SM2	84.6	0.014
65466	M3	73.9	0.024
65466	L2	166.3	0.026
65466	2MK3	291	0.026
65466	K2	98.1	0.023
65466	M8	116.7	0.022
65466	MS4	114.2	0.012
65467	M2	84	0.583
65467	S2	101.5	0.131
65467	N2	49	0.118
65467	K1	79.1	0.326
65467	M4	156.8	0.04
65467	O1	70	0.17
65467	M6	23.2	0.023
65467	MK3	98	0.025
65467	S4	327.7	0.007
65467	MN4	103.1	0.009
65467	S6	204.2	0.004
65467	2N2	253.4	0.037
65467	OO1	192.4	0.077
65467	M1	247.5	0.041
65467	J1	345.3	0.021
65467	Q1	114.3	0.013
65467	2Q1	170.1	0.013
65467	P1	72.7	0.077
65467	2SM2	83.8	0.016
65467	M3	70.7	0.024
65467	L2	172.5	0.026
65467	2MK3	290	0.028
65467	K2	89.5	0.025
65467	M8	120.4	0.022
65467	MS4	124.6	0.013
65468	M2	84	0.574
65468	S2	101.7	0.132
65468	N2	47.7	0.116
65468	K1	78.7	0.331
65468	M4	165	0.042
65468	O1	69.8	0.17
65468	M6	21	0.022
65468	MK3	105.4	0.018
65468	S4	333.7	0.007
65468	MN4	107	0.009
65468	S6	202.4	0.004
65468	2N2	252.6	0.038
65468	OO1	193.2	0.079
65468	M1	245.9	0.044
65468	J1	341.4	0.025
65468	Q1	121.2	0.011
65468	2Q1	155.4	0.012
65468	P1	73.5	0.074
65468	2SM2	80.6	0.017
65468	M3	67.9	0.025
65468	L2	179.2	0.026
65468	2MK3	287	0.029
65468	K2	81.7	0.026
65468	M8	123.6	0.021
65468	MS4	133.9	0.014
65469	M2	84	0.564
65469	S2	101.1	0.134
65469	N2	46.4	0.115
65469	K1	77.6	0.333
65469	M4	172	0.043
65469	O1	68.9	0.169
65469	M6	18.1	0.019
65469	MK3	131.9	0.01
65469	S4	335.9	0.008
65469	MN4	118.2	0.01
65469	S6	218.5	0.003
65469	2N2	250.7	0.038
65469	OO1	193.6	0.078
65469	M1	244.2	0.047
65469	J1	338.1	0.028
65469	Q1	137.3	0.01
65469	2Q1	136.2	0.013
65469	P1	74.5	0.073
65469	2SM2	77.2	0.018
65469	M3	66.7	0.026
65469	L2	184.6	0.027
65469	2MK3	284.2	0.031
65469	K2	76.9	0.029
65469	M8	125.4	0.021
65469	MS4	139.2	0.015
65470	M2	83.8	0.555
65470	S2	99.5	0.137
65470	N2	45.4	0.114
65470	K1	76	0.334
65470	M4	178.8	0.043
65470	O1	67.1	0.168
65470	M6	10.5	0.018
65470	MK3	194.7	0.01
65470	S4	340.3	0.008
65470	MN4	127	0.01
65470	S6	236.2	0.002
65470	2N2	250.3	0.036
65470	OO1	192.9	0.072
65470	M1	241.1	0.048
65470	J1	339.4	0.029
65470	Q1	154.9	0.01
65470	2Q1	119.7	0.016
65470	P1	76.4	0.073
65470	2SM2	73	0.018
65470	M3	65.7	0.027
65470	L2	187.8	0.028
65470	2MK3	281.2	0.034
65470	K2	74.7	0.033
65470	M8	127.4	0.019
65470	MS4	143.6	0.016
65471	M2	83	0.547
65471	S2	97.3	0.142
65471	N2	43.7	0.114
65471	K1	72.9	0.329
65471	M4	189.2	0.043
65471	O1	63	0.163
65471	M6	355.2	0.017
65471	MK3	229.2	0.02
65471	S4	349.2	0.008
65471	MN4	137.1	0.01
65471	S6	203.9	0.002
65471	2N2	250.9	0.033
65471	OO1	189.1	0.06
65471	M1	238.5	0.046
65471	J1	344	0.031
65471	Q1	151.5	0.011
65471	2Q1	104.7	0.018
65471	P1	78.3	0.076
65471	2SM2	67.4	0.016
65471	M3	64.7	0.027
65471	L2	190.2	0.028
65471	2MK3	279.9	0.037
65471	K2	77.8	0.04
65471	M8	131.8	0.017
65471	MS4	141.1	0.018
65472	M2	81.4	0.537
65472	S2	95.2	0.145
65472	N2	41.4	0.113
65472	K1	67.8	0.314
65472	M4	199.9	0.043
65472	O1	55.8	0.158
65472	M6	338.2	0.017
65472	MK3	240.7	0.032
65472	S4	349.9	0.009
65472	MN4	149.5	0.01
65472	S6	136.2	0.002
65472	2N2	257.7	0.028
65472	OO1	177.6	0.043
65472	M1	234.6	0.042
65472	J1	353.2	0.032
65472	Q1	140.6	0.015
65472	2Q1	90.7	0.018
65472	P1	76.9	0.086
65472	2SM2	59.9	0.013
65472	M3	64.9	0.026
65472	L2	189.8	0.026
65472	2MK3	280.5	0.038
65472	K2	83.3	0.049
65472	M8	136.3	0.014
65472	MS4	133.8	0.018
65473	M2	78	0.502
65473	S2	95	0.135
65473	N2	37.6	0.107
65473	K1	59.1	0.305
65473	M4	208.9	0.058
65473	O1	38.8	0.148
65473	M6	327.3	0.013
65473	MK3	254.2	0.062
65473	S4	7.5	0.008
65473	MN4	166	0.015
65473	S6	52	0.006
65473	2N2	256.5	0.026
65473	OO1	161.5	0.03
65473	M1	231.7	0.042
65473	J1	350.6	0.033
65473	Q1	128	0.015
65473	2Q1	85	0.02
65473	P1	75.1	0.08
65473	2SM2	79.5	0.008
65473	M3	65.3	0.021
65473	L2	181.9	0.021
65473	2MK3	267.5	0.042
65473	K2	94.7	0.059
65473	M8	126.5	0.011
65473	MS4	150.8	0.024
65474	M2	48.8	1.016
65474	S2	69.4	0.244
65474	N2	11.9	0.215
65474	K1	58.9	0.584
65474	M4	202.3	0.185
65474	O1	28.9	0.576
65474	M6	59.5	0.018
65474	MK3	217.3	0.341
65474	S4	222.9	0.014
65474	MN4	179.4	0.1
65474	S6	84.4	0.004
65474	2N2	212.1	0.064
65474	OO1	232.6	0.011
65474	M1	292	0.042
65474	J1	24.9	0.044
65474	Q1	348.1	0.122
65474	2Q1	140	0.05
65474	P1	38.6	0.159
65474	2SM2	351.1	0.017
65474	M3	216.9	0.04
65474	L2	146.3	0.033
65474	2MK3	189.4	0.163
65474	K2	60	0.188
65474	M8	158.2	0.016
65474	MS4	189.1	0.043
65475	M2	51.5	1.186
65475	S2	71.2	0.273
65475	N2	4.9	0.229
65475	K1	68	0.574
65475	M4	212.2	0.143
65475	O1	36.9	0.636
65475	M6	225.2	0.007
65475	MK3	214.9	0.375
65475	S4	236.7	0.012
65475	MN4	175	0.088
65475	S6	47.3	0.012
65475	2N2	182	0.065
65475	OO1	276.3	0.023
65475	M1	316.8	0.097
65475	J1	23	0.093
65475	Q1	347.4	0.146
65475	2Q1	131.3	0.084
65475	P1	48.6	0.172
65475	2SM2	336.2	0.053
65475	M3	234.2	0.038
65475	L2	142.2	0.08
65475	2MK3	195.7	0.174
65475	K2	55.8	0.209
65475	M8	139.3	0.022
65475	MS4	185.8	0.023
65476	M2	53.3	1.174
65476	S2	74.6	0.284
65476	N2	7.4	0.226
65476	K1	71.5	0.554
65476	M4	211.7	0.137
65476	O1	41.2	0.632
65476	M6	246	0.014
65476	MK3	212.3	0.382
65476	S4	233.3	0.011
65476	MN4	170.7	0.084
65476	S6	45.1	0.014
65476	2N2	165.7	0.064
65476	OO1	345.3	0.013
65476	M1	315.7	0.087
65476	J1	18.2	0.086
65476	Q1	355.3	0.138
65476	2Q1	127.1	0.091
65476	P1	52.4	0.19
65476	2SM2	339.9	0.051
65476	M3	215.5	0.043
65476	L2	138.9	0.075
65476	2MK3	190.9	0.175
65476	K2	55.3	0.225
65476	M8	147.7	0.023
65476	MS4	171.8	0.025
65477	M2	40.3	1.25
65477	S2	51.4	0.316
65477	N2	1.6	0.28
65477	K1	52.1	0.613
65477	M4	195.5	0.168
65477	O1	17.6	0.593
65477	M6	53	0.012
65477	MK3	224.8	0.433
65477	S4	83.1	0.007
65477	MN4	165.9	0.089
65477	S6	319	0.003
65477	2N2	182.5	0.072
65477	OO1	256.2	0.042
65477	M1	282.3	0.065
65477	J1	6.6	0.056
65477	Q1	337.4	0.13
65477	2Q1	119.2	0.055
65477	P1	34	0.152
65477	2SM2	26.1	0.016
65477	M3	143.8	0.056
65477	L2	120.6	0.045
65477	2MK3	206.7	0.221
65477	K2	60	0.207
65477	M8	24.3	0.007
65477	MS4	227.2	0.057
65478	M2	42.7	1.529
65478	S2	50.3	0.39
65478	N2	359.3	0.325
65478	K1	56.9	0.686
65478	M4	197.6	0.186
65478	O1	21.8	0.691
65478	M6	305.9	0.025
65478	MK3	219.4	0.484
65478	S4	21.9	0.016
65478	MN4	169.1	0.09
65478	S6	310.4	0.009
65478	2N2	166.4	0.096
65478	OO1	262	0.048
65478	M1	284.2	0.091
65478	J1	5.7	0.087
65478	Q1	339.3	0.153
65478	2Q1	127.8	0.077
65478	P1	40.2	0.163
65478	2SM2	5.3	0.035
65478	M3	160.3	0.039
65478	L2	132.8	0.098
65478	2MK3	201.5	0.221
65478	K2	51	0.27
65478	M8	84.4	0.015
65478	MS4	253	0.065
65479	M2	43.3	1.525
65479	S2	50.5	0.397
65479	N2	359.7	0.33
65479	K1	58.6	0.681
65479	M4	200	0.178
65479	O1	22.6	0.684
65479	M6	300	0.03
65479	MK3	220.1	0.485
65479	S4	22	0.02
65479	MN4	169.1	0.081
65479	S6	325.8	0.013
65479	2N2	166.8	0.103
65479	OO1	271.1	0.046
65479	M1	288.5	0.098
65479	J1	8.5	0.096
65479	Q1	340.7	0.155
65479	2Q1	133.4	0.085
65479	P1	42	0.166
65479	2SM2	8.7	0.036
65479	M3	170	0.037
65479	L2	135.8	0.101
65479	2MK3	201.1	0.22
65479	K2	52.4	0.278
65479	M8	87.1	0.015
65479	MS4	250.9	0.062
65480	M2	75.6	1.813
65480	S2	92.2	0.452
65480	N2	45.2	0.399
65480	K1	88.3	1.069
65480	M4	344	0.073
65480	O1	74.2	0.588
65480	M6	41.3	0.049
65480	MK3	4.2	0.054
65480	S4	152.2	0.011
65480	MN4	298.8	0.008
65480	2N2	300	0.081
65480	OO1	124.4	0.033
65480	M1	328.5	0.026
65480	J1	77.5	0.051
65480	Q1	60.6	0.072
65480	2Q1	239.9	0.018
65480	P1	78.2	0.299
65480	2SM2	273.9	0.008
65480	M3	304	0.013
65480	L2	124.2	0.043
65480	2MK3	333.9	0.018
65480	K2	103	0.126
65480	M8	30.1	0.011
65480	MS4	359.4	0.04
65481	M2	78.6	2.185
65481	S2	93.3	0.531
65481	N2	42.8	0.501
65481	K1	84.9	1.54
65481	M4	250.5	0.061
65481	O1	55.1	0.942
65481	MK3	233.7	0.111
65481	S4	216.5	0.019
65481	MN4	194.3	0.034
65481	S6	142.6	0.013
65481	2N2	271	0.047
65481	OO1	149	0.062
65481	M1	216.3	0.037
65481	J1	55.9	0.088
65481	Q1	29.8	0.112
65481	2Q1	89.8	0.041
65481	P1	80.8	0.396
65481	2SM2	341.8	0.02
65481	M3	83.4	0.016
65481	L2	173.6	0.04
65481	2MK3	234.1	0.056
65481	K2	72.8	0.23
65481	M8	110	0.005
65481	MS4	60.4	0.014
65482	M2	79.1	2.217
65482	S2	93.9	0.521
65482	N2	42.3	0.502
65482	K1	84.2	1.572
65482	M4	251.4	0.077
65482	O1	53.8	0.965
65482	M6	259.2	0.006
65482	MK3	244.3	0.131
65482	S4	212.5	0.021
65482	MN4	197.4	0.04
65482	S6	140.7	0.015
65482	2N2	263.3	0.049
65482	OO1	150.1	0.07
65482	M1	221.3	0.032
65482	J1	49.2	0.107
65482	Q1	31.8	0.123
65482	2Q1	105.4	0.036
65482	P1	80.7	0.417
65482	2SM2	344.7	0.024
65482	M3	162.8	0.003
65482	L2	166.1	0.05
65482	2MK3	225.9	0.076
65482	K2	67.9	0.256
65482	M8	84.4	0.006
65482	MS4	75.4	0.01
65483	M2	88.3	2.251
65483	S2	102.3	0.598
65483	N2	57.6	0.539
65483	K1	95	1.505
65483	M4	325.2	0.051
65483	O1	71.8	0.87
65483	M6	125.6	0.027
65483	MK3	331.8	0.028
65483	S4	271.3	0.015
65483	MN4	145.2	0.014
65483	S6	157.9	0.004
65483	2N2	315.4	0.14
65483	OO1	231.3	0.013
65483	M1	352.6	0.051
65483	J1	98.3	0.121
65483	Q1	39	0.075
65483	2Q1	170.5	0.03
65483	P1	78.2	0.413
65483	2SM2	146.2	0.012
65483	M3	303.2	0.018
65483	L2	200.7	0.021
65483	2MK3	142	0.021
65483	K2	109.8	0.216
65483	M8	264	0.009
65483	MS4	267.1	0.004
65484	M2	89.2	2.278
65484	S2	101.6	0.622
65484	N2	54.2	0.529
65484	K1	90.9	1.516
65484	M4	270.7	0.077
65484	O1	63.2	0.919
65484	M6	121	0.004
65484	MK3	244	0.074
65484	S4	236.3	0.01
65484	MN4	201.2	0.026
65484	S6	291.7	0.004
65484	2N2	314.3	0.092
65484	OO1	135	0.025
65484	M1	338.3	0.021
65484	J1	88.4	0.109
65484	Q1	36.5	0.106
65484	2Q1	128.6	0.017
65484	P1	77.1	0.412
65484	2SM2	43.6	0.026
65484	M3	181.5	0.016
65484	L2	176.8	0.034
65484	2MK3	131.4	0.021
65484	K2	100.2	0.23
65484	M8	23.2	0.003
65484	MS4	291.4	0.021
65485	M2	88.2	2.188
65485	S2	100	0.603
65485	N2	53.5	0.514
65485	K1	88.6	1.435
65485	M4	268	0.119
65485	O1	60.3	0.868
65485	M6	232.4	0.016
65485	MK3	278.6	0.114
65485	S4	207	0.016
65485	MN4	211.7	0.047
65485	S6	277	0.004
65485	2N2	301.7	0.074
65485	OO1	152.8	0.052
65485	M1	311.4	0.021
65485	J1	79.5	0.097
65485	Q1	36.6	0.107
65485	2Q1	115.9	0.012
65485	P1	76.3	0.394
65485	2SM2	50.7	0.022
65485	M3	180.6	0.031
65485	L2	161.6	0.032
65485	2MK3	254.5	0.044
65485	K2	109	0.25
65485	M8	120.9	0.011
65485	MS4	263.7	0.035
65486	M2	88.1	1.803
65486	S2	104.5	0.394
65486	N2	57.6	0.398
65486	K1	97.5	1.186
65486	M4	337.9	0.098
65486	O1	84.7	0.669
65486	M6	62.3	0.058
65486	MK3	347.8	0.139
65486	S4	172.7	0.047
65486	MN4	279.1	0.014
65486	S6	87.5	0.011
65486	2N2	302.5	0.135
65486	OO1	328.8	0.047
65486	M1	341.8	0.084
65486	J1	87.2	0.133
65486	Q1	48.2	0.072
65486	2Q1	189.9	0.061
65486	P1	84.7	0.315
65486	2SM2	3.9	0.01
65486	M3	259.3	0.046
65486	L2	122.4	0.023
65486	2MK3	181.1	0.041
65486	K2	76.3	0.169
65486	M8	8.2	0.029
65486	MS4	235.9	0.031
65487	M2	82.1	1.697
65487	S2	93.4	0.448
65487	N2	49.5	0.395
65487	K1	85	0.985
65487	M4	232.7	0.112
65487	O1	60.3	0.606
65487	M6	8.7	0.051
65487	MK3	172.1	0.073
65487	S4	98.4	0.003
65487	MN4	231.9	0.039
65487	S6	83.5	0.003
65487	2N2	319.8	0.087
65487	OO1	61.5	0.128
65487	M1	118.8	0.012
65487	J1	108.4	0.058
65487	Q1	47.5	0.085
65487	2Q1	28.9	0.022
65487	P1	72.6	0.28
65487	2SM2	7.9	0.018
65487	M3	62.4	0.025
65487	L2	170.1	0.04
65487	2MK3	79.4	0.082
65487	K2	74.4	0.157
65487	M8	115.6	0.014
65487	MS4	225.9	0.071
65488	M2	80.1	1.608
65488	S2	93.5	0.418
65488	N2	47.2	0.382
65488	K1	81.9	0.959
65488	M4	222.2	0.139
65488	O1	54.7	0.589
65488	M6	358.2	0.039
65488	MK3	186	0.095
65488	S4	335.7	0.008
65488	MN4	219.6	0.042
65488	S6	92.5	0.006
65488	2N2	317	0.077
65488	OO1	60.4	0.133
65488	M1	193.3	0.014
65488	J1	107.9	0.04
65488	Q1	46.8	0.08
65488	2Q1	43.5	0.028
65488	P1	75.5	0.251
65488	2SM2	353	0.018
65488	M3	45.9	0.022
65488	L2	148.8	0.043
65488	2MK3	81.1	0.054
65488	K2	84.3	0.14
65488	M8	144.8	0.022
65488	MS4	218.6	0.086
65489	M2	57.9	1.433
65489	S2	72.7	0.35
65489	N2	24.2	0.323
65489	K1	76.4	0.67
65489	M4	303.2	0.121
65489	O1	85.3	0.526
65489	M6	44.6	0.065
65489	MK3	336.9	0.38
65489	S4	330.7	0.015
65489	MN4	281.5	0.064
65489	S6	200.6	0.007
65489	2N2	221.8	0.082
65489	OO1	111.8	0.042
65489	M1	247	0.037
65489	J1	83.3	0.057
65489	Q1	76.9	0.073
65489	2Q1	158.1	0.059
65489	P1	69.6	0.18
65489	2SM2	109.2	0.013
65489	M3	208.3	0.025
65489	L2	101.8	0.054
65489	2MK3	294.5	0.17
65489	K2	101.2	0.219
65489	M8	264.6	0.033
65489	MS4	67.9	0.087
65490	M2	59.2	1.786
65490	S2	67.9	0.379
65490	N2	26.5	0.358
65490	K1	67.2	0.766
65490	M4	296.7	0.196
65490	O1	77.7	0.475
65490	M6	23.2	0.079
65490	MK3	308.1	0.374
65490	S4	56.5	0.009
65490	MN4	272.2	0.073
65490	S6	198.2	0.005
65490	2N2	199.4	0.083
65490	OO1	120.2	0.072
65490	M1	232.8	0.067
65490	J1	73.8	0.045
65490	Q1	111	0.048
65490	2Q1	109.3	0.045
65490	P1	67.5	0.188
65490	2SM2	35.5	0.007
65490	M3	209.1	0.059
65490	L2	104.5	0.113
65490	2MK3	278.3	0.182
65490	K2	83.7	0.239
65490	M8	244.3	0.042
65490	MS4	20.4	0.05
65491	M2	57.9	2.041
65491	S2	65	0.367
65491	N2	23.5	0.361
65491	K1	59.9	0.779
65491	M4	298.3	0.204
65491	O1	74.9	0.383
65491	M6	12.7	0.119
65491	MK3	289.7	0.424
65491	S4	181.9	0.007
65491	MN4	261.4	0.067
65491	S6	330	0.007
65491	2N2	156	0.083
65491	OO1	112.6	0.088
65491	M1	241.7	0.091
65491	J1	37.4	0.034
65491	Q1	157.4	0.053
65491	2Q1	91.4	0.047
65491	P1	58.4	0.199
65491	2SM2	355.4	0.015
65491	M3	206.7	0.083
65491	L2	95.9	0.184
65491	2MK3	255.5	0.201
65491	K2	68.2	0.206
65491	M8	244.3	0.053
65491	MS4	8.1	0.05
65492	M2	94.8	0.325
65492	S2	96.2	0.146
65492	N2	49.4	0.119
65492	K1	128.6	0.31
65492	M4	100.1	0.029
65492	O1	121.9	0.219
65492	M6	329	0.011
65492	MK3	118.8	0.073
65492	S4	272.4	0.022
65492	MN4	59	0.01
65492	S6	63.7	0.01
65492	2N2	287.7	0.092
65492	OO1	202.2	0.065
65492	M1	284.8	0.014
65492	J1	292.4	0.034
65492	Q1	67.7	0.056
65492	2Q1	206.4	0.049
65492	P1	89.5	0.105
65492	2SM2	268.4	0.003
65492	M3	242.7	0.021
65492	L2	221.8	0.04
65492	2MK3	71.9	0.074
65492	M8	227.3	0.01
65492	MS4	241	0.035
65493	M2	78.9	0.602
65493	S2	78.1	0.125
65493	N2	32.9	0.131
65493	K1	94.5	0.346
65493	M4	144.5	0.04
65493	O1	54.1	0.168
65493	M6	180.8	0.009
65493	MK3	3.8	0.084
65493	S4	289.4	0.039
65493	MN4	202.6	0.033
65493	S6	128	0.002
65493	2N2	223.5	0.07
65493	OO1	231.6	0.097
65493	M1	267.7	0.079
65493	J1	331.5	0.073
65493	Q1	334.2	0.072
65493	2Q1	88.3	0.083
65493	P1	64.8	0.166
65493	2SM2	118.7	0.022
65493	M3	122.9	0.036
65493	L2	166.3	0.059
65493	2MK3	334.3	0.078
65493	M8	286.2	0.012
65493	MS4	93.8	0.033
65494	M2	81.5	0.705
65494	S2	63.8	0.166
65494	N2	32.6	0.122
65494	K1	88.1	0.426
65494	M4	147.5	0.059
65494	O1	51.6	0.244
65494	M6	157.6	0.008
65494	MK3	92	0.026
65494	S4	275.6	0.032
65494	MN4	197.8	0.044
65494	S6	29.3	0.006
65494	2N2	239.3	0.04
65494	OO1	164.6	0.034
65494	M1	260	0.054
65494	J1	332	0.058
65494	Q1	357.4	0.068
65494	2Q1	82.8	0.067
65494	P1	69	0.196
65494	2SM2	286.7	0.005
65494	M3	230.6	0.008
65494	L2	128.8	0.072
65494	2MK3	357.2	0.069
65494	M8	300.9	0.019
65494	MS4	48.9	0.03
65495	M2	77.2	1.308
65495	S2	91.3	0.375
65495	N2	46.2	0.291
65495	K1	71.6	0.869
65495	M4	129.2	0.185
65495	O1	50.2	0.523
65495	M6	301.1	0.029
65495	MK3	145.5	0.188
65495	S4	167.4	0.012
65495	MN4	114.9	0.086
65495	S6	237.2	0.008
65495	2N2	267.9	0.043
65495	OO1	101.5	0.055
65495	M1	180.5	0.037
65495	J1	123.5	0.026
65495	Q1	18.4	0.085
65495	2Q1	66.6	0.066
65495	P1	65.2	0.186
65495	2SM2	209.6	0.015
65495	M3	119	0.047
65495	2MK3	92.9	0.102
65495	K2	63.1	0.137
65495	M8	34.7	0.012
65495	MS4	152.2	0.082
65496	M2	85.8	1.382
65496	S2	93.6	0.394
65496	N2	49	0.332
65496	K1	91.6	0.947
65496	M4	143.8	0.226
65496	O1	82.3	0.589
65496	M6	213.9	0.042
65496	MK3	143.6	0.309
65496	S4	96.8	0.015
65496	MN4	99.9	0.084
65496	S6	276.5	0.007
65496	2N2	261.6	0.122
65496	OO1	181	0.098
65496	M1	252.9	0.113
65496	J1	235	0.032
65496	Q1	345.1	0.046
65496	2Q1	144.5	0.044
65496	P1	78.6	0.218
65496	2SM2	253.4	0.013
65496	M3	73.6	0.04
65496	L2	187.4	0.072
65496	2MK3	94.4	0.117
65496	K2	71.3	0.119
65496	M8	110.5	0.011
65496	MS4	146.6	0.158
65497	M2	89.7	1.395
65497	S2	96.1	0.387
65497	N2	53.5	0.324
65497	K1	100.4	0.982
65497	M4	143.6	0.219
65497	O1	95.8	0.624
65497	M6	189.4	0.043
65497	MK3	142	0.349
65497	S4	32.4	0.012
65497	MN4	95.5	0.089
65497	S6	286.9	0.008
65497	2N2	255.2	0.179
65497	OO1	176	0.133
65497	M1	259.8	0.162
65497	J1	291.9	0.044
65497	Q1	311.7	0.023
65497	2Q1	161.4	0.066
65497	P1	88.5	0.224
65497	2SM2	276	0.026
65497	M3	67.5	0.029
65497	L2	180	0.102
65497	2MK3	94.9	0.106
65497	K2	94	0.104
65497	M8	142.2	0.019
65497	MS4	142.7	0.166
65498	M2	66.4	0.632
65498	S2	99.1	0.106
65498	N2	24	0.143
65498	K1	52.1	0.398
65498	M4	327.3	0.053
65498	O1	46.4	0.27
65498	M6	337.3	0.037
65498	MK3	282.2	0.072
65498	S4	285.5	0.007
65498	MN4	230.5	0.015
65498	S6	39.4	0.004
65498	2N2	20.7	0.051
65498	OO1	86.8	0.069
65498	M1	118.8	0.056
65498	J1	103.2	0.044
65498	Q1	69.2	0.073
65498	2Q1	50.6	0.004
65498	P1	82.4	0.177
65498	2SM2	35.3	0.017
65498	M3	348.9	0.012
65498	L2	102.9	0.031
65498	2MK3	223.4	0.025
65498	K2	326.7	0.055
65498	M8	195.4	0.005
65498	MS4	303.2	0.031
65499	M2	67.4	0.919
65499	S2	62	0.191
65499	N2	33	0.16
65499	K1	69.9	0.354
65499	M4	155.6	0.052
65499	O1	62.1	0.237
65499	M6	11.6	0.056
65499	MK3	166.7	0.032
65499	S4	2.3	0.006
65499	MN4	2.9	0.009
65499	S6	68.1	0.013
65499	2N2	71.6	0.024
65499	OO1	261.3	0.018
65499	M1	262.2	0.068
65499	J1	242.6	0.025
65499	Q1	264.2	0.018
65499	2Q1	154.6	0.032
65499	P1	33.9	0.099
65499	2SM2	152.9	0.017
65499	M3	149.2	0.051
65499	L2	96	0.083
65499	2MK3	206.2	0.045
65499	K2	48.5	0.093
65499	M8	42.9	0.004
65499	MS4	44.5	0.019
65500	M2	65.7	1.105
65500	S2	53.1	0.217
65500	N2	36.5	0.162
65500	K1	74.2	0.343
65500	M4	158.3	0.085
65500	O1	61.5	0.274
65500	M6	12.9	0.055
65500	MK3	152.9	0.045
65500	S4	15.2	0.012
65500	MN4	233.1	0.013
65500	S6	58	0.019
65500	2N2	150.4	0.028
65500	OO1	7.4	0.015
65500	M1	257.7	0.126
65500	J1	249.8	0.034
65500	Q1	214.5	0.043
65500	2Q1	171.7	0.035
65500	P1	8.7	0.085
65500	2SM2	187.2	0.016
65500	M3	156.8	0.047
65500	L2	106.2	0.123
65500	2MK3	211	0.065
65500	K2	49.6	0.144
65500	M8	72.9	0.007
65500	MS4	23.4	0.017
65501	M2	57.6	1.163
65501	S2	69.9	0.263
65501	N2	22.2	0.251
65501	K1	63.5	0.483
65501	M4	302.5	0.11
65501	O1	55.4	0.285
65501	M6	35	0.011
65501	MK3	319.5	0.128
65501	S4	178.4	0.004
65501	MN4	316.6	0.03
65501	S6	233.7	0.012
65501	2N2	14.5	0.031
65501	OO1	6.8	0.039
65501	M1	174.2	0.05
65501	J1	186.5	0.007
65501	Q1	82.8	0.034
65501	2Q1	35.8	0.027
65501	P1	54.6	0.1
65501	2SM2	5.9	0.019
65501	M3	87.4	0.007
65501	L2	81.6	0.05
65501	2MK3	283.7	0.059
65501	K2	60.5	0.146
65501	M8	107.2	0.022
65501	MS4	264.8	0.031
65502	M2	56	1.127
65502	S2	71.1	0.259
65502	N2	18.9	0.277
65502	K1	53.8	0.491
65502	M4	277.3	0.095
65502	O1	46.2	0.274
65502	M6	78.3	0.028
65502	MK3	309.5	0.135
65502	S4	231.4	0.015
65502	MN4	344.2	0.007
65502	S6	264.6	0.005
65502	2N2	289.3	0.002
65502	OO1	352.9	0.042
65502	M1	183.8	0.047
65502	J1	302.8	0.048
65502	Q1	10.7	0.008
65502	2Q1	36.4	0.047
65502	P1	44.2	0.127
65502	2SM2	33.2	0.015
65502	M3	90.1	0.028
65502	L2	74.3	0.042
65502	2MK3	279.6	0.115
65502	K2	71.6	0.145
65502	M8	126	0.024
65502	MS4	237.5	0.035
65503	M2	54.6	1.088
65503	S2	72.7	0.255
65503	N2	20.4	0.293
65503	K1	49	0.504
65503	M4	265.7	0.1
65503	O1	40.4	0.272
65503	M6	93.8	0.033
65503	MK3	302.5	0.13
65503	S4	237.3	0.023
65503	MN4	77.9	0.005
65503	S6	298.9	0.006
65503	2N2	218.8	0.035
65503	OO1	5.5	0.029
65503	M1	177	0.05
65503	J1	301	0.054
65503	Q1	289.3	0.005
65503	2Q1	34.7	0.058
65503	P1	45.7	0.127
65503	2SM2	72.1	0.02
65503	M3	90.5	0.031
65503	L2	56.7	0.023
65503	2MK3	279.3	0.127
65503	K2	77.1	0.159
65503	M8	140.6	0.026
65503	MS4	234.6	0.033
\.



COPY public.constituents (name, definition, speed) FROM stdin;
J1	Basic 1 1 1 -1 0 -90    0 -1 0 0 0 0     76	15.5854433
K1	Compound 0 1 0 0 0 0 0 0	15.0410686
K2	Compound 0 0 0 0 0 0 0 1	30.0821373
L2	Compound 0 0 0 0 0 0 1 0	29.5284789
M1	Basic 1 -1 1 0 0 -90    1 -1 0 0 1 0     206	14.4966939
M2	Compound 0 0 0 1 0 0 0 0	28.9841042
M3	Basic 3 -3 3 0 0 0      3 -3 0 0 0 0     149	43.4761563
M4	Compound 0 0 0 2 0 0 0 0	57.9682084
M6	Compound 0 0 0 3 0 0 0 0	86.9523126
M8	Compound 0 0 0 4 0 0 0 0	115.9364169
N2	Compound 0 0 0 0 0 1 0 0	28.4397295
2N2	Basic 2 -4 2 2 0 0      2 -2 0 0 0 0     78	27.8953548
O1	Compound 1 0 0 0 0 0 0 0	13.9430356
OO1	Basic 1 2 1 0 0 -90     -2 -1 0 0 0 0    77	16.1391017
P1	Compound 0 0 1 0 0 0 0 0	14.9589314
Q1	Compound 0 0 0 0 0 0 0 0 1	13.3986609
2Q1	Basic 1 -4 1 2 0 90     2 -1 0 0 0 0     75	12.8542862
R2	Basic 2 0 1 0 -1 180    0 0 0 0 0 0      1	30.0410667
S1	Basic 1 0 0 0 0 0       0 0 0 0 0 0      1	15
S2	Compound 0 0 0 0 1 0 0 0	30
S4	Compound 0 0 0 0 2 0 0 0	60
S6	Compound 0 0 0 0 3 0 0 0	90
T2	Basic 2 0 -1 0 1 0      0 0 0 0 0 0      1	29.9589333
LDA2	Basic 2 -1 0 1 0 180    2 -2 0 0 0 0     78	29.4556253
MU2	Basic 2 -4 4 0 0 0      2 -2 0 0 0 0     78	27.9682084
NU2	Basic 2 -3 4 -1 0 0     2 -2 0 0 0 0     78	28.5125831
RHO1	Basic 1 -3 3 -1 0 90    2 -1 0 0 0 0     75	13.4715145
MK3	Compound 0 1 0 1 0 0 0 0	44.0251729
2MK3	Compound 0 -1 0 2 0 0 0 0	42.9271398
MN4	Compound 0 0 0 1 0 1 0 0	57.4238337
MS4	Compound 0 0 0 1 1 0 0 0	58.9841042
2SM2	Compound 0 0 0 -1 2 0 0 0	31.0158958
MF	Basic 0 2 0 0 0 0       -2 0 0 0 0 0     74	1.0980331
MSF	Compound 0 0 0 -1 1 0 0 0	1.0158958
MM	Basic 0 1 0 -1 0 0      0 0 0 0 0 0      73	0.5443747
SA	Basic 0 0 1 0 0 0       0 0 0 0 0 0      1	0.0410686
SSA	Basic 0 0 2 0 0 0       0 0 0 0 0 0      1	0.0821373
SA-IOS	Doodson 0 0 1 0 -1 0    0	0.0410667
MF-IOS	Doodson 0 2 0 0  0 0    0	1.0980331
S1-IOS	Doodson 1 0 0 0 1 -90   2\n  0  0 -2 .0  0.3534     0  1  0 .50 0.0264	15.000002
OO1-IOS	Doodson 1  2  1  0  0 -90    8\n  -2 -1  0 .50 0.0037    -2  0  0 .0  0.1496    -2  1  0 .0  0.0296\n  -1  0  0 .25 0.0240R1  -1  1  0 .25 0.0099R1   0  1  0 .0  0.6398\n  0  2  0 .0  0.1342     0  3  0 .0  0.0086	16.1391017
R2-IOS	Doodson 2 0 1 0 -1 180    2\n  0  0  2 .50 0.2535     0  1  2 .0  0.0141	30.0410667
A7	Basic 0 3 0 -1 0 0      -2 0 0 0 0 0     74	1.6424078
2MK5	Compound 0  1  0  2  0  0  0  0	73.0092771
2MK6	Compound 0  0  0  2  0  0  0  1	88.0503457
2MN2	Compound 0  0  0  2  0 -1  0  0	29.5284789
2MN6	Compound 0  0  0  2  0  1  0  0	86.4079379
2MS6	Compound 0  0  0  2  1  0  0  0	87.9682084
2NM6	Compound 0  0  0  1  0  2  0  0	85.8635632
2SK5	Compound 0  1  0  0  2  0  0  0	75.0410686
2SM6	Compound 0  0  0  1  2  0  0  0	88.9841042
3MK7	Compound 0  1  0  3  0  0  0  0	101.9933813
3MN8	Compound 0  0  0  3  0  1  0  0	115.3920422
3MS2	Compound 0  0  0  3 -2  0  0  0	26.9523126
3MS4	Compound 0  0  0  3 -1  0  0  0	56.9523126
3MS8	Compound 0  0  0  3  1  0  0  0	116.9523126
ALP1	Doodson 1 -5 3 1 0 90     2\n  -1  0  0 .75 0.0360R1   0 -1  0 .00 0.1906	12.3827651
BET1	Doodson 1 -1 -1 1 0 -90   1\n  0 -1  0 .00 0.2266	14.4145567
CHI1	Basic 1 -1 3 -1 0 -90   0 -1 0 0 0 0     76	14.5695476
H1	Doodson 2 -2 1 0 1 180    2\n  0 -1  0 .50 0.0224     1  0 -1 .50 0.0447	28.9430375
H2	Doodson 2 -2 3 0 -1 0     1\n  0 -1  0 .50 0.0217	29.0251709
KJ2	Basic 2 1 2 -1 0 0      0 -2 0 0 0 0     79	30.626512
ETA2	Doodson 2 1 2 -1 0 0      7\n  0 -1  0 .50 0.0187     0  1  0 .0  0.4355     0  2  0 .0  0.0467\n  1  0  0 .75 0.0747R2   1  1  0 .75 0.0482R2   1  2  0 .75 0.0093R2\n  2  0  0 .50 0.0078	30.626512
KQ1	Basic 1 3 1 -1 0 -90    -2 -1 0 0 0 0    77	16.6834764
UPS1	Doodson 1 3 1 -1 0 -90    5\n  -2  0  0 .00 0.0611     0  1  0 .00 0.6399     0  2  0 .00 0.1318\n  1  0  0 .25 0.0289R1   1  1  0 .25 0.0257R1	16.6834764
M10	Compound 0 0 0 5 0 0 0 0	144.9205211
M12	Compound 0 0 0 6 0 0 0 0	173.9046253
MK4	Compound 0  0  0  1  0  0  0  1	59.0662415
MKS2	Compound 0  0  0  1 -1  0  0  1	29.0662415
MNS2	Compound 0  0  0  1 -1  1  0  0	27.4238337
EPS2	Doodson 2 -5 4 1 0 0   3\n  -1 -1  0 .25 0.0075R2  -1  0  0 .25 0.0402R2   0 -1  0 .50 0.0373	27.4238337
MO3	Compound 1 0 0 1 0 0 0 0	42.9271398
MP1	Basic 1 -2 3 0 0 -90    0 -1 0 0 0 0     76	14.0251729
TAU1	Doodson 1 -2 3 0 0 -90    5\n  -2  0  0 .0  0.0446    -1  0  0 .25 0.0426R1   0 -1  0 .50 0.0284\n  0  1  0 .50 0.2170     0  2  0 .50 0.0142	14.0251729
MPS2	Compound 0 0 1 1 0 0 0 0 0 0 -1	28.9430356
MSK6	Compound 0  0  0  1  1  0  0  1	89.0662415
MSM	Basic 0 1 -2 1 0 0      0 0 0 0 0 0      73	0.4715211
MSN2	Compound 0  0  0  1  1 -1  0  0	30.5443747
MSN6	Compound 0  0  0  1  1  1  0  0	87.4238337
NLK2	Compound 0 0 0 0 0 1 1 -1	27.8860711
NO1	Compound -1 0 0 0 0 1 0 0	14.4966939
OP2	Compound 1  0  1  0  0  0  0  0	28.9019669
OQ2	Doodson 2 -5 2 3 0 0   2\n  -1  0  0 .25 0.1042R2   0 -1  0 .50 0.0386	27.3509801
PHI1	Basic 1 0 3 0 0 -90     0 0 0 0 0 0      1	15.1232059
KP1	Compound 0 0 -1 0 0 0 0 1	15.1232059
PI1	Basic 1 0 -2 0 1 90     0 0 0 0 0 0      1	14.9178647
TK1	Basic 1 0 -2 0 1 90     0 0 1 0 0 0      227	14.9178647
PSI1	Basic 1 0 2 0 -1 -90    0 0 0 0 0 0      1	15.0821353
RP1	Basic 1 0 2 0 -1 90     0 0 0 0 0 0      1	15.0821353
S3	Basic 3 0 0 0 0 0       0 0 0 0 0 0      1	45
SIG1	Basic 1 -4 3 0 0 90     2 -1 0 0 0 0     75	12.9271398
SK3	Compound 0  1  0  0  1  0  0  0	45.0410686
SK4	Compound 0 0 0 0 1 0 0 1	60.0821373
SN4	Compound 0  0  0  0  1  1  0  0	58.4397295
SNK6	Compound 0 0 0 0 1 1 0 1	88.5218668
SO1	Basic 1 2 -1 0 0 -90    0 -1 0 0 0 0     76	16.0569644
SO3	Compound 1  0  0  0  1  0  0  0	43.9430356
THE1	Basic 1 1 -1 1 0 -90    0 -1 0 0 0 0     76	15.5125897
2PO1	Compound -1  0  2  0  0  0  0  0	15.9748271
2NS2	Compound 0  0  0  0 -1  2  0  0	26.879459
MLN2S2	Compound 0  0  0  1 -2  1  1  0	26.9523126
2ML2S2	Compound 0  0  0  2 -2  0  1  0	27.4966873
SKM2	Compound 0  0  0 -1  1  0  0  1	31.0980331
2MS2K2	Compound 0  0  0  2  1  0  0 -2	27.8039339
MKL2S2	Compound 0  0  0  1 -2  0  1  1	28.5947204
M2(KS)2	Compound 0  0  0  1 -2  0  0  2	29.1483788
2SN(MK)2	Compound 0  0  0 -1  2  1  0 -1	29.373488
2KM(SN)2	Compound 0  0  0  1 -1 -1  0  2	30.7086493
NO3	Compound 1  0  0  0  0  1  0  0	42.3827651
2MLS4	Compound 0  0  0  2 -1  0  1  0	57.4966873
ML4	Compound 0  0  0  1  0  0  1  0	58.5125831
N4	Compound 0  0  0  0  0  2  0  0	56.879459
SL4	Compound 0  0  0  0  1  0  1  0	59.5284789
MNO5	Compound 1  0  0  1  0  1  0  0	71.3668693
2MO5	Compound 1  0  0  2  0  0  0  0	71.911244
MSK5	Compound 0  1  0  1  1  0  0  0	74.0251729
2MP5	Compound 0  0  1  2  0  0  0  0	72.9271398
3MP5	Compound 0  0 -1  3  0  0  0  0	71.9933813
MNK5	Compound 0  1  0  1  0  1  0  0	72.4649024
2NMLS6	Compound 0  0  0  1 -1  2  1  0	85.3920422
MSL6	Compound 0  0  0  1  1  0  1  0	88.5125831
2ML6	Compound 0  0  0  2  0  0  1  0	87.4966873
2MNLS6	Compound 0  0  0  2 -1  1  1  0	85.9364169
3MLS6	Compound 0  0  0  3 -1  0  1  0	86.4807916
2MNO7	Compound 1  0  0  2  0  1  0  0	100.3509735
2NMK7	Compound 0  1  0  1  0  2  0  0	100.9046319
2MSO7	Compound 1  0  0  2  1  0  0  0	101.911244
MSKO7	Compound 1  0  0  1  1  0  0  1	103.0092771
2MSN8	Compound 0  0  0  2  1  1  0  0	116.4079379
2(MS)8	Compound 0  0  0  2  2  0  0  0	117.9682084
2(MN)8	Compound 0  0  0  2  0  2  0  0	114.8476675
2MSL8	Compound 0  0  0  2  1  0  1  0	117.4966873
4MLS8	Compound 0  0  0  4 -1  0  1  0	115.4648958
3ML8	Compound 0  0  0  3  0  0  1  0	116.4807916
3MK8	Compound 0  0  0  3  0  0  0  1	117.0344499
2MSK8	Compound 0  0  0  2  1  0  0  1	118.0503457
2M2NK9	Compound 0  1  0  2  0  2  0  0	129.8887361
3MNK9	Compound 0  1  0  3  0  1  0  0	130.4331108
4MK9	Compound 0  1  0  4  0  0  0  0	130.9774855
3MSK9	Compound 0  1  0  3  1  0  0  0	131.9933813
4MN10	Compound 0  0  0  4  0  1  0  0	144.3761464
3MNS10	Compound 0  0  0  3  1  1  0  0	145.3920422
4MS10	Compound 0  0  0  4  1  0  0  0	145.9364169
3MSL10	Compound 0  0  0  3  1  0  1  0	146.4807916
3M2S10	Compound 0  0  0  3  2  0  0  0	146.9523126
4MSK11	Compound 0  1  0  4  1  0  0  0	160.9774855
4MNS12	Compound 0  0  0  4  1  1  0  0	174.3761464
5MS12	Compound 0  0  0  5  1  0  0  0	174.9205211
4MSL12	Compound 0  0  0  4  1  0  1  0	175.4648958
4M2S12	Compound 0  0  0  4  2  0  0  0	175.9364169
M1C	Basic 1 -1 1 0 0 0   1 -1 0 0 0 0   144	14.4920521
3MKS2	Compound 0 0 0 3 -1 0 0 -1	26.8701754
OQ2-HORN	Compound 1 0 0 0 0 0 0 0 1	27.3416965
MSK2	Compound 0 0 0 1 1 0 0 -1	28.9019669
MSP2	Compound 0 0 -1 1 0 0 0 0 0 0 1	29.0251729
2MP3	Compound 0 0 -1 2 0 0 0 0	43.0092771
4MS4	Compound 0 0 0 4 -2 0 0 0	55.9364169
2MNS4	Compound 0 0 0 2 -1 1 0 0	56.4079379
2MSK4	Compound 0 0 0 2 1 0 0 -1	57.8860711
3MN4	Compound 0 0 0 3 0 -1 0 0	58.5125831
2MSN4	Compound 0 0 0 2 1 -1 0 0	59.5284789
3MK5	Compound 0 -1 0 3 0 0 0 0	71.911244
3MO5	Compound -1 0 0 3 0 0 0 0	73.0092771
3MNS6	Compound 0 0 0 3 -1 1 0 0	85.3920422
4MS6	Compound 0 0 0 4 -1 0 0 0	85.9364169
2MNU6	Compound 0 0 0 2 0 0 0 0 0 1	86.4807916
3MSK6	Compound 0 0 0 3 1 0 0 -1	86.8701754
MKNU6	Compound 0 0 0 1 0 0 0 1 0 1	87.5788246
3MSN6	Compound 0 0 0 3 1 -1 0 0	88.5125831
M7	Compound 0 0 0 3 0 0 0 0 0 0 0 1	101.4490066
2MNK8	Compound 0 0 0 2 0 1 0 1	116.4900752
2(MS)N10	Compound 0 0 0 2 2 1 0 0	146.4079379
MNUS2	Compound 0 0 0 1 -1 0 0 0 0 1	27.4966873
2MK2	Compound 0 0 0 2 0 0 0 -1	27.8860711
3KM5	Compound 0  1  0  1  0  0  0  1	74.1073101
KJ2-IHO	Basic  2 1 2 -1 0 180    0 -2 0 0 0 0   79	30.626512
\.



COPY public.data_sets (index, name, station_id_context, station_id, lat, lng, timezone, country, units, min_dir, max_dir, legalese, notes, comments, source, restriction, date_imported, xfields, meridian, datumkind, datum, months_on_station, last_date_on_station, ref_index, min_time_add, min_level_add, min_level_multiply, max_time_add, max_level_add, max_level_multiply, flood_begins, ebb_begins, original_name, state) FROM stdin;
16144	Baltimore Harbor Approach (off Sandy Point), Maryland Current	NOS	ACT4996_1	39.013	-76.368333	:America/New_York	USA	knots	190	25	\N	\N	1      Baltimore Harbor, Maryland    T.M. 75 W.\n000000 1 3 1 0 0 0 025 190	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore Harbor, Maryland    T.M. 75 W.	MD
16145	Bergen Point Reach (Bayonne Bridge), Kill van Kull, New York Current (16d)	NOS	ACT3951_1	40.641667	-74.143333	:America/New_York	USA	knots	76	259	\N	\N	1      Bayonne Bridge, Kill van Kull, New York      T.M. 75 W\n000000 1 3 1 0 0 0 259 076	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayonne Bridge, Kill van Kull, New York      T.M. 75 W	NY
16157	Pollock Rip Channel (Butler Hole), Massachusetts Current	NOS	ACT1616_1	41.55	-69.983333	:America/New_York	USA	knots	225	35	\N	\N	1      Pollock Rip Channel, Massachusetts    T.M. 75 W.\n  0150 1 3 1 0 0 0 035 225	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pollock Rip Channel, Massachusetts    T.M. 75 W.	MA
16151	Hell Gate (off Mill Rock), New York Current	NOS	ACT3401_1	40.778333	-73.938333	:America/New_York	USA	knots^2	230	50	\N	\N	1      Hell Gate, New York     T.M. 75 W.\n-00600 1 3 1 1 0 0 050 230	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hell Gate, New York     T.M. 75 W.	NY
16148	Charleston Harbor (off Fort Sumter), South Carolina Current	NOS	ACT6651_1	32.756	-79.870333	:America/New_York	USA	knots	127	313	\N	\N	1      Charleston Harbor, South Carolina    T.M. 75 W. ** Used 1997 -> **\n  -217 1 3 1 0 0 0 313 127 0                       Used 1997 ->	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston Harbor, South Carolina    T.M. 75 W. ** Used 1997 -> **	SC
16146	Bolivar Roads, Texas Current (14d)	NOS	ACT8856_2	29.343333	-94.781333	:America/Chicago	USA	knots	123	296	\N	\N	1      Bolivar Roads, Texas   T.M. 90 W.           Used 2000 ->\n-00135 1 3 1 0 0 0 306 116\nHarmonized directions with 2009 predictions	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-06:00:00	\N	-0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolivar Roads, Texas   T.M. 90 W.           Used 2000 ->	TX
16143	Aransas Pass, Texas Current (35d)	NOS	ACT8896_2	27.833833	-97.044167	:America/Chicago	USA	knots	120	300	\N	\N	1      Aransas Pass, Texas     T.M. 90 W           ** USED 1995 -> **\n+00032 1 3 1 0 0 0 300 120                    major axis only	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-06:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas Pass, Texas     T.M. 90 W           ** USED 1995 -> **	TX
16171	Vieques Passage, Puerto Rico Current	NOS	ACT8926_1	18.188333	-65.618333	:America/Puerto_Rico	USA	knots	55	250	\N	\N	1      Vieques Passage, Puerto Rico     T.M. 60 W.\n-00030 1 3 1 0 0 0 250 055	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-04:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vieques Passage, Puerto Rico     T.M. 60 W.	PR
25446	Wrangell Narrows (off Petersburg), Alaska Current (6d)	NOS	SEA0103_8	56.8163	-132.964	:America/Anchorage	USA	knots	62	246	\N	\N	1      Wrangell Narrows (off Petersburg), Alaska  T.M. 135 W\n   290 1 3 1 0 0 0 246 062         Used 2004 ->	NOS data via Mitch Cline and Dean Pentcheff, 2011-02-07	Public domain	2011-04-07	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	0.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell Narrows (off Petersburg), Alaska  T.M. 135 W	AK
16154	Kvichak Bay (off Naknek River entrance), Alaska Current	NOS	PCT5776_1	58.7	-157.25	:America/Anchorage	USA	knots	240	55	\N	\N	1      Kvichak Bay (off Naknek River Entr.), Alaska        T.M. 135 W\n-00300 1 3 1 0 0 0 055 240	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kvichak Bay (off Naknek River Entr.), Alaska        T.M. 135 W	AK
65504	Port Allen, Hanapepe Bay, Kauai Island, Hawaii	NOS	1611347	21.9033	-159.592	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ALLEN, HANAPEPE BAY, KAUAI ISLAND	HI
16152	Isanotski Strait (False Pass Cannery), Alaska Current	NOS	PCT5446_1	54.866667	-163.4	:America/Anchorage	USA	knots^2	185	0	\N	\N	1      Isanotski Strait (False Pass Cannery), Alaska    T.M. 135 W\n000400 1 3 1 1 0 0 000 185	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	0.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isanotski Strait (False Pass Cannery), Alaska    T.M. 135 W	AK
65505	Nawiliwili, Nawiliwili Harbor, Kauai Island, Hawaii	NOS	1611400	21.9544	-159.3561	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nawiliwili	HI
65506	Honolulu, Honolulu Harbor, Oahu Island, Hawaii	NOS	1612340	21.30669444444445	-157.867	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Honolulu	HI
65507	Fort Kamehameha, Bishop Point, Pearl Harbor, Oahu Island, Hawaii	NOS	1612366	21.33	-157.967	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT KAMEHAMEHA, BISHOP POINT, PEARL HBR	HI
65508	Pearl Harbor, Ford Island Ferry Dock, Oahu Island, Hawaii	NOS	1612404	21.3683	-157.94	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORD ISLAND, FERRY DOCK, PEARL HARBOR	HI
65509	Moku o Loe, Kaneohe Bay, Oahu Island, Hawaii	NOS	1612480	21.43305555555556	-157.79	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mokuoloe	HI
65510	Kaunakakai Harbor, Molokai Island, Hawaii	NOS	1613198	21.085	-157.032	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaunakakai Harbor	HI
65511	Kahului, Kahului Harbor, Hawaii	NOS	1615680	20.895	-156.4766944444444	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahului, Kahului Harbor	HI
65512	Kawaihae, Hawaii Island, Hawaii	NOS	1617433	20.0366	-155.8294	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kawaihae	HI
65513	Hilo, Hilo Bay, Kuhio Bay, Hawaii Island, Hawaii	NOS	1617760	19.73027777777778	-155.0555555555555	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hilo, Hilo Bay, Kuhio Bay	HI
65514	Johnston Atoll, Pacific Ocean	NOS	1619000	16.7383	-169.53	:Pacific/Johnston	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnston Atoll	\N
65515	Sand Island, Midway Islands	NOS	1619910	28.2117	-177.36	:Pacific/Midway	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6499999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Island, Midway Islands	\N
65516	Apra Harbor, Guam	NOS	1630000	13.44338888888889	144.6563611111111	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apra Harbor, Guam	GU
65517	Pago Bay, Guam	NOS	1631428	13.4283333	144.7969444	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Bay, Guam	GU
65518	Tanapag Harbor, Saipan Island, Marianas	NOS	1633227	15.2267	145.737	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saipan	MP
65519	Pago Pago, American Samoa	NOS	1770000	-14.2766667	-170.6894444	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Pago, American Samoa	AS
65520	Kwajalein, Marshall Islands	NOS	1820000	8.731666564941406	167.7361145019531	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kwajalein, Marshall Islands	MH
65521	Chuuk, Moen Island, E. Caroline Islands, FSM	NOS	1840000	7.44667	151.847	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHUUK, MOEN ISLAND, E. CAROLINE ISLANDS	FM
65522	Wake Island, Pacific Ocean	NOS	1890000	19.29066666666667	166.6175833333333	:Pacific/Wake	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wake Island, Pacific Ocean	MH
65523	Eastport, Passamaquoddy Bay, Maine	NOS	8410140	44.90330555555556	-66.985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastport	ME
65524	Coffin Point, Coffin Neck, Maine	NOS	8410714	44.87	-67.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COFFIN POINT, COFFIN NECK	ME
65525	Garnet Point, Hersey Neck, Pennamquan River, Cobscook Bay, Maine	NOS	8410715	44.9233	-67.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARNET POINT, HERSEY NECK	ME
65526	Pettegrove Point, Dochet Island, Maine	NOS	8410834	45.12844444444445	-67.14466666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pettegrove Point, Dochet Island	ME
65527	Gravelly Point, Whiting Bay, Maine	NOS	8410864	44.82333333333333	-67.15166666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gravelly Point, Whiting Bay	ME
65528	Cutler (Farris Wharf), Little River, Maine	NOS	8411060	44.65702819824219	-67.20466613769531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Farris Wharf	ME
65529	Cutler Naval Base, Machias Bay, Maine	NOS	8411250	44.6417	-67.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Naval Base	ME
65530	Milbridge, Narraguagus River, Maine	NOS	8412581	44.54	-67.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Milbridge	ME
65531	Bar Harbor, Frenchman Bay, Maine	NOS	8413320	44.39219444444444	-68.20427777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Harbor	ME
65532	Ellsworth, Union River, Blue Hill Bay, Maine	NOS	8413801	44.535	-68.4217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ellsworth	ME
65533	Mackerel Cove, Swans Island, Blue Hill Bay, Maine	NOS	8413825	44.17	-68.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MACKEREL COVE, SWANS ISLAND	ME
65534	Oceanville, Deer Isle, Penobscot Bay, Maine	NOS	8414249	44.19230555555556	-68.62093055555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.289999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oceanville, Deer Isle	ME
65535	Bangor, Penobscot River, Maine	NOS	8414612	44.785	-68.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	ME
65536	Fort Point, Penobscot River, Maine	NOS	8414721	44.4717	-68.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
65537	Pulpit Harbor, North Haven Island, Penobscot Bay, Maine	NOS	8414888	44.1567	-68.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PULPIT HARBOR, PENOBSCOT BAY	ME
65538	Rockland, Penobscot River, Maine	NOS	8415490	44.105	-69.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.329999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockland	ME
65539	Thomaston, St. George River, Maine	NOS	8415709	44.0717	-69.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thomaston	ME
65540	Walpole, Damariscotta River, Maine	NOS	8416731	43.9333	-69.58	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WALPOLE, DAMARISCOTTA RIVER	ME
65541	Wiscasset, Sheepscot River, Maine	NOS	8416921	44	-69.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.059999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wiscasset	ME
65542	Phipps Point, Back River, Maine	NOS	8417087	43.8983	-69.7433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Phipps Pt.	ME
65543	Gardiner, Kennebec River, Maine	NOS	8417134	44.2333	-69.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gardiner	ME
65545	Fort Popham, Hunniwell Point, Kennebec River, Maine	NOS	8417177	43.755	-69.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hunniwell Point	ME
65546	Richmond, Kennebec River, Maine	NOS	8417208	44.0883	-69.7983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9700000000000024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	ME
65547	Bath, Kennebec River, Maine	NOS	8417227	43.925	-69.815	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath	ME
65548	Portland, Casco Bay, Maine	NOS	8418150	43.656700134277344	-70.24669647216797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland	ME
65549	Pine Point, Maine	NOS	8418445	43.545	-70.3333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.759999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pine Point	ME
65551	Biddeford, Saco River, Maine	NOS	8418828	43.4917	-70.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDDEFORD, SACO RIVER	ME
65552	Kennebunkport, Kennebunk River, Maine	NOS	8418911	43.3583	-70.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KENNEBUNKPORT, KENNEBUNK RIVER	ME
65553	Wells, Webhannet River, Maine	NOS	8419317	43.32	-70.56330555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.77	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wells	ME
65554	Seavey Island, Portsmouth Harbor, New Hampshire	NOS	8419870	43.08	-70.7417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seavey Island	NH
65555	Dover, Cocheco River, Piscataqua River, New Hampshire	NOS	8420411	43.1983	-70.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9099999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOVER, COCHECO RIVER	NH
65556	Atlantic Terminals T14A, New Hampshire	NOS	8423005	43.1167	-70.8117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATLANTIC TERMINALS  T14A	NH
65557	Fort Point, Portsmouth Harbor, New Hampshire	NOS	8423898	43.071388244628906	-70.71055603027344	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	NH
65558	Salisbury Point, Merrimack River, Massachusetts	NOS	8440273	42.8383	-70.9083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY POINT, MERRIMACK RIVER	MA
65559	Merrimacport, Merrimack River, Massachusetts	NOS	8440369	42.825	-70.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MERRIMACPORT, MERRIMACK RIVER	MA
65561	Newburyport, Merrimack River, Massachusetts	NOS	8440466	42.815	-70.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWBURYPORT, MERRIMACK RIVER	MA
65562	Riverside, Merrimack River, Massachusetts	NOS	8440889	42.7633	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERSIDE, MERRIMACK RIVER	MA
65563	Plum Island Sound (south end), Massachusetts	NOS	8441241	42.71013888888889	-70.78861111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island South	MA
65564	Rockport Harbor, Massachusetts	NOS	8441551	42.6583	-70.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.709999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROCKPORT HARBOR	MA
65565	Essex, Essex River, Massachusetts	NOS	8441771	42.6317	-70.7767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.080000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESSEX, ESSEX RIVER	MA
65566	Salem, Salem Harbor, Massachusetts	NOS	8442645	42.5233	-70.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALEM, SALEM HARBOR	MA
65567	Lynn, Lynn Harbor, Massachusetts	NOS	8443187	42.4583	-70.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LYNN, LYNN HARBOR	MA
65568	Amelia Earhart Dam, Mystic River, Boston Harbor, Massachusetts	NOS	8443662	42.395	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.239999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AMELIA EARHART DAM, MYSTIC RIVER	MA
65569	Chelsea St. Bridge, Chelsea River, Boston Harbor, Massachusetts	NOS	8443725	42.3867	-71.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chelsea	MA
65570	Boston, Boston Harbor, Massachusetts	NOS	8443970	42.35391666666666	-71.05033333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston	MA
65571	Boston Light, Boston Harbor, Massachusetts	NOS	8444162	42.3283	-70.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.910000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Light	MA
65572	Nut Island, Quincy Bay, Massachusetts	NOS	8444525	42.28	-70.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.170000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nut Island	MA
65573	Shipyard Point, Weymouth Fore River, Massachusetts	NOS	8444788	42.2483	-70.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Fore River	MA
65574	Scituate, Scituate Harbor, Massachusetts	NOS	8445138	42.2017	-70.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SCITUATE, SCITUATE HARBOR	MA
65575	Brant Rock, Green Harbor River, Massachusetts	NOS	8446009	42.0833	-70.6467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRANT ROCK, GREEN HARBOR RIVER	MA
65576	Provincetown, Cape Cod, Massachusetts	NOS	8446121	42.04959166666666	-70.18215833333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.030000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provincetown	MA
65577	Duxbury, Duxbury Harbor, Cape Cod Bay, Massachusetts	NOS	8446166	42.0383	-70.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.489999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUXBURY, DUXBURY HARBOR	MA
65578	Plymouth Harbor, Plymouth, Cape Cod Bay, Massachusetts	NOS	8446493	41.96	-70.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLYMOUTH, PLYMOUTH HARBOR	MA
65579	Cape Cod Canal (Sta. 115), Sagamore, Cape Cod Bay, Massachusetts	NOS	8447173	41.775	-70.535	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.41	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore, Cape Cod Canal (Sta. 115)	MA
65580	Cape Cod Canal, Sandwich, Cape Cod Bay, Massachusetts	NOS	8447180	41.7717	-70.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandwich	MA
65581	Cape Cod Canal (Sta. 200), Bournedale, Cape Cod Bay, Massachusetts	NOS	8447191	41.77	-70.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale, Cape Cod Canal (Sta. 200)	MA
65582	Sesuit Harbor, East Dennis, Cape Cod Bay, Massachusetts	NOS	8447241	41.7517	-70.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.220000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SESUIT HARBOR, EAST DENNIS	MA
65583	Cape Cod Canal (Sta. 320), Bourne Bridge, Cape Cod Bay, Massachusetts	NOS	8447259	41.745	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bourne Bridge, Cape Cod Canal (Sta. 320)	MA
65584	Cape Cod Canal, RR. bridge, Buzzards Bay, Massachusetts	NOS	8447270	41.7417	-70.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buzzards Bay	MA
65585	Gray Gables, Buzzards Bay, Massachusetts	NOS	8447295	41.735	-70.6233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7700000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gray Gables	MA
65586	Great Hill, Buzzards Bay, Massachusetts	NOS	8447368	41.7117	-70.715	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Hill	MA
65587	Fall River, Narragansett Bay, Massachusetts	NOS	8447386	41.70430555555556	-71.16411111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River	MA
65588	Piney Point, Buzzards Bay, Massachusetts	NOS	8447416	41.695	-70.72	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point	MA
65589	Chatham, Cape Cod, Massachusetts	NOS	8447435	41.68847222222222	-69.95108333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.76	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chatham, Lydia Cove	MA
65590	Saquatucket Harbor, Nantucket Sound, Massachusetts	NOS	8447495	41.6683	-70.0567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAQUATUCKET HARBOR	MA
65591	Chatham, Stage Harbor, Cape Cod, Massachusetts	NOS	8447505	41.6667	-69.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHATHAM, STAGE HARBOR	MA
65592	Hyannis Port, Nantucket Sound, Massachusetts	NOS	8447605	41.6317	-70.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HYANNISPORT	MA
65593	Chapoquoit Point, West Falmouth Harbor, Buzzards Bay, Massachusetts	NOS	8447685	41.605	-70.6517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chappaquoit Point	MA
65594	Clarks Point, New Bedford, Buzzards Bay, Massachusetts	NOS	8447712	41.5933	-70.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BEDFORD, CLARKS POINT	MA
65595	Round Hill Point, Buzzards Bay, Massachusetts	NOS	8447842	41.5383	-70.9283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6700000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROUND HILL POINT	MA
65596	Woods Hole, Buzzards Bay, Massachusetts	NOS	8447930	41.52361297607422	-70.67111206054688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole	MA
65597	Vineyard Haven Harbor, Vineyard Haven, Massachusetts	NOS	8448157	41.4583	-70.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VINEYARD HAVEN, VINEYARD HVN HBR	MA
65598	Penikese Island, Buzzards Bay, Massachusetts	NOS	8448248	41.45	-70.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PENIKESE ISLAND	MA
65599	Edgartown, Martha's Vineyard, Massachusetts	NOS	8448558	41.3883	-70.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgartown	MA
65600	Menemsha Harbor, Massachusetts	NOS	8448725	41.35444444444445	-70.76783333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Menemsha Harbor, MA	MA
65601	Martha's Vineyard GPS buoy, Martha's Vineyard, Massachusetts	NOS	8448875	41.32622222222222	-70.59033333333333	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martha's Vineyard GPS Buoy	MA
65602	Nantucket, Nantucket Island, Nantucket Island, Massachusetts	NOS	8449130	41.2852783203125	-70.09638977050781	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nantucket Island	MA
65603	Sakonnet, Sakonnet River, Rhode Island	NOS	8450768	41.465	-71.1933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6100000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAKONNET	RI
65604	Bristol Ferry, Narragansett Bay, Rhode Island	NOS	8451552	41.6367	-71.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRISTOL FERRY	RI
65605	Bristol Highlands, Narragansett Bay, Rhode Island	NOS	8452154	41.69670104980469	-71.29329681396484	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bristol Highlands	RI
65606	Newport, Narragansett Bay, Rhode Island	NOS	8452660	41.505	-71.3267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport	RI
65607	Conimicut Light, Narragansett Bay, Rhode Island	NOS	8452944	41.71666666666667	-71.34333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Conimicut Light	RI
65608	West Jamestown, Dutch Island Harbor, Conanicut Island, Rhode Island	NOS	8453742	41.4967	-71.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST JAMESTOWN	RI
65609	Providence, State Pier no.1, Narragansett Bay, Rhode Island	NOS	8454000	41.8066667	-71.4005556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Providence	RI
65610	Quonset Point, Rhode Island	NOS	8454049	41.5868	-71.411	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quonset Point	RI
65611	Wickford, Narragansett Bay, Rhode Island	NOS	8454538	41.5717	-71.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WICKFORD, NARRAGANSETT BAY	RI
65612	East Greenwich, Narragansett Bay, Rhode Island	NOS	8454578	41.665000915527344	-71.44499969482422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Greenwich	RI
65613	Point Judith, Harbor of Refuge, Rhode Island	NOS	8455083	41.3633	-71.49	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT JUDITH, HARBOR OF REFUGE	RI
65614	Kickamuit River, Narragansett Bay, Rhode Island	NOS	8455137	41.707801818847656	-71.24169921875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1900000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kickamuit River	RI
65615	Westerly, Pawcatuck River, Rhode Island	NOS	8455189	41.3817	-71.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westerly Pawcatuck	RI
65616	Weekapaug Point, Block Island Sound, Rhode Island	NOS	8458022	41.3283	-71.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEEKAPAUG POINT, BLOCK ISLAND SOUND	RI
65617	Block Island (Old Harbor), Rhode Island	NOS	8459338	41.1733	-71.5567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
65619	Block Island (SW end), Block Island Sound, Rhode Island	NOS	8459681	41.1633	-71.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
65620	West Mystic, Mystic River, Long Island Sound, Connecticut	NOS	8460751	41.343299865722656	-71.9749984741211	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Mystic River	CT
65621	New London, Thames River, Connecticut	NOS	8461490	41.355	-72.0867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5399999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London, Thames River	CT
65622	Clinton Harbor, Connecticut	NOS	8463701	41.2683	-72.5317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.469999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Harbor	CT
65623	New Haven Harbor, New Haven Reach, Connecticut	NOS	8465705	41.2833	-72.9083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven	CT
65624	Bridgeport Harbor, Bridgeport, Connecticut	NOS	8467150	41.17575	-73.18402777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport	CT
65625	Black Rock Harbor, Cedar Creek, Connecticut	NOS	8467373	41.1567	-73.2133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.630000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Rock Harbor	CT
65626	Southport, Southport Harbor, Connecticut	NOS	8467726	41.1333	-73.2833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport, Southport Harbor	CT
65627	Saugatuck, Saugatuck River, Long Island Sound, Connecticut	NOS	8468191	41.119998931884766	-73.36830139160156	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saugatuck River	CT
65628	South Norwalk, Norwalk River, Connecticut	NOS	8468448	41.0967	-73.415	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Norwalk	CT
65629	Long Neck Point, Long Island Sound, Connecticut	NOS	8468799	41.0383	-73.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.82	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG NECK POINT, LONG ISLAND SOUND	CT
65630	Mianus, Connecticut	NOS	8469057	41.039194	-73.592028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mianus	CT
65631	Stamford Harbor, Stamford, Connecticut	NOS	8469198	41.0383	-73.5467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stamford Harbor	CT
65633	Lake Montauk, Long Island, New York	NOS	8510448	41.0733	-71.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Montauk	NY
65634	Montauk, Fort Pond Bay, Long Island Sound, New York	NOS	8510560	41.0483333	-71.9594444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montauk	NY
65635	Silver Eel Pond, Fishers Island, New York	NOS	8510719	41.2567	-72.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4200000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Eel Pond	NY
65637	Plum Gut Harbor, Plum Island, Long Island, New York	NOS	8511236	41.1717	-72.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND  PLUM GUT HARBOR	NY
65638	Sag Harbor, Shelter Island Sound, New York	NOS	8511629	41.0033	-72.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sag Harbor	NY
65639	Orient Harbor, Orient, Shelter Island Sound, New York	NOS	8511671	41.1367	-72.3067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orient Harbor	NY
65640	Greenport, Shelter Island Sound, New York	NOS	8511907	41.101	-72.36116666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenport	NY
65641	Shinnecock Inlet (ocean), Long Island, New York	NOS	8512354	40.8367	-72.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.610000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK INLET OPEN COAST	NY
65642	Ponquoque Point, Shinnecock Bay, New York	NOS	8512451	40.85	-72.5033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PONQUOGUE POINT	NY
65643	Mattituck Inlet, Long Island Sound, New York	NOS	8512668	41.015	-72.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mattituck Inlet, Long Island	NY
65644	South Jamesport, Great Peconic Bay, New York	NOS	8512735	40.935	-72.5817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jamesport	NY
65645	Shinnecock Yacht Club, Penniman Creek, Shinnecock Bay, New York	NOS	8512769	40.81855555555556	-72.58661111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK YACHT CLUB, PENNIMAN CREEK	NY
65646	Northville, Long Island, New York	NOS	8512987	40.9817	-72.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northville	NY
65647	Moriches Coast Guard Station, Long Island, New York	NOS	8513388	40.7867	-72.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches CGS, Moriches Bay	NY
65648	Moriches Inlet, Long Island, New York	NOS	8513398	40.76441666666667	-72.75597222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches Inlet	NY
65649	Smith Point Bridge, Narrow Bay, Long Island, New York	NOS	8513825	40.7383	-72.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SMITH POINT BRIDGE, NARROW BAY	NY
65650	Patchogue, Patchogue River, Great South Bay, New York	NOS	8514322	40.75	-73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PATCHOGUE, PATCHOGUE RIVER	NY
65651	Cedar Beach, Long Island, New York	NOS	8514422	40.965	-73.0433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR BEACH	NY
65652	Seaview Ferry Dock, Great South Bay, New York	NOS	8514779	40.64925	-73.15061111111112	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seaview Ferry Dock	NY
65653	Fire Island Coast Guard Station, Great South Bay, New York	NOS	8515186	40.6267	-73.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island	NY
65654	Northport, Northport Bay, Long Island, New York	NOS	8515586	40.9	-73.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTHPORT, NORTHPORT BAY	NY
65655	Eatons Neck Point, Long Island, New York	NOS	8515786	40.9533	-73.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck	NY
65656	Huntington Harbor Lighthouse, Huntington Bay, Long Island, New York	NOS	8515921	40.91	-73.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LLOYD HARBOR LIGHTHOUSE	NY
65657	Cold Spring Harbor, Oyster Bay, New York	NOS	8516061	40.8733	-73.47	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLD SPRINGS HARBOR	NY
65658	Green Island, Hempstead Bay, New York	NOS	8516155	40.6233	-73.5017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.759999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREEN ISLAND	NY
65659	Bayville Bridge, Oyster Bay, New York	NOS	8516299	40.9033	-73.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYVILLE BRIDGE, OYSTER BAY	NY
65660	Point Lookout, Long Island, New York	NOS	8516402	40.59388888888889	-73.58397222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lookout	NY
65661	Parsonnage Cove, Long Island, New York	NOS	8516501	40.6333	-73.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.419999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parsonnage Cove	NY
65662	Harry Tappen Marina, Hempstead Harbor, Long Island, New York	NOS	8516607	40.83461111111111	-73.65241666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harry Tappen Marina	NY
65663	Glen Cove Yacht Club, Hempstead Harbor, Long Island, New York	NOS	8516614	40.8633	-73.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GLEN COVE YACHT CLUB, LONG ISLAND	NY
65664	Bay Park, East Rockaway, Hewlett Bay, New York	NOS	8516661	40.63	-73.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5600000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Park, NY	NY
65665	Long Beach (Bridgeview Yacht Club), New York	NOS	8516663	40.59633333333333	-73.65508333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4400000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, NEW YORK	NY
65666	Port Washington, Manhasset Bay, Long Island, New York	NOS	8516761	40.8317	-73.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT WASHINGTON, MANHASSSET BAY	NY
65667	Atlantic Beach, East Rockaway Inlet, Long Island, New York	NOS	8516881	40.595	-73.7433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach	NY
65668	Norton Point, Head of Bay, Jamaica Bay, New York	NOS	8516891	40.635	-73.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTON POINT, HOOK CREEK, NEW YORK	NY
65669	Kings Point, Long Island Sound, New York	NOS	8516945	40.81030555555556	-73.765	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.889999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Point	NY
65670	Willets Point, Little Bay, East River, New York	NOS	8516990	40.7933	-73.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Willets Point	NY
65671	Beach Channel (bridge), Jamaica Bay, New York	NOS	8517137	40.5883	-73.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beach Channel	NY
65672	North Channel Bridge, Grassy Bay, Jamaica Bay, New York	NOS	8517201	40.645	-73.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0299999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Channel	NY
65673	Worlds Fair Marina, Flushing Bay, New York	NOS	8517251	40.761	-73.85036111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Worlds Fair Marina	NY
65675	Kingsborough Community College, Sheepshead Bay, Long Island, New York	NOS	8517756	40.581199645996094	-73.93379974365234	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6499999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsborough CC	NY
65676	Brooklyn Bridge, East River, New York	NOS	8517847	40.7033	-73.995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
65677	Rye Beach (Amusement Park), New York	NOS	8518091	40.9617	-73.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RYE BEACH, AMUSEMENT PARK	NY
65678	Throgs Neck, New York	NOS	8518526	40.805	-73.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck	NY
65679	Port Morris (Stony Point), East River, New York	NOS	8518639	40.8017	-73.9067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Morris	NY
65680	Harlem River, Randalls Island, East River, New York	NOS	8518643	40.8	-73.9283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Randalls Island	NY
65681	Horns Hook, East 90th Street, East River, New York, New York	NOS	8518668	40.7767	-73.9417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5299999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horns Hook	NY
65682	Queensboro Bridge, East River, New York	NOS	8518687	40.7583	-73.9583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Queensboro Bridge	NY
65683	Williamsburg Bridge, East River, New York	NOS	8518699	40.7117	-73.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Williamsburg Bridge	NY
65684	The Battery, New York Harbor, New York	NOS	8518750	40.7005556	-74.0141667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Battery	NY
65685	Ferry Slip, Dyckman Street, Hudson River, New York	NOS	8518902	40.8683	-73.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dyckman Street	NY
65688	Haverstraw Bay, Hudson River, New York	NOS	8518924	41.2183	-73.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAVERSTRAW BAY	NY
65689	Beacon, Flushkill, Hudson River, New York	NOS	8518934	41.5	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon, Hudson River	NY
65690	Hyde Park, Hudson River, New York	NOS	8518951	41.7833	-73.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.009999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hyde Park	NY
65691	Turkey Point Hudson River NERRS, Hudson River, New York	NOS	8518962	42.01390075683594	-73.93920135498047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turkey Point Hudson River NERRS	NY
65692	Albany, Hudson River, New York	NOS	8518995	42.65	-73.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALBANY, HUDSON RIVER	NY
65693	USCG Station, The Narrows, New York	NOS	8519050	40.612	-74.0598611111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station NY	NY
65694	Great Kills Harbor, New Jersey	NOS	8519436	40.5433	-74.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.729999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Kills Harbor	NJ
65695	Bergen Point West Reach, Kill Van Kull, New York	NOS	8519483	40.63669444444444	-74.14169444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bergen Point West Reach	NY
65696	Port Reading, Arthur Kill, New York	NOS	8531142	40.55500030517578	-74.24500274658203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Reading	NY
65697	Cheesequake Creek, Garden State Parkway, New Jersey	NOS	8531223	40.4533	-74.2733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHEESEQUAKE CREEK	NJ
65699	Keasbey, Raritan River, New Jersey	NOS	8531262	40.50830078125	-74.31169891357422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.86	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEASBEY, RARITAN RIVER	NJ
65700	Old Bridge, South River, Raritan River, New Jersey	NOS	8531369	40.41669845581055	-74.36329650878906	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH OLD BRIDGE, SOUTH RIVER	NJ
65701	Sayreville, Raritan River, New Jersey	NOS	8531390	40.47829818725586	-74.35669708251953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAYREVILLE, RARITAN RIVER	NJ
65702	New Brunswick, Raritan River, New Jersey	NOS	8531463	40.48830032348633	-74.43499755859375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BRUNSWICK  RARITAN RIVER	NJ
65703	Sandy Hook, New Jersey	NOS	8531680	40.4669444	-74.0094444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook	NJ
65704	Sea Bright, Shrewsbury River, New Jersey	NOS	8531804	40.365	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Bright	NJ
65705	Toms River (town), Toms River, Barnegat Bay, New Jersey	NOS	8533051	39.95000076293945	-74.19830322265625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toms River	NJ
65706	Stouts Creek, Barnegat Bay, New Jersey	NOS	8533365	39.845	-74.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.44000000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Creek	NJ
65707	Barnegat Inlet, USCG Station, Barnegat Bay, New Jersey	NOS	8533615	39.7617	-74.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BARNEGAT INLET (INSIDE)	NJ
65723	Paulsboro, Mantua Creek, New Jersey	NOS	8538512	39.835	-75.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAULSBORO, MANTUA CREEK	NJ
65708	Shooting Thorofare, Little Egg Inlet, Great Bay, New Jersey	NOS	8534319	39.50830078125	-74.32499694824219	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01409335.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREAT BAY, SHOOTING THOROFARE	NJ
65709	Mays Landing, Great Egg Harbor River, New Jersey	NOS	8534468	39.4483	-74.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYS LANDING, GREAT EGG HARBOR RIVER	NJ
65710	Atlantic City, New Jersey	NOS	8534720	39.355	-74.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic City	NJ
65711	Ventnor City, ocean pier, New Jersey	NOS	8534770	39.335	-74.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENTNOR CITY, FISHING PIER	NJ
65712	Longport, Risely Channel, New Jersey	NOS	8534836	39.3083	-74.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONGPORT, RISELY CHANNEL	NJ
65713	Tuckahoe, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8534883	39.295	-74.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKAHOE,TUCKAHOE RIVER	NJ
65714	Bivalve, Maurice River, Delaware Bay, New Jersey	NOS	8535055	39.23249816894531	-75.03279876708984	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01412150.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1300000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bivalve, Maurice River	NJ
65715	Ocean Drive bridge, Townsends Inlet, New Jersey	NOS	8535375	39.1217	-74.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Townsend Inlet	NJ
65716	Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535419	39.11	-74.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ingram Thorofare	NJ
65738	Inlet (Coast Guard Station), Indian River, Delaware	NOS	8558690	38.61	-75.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	INDIAN RIVER INLET	DE
65739	Ocean City (fishing pier), Maryland	NOS	8570280	38.3267	-75.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN CITY, FISHING PIER	MD
65740	Ocean City Inlet, Maryland	NOS	8570283	38.32833	-75.09166666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean City Inlet	MD
65717	Stone Harbor, Great Channel, Hereford Inlet, New Jersey	NOS	8535581	39.05670166015625	-74.76499938964844	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01411360.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STONE HARBOR, GREAT CHANNEL	NJ
65718	Wildwood Crest, ocean pier, New Jersey	NOS	8535835	38.975	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILDWOOD CREST	NJ
65719	Cape May Canal, Cape May, Delaware Bay, New Jersey	NOS	8536110	38.96777777777778	-74.95972222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May	NJ
65720	Bidwell Creek entrance, Delaware Bay, New Jersey	NOS	8536581	39.1283	-74.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDWELL CREEK ENTRANCE, DELAWARE BAY	NJ
65721	Fortescue Creek, New Jersey	NOS	8536931	39.2383	-75.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORTESCUE CREEK	NJ
65722	Ship John Shoal, Delaware River, New Jersey	NOS	8537121	39.305	-75.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0599999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship John Shoal	NJ
65724	Tacony-Palmyra Bridge, New Jersey	NOS	8538886	40.01194	-75.04299999978807	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacony-Palmyra Bridge	NJ
65725	Burlington, Delaware River, New Jersey	NOS	8539094	40.08	-74.87333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burlington, Delaware River	NJ
65726	Fieldsboro, Delaware River, New Jersey	NOS	8539487	40.1367	-74.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDSBORO, DELAWARE RIVER	NJ
65727	Trenton Marine Terminal, Trenton, New Jersey	NOS	8539993	40.1883	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.470000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TRENTON MARINE TERMINAL	NJ
65728	Marcus Hook, Pennsylvania	NOS	8540433	39.8116667	-75.4094444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook	PA
65729	Philadelphia (USCG Station), Delaware River, Pennsylvania	NOS	8545240	39.93333333333333	-75.14166666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4899999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Philadelphia	PA
65730	Philadelphia, Municipal Pier 11, Pennsylvania	NOS	8545530	39.9533	-75.1383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHILADELPHIA (PIER 11 NORTH), DEL. RIVER	PA
65731	Bridesburg, Philadelphia, Pennsylvania	NOS	8546252	39.98333333333333	-75.075	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridesburg	PA
65732	Newbold, Delaware River, Pennsylvania	NOS	8548989	40.13730555555556	-74.75188888888889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.329999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold	PA
65733	Delaware City, Delaware River, Delaware	NOS	8551762	39.5817	-75.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.960000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware City	DE
65734	Reedy Point, C&D Canal, Delaware	NOS	8551910	39.5583	-75.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9199999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
65735	Mahon River entrance, Delaware Bay, Delaware	NOS	8554399	39.185	-75.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mahon River Entrance	DE
65736	Brandywine Shoal Light, Delaware Bay, New Jersey	NOS	8555889	38.98667	-75.11333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.610000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light	NJ
65737	Lewes, Fort Miles, Delaware	NOS	8557380	38.782779693603516	-75.1191635131836	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewes	DE
65741	South Point, Sinepuxent Neck, Chincoteague Bay, Maryland	NOS	8570536	38.215	-75.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH POINT, SINEPUXENT NECK, CHINC. BAY	MD
65742	Public Landing, Chincoteague Bay, Maryland	NOS	8570649	38.1483	-75.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUBLIC LANDING, CHINCOTEAGUE BAY	MD
65743	Buntings Bridge, Chincoteague Bay, Maryland	NOS	8570691	38.13894444444445	-75.18352777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buntings Bridge	MD
65744	Crisfield, Little Annemessex River, Chesapeake Bay, Maryland	NOS	8571091	37.9767	-75.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISFIELD	MD
65745	Ewell, Smith Island, Chesapeake Bay, Maryland	NOS	8571117	37.995	-76.0317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ewell, Smith Island	MD
65746	Snow Hill, city park, Pocomoke River, Maryland	NOS	8571359	38.17833	-75.39666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Hill	MD
65747	Bishops Head, Hooper Strait, Maryland	NOS	8571421	38.22038888888889	-76.03866666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishops Head	MD
65748	McCready's Creek, Fishing Bay, Chesapeake Bay, Maryland	NOS	8571559	38.3	-76.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	McCready's Creek	MD
65749	Barren Island, Chesapeake Bay, Maryland	NOS	8571579	38.3417	-76.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barren Island	MD
65750	Salisbury, Wicomico River, Maryland	NOS	8571616	38.3650016784668	-75.60669708251953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY, WICOMICO RIVER	MD
65751	Smithville Road Bridge, Beaverdam Creek, Little Choptank River, Maryland	NOS	8571702	38.42833	-76.23666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaverdam Creek	MD
65752	Vienna, Nanticoke River, Maryland	NOS	8571773	38.48333	-75.81833333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vienna	MD
65753	Cambridge, Choptank River, Maryland	NOS	8571892	38.5741667	-76.0722222	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cambridge	MD
65754	Poplar Island, Chesapeake Bay, Maryland	NOS	8572271	38.75833333333333	-76.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.78	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Poplar Island	MD
65756	Kent Point Marina, Chesapeake Bay, Maryland	NOS	8572467	38.8367	-76.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kent Point	MD
65757	Hillsboro, Tuckahoe Creek, Maryland	NOS	8572669	38.9167	-75.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4600000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hillsboro	MD
65758	Matapeake, Kent Island, Chesapeake Bay, Maryland	NOS	8572770	38.9567	-76.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matapeake	MD
65759	Love Point, Chester River, Maryland	NOS	8572955	39.0317	-76.3017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Love Point Pier	MD
65760	Crumpton, Chester River, Maryland	NOS	8573349	39.245	-75.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crumpton	MD
65761	Tolchester Beach, Chesapeake Bay, Maryland	NOS	8573364	39.21333	-76.245	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tolchester Beach	MD
65762	Sassafras River, Betterton, Chesapeake Bay, Maryland	NOS	8573704	39.3717	-76.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Betterton	MD
65763	Town Point Wharf, Elk River, Maryland	NOS	8573903	39.5033	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TOWN POINT WHARF	MD
65764	Chesapeake City, Chesapeake and Delaware Canal, Maryland	NOS	8573927	39.5267	-75.81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake City	MD
65765	Havre de Grace, Susquehanna River, Maryland	NOS	8574070	39.5367	-76.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Havre De Grace	MD
65766	Pond Point (Aberdeen P.G.), Bush River, Chesapeake Bay, Maryland	NOS	8574459	39.3883	-76.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POND POINT (ABERDEEN P.G.), BUSH RIVER	MD
65767	Baltimore (Fort McHenry), Maryland	NOS	8574680	39.26667	-76.57833333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore, Fort McHenry, Patapsco River	MD
65768	Fort McHenry Marsh, Patapsco River, Maryland	NOS	8574683	39.2617	-76.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort McHenry Marsh	MD
65769	Annapolis (US Naval Academy), Severn River, Maryland	NOS	8575512	38.98328	-76.4815555551317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Annapolis	MD
65770	Long Beach, Chesapeake Bay, Maryland	NOS	8577004	38.465	-76.4733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Beach	MD
65771	Cove Point, Chesapeake Bay, Maryland	NOS	8577188	38.3917	-76.3983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COVE POINT	MD
65772	Solomons Island, Patuxent River, Maryland	NOS	8577330	38.3172222	-76.4508333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Solomons Island	MD
65773	Lower Marlboro, Patuxent River, Maryland	NOS	8579542	38.655	-76.68333333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1099999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Marlboro	MD
65774	Bladensburg, Anacostia River, Maryland	NOS	8579997	38.9333	-76.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLADENSBURG, ANACOSTIA RIVER	MD
65775	Washington, Potomac River, DC	NOS	8594900	38.87333	-77.02166666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Washington	DC
65776	Jesters Island, Virginia	NOS	8630111	37.9817008972168	-75.30169677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JESTERS ISLAND, CHINCOTEAGUE BAY	VA
65777	Chincoteague Island, USCG station, Virginia	NOS	8630249	37.93170166015625	-75.38330078125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE, USCG STATION	VA
65778	Chincoteague Channel (south end), Chincoteague Bay, Virginia	NOS	8630308	37.9067	-75.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1700000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE CHANNEL, SOUTH END	VA
65779	Wachapreague, Wachapreague Channel, Virginia	NOS	8631044	37.60777777777778	-75.68583333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2899999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wachapreague	VA
65780	Kiptopeke Beach, Chesapeake Bay, Virginia	NOS	8632200	37.16519	-75.98844444433848	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kiptopeke	VA
65782	Rappahannock Light, Virginia	NOS	8632837	37.5383	-76.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Light	VA
65783	Gaskins Point, Occohannock Creek, Chesapeake Bay, Virginia	NOS	8632869	37.5567	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GASKINS PT., OCCOHANNOCK CREEK	VA
65784	Tangier Island, Chesapeake Bay, Virginia	NOS	8633532	37.8283	-75.9933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tangier Island	VA
65785	Saxis, Starling Creek, Virginia	NOS	8633777	37.92169952392578	-75.72830200195312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAXIS, STARLING CREEK	VA
65786	Dahlgren, Upper Machodoc Creek, Potomac River, Virginia	NOS	8635027	38.31975	-77.03661111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dahlgren	VA
65787	Colonial Beach, Potomac River, Virginia	NOS	8635150	38.2517	-76.96	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Colonial Beach, Potomac River	VA
65788	Rappahannock Bend, Virginia	NOS	8635257	38.2133	-77.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Bend	VA
65789	Lewisetta, Potomac River, Virginia	NOS	8635750	37.99538888888889	-76.46461111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewisetta	VA
65790	Wares Wharf, Rappahannock River, Virginia	NOS	8635985	37.8733	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wares Wharf	VA
65791	Windmill Point, Rappahannock River, Virginia	NOS	8636580	37.61611111111111	-76.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Windmill Point	VA
65792	Lester Manor, Pamunkey River, Virginia	NOS	8636653	37.5833	-76.99	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lester Manor	VA
65793	Richmond Deepwater Terminal, James River, Virginia	NOS	8636941	37.45955555555555	-77.42077777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond Deepwater Terminal, James River	VA
65796	Gloucester Point, York River, Virginia	NOS	8637624	37.2467	-76.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2900000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	VA
65797	Yorktown USCG Training Center, York River, Virginia	NOS	8637689	37.2265	-76.47880555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yorktown USCG Training Center	VA
65798	Jamestown Wharf, Jamestown, Virginia	NOS	8637712	37.22011111111111	-76.79141666666666	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=02042770.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jamestown Wharf	VA
65799	Fort Eustis (MARAD), James River, Virginia	NOS	8638017	37.13822222222223	-76.62275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2799999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT EUSTIS (MARAD), JAMES RIVER	VA
65800	Western Branch, Elizabeth River, Virginia	NOS	8638339	36.82322222222222	-76.39911111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Branch	VA
65802	Kingsmill, James River, Virginia	NOS	8638424	37.22	-76.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2799999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsmill	VA
65803	Scotland, James River, Virginia	NOS	8638433	37.185	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotland	VA
65804	Lanexa, Chickahominy River, Virginia	NOS	8638445	37.4033	-76.9117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lanexa, Chickahominy River	VA
65805	Tettington, James River, Virginia	NOS	8638450	37.24	-76.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tettington, James River	VA
65806	Willcox Wharf, Charles City, James River, Virginia	NOS	8638464	37.315	-77.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3099999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilcox Wharf	VA
65807	Hopewell, City Point, James River, Virginia	NOS	8638481	37.3133	-77.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hopewell	VA
65808	Puddledock Sand & Gravel, Appomattox River, Virginia	NOS	8638489	37.2667	-77.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puddledock	VA
65809	Richmond River Locks, James River, Virginia	NOS	8638495	37.525	-77.42	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond River Locks, James River	VA
65810	Sewells Point, Hampton Roads, Virginia	NOS	8638610	36.94666666666667	-76.33	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point	VA
65811	Portsmouth, Naval Shipyard, Elizabeth River, Virginia	NOS	8638660	36.8217	-76.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5299999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORTSMOUTH, NORFOLK NAVAL SHIPYARD	VA
65812	Lafayette River, Virginia	NOS	8638671	36.88422222222222	-76.27585833333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lafayette River	VA
65813	Chesapeake Bay Bridge-Tunnel, Virginia	NOS	8638863	36.9667	-76.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge Tunnel	VA
65836	Wharf 3, MOTSU, Cape Fear River, North Carolina	NOS	8658579	34.0233	-77.9467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUNNY POINT, MOTSU NORTH WHARF	NC
65837	Zekes Island, Cape Fear River, North Carolina	NOS	8658741	33.95	-77.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZEKES ISLAND, CAPE FEAR RIVER	NC
65814	Chesapeake Bay Bridge-Tunnel, Chesapeake Bay, Virginia	NOS	8638901	37.032901763916016	-76.08329772949219	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CBBT, Chesapeake Channel	VA
65815	Inside channel, Rudee Inlet, Virginia	NOS	8639207	36.8317	-75.9733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rudee Inlet	VA
65816	Money Point, South Bridge, Elizabeth River, Virginia	NOS	8639348	36.77830555555556	-76.30169444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Money Point	VA
65817	FRF Pier, Duck, North Carolina	NOS	8651370	36.18330555555556	-75.74669444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7700000000000031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Duck	NC
65818	Manns Harbor, outer coast, North Carolina	NOS	8652247	35.9033	-75.77	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.21999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manns Harbor	NC
65819	Oyster Creek, Croatan Sound, North Carolina	NOS	8652437	35.845	-75.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.31000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Creek	NC
65820	Roanoke Marshes Light, outer coast, North Carolina	NOS	8652547	35.8117	-75.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Marshes Light	NC
65821	Oregon Inlet Marina, Pamlico Sound, North Carolina	NOS	8652587	35.795	-75.5480556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5800000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oregon Inlet Marina	NC
65822	Oregon Inlet (USCG Station), North Carolina	NOS	8652678	35.7683	-75.5267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG LIFEBOAT STATION, OREGON INLET	NC
65823	Avon Seafood dock, Peter's Ditch, Avon, North Carolina	NOS	8653951	35.35013888888889	-75.51202777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peter's Ditch	NC
65824	Cape Hatteras (fishing pier), North Carolina	NOS	8654400	35.2233	-75.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hatteras Fishing Pier	NC
65825	Hatteras (USCG Station), North Carolina	NOS	8654467	35.20863888888889	-75.70416666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station Hatteras	NC
65826	Ocracoke, Ocracoke Island, North Carolina	NOS	8654792	35.115	-75.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCRACOKE ISLAND	NC
65827	Sea Level, Core Sound, North Carolina	NOS	8655875	34.875	-76.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Level	NC
65828	Core Creek Bridge, North Carolina	NOS	8656084	34.82500076293945	-76.69000244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CORE CREEK BRIDGE	NC
65829	Davis, Core Sound, North Carolina	NOS	8656201	34.79675	-76.45547222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Core Sound	NC
65830	Spooner Creek, North Carolina	NOS	8656467	34.725	-76.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spooners Creek	NC
65831	Duke Marine Lab, Beaufort, North Carolina	NOS	8656483	34.72	-76.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaufort, Duke Marine Lab	NC
65832	Triple S Pier, Atlantic Beach, North Carolina	NOS	8656590	34.6933	-76.7117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach Triple S Pier	NC
65833	Cape Lookout Bight, North Carolina	NOS	8656841	34.6133	-76.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE LOOKOUT, LOOKOUT BIGHT	NC
65834	Wilmington, North Carolina	NOS	8658120	34.2275	-77.9536111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington	NC
65835	Wrightsville Beach, North Carolina	NOS	8658163	34.21330555555556	-77.78669444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.150000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrightsville Beach	NC
65838	Southport, Cape Fear River, North Carolina	NOS	8659084	33.915	-78.0183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
65839	Oak Island, Yaupon Beach, North Carolina	NOS	8659182	33.9017	-78.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5400000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oak Island, Atlantic Ocean	NC
65840	Sunset Beach Pier, North Carolina	NOS	8659897	33.865	-78.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunset Beach	NC
65841	Springmaid Pier, South Carolina	NOS	8661070	33.655	-78.91830555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Springmaid Pier	SC
65842	Bucksport, Waccamaw River, South Carolina	NOS	8661139	33.6467	-79.095	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUCKSPORT, WACCAMAW RIVER	SC
65843	Garden City Bridge, Main Creek, Murrells Inlet, South Carolina	NOS	8661419	33.5783	-79.0033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY BRIDGE, MURRELLS INLET	SC
65844	Garden City Pier (ocean), South Carolina	NOS	8661437	33.575	-78.9967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7100000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY PIER, MURRELLS INLET	SC
65845	Oaks Creek, upper end, Murrells Inlet, South Carolina	NOS	8661684	33.5117	-79.0683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OAKS CREEK, UPPER END, MURRELLS INLET	SC
65846	Thoroughfare Creek entrance, Waccamaw River, South Carolina	NOS	8661703	33.5067	-79.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY ISLAND, THOROUGHFARE CREEK	SC
65847	Bennet's Dock, Pawleys Island Creek, South Carolina	NOS	8661989	33.435	-79.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNETT'S DOCK	SC
65848	Pawleys Island Pier (ocean), South Carolina	NOS	8662006	33.4317	-79.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS ISLAND PIER, ATLANTIC OCEAN	SC
65849	Ward's Dock, Pawleys Inlet, South Carolina	NOS	8662071	33.4117	-79.135	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS INLET, WARDS DOCK	SC
65850	Crab Haul Creek north inlet estuary, Oyster Landing, South Carolina	NOS	8662245	33.3517	-79.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Landing (N Inlet Estuary)	SC
65851	Clambank Creek Dock, Goat Island, North Inlet, South Carolina	NOS	8662299	33.3333	-79.1933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7100000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAMBANK CREEK DOCK, GOAT ISLAND	SC
65852	South Island Plantation (C.G. Station), Winyah Bay, South Carolina	NOS	8662746	33.235	-79.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINYAH BAY, SOUTH ISLAND PLANTATION	SC
65853	Waccamaw River entrance, Winyah Bay, South Carolina	NOS	8662931	33.36669921875	-79.25499725341797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.990000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WACCAMAW RIVER ENTRANCE	SC
65854	Windsor Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8662953	33.415	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9599999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINDSOR PLANTATION, BLACK RIVER	SC
65855	General Dynamics Pier, Cooper River, South Carolina	NOS	8664022	33.0083	-79.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GEN. DYNAMICS PIER, COOPER R.	SC
65856	Cainhoy, Wando River, South Carolina	NOS	8664545	32.9267	-79.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5400000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cainhoy, Wando River	SC
65857	Army Depot, Cooper River, South Carolina	NOS	8664662	32.91	-79.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Army Depot	SC
65858	Capers Creek, South Capers Island, South Carolina	NOS	8664941	32.8567	-79.7067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5799999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Capers Island	SC
65859	I-526 bridge, Ashley River, South Carolina	NOS	8665099	32.8367	-80.0217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.289999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-526 BRIDGE, ASHLEY RIVER	SC
65861	Clarendon Plantation, South Carolina	NOS	8667633	32.5025	-80.7841	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clarendon Plantation	SC
65862	Beaufort, Beaufort River, South Carolina	NOS	8667999	32.43	-80.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BEAUFORT	SC
65863	Fripp Inlet, Hunting Island Bridge, St. Helena Sound, South Carolina	NOS	8668498	32.34	-80.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fripps Inlet	SC
65864	Skull Creek, Ribaut Island, South Carolina	NOS	8668918	32.2667	-80.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIBAUT ISLAND, SKULL CREEK	SC
65865	Port Wentworth, Savannah River, Georgia	NOS	8670424	32.1433	-81.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Wentworth	GA
65869	Skidaway Institute, Skidaway River, Georgia	NOS	8671086	31.99	-81.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.2700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SKIDAWAY INSTITUTE, SKIDAWAY RIVER	GA
65870	Halfmoon Reef, Halfmoon River, Georgia	NOS	8671314	31.963300704956055	-80.94329833984375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALFMOON REEF, HALFMOON RIVER	GA
65871	Priest Landing, Wilmington River, Georgia	NOS	8671315	31.963300704956055	-81.01170349121094	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRIEST LANDING, WILMINGTON RIVER	GA
65872	Bear River, (Range 'A' Light), Georgia	NOS	8672667	31.7933	-81.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A Light, Bear River	GA
65873	Sunbury, Sunbury Channel, Georgia	NOS	8672875	31.7667	-81.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunbury, Sunbury Channel	GA
65874	South Ossabaw Island, Bear River, Georgia	NOS	8673171	31.72302777777778	-81.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ossabaw Island, Bear River	GA
65875	South Newport River (Daymark 135), Georgia	NOS	8674301	31.575	-81.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7900000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #135, South Newport River	GA
65876	Mud River, head of (Daymark 156), Georgia	NOS	8674975	31.4867	-81.32	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #156, Head of Mud River	GA
65877	Rockdedundy River (Daymark 185), Georgia	NOS	8675761	31.37386111111111	-81.33394444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #185, Rockdedundy River Entrance	GA
65878	Crispen Island, Turtle River, Georgia	NOS	8676808	31.213300704956055	-81.55000305175781	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISPEN ISLAND,TURTLE RIVER	GA
65879	St. Simons Lighthouse, St. Simons Island, Georgia	NOS	8677344	31.1317	-81.3967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5699999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St.Simons Island	GA
65880	Howe Street Pier, Brunswick, Georgia	NOS	8677406	31.14455555555556	-81.49680555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.009999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Howe Street Pier, Brunswick	GA
65881	Raccoon Key Spit, St. Andrew Sound, Georgia	NOS	8678124	31.01480555555555	-81.45597222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5599999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Key Spit	GA
65882	Bailey Cut, 0.8 mile west of, Satilla River, Georgia	NOS	8678322	30.985	-81.5917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bailey Cut, Satilla River	GA
65883	Kings Bay, Navy Base, Georgia	NOS	8679511	30.7967	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KINGS BAY	GA
65884	Dungeness, Seacamp Dock, Georgia	NOS	8679758	30.7633	-81.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUNGENESS, SEACAMP DOCK	GA
65885	St. Marys, St. Marys River, Georgia	NOS	8679964	30.72	-81.5483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARYS, ST. MARYS RIVER	GA
65886	Crandall, St. Marys River, Florida	NOS	8720004	30.7217	-81.6217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRANDALL, ST. MARYS RIVER	FL
65887	Cut 1N front range, St. Marys River, Florida	NOS	8720011	30.7083	-81.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 1N FRONT RANGE, ST MARYS RIVER ENTR	FL
65889	Chester, Bells River, Florida	NOS	8720023	30.6833	-81.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHESTER, BELLS RIVER	FL
65890	Fernandina Beach, Amelia River, Florida	NOS	8720030	30.6713889	-81.4658333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach	FL
65891	Lofton, Lanceford Creek, Florida	NOS	8720051	30.6433	-81.5233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANCEFORD CREEK, LOFTON	FL
65892	Vaughns Landing, Florida	NOS	8720059	30.63	-81.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaughns Landing	FL
65893	Nassauville, Nassau River East, Florida	NOS	8720098	30.5683	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NASSAUVILLE, NASSAU RIVER EAST	FL
65894	Edwards Creek, Nassau River, Florida	NOS	8720145	30.5017	-81.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edwards Creek	FL
65895	Cedar Heights, Broward River, Florida	NOS	8720189	30.4367	-81.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR HEIGHTS	FL
65896	Sisters Creek, Florida	NOS	8720196	30.4167	-81.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3800000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SISTERS CREEK	FL
65897	Clapboard Creek, Pelotes Island, Florida	NOS	8720198	30.4067	-81.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAPBOARD CREEK	FL
66268	Charleston, Coos Bay, Oregon	NOS	9432780	43.345	-124.322	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston	OR
65898	Water Treatment Dock, Mayport Naval Station, St Johns River, Florida	NOS	8720211	30.4	-81.4133	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Naval Sta., St Johns River	FL
65899	Sherwood Forest, Trout River, Florida	NOS	8720213	30.42	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TROUT R., SHERWOOD FOREST	FL
65900	Degaussing structure, Mayport Naval Station, Florida	NOS	8720214	30.3967	-81.395	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Degaussing Structure	FL
65901	Bar Pilot Dock, St. Johns River, Florida	NOS	8720218	30.39816666666667	-81.42788888888889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.469999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Bar Pilots Dock)	FL
65902	Dame Point, St. Johns River, Florida	NOS	8720219	30.3867	-81.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8500000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point	FL
65903	Mayport (Ferry Depot), Florida	NOS	8720220	30.3933	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Ferry Depot)	FL
65904	Mayport, St. Johns River, Florida	NOS	8720224	30.395	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYPORT, ST JOHNS RIVER	FL
65905	Phoenix Park, Florida	NOS	8720225	30.3833	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHOENIX PARK	FL
65906	Main Street Bridge, St. Johns River, Florida	NOS	8720226	30.32	-81.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southbank Riverwalk, St Johns River	FL
65907	Jacksonville, Long Branch, Florida	NOS	8720242	30.36	-81.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Longbranch	FL
65908	Jacksonville Beach, Florida	NOS	8720291	30.2833	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacksonville Beach	FL
65909	I-295 Bridge (west end), St. Johns River, Florida	NOS	8720357	30.1917	-81.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.53	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-295 Bridge, St Johns River	FL
65910	Peoria Point, Doctors Lake, Florida	NOS	8720406	30.12	-81.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOCTORS LAKE, PEORIA POINT	FL
65911	Black Creek, S.C.L. RR. bridge, Florida	NOS	8720434	30.08	-81.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACK CREEK	FL
65912	Red Bay Point, St. Johns River, Florida	NOS	8720503	29.98166666666667	-81.63416666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Point, St Johns River	FL
65913	Vilano Beach ICWW, Tolomato River, Florida	NOS	8720554	29.9167	-81.3	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vilano Beach ICWW	FL
65924	Daytona Beach Shores, Sunglow Pier, Florida	NOS	8721120	29.1467	-80.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH SHORES	FL
65925	Ponce De Leon Inlet South, Florida	NOS	8721147	29.0633	-80.915	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ponce De Leon Inlet South	FL
65914	State Road 312, Matanzas River, ICWW, Florida	NOS	8720582	29.8667	-81.3067	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road 312, Matanzas River	FL
65915	St. Augustine Beach, Florida	NOS	8720587	29.8567	-81.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4300000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Augustine Beach	FL
65916	Racy Point, St. Johns River, Florida	NOS	8720625	29.8017	-81.5483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Racy Point, St Johns River	FL
65917	Crescent Beach, Matanzas River, ICWW, Florida	NOS	8720651	29.7683	-81.2583	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent Beach, Matanzas River	FL
65918	State Road A1A Bridge, Florida	NOS	8720692	29.70453055555556	-81.22785555555555	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road A1A Bridge	FL
65919	Bings Landing, Matanzas River, ICWW, Florida	NOS	8720757	29.615	-81.205	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bings Landing, Matanzas River	FL
65942	South Delray Beach, ICWW, Florida	NOS	8722761	26.4467	-80.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH DELRAY BEACH	FL
65943	Lake Wyman, ICWW, Florida	NOS	8722802	26.37	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKE WYMAN	FL
65920	Buffalo Bluff, St. Johns River, Florida	NOS	8720767	29.595	-81.6817	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5800000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buffalo Bluff, St Johns River	FL
65921	Palatka, St. Johns River, Florida	NOS	8720774	29.6433	-81.6317	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.72	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Palatka, St Johns River	FL
65922	Welaka, St. Johns River, Florida	NOS	8720832	29.4767	-81.675	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Welaka	FL
65926	Mosquito Lagoon, New Smyrna Beach, Florida	NOS	8721164	29.0233	-80.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Smyrna Beach	FL
65927	Packwood Place, Florida	NOS	8721222	28.94	-80.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PACKWOOD PLACE	FL
65928	Turtle Mound, Florida	NOS	8721223	28.9267	-80.825	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE MOUND	FL
65929	Trident Pier, Port Canaveral, Florida	NOS	8721604	28.4158333	-80.5930556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Pier, Port Canaveral	FL
65931	Cocoa Beach, Florida	NOS	8721649	28.3683	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCOA BEACH, ATLANTIC OCEAN	FL
65932	Vero Beach, Indian River, Florida	NOS	8722125	27.6317	-80.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.43000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vero Beach	FL
65933	North Beach Causeway, Indian River, Florida	NOS	8722208	27.4717	-80.325	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Beach Causeway	FL
65934	Fort Pierce Inlet, Binney Dock, Florida	NOS	8722213	27.4683	-80.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Binney Dock	FL
65935	South Beach Causeway, Indian River, Florida	NOS	8722219	27.4567	-80.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach Causeway	FL
65936	PGA Boulevard Bridge, Palm Beach, Florida	NOS	8722548	26.8433	-80.0667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PGA Boulevard Bridge, Palm Beach	FL
65937	Port of West Palm Beach, Florida	NOS	8722588	26.77	-80.0517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of West Palm Beach	FL
65938	Lake Worth ICW, Florida	NOS	8722669	26.6133	-80.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth ICW	FL
65939	Lake Worth Pier, Florida	NOS	8722670	26.6127778	-80.0341667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Pier, Atlantic Ocean	FL
65941	Ocean Ridge, ICWW, Florida	NOS	8722718	26.52669906616211	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN RIDGE	FL
65944	Boca Raton, Lake Boca Raton, Florida	NOS	8722816	26.343299865722656	-80.07669830322266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA RATON	FL
65945	Hillsboro Inlet Marina, Florida	NOS	8722859	26.260000228881836	-80.08499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HILLSBORO	FL
65946	Lauderdale-by-the-Sea, Anglin Fishing Pier, Florida	NOS	8722899	26.18829917907715	-80.09329986572266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4599999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAUDERDALE-BY-THE-SEA	FL
65947	South Port Everglades, ICWW, Florida	NOS	8722956	26.08169937133789	-80.11669921875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port Everglades	FL
65948	Haulover Pier, N. Miami Beach, Florida	NOS	8723080	25.9033	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAULOVER PIER, N. MIAMI BEACH	FL
65949	Miami, Miamarina, Biscayne Bay, Florida	NOS	8723165	25.7783	-80.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI, BISCAYNE BAY	FL
65950	Miami Beach (city pier), Florida	NOS	8723170	25.7683	-80.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Beach	FL
65952	Virginia Key, Bear Cut, Biscayne Bay, Florida	NOS	8723214	25.7314	-80.1618	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1099999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Virginia Key, Biscayne Bay	FL
65953	Cutler, Biscayne Bay, Florida	NOS	8723289	25.615	-80.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTLER, BISCAYNE BAY	FL
65954	Ragged Key No. 5, Biscayne Bay, Florida	NOS	8723355	25.5233	-80.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RAGGED KEY NO. 5, BISCAYNE BAY	FL
65955	Elliott Key Harbor, Elliott Key, Biscayne Bay, Florida	NOS	8723409	25.4533	-80.1967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELLIOTT KEY HARBOR, ELLIOTT KEY	FL
65956	Turkey Point, Biscayne Bay, Florida	NOS	8723423	25.4367	-80.33	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT, BISCAYNE BAY	FL
65957	East Arsenicker, Card Sound, Florida	NOS	8723465	25.3733	-80.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST ARSENICKER, CARD SOUND	FL
65958	Pumpkin Key, south end, Card Sound, Florida	NOS	8723506	25.325	-80.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUMPKIN KEY, CARD SOUND	FL
65959	Little Card Sound bridge, Florida	NOS	8723534	25.2883	-80.37	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARD SOUND BRIDGE	FL
65960	Key Colony Beach, Florida	NOS	8723962	24.7183	-81.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key Colony Beach	FL
65961	Vaca Key, Florida Bay, Florida	NOS	8723970	24.711	-81.1065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5099999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaca Key, Florida Bay	FL
65962	Boca Chica Marina, Florida	NOS	8724493	24.575	-81.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6499999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA CHICA MARINA	FL
65963	Fleming Key, north end, Florida	NOS	8724571	24.5917	-81.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7100000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key	FL
65964	Key West, Florida	NOS	8724580	24.55083333333333	-81.80805555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West	FL
65965	Sand Key Lighthouse, Sand Key Channel, Florida	NOS	8724635	24.4533	-81.8783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAND KEY LIGHTHOUSE	FL
65966	Smith Shoal Light, Florida	NOS	8724671	24.71827777777778	-81.92152777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Shoal Light	FL
65967	Loggerhead Key, Dry Tortugas, Florida	NOS	8724698	24.6317	-82.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Loggerhead Key	FL
65968	Dismal Key, Pumpkin Bay, Florida	NOS	8724963	25.895	-81.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DISMAL KEY, PUMPKIN BAY	FL
65969	Coon Key Pass, Gullivan Bay, Florida	NOS	8724964	25.8967	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COON KEY PASS, GULLIVAN BAY	FL
65970	Marco Island, Caxambas Pass, Florida	NOS	8724967	25.9083	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.68	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO ISLAND, CAXAMBAS PASS	FL
65971	Marco, Big Marco River, Florida	NOS	8724991	25.9717	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO, BIG MARCO RIVER	FL
65972	McIlvaine Bay, Florida	NOS	8724996	25.985	-81.7017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.44	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MCILVAINE BAY	FL
65973	Keewaydin Island (inside), Florida	NOS	8725019	26.025	-81.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEEWAYDIN ISLAND, INSIDE	FL
65974	Naples, Gulf Of Mexico, Florida	NOS	8725110	26.13166666666667	-81.80747222222222	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naples, Gulf of Mexico	FL
65975	Coconut Point, Estero Bay, Florida	NOS	8725319	26.4	-81.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCONUT POINT, ESTERO BAY	FL
65976	Estero Island, Estero Bay, Florida	NOS	8725351	26.4383	-81.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTERO ISLAND, ESTERO BAY	FL
65977	Tarpon Bay, Sanibel Island, Florida	NOS	8725362	26.4433	-82.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TARPON BAY	FL
65978	Hendry Creek, Estero Bay, Florida	NOS	8725377	26.47	-81.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HENDRY CREEK, ESTERO BAY	FL
65979	Punta Rassa, San Carlos Bay, Florida	NOS	8725391	26.4883	-82.0133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA RASSA, SAN CARLOS BAY	FL
65980	North Captiva Island, Florida	NOS	8725488	26.605	-82.2183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH CAPTIVA ISLAND	FL
65981	Fort Myers, Caloosahatchee River, Florida	NOS	8725520	26.6477	-81.8712	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Myers, Caloosahatchee River	FL
65982	Bokellia, Charlotte Harbor, Florida	NOS	8725541	26.70669937133789	-82.16329956054688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOKEELIA, CHARLOTTE HARBOR	FL
65983	Port Boca Grande, Charlotte Harbor, Florida	NOS	8725577	26.72	-82.2583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT BOCA GRANDE, CHARLOTTE HBR.	FL
65984	Turtle Bay, Charlotte Harbor, Florida	NOS	8725649	26.7967	-82.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE BAY	FL
65985	Don Pedro Island State Park, cutoff (south), Florida	NOS	8725685	26.855	-82.3033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTOFF SOUTH	FL
65986	Locust Point, Hog Island, Charlotte Harbor, Florida	NOS	8725745	26.93	-82.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOCUST POINT, HOG ISLAND	FL
65987	Harbour Heights, Peace River, Charlotte Harbor, Florida	NOS	8725791	26.9883	-81.9933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HARBOUR HEIGHTS, PEACE RIVER	FL
65988	Manasota, Lemon Bay, Florida	NOS	8725809	27.0117	-82.41	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MANASOTA	FL
65989	Myakka River, US 41 bridge, Charlotte Harbor, Florida	NOS	8725837	27.045	-82.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MYAKKA RIVER, US 41	FL
65990	Venice Municipal Airport, Florida	NOS	8725858	27.0717	-82.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GULF OF MEXICO	FL
65991	Egmont Key, Egmont Channel, Tampa Bay, Florida	NOS	8726347	27.6017	-82.76	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EGMONT KEY, TAMPA BAY	FL
65992	Mullet Key Channel (Skyway), Tampa Bay, Florida	NOS	8726364	27.615	-82.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1099999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MULLET KEY, TAMPA BAY	FL
65993	Port Manatee, Tampa Bay, Florida	NOS	8726384	27.6383333	-82.5625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee	FL
65994	Little Manatee River, Florida	NOS	8726436	27.705	-82.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LITTLE MANATEE RIVER	FL
65995	St. Petersburg, Tampa Bay, Florida	NOS	8726520	27.7606	-82.6269	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Petersburg, Tampa Bay	FL
65996	Newman Branch, Tampa Bay, Florida	NOS	8726539	27.7833	-82.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWMAN BRANCH	FL
65997	Port Tampa, Old Tampa Bay, Florida	NOS	8726607	27.8577778	-82.5527778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Port Tampa	FL
65998	Ballast Point, Tampa, Florida	NOS	8726639	27.89	-82.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TAMPA, BALLAST POINT	FL
66000	Clearwater Beach, Gulf Of Mexico, Florida	NOS	8726724	27.9783	-82.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clearwater Beach	FL
66001	Safety Harbor, Old Tampa Bay, Florida	NOS	8726738	27.9883	-82.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAFETY HARBOR, OLD TAMPA BAY	FL
66002	Anclote Lighthouse, Anclote Key, Florida	NOS	8726917	28.165	-82.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANCLOTE LIGHTHOUSE, ANCLOTE KEY	FL
66003	Bayport, Florida	NOS	8727151	28.5333	-82.65	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYPORT	FL
66004	Johns Island, Chassahowitzka Bay, Florida	NOS	8727235	28.6917	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JOHNS ISLAND, CHASSAHOWITZKA BAY	FL
66005	Chassahowitzka, Chassahowitzka River, Florida	NOS	8727246	28.715	-82.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHASSAHOWITZKA RIVER	FL
66006	Mason Creek, Homosassa Bay, Florida	NOS	8727274	28.7617	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MASON CREEK, HOMOSASSA BAY	FL
66007	Tuckers Island, Homosassa River, Florida	NOS	8727277	28.7717	-82.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKERS ISLAND, HOMOSASSA RIVER	FL
66008	Halls River bridge, Homosassa River, Florida	NOS	8727293	28.8	-82.6033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.32999999999999985	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALLS RIVER BRIDGE, HALLS RIVER	FL
66009	Ozello, St. Martin's River, Florida	NOS	8727306	28.825	-82.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.34999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO	FL
66010	Ozello North, Crystal Bay, Florida	NOS	8727328	28.8633	-82.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO NORTH	FL
66011	Mangrove Pt., Crystal Bay, Florida	NOS	8727333	28.87	-82.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mangrove Point	FL
66012	Dixie Bay, Salt River, Crystal Bay, Florida	NOS	8727336	28.8817	-82.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DIXIE BAY	FL
66013	Crystal River, Kings Bay, Florida	NOS	8727343	28.8983	-82.5983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRYSTAL RIVER, KINGS BAY	FL
66014	Twin Rivers Marina, Crystal River, Florida	NOS	8727348	28.905	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Twin Rivers Marina	FL
66015	Shell Island, north end, Crystal River, Florida	NOS	8727359	28.9233	-82.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5099999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL ISLAND, CRYSTAL RIVER	FL
66016	Cedar Key, Gulf Of Mexico, Florida	NOS	8727520	29.135000228881836	-83.03170013427734	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cedar Key	FL
66017	Horseshoe Point, Florida	NOS	8727648	29.4367	-83.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HORSESHOE POINT	FL
66018	Spring Warrior Creek, Florida	NOS	8727843	29.92	-83.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPRING WARRIOR CREEK	FL
66019	St. Marks lighthouse, Apalachee Bay, Florida	NOS	8728130	30.0783	-84.1783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARKS LHTSE., APALACHEE BAY	FL
66020	Shell Point, Walker Creek, Apalachee Bay, Florida	NOS	8728229	30.06	-84.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.95	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL POINT, WALKER CREEK	FL
66021	Turkey Point, Apalachee Bay, St. James Island, Florida	NOS	8728360	29.915	-84.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT	FL
66022	Dog Island, east end, St. George Sound, Florida	NOS	8728408	29.81	-84.585	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOG ISLAND, EAST END	FL
66023	Lanark, St. George Sound, Florida	NOS	8728412	29.878299713134766	-84.59500122070312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANARK, ST. GEORGES SOUND	FL
66024	Carrabelle, Carrabelle River, St. George Sound, Florida	NOS	8728464	29.85	-84.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARRABELLE RIVER, ST. GEORGE SOUND	FL
66025	St. George Island, NE end, St. George Sound, Florida	NOS	8728486	29.766700744628906	-84.69999694824219	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE END, ST. GEORGE ISLAND	FL
66026	South Carrabelle Beach, Florida	NOS	8728488	29.801700592041016	-84.73670196533203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH CARRABELLE BEACH	FL
66027	Cat Point, Apalachicola Bay, Florida	NOS	8728619	29.7233	-84.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAT POINT, APALACHICOLA BAY	FL
66028	St. George Island, 12th St. W (bayside), St. George Sound, Florida	NOS	8728626	29.6533	-84.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. GEORGE ISLAND, BAYSIDE	FL
66029	St. George Island, Sikes Cut, St. George Sound, Florida	NOS	8728669	29.613300323486328	-84.95829772949219	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SIKES CUT, ST. GEORGE ISLAND	FL
66030	Apalachicola, Apalachicola Bay, Florida	NOS	8728690	29.726699829101562	-84.98169708251953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apalachicola	FL
66031	White Beach, East Bay, Florida	NOS	8728694	29.785	-84.8983	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITE BEACH, EAST BAY	FL
66032	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida	NOS	8728711	29.7633	-85.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	APALACHICOLA RIVER	FL
66033	Huckleberry Landing, Jackson River, Florida	NOS	8728757	29.770000457763672	-85.08499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUCKLEBERRY LANDING, JACKSON RIVER	FL
66034	Eleven Mile, St. Vincent Sound, Florida	NOS	8728786	29.70669937133789	-85.1532974243164	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELEVEN MILE, ST. VINCENT SOUND	FL
66035	White City, ICWW, Florida	NOS	8728853	29.88069444444444	-85.22144444444444	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White City, ICWW	FL
66036	Port Saint Joe, St. Joseph Bay, Florida	NOS	8728912	29.815	-85.3133	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port St. Joe	FL
66038	Overstreet, St. Andrew Bay, Florida	NOS	8728957	29.996700286865234	-85.37000274658203	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OVERSTREET	FL
66039	St. Joseph Point, St. Joseph Bay, Florida	NOS	8728958	29.873300552368164	-85.38999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.76	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. JOSEPH POINT, ST. JOSEPH BAY	FL
66040	Panama City, St. Andrew Bay, Florida	NOS	8729108	30.15227777777778	-85.66694444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City	FL
66041	Panama City Beach (outside), St. Andrew Bay, Florida	NOS	8729210	30.213300704956055	-85.87830352783203	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City Beach	FL
66042	Valparaiso, Florida	NOS	8729501	30.5033	-86.4933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valparaiso	FL
66043	Navarre Beach, Florida	NOS	8729678	30.3767	-86.865	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAVARRE BEACH	FL
66044	East Bay, Pensacola Bay, Florida	NOS	8729702	30.450000762939453	-86.91829681396484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST BAY, HOLLEY	FL
66045	Woodlawn Beach, Florida	NOS	8729736	30.386699676513672	-86.99169921875	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WOODLAWN BEACH	FL
66047	Shield Point, Blackwater River, Florida	NOS	8729747	30.58169937133789	-87.01499938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHIELD POINT, BLACKWATER RIVER	FL
66048	Hawkins Recreational Park, Blackwater River, Florida	NOS	8729753	30.636699676513672	-87.0282974243164	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACKWATER RIVER	FL
66049	Hernandez Point North, Florida	NOS	8729791	30.454999923706055	-87.0999984741211	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERNANDEZ POINT NORTH	FL
66050	Fishing Bend, Santa Rosa Sound, Florida	NOS	8729806	30.336700439453125	-87.13999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FISHING BEND, SANTA ROSA SOUND	FL
66051	Lora Point, Escambia Bay, Pensacola Bay, Florida	NOS	8729816	30.514999389648438	-87.16169738769531	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LORA POINT, ESCAMBIA BAY	FL
66052	Floridatown, Escambia Bay, Florida	NOS	8729824	30.58169937133789	-87.18000030517578	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FLORIDATOWN, ESCAMBIA BAY	FL
66053	Pensacola, Florida	NOS	8729840	30.40438888888889	-87.21119444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pensacola	FL
66054	Millview, Perdido Bay, Florida	NOS	8729905	30.4183	-87.3567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Millview, Perdido Bay	FL
66055	Big Lagoon, Florida	NOS	8729909	30.32670021057129	-87.35669708251953	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIG LAGOON	FL
66056	Blue Angels Park, Perdido Bay, Florida	NOS	8729941	30.38694444444445	-87.42880555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blue Angels Park	FL
66057	Alabama Point, Perdido Pass, Alabama	NOS	8730667	30.27861111111111	-87.55500030517578	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alabama Point	AL
66058	Gulf Shores, ICWW, Alabama	NOS	8731439	30.27988888888889	-87.68427777777778	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulf Shores, ICWW	AL
66059	Weeks Bay, Vermilion Bay, Louisiana	NOS	8732828	30.41688888888889	-87.8253888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay, Mobile Bay	LA
66060	Point Clear, Mobile Bay, Alabama	NOS	8733821	30.48663888888889	-87.93452777777777	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Clear, Mobile Bay	AL
66061	Meaher State Park, Mobile Bay, Alabama	NOS	8733839	30.66716666666667	-87.93644444444445	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Meaher State Park, Mobile Bay	AL
66062	Dauphin Island, Mobile Bay, Alabama	NOS	8735180	30.25	-88.075	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island	AL
66063	Dauphin Island Hydro, Alabama	NOS	8735181	30.25131944444444	-88.07948611111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island Hydro	AL
66064	Dog River Bridge, Alabama	NOS	8735391	30.56516666666667	-88.088	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog River Bridge	AL
66065	East Fowl River Bridge, Alabama	NOS	8735523	30.4436111	-88.1138889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Fowl River Bridge	AL
66066	Coast Guard sector, Mobile, Alabama	NOS	8736897	30.64830555555556	-88.05830555555555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coast Guard Sector Mobile	AL
66067	Mobile (Mobile State Docks), Alabama	NOS	8737048	30.7083	-88.0433	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile State Docks	AL
66068	Chickasaw Creek, Alabama	NOS	8737138	30.78188888888889	-88.0736111111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.860000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chickasaw Creek	AL
66069	Lower Bryant Landing, Tensay River, Alabama	NOS	8737373	30.9783	-87.8733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9300000000000033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Bryant Landing	AL
66070	West Fowl River Bridge, Alabama	NOS	8738043	30.37663888888889	-88.15855555555555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Fowl River Bridge	AL
66071	Bayou La Batre Bridge, Alabama	NOS	8739803	30.40566666666667	-88.24769444444445	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayou La Batre Bridge	AL
66072	Grand Bay NERR, Mississippi Sound, Mississippi	NOS	8740166	30.41319444444444	-88.4028888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Bay NERR, Mississippi Sound	MS
66073	Petit Bois Island, Mississippi Sound, Mississippi	NOS	8740405	30.2033	-88.4417	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETIT BOIS ISLAND, MISS. SOUND	MS
66074	Dock E, Port of Pascagoula, Mississippi	NOS	8741041	30.3477778	-88.5058333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dock E, Port of Pascagoula	MS
66075	Pascagoula Point, Mississippi Sound, Mississippi	NOS	8741196	30.34	-88.5333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula Point	MS
66076	Pascagoula NOAA Lab, Pascagoula River, Mississippi	NOS	8741533	30.36777777777778	-88.56305555555555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula NOAA Lab	MS
66077	Gautier, Mississippi	NOS	8741798	30.3833	-88.61	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gautier	MS
66078	Graveline Bayou entrance, Mississippi	NOS	8742205	30.3617	-88.6633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAVELINE BAYOU ENTRANCE	MS
66079	Horn Island, Mississippi Sound, Mississippi	NOS	8742221	30.2383	-88.6667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island	MS
66080	North Shore, Mississippi	NOS	8742523	30.3733	-88.705	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Shore	MS
66081	Hollingsworth Point, Davis Bayou, Mississippi	NOS	8743081	30.3867	-88.7733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HOLLINGSWORTH POINT, DAVIS BAYOU	MS
66082	Ocean Springs Marina, Old Fort Bayou, Mississippi	NOS	8743181	30.4217	-88.7883	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fort Bayou, Ocean Springs Marina	MS
66083	Ocean Springs, Mississippi	NOS	8743281	30.3917	-88.7983	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean Springs	MS
66084	Bayou Talla, Back Bay, Biloxi, Mississippi	NOS	8743301	30.43	-88.8	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU TALLA, BACK BAY OF BILOXI	MS
66085	Ocean Springs, Old Fort Bayou, Mississippi	NOS	8743495	30.42	-88.8283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN SPRINGS, OLD FORT BAYOU	MS
66086	Bayou Poito, Back Bay, Biloxi, Mississippi	NOS	8743639	30.4383	-88.845	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU POITO, BACK BAY OF BILOXI	MS
66087	Biloxi (Cadet Point), Biloxi Bay, Mississippi	NOS	8743735	30.39	-88.8567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi (Cadet Point)	MS
66088	Deer Island, Mississippi	NOS	8743812	30.3833	-88.8667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island	MS
66089	Langley Point, Mississippi	NOS	8743838	30.425	-88.87	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Langley Point	MS
66090	Biloxi, Biloxi Bay, Mississippi	NOS	8744117	30.4117	-88.9033	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi	MS
66093	Popps Ferry, Back Bay, Biloxi, Mississippi	NOS	8744671	30.4133	-88.975	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POPPS FERRY, BACK BAY OF BILOXI	MS
66094	Ship Island, Mississippi Sound, Mississippi	NOS	8744756	30.2133	-88.9717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, Mississippi Sound	MS
66095	Biloxi River, lower end, Mississippi	NOS	8744934	30.435	-89.0083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BILOXI RIVER, LOWER END	MS
66096	Handsboro Bridge, Bernard Bayou, Mississippi	NOS	8745101	30.4067	-89.0267	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANDSBORO BRIDGE, BERNARD BAYOU	MS
66097	Landon, Mississippi	NOS	8745555	30.4317	-89.0817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Landon	MS
66098	Gulfport, Gulfport Harbor, Mississippi	NOS	8745557	30.36	-89.0817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulfport Harbor	MS
66099	Pass Christian Yacht Club, Mississippi Sound, Mississippi	NOS	8746819	30.31	-89.245	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PASS CHRISTIAN YACHT CLUB, MISS. SOUND	MS
66100	Bay Waveland Yacht Club, Bay St. Louis, Mississippi	NOS	8747437	30.325	-89.325	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Waveland Yacht Club	MS
66101	Waveland, Mississipi Sound, Mississippi	NOS	8747766	30.2817	-89.3667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waveland	MS
66102	Devon Energy Facility, Louisiana	NOS	8760417	29.20075	-89.04446666666666	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devon Energy Facility	LA
66103	South Pass, Louisiana	NOS	8760551	28.99	-89.14	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Pass	LA
66104	Grand Pass, Louisiana	NOS	8760668	30.126699447631836	-89.2217025756836	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND PASS	LA
66105	Pilottown, Louisiana	NOS	8760721	29.17830555555556	-89.25830555555555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilottown	LA
66107	Olga Compressor Station, Grand Bay, Louisiana	NOS	8760889	29.38655555555556	-89.3801388888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olga Compressor Station, Grand Bay	LA
66108	Pilots Station (east), Southwest Pass, Louisiana	NOS	8760922	28.9322	-89.4075	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilots Station East, S.W. Pass	LA
66109	Pilot Station, Southwest Pass, Louisiana	NOS	8760943	28.925	-89.4183	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Pass	LA
66110	Shell Beach, Lake Borgne, Louisiana	NOS	8761305	29.86811111111111	-89.67325	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shell Beach	LA
66111	University of New Orleans vicinity, Chef Menteur Pass, Louisiana	NOS	8761385	30.06875	-89.802083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VICINITY OF UNO CHEF MENTEUR	LA
66112	The Rigolets, U.S. Highway 90, Louisiana	NOS	8761402	30.1667	-89.7367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Rigolets	LA
66113	Martello Castle, Lake Borgne, Louisiana	NOS	8761529	29.945	-89.835	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARTELLO CASTLE, LAKE BORGNE	LA
66115	Grand Isle, Mississippi River Delta, Louisiana (2)	NOS	8761724	29.26333333333333	-89.95666666666666	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Isle	LA
66116	Mendicant Island, Barataria Bay, Louisiana	NOS	8761742	29.318300247192383	-89.9800033569336	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MENDICANT ISLAND, BARATARIA BAY	LA
66117	Texaco Dock, Hackberry Bay, Louisiana	NOS	8761819	29.4017	-90.0383	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEXACO DOCK, HACKBERRY BAY	LA
66118	Caminada Pass (bridge), Louisiana	NOS	8761826	29.209999084472656	-90.04000091552734	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHENIERE CAMINADA, CAMINADA PASS	LA
66119	Lafitte, Barataria Waterway, Louisiana	NOS	8761899	29.6667	-90.1117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.17000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAFITTE, BARATARIA WATERWAY	LA
66120	New Canal USCG station, Lake Pontchartrain, Louisiana	NOS	8761927	30.02722222222222	-90.11333333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Canal Station	LA
66121	Port Fourchon, Belle Pass, Louisiana	NOS	8762075	29.11425	-90.19925	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Fourchon, Belle Pass	LA
66122	Leeville, Bayou Lafourche, Louisiana	NOS	8762084	29.2483	-90.2117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LEEVILLE, BAYOU LAFOURCHE	LA
66123	Golden Meadow, Plaisance Canal, Louisiana	NOS	8762184	29.373300552368164	-90.26499938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GOLDEN MEADOW, PLAISANCE CANAL	LA
66124	East Timbalier Island, Timbalier Bay, Louisiana	NOS	8762223	29.0767	-90.285	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST TIMBALIER ISLAND, TIMBALIER BAY	LA
66125	East Bank 1, Norco, Bayou LaBranche, Louisiana	NOS	8762372	30.05033333333333	-90.368	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bank 1, Norco, B. LaBranche	LA
66126	I-10 Bonnet Carre Floodway, Louisiana	NOS	8762483	30.06786111111111	-90.38997222222223	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-10 Bonnet Carre Floodway	LA
66127	East Isle Dernire, Lake Pelto, Louisiana	NOS	8762888	29.0717	-90.64	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	E. ISLE DERNIERES, LAKE PELTO	LA
66128	Cocodrie, Terrebonne Bay, Louisiana	NOS	8762928	29.245	-90.6617	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cocodrie	LA
66129	Texas Gas Platform, Caillou Bay, Louisiana	NOS	8763535	29.17477777777778	-90.97644444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Gas Platform, Caillou Bay	LA
66130	Stouts Pass At Six Mile Lake, Louisiana	NOS	8764025	29.7433	-91.23	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Pass at Six Mile Lake	LA
66131	Tesoro Marine Term., Atchafalaya River, Louisiana	NOS	8764044	29.6675	-91.23761111111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.29999999999999716	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Berwick, Atchafalaya River	LA
66132	Lawma, Amerada Pass, Louisiana	NOS	8764227	29.44961111111111	-91.33811111111112	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAWMA, Amerada Pass	LA
66134	Eugene Island, north of, Louisiana	NOS	8764314	29.3675	-91.38388888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0200000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island, North of , Gulf of Mexico	LA
66135	Weeks Bay, Louisiana	NOS	8765148	29.83722222222222	-91.8375	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay	LA
66136	Cypremort Point, Louisiana	NOS	8765251	29.71336111111111	-91.88	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cypremort Point	LA
66137	Freshwater Canal Locks, Louisiana	NOS	8766072	29.55169444444444	-92.30519444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freshwater Canal Locks	LA
66138	Lake Charles, Calcasieu River, Louisiana	NOS	8767816	30.22363888888889	-93.22166666666666	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Charles	LA
66139	Bulk Terminal, Louisiana	NOS	8767961	30.19019444444444	-93.30080555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bulk Terminal	LA
66141	Sabine Naches Canal, Port Arthur, Texas	NOS	8770475	29.86708333333333	-93.931	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Arthur	TX
66142	Rainbow Bridge, Neches River, Texas	NOS	8770520	29.979999542236328	-93.88169860839844	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge	TX
66143	Mesquite Point, Sabine Pass, Texas	NOS	8770539	29.7667	-93.895	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mesquite Point	TX
66213	Elkhorn Slough railroad bridge, Monterey Bay, California	NOS	9413663	36.85667	-121.755	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9300000000000033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough Railroad Bridge	CA
66144	Round Point, Trinity Bay, Galveston Bay, Texas	NOS	8770559	29.7133	-94.69	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.76	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Point	TX
66145	Sabine Pass (north), Texas	NOS	8770570	29.7284	-93.8701	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass North	TX
66146	Orange (Old Navy Base), Texas	NOS	8770597	30.0983	-93.7217	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orange	TX
66147	Barbours Cut, Morgans Point, Galveston Bay, Texas	NOS	8770613	29.68169444444445	-94.985	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Morgans Point, Barbours Cut	TX
66148	Umbrella Point, Trinity Bay, Texas	NOS	8770625	29.68	-94.8683	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UMBRELLA POINT, TRINITY BAY	TX
66149	Lynchburg Landing, San Jacinto River, Galveston Bay, Texas	NOS	8770733	29.76486111111111	-95.07886111111111	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lynchburg Landing	TX
66163	Galveston Pleasure Pier, Gulf Of Mexico, Texas	NOS	8771510	29.2853	-94.7894	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1100000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pleasure Pier	TX
66150	San Jacinto Battleground State Historic Site, Texas	NOS	8770743	29.7567	-95.09	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battleship Texas State Park	TX
66151	Houston Ship Channel, Galveston Bay, Manchester, Texas	NOS	8770777	29.72622222222222	-95.26577777777777	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manchester	TX
66152	High Island (TCOON), Texas	NOS	8770808	29.59469985961914	-94.39029693603516	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7799999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	High Island	TX
66153	Texas Point, Sabine Pass, Texas	NOS	8770822	29.68938888888889	-93.84191666666666	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Point, Sabine Pass	TX
66154	Clear Lake, Galveston Bay, Texas	NOS	8770933	29.5633	-95.0667	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clear Lake	TX
66155	Rollover Pass, Texas	NOS	8770971	29.5155556	-94.5105556	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rollover Pass	TX
66156	Eagle Point, Galveston Bay, Texas	NOS	8771013	29.48	-94.91830555555556	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point, Galveston Bay	TX
66158	Port Bolivar, Galveston Bay, Texas	NOS	8771328	29.365	-94.78	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8400000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Bolivar	TX
66161	Galveston Pier 21, Galveston Channel, Texas	NOS	8771450	29.31	-94.79330555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pier 21	TX
66162	Galveston Railroad Bridge, Texas	NOS	8771486	29.302600860595703	-94.89710235595703	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.740000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Railroad Bridge	TX
66164	San Luis Pass (TCOON), Texas	NOS	8771972	29.08097222222222	-95.13133333333333	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Luis Pass	TX
66165	Freeport, DOW Barge Canal, Texas	NOS	8772440	28.9483	-95.3083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
66166	USCG Freeport, Texas	NOS	8772447	28.94330555555555	-95.3025	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
66167	Freeport SPIP, Freeport Harbor, Texas	NOS	8772471	28.935699462890625	-95.29419708251953	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport SPIP, Freeport Harbor	TX
66157	Sabine (offshore), Texas	NOS	8771081	29.4983	-93.64	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Offshore	TX
66168	Sargent (TCOON), Texas	NOS	8772985	28.77141666666667	-95.61716666666666	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sargent	TX
66214	Pillar Point Harbor, Half Moon Bay, California	NOS	9414131	37.5025	-122.4821666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9899999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point Harbor	CA
66169	Seadrift, San Antonio Bay, Texas	NOS	8773037	28.40690040588379	-96.71240234375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.19999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seadrift	TX
66170	Matagorda City (TCOON), Texas	NOS	8773146	28.71005555555556	-95.914	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda City	TX
66171	Port Lavaca, Lavaca Causeway, Matagorda Bay, Texas	NOS	8773259	28.640600204467773	-96.60980224609375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5099999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lavaca	TX
66172	Port O'Connor, Matagorda Bay, Texas	NOS	8773701	28.44586111111111	-96.39555555555556	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port O'Connor	TX
66174	Aransas Wildlife Refuge (TCOON), Texas	NOS	8774230	28.228300094604492	-96.79499816894531	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.14999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas Wildlife Refuge	TX
66175	Copano Bay State Fishing Pier, Texas	NOS	8774513	28.11440086364746	-97.02439880371094	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Copano Bay	TX
66176	Rockport, Aransas Bay, Texas	NOS	8774770	28.0216667	-97.0466667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.1899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockport	TX
66177	White Point Bay, Texas	NOS	8775188	27.8583	-97.475	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White Point	TX
66178	Port Aransas, Texas	NOS	8775237	27.83970069885254	-97.07250213623047	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Aransas	TX
66179	Aransas, Aransas Pass, Texas	NOS	8775241	27.836599349975586	-97.03910064697266	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas, Aransas Pass	TX
66180	Nueces Bay (TCOON), Texas	NOS	8775244	27.83275	-97.48594444444444	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nueces Bay	TX
66181	Port Aransas (H. Caldwell Pier), Texas	NOS	8775270	27.82670021057129	-97.05000305175781	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ARANSAS, H. CALDWELL PIER	TX
66182	Port Ingleside, Corpus Christi Bay, Texas	NOS	8775283	27.8217	-97.2033	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Ingleside	TX
66183	Texas State Aquarium, Corpus Christi, Texas	NOS	8775296	27.814899444580078	-97.38919830322266	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USS Lexington, Corpus Christi Bay	TX
66200	Los Angeles (outer harbor), California	NOS	9410660	33.71994444444444	-118.2728611111111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Los Angeles	CA
66311	Jim Creek, Washington	NOS	9443551	48.187198638916016	-124.0625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.059999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jim Creek	WA
66184	Corpus Christi Naval Air Station, Texas	NOS	8775421	27.705	-97.28	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naval Air Station	TX
66185	Packery Channel, Texas	NOS	8775792	27.63330555555556	-97.23669444444444	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Packery Channel	TX
66186	Corpus Christi, Gulf Of Mexico, Texas	NOS	8775870	27.58	-97.2167	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bob Hall Pier, Corpus Christi	TX
66187	Realitos Peninsula, Texas	NOS	8779280	26.262444	-97.285333	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Realitos Peninsula	TX
66188	Coast Guard Station, South Padre Island, Texas	NOS	8779748	26.07309913635254	-97.1675033569336	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island CG Station	TX
66215	San Francisco, San Francisco Bay, California	NOS	9414290	37.80630555555555	-122.4658888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.119999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco	CA
66217	Rincon Point, Pier 22, San Francisco Bay, California	NOS	9414317	37.79	-122.387	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PIER 22 1/2, SAN FRANCISCO	CA
66189	South Padre Island, Brazos Santiago Pass, Texas	NOS	8779749	26.06738888888889	-97.15477777777778	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPI Brazos Santiago	TX
66190	Padre Island, Brazos Santiago Pass, Texas	NOS	8779750	26.0683	-97.1567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island, Brazos Santiago Pass	TX
66191	Port Isabel, Laguna Madre, Texas	NOS	8779770	26.06116666666667	-97.21552777777778	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Isabel	TX
66192	Wilson Cove, San Clemente Island, California	NOS	9410032	33.005001068115234	-118.55699920654297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILSON COVE, SAN CLEMENTE IS.	CA
66193	Avalon, Santa Catalina Island, California	NOS	9410079	33.345001220703125	-118.32499694824219	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.719999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AVALON, SANTA CATALINA ISLAND	CA
66194	South San Diego Bay, California	NOS	9410135	32.62910079956055	-117.10780334472656	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South San Diego Bay	CA
66195	Ballast Point, California	NOS	9410155	32.6867	-117.233	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballast Point	CA
66196	San Diego, San Diego Bay, California	NOS	9410170	32.71419444444445	-117.1735833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego, San Diego Bay	CA
66197	Mission Bay, California	NOS	9410196	32.793701171875	-117.22380065917969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8100000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mission Bay	CA
66198	La Jolla (Scripps Institution Wharf), California	NOS	9410230	32.86688888888889	-117.2571388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Jolla	CA
66201	Long Beach, Terminal Island, California	NOS	9410680	33.7517	-118.227	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, TERMINAL ISLAND	CA
66202	Santa Monica, Municipal Pier, San Pedro Channel, California	NOS	9410840	34.0083	-118.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7900000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Monica	CA
66203	Rincon Island, Mussel Shoals, Santa Barbara Channel, California	NOS	9411270	34.3483	-119.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RINCON ISLAND, PACIFIC OCEAN	CA
66204	Santa Barbara, California	NOS	9411340	34.40311111111111	-119.6928055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Barbara	CA
66205	Gaviota State Park, California	NOS	9411399	34.46938888888889	-120.2283055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gaviota State Park, Pacific Ocean	CA
66206	Oil Platform Harvest (Topex Project), California	NOS	9411406	34.46916666666667	-120.6819444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.719999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oil Platform Harvest	CA
66207	Port San Luis, California	NOS	9412110	35.16880555555556	-120.7541944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port San Luis	CA
66208	Mansfield Cone, California	NOS	9412802	35.94952777777777	-121.4819444444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7399999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mansfield Cone	CA
66209	Monterey, Monterey Harbor, California	NOS	9413450	36.60499954223633	-121.88805389404297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monterey	CA
66210	Elkhorn Slough at Elkhorn, Monterey Bay, California	NOS	9413631	36.81829833984375	-121.74700164794922	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough at Elkhorn	CA
66211	Tidal Creek, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413643	36.83330154418945	-121.74500274658203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tidal Creek, Elkhorn Slough	CA
66212	Kirby Park, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413651	36.84130096435547	-121.74530029296875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.950000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kirby Park, Elkhorn Slough	CA
66218	Hunters Point, San Francisco Bay, California	NOS	9414358	37.73	-122.357	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUNTERS POINT, S.F. BAY	CA
66219	Oyster Point Marina, San Francisco Bay, California	NOS	9414392	37.665	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OYSTER POINT MARINA, SAN FRANCISCO BAY	CA
66220	San Mateo Bridge (west end), San Francisco Bay, California	NOS	9414458	37.58	-122.253	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.109999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
66222	Dumbarton Highway Bridge, San Francisco Bay, California	NOS	9414509	37.5067	-122.115	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.68	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Bridge	CA
66223	Redwood City, Wharf 5, San Francisco Bay, California	NOS	9414523	37.50669860839844	-122.20999908447266	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood City	CA
66224	Coyote Creek, Alviso Slough, San Francisco Bay, California	NOS	9414575	37.465	-122.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.869999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Creek	CA
66225	San Leandro Marina, San Francisco Bay, California	NOS	9414688	37.695	-122.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.920000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Leandro Marina	CA
66226	Oakland Harbor, Park Street Bridge, San Francisco Bay, California	NOS	9414746	37.7717	-122.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3800000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PARK STREET BRIDGE	CA
66227	Alameda, San Francisco Bay, California	NOS	9414750	37.7717	-122.3	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alameda	CA
66228	Oakland Inner Harbor, San Francisco Bay, California	NOS	9414764	37.795	-122.282	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor	CA
66229	Alameda Naval Air Station fuel pier, San Francisco Bay, California	NOS	9414767	37.7933	-122.315	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALAMEDA NAS, NAVY FUEL PIER	CA
66230	Sausalito, San Francisco Bay, California	NOS	9414806	37.8467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, SAN FRANCISCO BAY	CA
66231	Nurse Slough, Bradmoor Island, Suisun Bay, California	NOS	9414811	38.1833	-121.923	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradmoor Island	CA
66232	Berkeley, San Francisco Bay, California	NOS	9414816	37.8650016784668	-122.30699920654297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BERKELEY,S.F.BAY	CA
66233	Sausalito, Corps of Engineers Dock, San Francisco Bay, California	NOS	9414819	37.865	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, COE DOCK, S.F. BAY	CA
66234	Chevron Oil Company Pier, Richmond, San Francisco Bay, California	NOS	9414863	37.923	-122.4095833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	CA
66235	Bolinas, Bolinas Lagoon, California	NOS	9414958	37.907779693603516	-122.6786117553711	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolinas, Bolinas Lagoon	CA
66236	Drakes Bay, Point Reyes, California	NOS	9415020	37.99611282348633	-122.97666931152344	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Reyes	CA
66237	Blackslough Landing, San Joaquin River, California	NOS	9415021	37.99469444444444	-121.4190444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8400000000000318	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACKSLOUGH LANDING, SAN JOAQUIN RIVER	CA
66238	Pinole Point, San Pablo Bay, California	NOS	9415056	38.015	-122.363	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, San Pablo Bay	CA
66239	Antioch, San Joaquin River, California	NOS	9415064	38.02	-121.815	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANTIOCH, SAN JOAQUIN RIVER	CA
66240	Martinez-Amorco Pier, California	NOS	9415102	38.03463888888889	-122.1251944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martinez-Amorco Pier	CA
66241	Wards Island, Little Connection Slough, San Joaquin River, California	NOS	9415105	38.05002527777778	-121.4968555555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WARDS ISLAND, SAN JOAQUIN RIVER	CA
66242	Mallard Island Ferry Wharf, Suisun Bay, California	NOS	9415112	38.0433	-121.918	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MALLARD ISLAND, SUISUN BAY	CA
66243	Crockett, Carquinez Strait, California	NOS	9415143	38.0583	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROCKETT, CARQUINEZ STRAIT	CA
66244	Port Chicago, Suisun Bay, California	NOS	9415144	38.056	-122.0395	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chicago	CA
66245	Threemile Slough entrance, San Joaquin River, California	NOS	9415193	38.0867	-121.685	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREE MILE SLOUGH,SAN JOAQUIN R.	CA
66246	Mare Island Naval Shipyard, Carquinez Strait, California	NOS	9415218	38.07	-122.25	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island	CA
66247	Korths Harbor, San Joaquin River, California	NOS	9415229	38.09761	-121.568383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KORTHS HBR, SAN JOAQUIN RIVER	CA
66248	Petaluma River entrance, San Pablo Bay, California	NOS	9415252	38.11530555555556	-122.5056666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETALUMA RIVER ENTRANCE	CA
66249	Suisun Slough entrance, Suisun Bay, California	NOS	9415265	38.1283	-122.073	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.61	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUISUN SLOUGH ENTRANCE	CA
66250	Rio Vista, Sacramento River, California	NOS	9415316	38.145	-121.692	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rio Vista	CA
66251	Sonoma Creek, San Pablo Bay, California	NOS	9415338	38.1567	-122.407	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sonoma Creek Entrance	CA
66252	Lakeville, Petaluma River, California	NOS	9415423	38.1983	-122.547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKEVILLE, PETALUMA RIVER	CA
66253	Upper drawbridge, Petaluma River, San Pablo Bay, California	NOS	9415584	38.2283	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petaluma River, Upper Drawbridge	CA
66254	Green Cove, California	NOS	9416409	38.70433333333333	-123.4493888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Cove	CA
66255	Arena Cove, California	NOS	9416841	38.91455555555556	-123.7110833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.139999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arena Cove	CA
66256	Noyo Harbor, Fort Bragg, California	NOS	9417426	39.42577777777778	-123.8051111111111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NOYO HARBOR	CA
66257	Shelter Cove, California	NOS	9418024	40.025001525878906	-124.05799865722656	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELTER COVE	CA
66258	Cockrobin Island Bridge, Eel River, San Francisco, California	NOS	9418637	40.63719940185547	-124.2822036743164	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cockrobin Island Bridge	CA
66259	Fields Landing, Humboldt Bay, California	NOS	9418723	40.7233	-124.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.72	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDS LANDING, HUMBOLDT BAY	CA
66260	North Spit, Humboldt Bay, California	NOS	9418767	40.7663	-124.2172	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Spit	CA
66261	Samoa, Humboldt Bay, California	NOS	9418817	40.8267	-124.18	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Samoa, Humboldt Bay	CA
66263	Crescent City, California	NOS	9419750	41.745	-124.183	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent City	CA
66264	Pyramid Point, Smith River, California	NOS	9419945	41.94525	-124.2009166666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.419999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pyramid Point	CA
66265	Gold Beach, Rogue River, Oregon	NOS	9431011	42.42163888888889	-124.4187222222222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9099999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gold Beach	OR
66266	Port Orford, Oregon	NOS	9431647	42.73899841308594	-124.49829864501953	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Orford	OR
66269	Halfmoon Bay, Umpqua River, Oregon	NOS	9433445	43.675	-124.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Half Moon Bay	OR
66270	Reedsport, Umpqua River, Oregon	NOS	9433501	43.70830154418945	-124.0979995727539	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.950000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEDSPORT	OR
66271	Cushman, Suislaw River, Oregon	NOS	9434068	43.98500061035156	-124.04499816894531	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cushman	OR
66272	Florence USCG Pier, Suislaw River, Oregon	NOS	9434098	44.00211111111111	-124.123	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence USCG Pier, Suislaw River	OR
66273	Waldport, Alsea Bay, Oregon	NOS	9434939	44.43436111111111	-124.0580833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldport	OR
66274	Weiser Point, Yaquina River, Oregon	NOS	9435308	44.5933	-124.008	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEISER POINT, YAQUINA RIVER	OR
66275	South Beach, Yaquina Bay and River, Oregon	NOS	9435380	44.625	-124.043	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.449999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach	OR
66276	Depoe Bay, Oregon	NOS	9435827	44.81	-124.058	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DEPOE BAY	OR
66277	Chinook Bend, Siletz River, Oregon	NOS	9435992	44.880001068115234	-123.9636001586914	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chinook Bend	OR
66278	Cascade Head, Salmon River, Oregon	NOS	9436381	45.04794444444445	-124.0073055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cascade Head, Salmon River	OR
66279	Dick Point, Tillamook Bay, Oregon	NOS	9437381	45.4817	-123.902	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dick Point	OR
66280	Garibaldi, Tillamook Bay, Oregon	NOS	9437540	45.55453	-123.91894444439146	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Garibaldi	OR
66282	North Fork, Nehalem River, Oregon	NOS	9437954	45.73379898071289	-123.87640380859375	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.440000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Fork	OR
66283	Cathcart Landing, Youngs River, Oregon	NOS	9438772	46.12425	-123.8043333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.659999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cathcart Landing	OR
66284	Hammond, Oregon	NOS	9439011	46.2017	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hammond	OR
66285	Tongue Point, Astoria, Columbia River, Oregon	NOS	9439040	46.20731	-123.76830555558205	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Astoria	OR
66286	Wauna, Columbia River, Oregon	NOS	9439099	46.16166687011719	-123.40888977050781	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	OR
66287	Rocky Point, Multnomah Channel, Oregon	NOS	9439189	45.6967	-122.868	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rocky Point	OR
66288	Saint Helens, Columbia River, Oregon	NOS	9439201	45.8633	-122.7962	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Helens	OR
66289	Portland, Morrison Street Bridge, Oregon	NOS	9439221	45.51	-122.673	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Morrison Street Bridge	OR
66290	Washougal, Columbia River, Washington	NOS	9440047	45.57830047607422	-122.38200378417969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WASHOUGAL, COLUMBIA RIVER	WA
66291	Beacon Rock State Park, Columbia River, Washington	NOS	9440079	45.62030029296875	-122.02030181884766	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon Rock State Park	WA
66310	Sekiu, Clallam Bay, Strait of Juan de Fuca, Washington	NOS	9443361	48.2633	-124.297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEKIU, CLALLAM BAY	WA
66292	Vancouver, Columbia River, Washington	NOS	9440083	45.63169444444444	-122.697	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3499999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vancouver	WA
66293	Knapp Landing, Columbia River, Washington	NOS	9440171	45.74169921875	-122.75499725341797	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KNAPP(THORNES)LNDG, WILLOW BAR	WA
66294	Temco Kalama Terminal, Columbia River, Washington	NOS	9440357	45.986698150634766	-122.83670043945312	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEMCO Kalama Terminal	WA
66295	Longview, Columbia River, Washington	NOS	9440422	46.10613888888889	-122.9541944444444	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Longview	WA
66296	Cape Horn, Columbia River, Washington	NOS	9440482	46.15169906616211	-123.29000091552734	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9899999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE HORN, COLUMBIA RIVER	WA
66297	Barlow Point, Columbia River, Washington	NOS	9440483	46.152198791503906	-123.03919982910156	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barlow Point	WA
66298	Skamokawa, Steamboat Slough, Columbia River, Washington	NOS	9440569	46.2667	-123.452	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skamokawa	WA
66299	Cape Disappointment, Washington	NOS	9440581	46.29999923706055	-124	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Disappointment	WA
66300	Greenhead Slough, Washington	NOS	9440650	46.37220001220703	-123.95030212402344	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.890000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenhead Slough	WA
66301	Nahcotta, Willapa Bay, Washington	NOS	9440747	46.5017	-124.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAHCOTTA, WILLAPA BAY	WA
66302	South Bend, Willapa River, Willapa Bay, Washington	NOS	9440875	46.6633	-123.798	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH BEND	WA
66303	Toke Point, Willapa Bay, Washington	NOS	9440910	46.70747	-123.96691666666004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.780000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toke Point	WA
66304	Westport, Point Chehalis, Grays Harbor, Washington	NOS	9441102	46.90431	-124.1050833331214	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westport	WA
66305	Aberdeen, Grays Harbor, Washington	NOS	9441187	46.9683	-123.853	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.6000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aberdeen	WA
66307	La Push, Quillayute River, Washington	NOS	9442396	47.91333333333333	-124.6369444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Push, Quillayute River	WA
66308	Tskawahyah Island, Cape Alava, Washington	NOS	9442705	48.17110061645508	-124.73690032958984	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tskawahyah Island, Cape Alava	WA
66309	Neah Bay, Strait Of Juan De Fuca, Washington	NOS	9443090	48.3702778	-124.6019444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Neah Bay	WA
66312	Port Angeles, Strait Of Juan De Fuca, Washington	NOS	9444090	48.12472222222223	-123.4411388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Angeles	WA
66313	Port Townsend (Point Hudson), Admiralty Inlet, Washington	NOS	9444900	48.1129	-122.7595	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend	WA
66314	Foulweather Bluff, Washington	NOS	9445016	47.9267	-122.617	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.869999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff	WA
66315	Bangor Wharf, Washington	NOS	9445133	47.7483	-122.727	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	WA
66316	Union, Hood Canal, Washington	NOS	9445478	47.3583	-123.098	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UNION, HOOD CANAL	WA
66317	Bremerton, Sinclair Inlet, Port Orchard, Puget Sound, Washington	NOS	9445958	47.56169891357422	-122.62300109863281	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.82	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BREMERTON	WA
66318	Wauna, Carr Inlet, Puget Sound, Washington	NOS	9446291	47.378299713134766	-122.63400268554688	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	WA
66319	Tacoma, Commencement Bay, Sitcum Waterway, Puget Sound, Washington	NOS	9446484	47.26667	-122.41333333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacoma	WA
66320	Yoman Point, Anderson Island, Balch Passage, Puget Sound, Washington	NOS	9446705	47.18	-122.675	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOMAN POINT, ANDERSON ISLAND	WA
66321	Sandy Point, Anderson Island, Puget Sound, Washington	NOS	9446804	47.15299987792969	-122.67510223388672	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.619999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT ANDERSON ISLAND, PUGET SOUND	WA
66322	Budd Inlet, south of Gull Harbor, Washington	NOS	9446807	47.0983	-122.895	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.329999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUDD INLET, SOUTH OF GULL HARBOR	WA
66323	Seattle, Puget Sound, Washington	NOS	9447130	47.60264	-122.3393055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seattle	WA
66324	Everett, Washington	NOS	9447659	47.98	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EVERETT	WA
66325	Priest Point, Washington	NOS	9447717	48.03494444444444	-122.2271944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Point	WA
66326	Tulalip, Tulalip Bay, Washington	NOS	9447773	48.065	-122.288	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulalip, Tulalip Bay	WA
66327	Greenbank, Whidbey Island, Washington	NOS	9447883	48.105	-122.57	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bank	WA
66328	Naval Air Station Whidbey Island, Washington	NOS	9447973	48.34280014038086	-122.68579864501953	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.439999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAS Whidbey Island	WA
66329	Spee-Bi-Dah, Washington	NOS	9448009	48.08825	-122.3223333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spee-Bi-Dah	WA
66330	Tulare Beach, Port Susan, Washington	NOS	9448043	48.10680555555555	-122.3472777777778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.459999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulare Beach, Port Susan	WA
66331	Sneeoosh Point, Washington	NOS	9448576	48.4	-122.548	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sneeoosh Point	WA
66333	Deception Pass St. Park, Bowman Bay, Fidalgo I., Washington	NOS	9448614	48.415000915527344	-122.6520004272461	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.630000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOWMAN BAY, FIDALGO ISLAND	WA
66334	Turner Bay, Similk Bay, Washington	NOS	9448657	48.445	-122.555	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turner Bay	WA
66335	Swinomish Channel entrance, Padilla Bay, Washington	NOS	9448682	48.45830154418945	-122.51300048828125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.040000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swinomish	WA
66336	Village Point, Lummi Island, Washington	NOS	9449161	48.7167	-122.708	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.010000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VILLAGE POINT, LUMMI ISLAND	WA
66337	Cherry Point, Strait of Georgia, Washington	NOS	9449424	48.8633	-122.758	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.279999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point	WA
66338	Point Roberts, Strait of Georgia, Washington	NOS	9449639	48.974998474121094	-123.08300018310547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Roberts	WA
66339	Drayton Harbor, Blaine, Strait of Georgia, Washington	NOS	9449679	48.9917	-122.765	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blaine, Drayton Harbor	WA
66340	Waldron Island, Haro Strait, Washington	NOS	9449746	48.686798095703125	-123.03759765625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island	WA
66341	Rosario, East Sound, Orcas Island, Washington	NOS	9449771	48.64670181274414	-122.87000274658203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario, Orcas Island	WA
66342	Hanbury Point, Mosquito Pass, San Juan I., Haro Strait, Washington	NOS	9449828	48.5817	-123.17	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANBURY POINT, SAN JUAN ISLAND	WA
66343	Kanaka Bay, San Juan Island, Haro Strait, Washington	NOS	9449856	48.48500061035156	-123.08300018310547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanaka Bay, San Juan Island	WA
66344	Friday Harbor, San Juan Island, San Juan Channel, Washington	NOS	9449880	48.54530555555556	-123.0128888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.550000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Friday Harbor	WA
66345	Upright Head, Lopez Island, Washington	NOS	9449911	48.57170104980469	-122.88500213623047	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Head	WA
66346	Armitage Island, Thatcher Pass, Washington	NOS	9449932	48.535	-122.797	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.660000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Armitage Island	WA
66347	Richardson, Lopez Island, San Juan Channel, Washington	NOS	9449982	48.4467	-122.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richardson	WA
66348	Telegraph Bay, Washington	NOS	9449988	48.44329833984375	-122.80500030517578	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Telegraph Bay	WA
66349	Windy Cove entrance, Alaska	NOS	9450251	55.0354	-133.0238	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance to Windy Cove	AK
66350	Dunbar Inlet GPS Tide Buoy, Alaska	NOS	9450286	55.0879	-132.81583	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.859999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dunbar Inlet GPS Tide Buoy	AK
66351	Custom House Cove, Mary Island, Alaska	NOS	9450296	55.1	-131.217	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Custom House Cove, Mary Island	AK
66352	Metlakatla, Port Chester, Alaska	NOS	9450314	55.1283	-131.567	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Metlakatla, Port Chester, AK	AK
66353	Hydaburg, Sukkwan Strait, Alaska	NOS	9450364	55.201698303222656	-132.822998046875	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hydaburg, Sukkwan Strait	AK
66354	Ketchikan, Tongass Narrows, Alaska	NOS	9450460	55.33183	-131.6261944442325	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketchikan	AK
66355	Trocadero Bay, Alaska	NOS	9450463	55.35166666666667	-132.9380555555556	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trocadero Bay	AK
66356	Craig, Klawock Inlet, Bucareli Bay, Alaska	NOS	9450551	55.4883	-133.142	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRAIG	AK
66358	Lindeman Cove, Kasaan Bay, Alaska	NOS	9450625	55.6017	-132.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.209999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lindeman Cove	AK
66359	Northern Carroll Inlet GPS Tide Buoy, Alaska	NOS	9450642	55.629	-131.362694	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.149999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northern Carroll Inlet GPS Tide Buoy	AK
66360	Nossuk Bay, Tonowek Bay, Gulf of Esquibel, Alaska	NOS	9450711	55.72166666666666	-133.35	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nossuk Bay	AK
66361	Magnetic Point, Union Bay, Earnest Sound, Alaska	NOS	9450753	55.78828333333333	-132.1908833333334	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magnetic Point, Union Bay, Earnest Sound	AK
66362	Burrough Bay, Behm Canal, Alaska	NOS	9450914	56.0383	-131.095	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrough Bay, Behm Canal	AK
66363	Thoms Point, Zimovia Strait, Alaska	NOS	9450970	56.1183	-132.078	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thoms Point	AK
66364	El Capitan Passage, Alaska	NOS	9450997	56.1633	-133.33	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.86	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EL Capitan Passage	AK
66365	Dry Pass, El Capitan Passage, Alaska	NOS	9450998	56.1633	-133.413	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dry Pass, EL Capitan Passage	AK
66366	Point Harrington, Clarence Strait, Alaska	NOS	9451005	56.1783	-132.697	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT HARRINGTON, CLARENCE STRAIT	AK
66367	Bradfield Canal, Alaska	NOS	9451012	56.1833	-131.572	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradfield Canal	AK
66368	Village Rock, Zimovia Strait, Alaska	NOS	9451037	56.22	-132.297	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Rock	AK
66369	Port Alexander, Baranof Island, Alaska	NOS	9451054	56.2467	-134.647	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Alexander	AK
66370	Bushy Island, Snow Passage, Alaska	NOS	9451074	56.2767	-132.985	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUSHY ISLAND, SNOW PASSAGE	AK
66371	Reef Point, Stikine Strait, Alaska	NOS	9451124	56.3533	-132.553	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEF POINT, STIKINE STRAIT	AK
66372	Madan Bay, Clarence Strait, Alaska	NOS	9451152	56.3922	-132.169	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Madan Bay	AK
66373	Wrangell, Wrangell Island, Alaska	NOS	9451204	56.47	-132.387	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell	AK
66374	Monte Carlo Island, Keku Strait, Alaska	NOS	9451247	56.535	-133.767	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monte Carlo Island	AK
66375	Point Lockwood, Woewodski Island, Wrangell Narrows, Alaska	NOS	9451263	56.5583	-132.963	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.729999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lockwood	AK
66376	Beecher Pass, Wrangell Narrows, Alaska	NOS	9451287	56.595	-132.987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beecher Pass	AK
66377	Anchor Point, Wrangell Narrows, Alaska	NOS	9451317	56.6383	-132.927	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point	AK
66378	Papke's Landing, Wrangell Narrows, Alaska	NOS	9451346	56.6767	-132.933	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.540000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Papke's Landing	AK
66379	The Summit, Keku Strait, Alaska	NOS	9451349	56.68242222222222	-133.7369083333333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Summit	AK
66380	Golf Island, Necker Islands, Alaska	NOS	9451421	56.7867	-135.393	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golf Island	AK
66381	Leconte Bay, Frederick Sound, Alaska	NOS	9451422	56.7883	-132.502	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LECONTE BAY	AK
66382	Turn Point, Alaska	NOS	9451434	56.8	-132.98	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point	AK
66383	Entrance Island, Keku Strait, Alaska	NOS	9451438	56.8117	-133.787	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance Island	AK
66384	Red Bluff Bay, Baranof Island, Alaska	NOS	9451467	56.8567	-134.723	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.789999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bluff Bay, Baranof Island	AK
66385	Saginaw Bay, Kuiu Island, Frederick Sound, Alaska	NOS	9451497	56.90333333333334	-134.3030555555556	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Bay, Kuiu Island	AK
66386	Kake Harbor, Keku Strait, Alaska	NOS	9451528	56.94830555555556	-133.8947222222222	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.509999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor, Keku Strait	AK
66387	Sitka, Baronof Island, Sitka Sound, Alaska	NOS	9451600	57.05169444444444	-135.342	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.290000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitka	AK
66388	Baranof, Warm Spring Bay, Alaska	NOS	9451625	57.08833333333333	-134.825	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baranof,  Warm Spring Bay	AK
66389	Whitestone Narrows, Neva Strait, Alaska	NOS	9451741	57.25	-135.567	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.319999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITESTONE NARROWS, Neva Strait	AK
66390	The Brothers, Stephens Passage, Alaska	NOS	9451785	57.295	-133.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THE BROTHERS, STEPHENS PASSAGE	AK
66391	Scraggy Island, Alaska	NOS	9451805	57.34	-135.707	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scraggy Island	AK
66392	Sergius Narrows, Alaska	NOS	9451853	57.41	-135.627	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.97	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
66393	Provorotni Island, Alaska	NOS	9451936	57.515	-135.555	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.930000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provorotni Island	AK
66394	Target Island, Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	9451953	57.5333	-134.417	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Target Island, Mitchell Bay	AK
66395	Juneau, Gastineau Channel, Stephens Pass, Alaska	NOS	9452210	58.2983	-134.412	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau	AK
66397	False Bay, Chatham Strait, Alaska	NOS	9452328	57.9667	-134.935	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Bay, Chatham Strait	AK
66398	Skagway, Taiya Inlet, Lynn Canal, Alaska	NOS	9452400	59.45	-135.327	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagway, Taiya Inlet	AK
66399	Chilkat Inlet, Lynn Canal, Alaska	NOS	9452421	59.17	-135.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHILKAT INLET	AK
66400	Hoonah, Port Fredrick, Alaska	NOS	9452438	58.10755555555556	-135.4441944444444	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.910000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hoonah, Port Fredrick	AK
66402	Pelican Harbor, Lisianski Inlet, Alaska	NOS	9452611	57.95777777777778	-136.2267777777778	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pelican Harbor, Lisianski Inlet, AK	AK
66403	Elfin Cove, Port Althorp, Cross Sound, Alaska	NOS	9452634	58.19472	-136.34694444444443	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elfin Cove	AK
66404	Tarr Inlet, Glacier Bay, Alaska	NOS	9452749	58.96477777777778	-136.8775833333333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.780000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tarr Inlet, Glacier Bay	AK
66405	Yakutat, Yakutat Bay, Alaska	NOS	9453220	59.5485	-139.7334	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakutat, Yakutat Bay	AK
66406	Cordova, Orca Inlet, Prince William Sd, Alaska	NOS	9454050	60.5583	-145.755	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.739999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cordova	AK
66407	Valdez, Prince William Sound, Alaska	NOS	9454240	61.125	-146.362	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez	AK
66408	Perch Point, Montague Island, Alaska	NOS	9454561	60.1267	-147.395	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Perch Point	AK
66409	Wooded Islands, Montague Island, Alaska	NOS	9454562	59.875	-147.403	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
66410	Seal Island, Alaska	NOS	9454564	60.425	-147.41	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEAL ISLAND	AK
66412	Montague Island, Alaska	NOS	9454616	60.025	-147.592	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Island	AK
66413	South Arm, Knight Island, Bay of Isles, Alaska	NOS	9454652	60.3667	-147.7	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH ARM, KNIGHT ISLAND, BAY OF ISLES	AK
66414	Snug Harbor, Knight Island, Alaska	NOS	9454662	60.25	-147.717	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
66415	Herring Point, Knight Island, Prince William Sound, Alaska	NOS	9454691	60.475	-147.792	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERRING POINT, KNIGHT ISLAND, PR WIL SND	AK
66416	South Bay, Perry Island, Alaska	NOS	9454721	60.6717	-147.932	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PERRY ISLAND (SOUTH BAY)	AK
66417	Guguak, Alaska	NOS	9454751	60.1	-148.038	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guguak	AK
66418	Point Elrington, Elrington Island, Prince William Sound, Alaska	NOS	9454814	59.9383	-148.227	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.680000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Erlington, Erlington Island	AK
66419	Whittier, Prince William Sound, Alaska	NOS	9454949	60.7783	-148.665	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whittier	AK
66420	Seward, Resurrection Bay, Alaska	NOS	9455090	60.12	-149.4266667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seward	AK
66421	Agnes Cove, Aialik Peninsula, Alaska	NOS	9455120	59.7733	-149.588	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGNES COVE	AK
66422	Aialik Bay, north end, Alaska	NOS	9455145	59.9533	-149.715	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.530000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK BAY, NORTH END	AK
66423	Aialik Sill, Aialik Bay, Alaska	NOS	9455146	59.885	-149.718	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.559999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK SILL, AIALIK BAY	AK
66424	Camp Cove, Harris Peninsula, Alaska	NOS	9455151	59.6933	-149.748	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP COVE, HARRIS PENNINSULA	AK
66425	Crater Bay, Harris Bay, Alaska	NOS	9455159	59.7133	-149.787	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRATER BAY, HARRIS BAY	AK
66426	Upper Northwestern Fiord, Harris Bay, Alaska	NOS	9455204	59.79	-150.032	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER NORTHWESTERN FIORD	AK
66427	Seldovia, Cook Inlet, Alaska	NOS	9455500	59.44052777777778	-151.7199444444445	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.559999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
66428	Kasitsna Bay, Kachemak Bay, Alaska	NOS	9455517	59.46830555555555	-151.565	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kasitsna Bay, Kachemak Bay	AK
66429	Homer, Coal Point, Kachemak Bay, Cook Inlet, Alaska	NOS	9455558	59.60139846801758	-151.4105987548828	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COAL POINT	AK
66430	Bear Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455595	59.725	-151.023	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Cove, Kachemak Bay	AK
66431	Anchor Point, Cook Inlet, Alaska	NOS	9455606	59.77197222222223	-151.8670277777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.709999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, Cook Inlet	AK
66432	Ninilchik, Cook Inlet, Alaska	NOS	9455653	60.055	-151.682	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ninilchik, Cook Inlet	AK
66433	Cape Kasilof, Cook Inlet, Alaska	NOS	9455711	60.3367	-151.38	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kasilof	AK
66434	Kaligan Island (north end), Cook Inlet, Alaska	NOS	9455732	60.51169967651367	-151.95199584960938	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KALIGAN ISLAND (NORTH END),  COOK INLET	AK
66435	Chinulna Point, Cook Inlet, Alaska	NOS	9455735	60.5033	-151.283	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINULNA POINT, COOK INLET	AK
66436	Nikiski, Cook Inlet, Alaska	NOS	9455760	60.68330555555556	-151.398	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.290000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski	AK
66437	Point Possession, Alaska	NOS	9455866	61.0367	-150.413	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.260000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession	AK
66438	North Foreland, Alaska	NOS	9455869	61.04330555555556	-151.163	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Foreland	AK
66439	Fire Island, Cook Inlet, Alaska	NOS	9455912	61.1733	-150.213	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, Cook Inlet	AK
66440	Anchorage, Knik Arm, Cook Inlet, Alaska	NOS	9455920	61.2375	-149.8904	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchorage	AK
66441	Port Mackenzie, Cook Inlet, Alaska	NOS	9455934	61.2682991027832	-149.91700744628906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie	AK
66442	Goose Creek, Knik Arm, Cook Inlet, Alaska	NOS	9455963	61.3933	-149.847	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	17.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Creek, Cook Inlet	AK
66443	Nukshak Island, Shelikof Strait, Alaska	NOS	9456717	58.3917	-153.958	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NUKSHAK ISLAND, SHELIKOF STRAIT	AK
66444	Aguchik Island, Kukak Bay, Alaska	NOS	9456901	58.29	-154.27	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.22	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGUCHIK ISLAND, KUKAK BAY	AK
66445	Ouzinkie, Spruce Island, Alaska	NOS	9457287	57.9217	-152.498	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ouzinkie, Spruce Island	AK
66446	Kodiak, Women's Bay, Alaska	NOS	9457292	57.73027777777778	-152.5138888888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Island	AK
66447	Uzkosti Point, Kupreanof Strait, Alaska	NOS	9457376	57.9283	-152.812	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uzkosti Point	AK
66448	Port Lions, Kodiak Island, Alaska	NOS	9457391	57.87347222222222	-152.8671111111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.789999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lions, AK	AK
66450	Nachalni Island, Kupreanof Strait, Alaska	NOS	9457407	57.9783	-152.925	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nachalni Island	AK
66451	Terror Bay (southwest), Kodiak Island, Alaska	NOS	9457493	57.74402777777778	-153.1954722222222	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Terror Bay	AK
66472	King Cove, Deer Passage, Alaska	NOS	9459881	55.05988888888889	-162.3261111111111	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6900000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	King Cove	AK
66452	Sitkalidak Island GPS Tide Buoy, Alaska	NOS	9457512	56.96572	-153.252194	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.340000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkalidak Island GPS Tide Buoy	AK
66453	Old Harbor, Kodiak Island, Alaska	NOS	9457527	57.20277777777778	-153.3038888888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.430000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OLD HARBOR, KODIAK ISLAND	AK
66454	West Raspberry Island, Alaska	NOS	9457535	58.10716666666666	-153.3401111111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.3500000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Raspberry Island	AK
66455	Japanese Bay, Kodiak Island, Alaska	NOS	9457634	56.96	-153.687	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Japanese Bay, Kodiak Island	AK
66456	Larsen Bay, Kodiak Island, Alaska	NOS	9457724	57.5333	-153.99	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.140000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Kodiak Island, AK	AK
66457	Geese Island GPS Tide Buoy, Alaska	NOS	9457726	56.594694	-153.996028	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island GPS Tide Buoy	AK
66459	Alitak, Lazy Bay, Alaska	NOS	9457804	56.8974	-154.248	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alitak	AK
66460	Puale Bay, Alaska	NOS	9458209	57.7067	-155.393	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puale Bay	AK
66461	Chirikof Island, Alaska	NOS	9458293	55.8083	-155.74	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chirikof Island	AK
66462	Chowiet Island, Semidi Island, Alaska	NOS	9458519	56.0517	-156.698	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chowiet island	AK
66464	Castle Bay, Northwest Arm, Alaska	NOS	9458907	56.2317	-158.347	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castle Bay	AK
66465	Hump Island, Kuiukta Bay, Alaska	NOS	9458964	56.1133	-158.598	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hump Island, Kuiukta Bay	AK
66466	Mitrofania Island, Alaska	NOS	9459016	55.89	-158.82	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mitrofania Island	AK
66467	Herendeen Island, Shumagin Islands, Alaska	NOS	9459163	55.06555555555556	-159.4186666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Herendeen Island, Shumagin Islands	AK
66468	Bird Island, Shumagin Bank, Shumagin Islands, Alaska	NOS	9459251	54.83522222222222	-159.7595555555556	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bird Island, Shumagin Bank	AK
66469	Sand Point, Popof Island, Alaska	NOS	9459450	55.33669444444445	-160.502	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Point	AK
66470	Zachary Bay, Unga Island, Shumagin Islands, Alaska	NOS	9459465	55.334999084472656	-160.61700439453125	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.969999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZACHARY BAY, UNGA IS (N. SIDE)	AK
66471	Dolgoi Harbor, Dolgoi Island, Alaska	NOS	9459758	55.121700286865234	-161.79200744628906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolgoi Harbor, Dolgoi Island	AK
66473	Cold Bay, Alaska	NOS	9459949	55.2083	-162.698	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cold Bay	AK
66514	Kinak Bay, Alaska	NOS	9465953	59.947528	-164.2107	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.760000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kinak Bay	AK
66474	Attu, Massacre Bay, Alaska	NOS	9460150	52.84000015258789	173.19500732421875	:America/Adak	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Station 9460150 Massacre Bay, Attu Island is a historic station with tidal\nharmonic constants and tidal datums based upon a 06/1943 - 06/1944\ninstallation. Due to the remote nature of this area, there are no plans to\ncollect updated water level values in the vicinity of Attu Island, AK.  During\nthe 1943-1944 installation of this station NOAA was able to obtain and compute\na full suite of harmonic constants.  Therefore, this station is used as a\ncontrol station for predictions at other subordinate harmonic stations in the\nfar western Aleutian Islands.In order to provide tidal predictions\n(http://tidesandcurrents.noaa.gov/tide_predictions.shtml) for this station and\nits subordinate stations, it is necessary to provide the separation between\nMean Sea Level (MSL) and Mean Lower Low Water (MLLW) only.Therefore, MSL has\nbeen held fixed as station datum and MLLW referenced to MSL in order to remove\nany reference to the terrestrial system.  The removal of a terrestrial\nreference frame enables the relationship between MSL and MLLW to remain\nconsistent over time and not require a periodic National Tidal Datum Epoch\n(NTDE) update to accountant for sea level rise.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.94	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATTU, MASSACRE BAY	AK
66475	Sweeper Cove, Adak Island, Alaska	NOS	9461380	51.86330555555556	-176.632	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Adak Island	AK
66476	Atka, Nazan Bay, Atka Island, Alaska	NOS	9461710	52.232	-174.1726	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9699999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atka	AK
66477	Nikolski, Umnak Island, Alaska	NOS	9462450	52.94061	-168.8713055557675	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikolski	AK
66478	Unalaska, Dutch Harbor, Alaska	NOS	9462620	53.87919444444444	-166.5403055555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0799999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalaska	AK
66479	Biorka Village, Biverly Inlet, Alaska	NOS	9462645	53.82891666666667	-166.21625	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biorka Village, Biverly Inlet	AK
66480	Reef Bight, Alaska	NOS	9462662	54.13072222222223	-166.0993333333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.009999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reef Bight	AK
66481	Broad Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462676	54.06458333333333	-165.9370555555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Broad Bight	AK
66482	Akutan, Aleutian Islands, Alaska	NOS	9462694	54.13327777777778	-165.7773055555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1599999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan, Alaska	AK
66483	Green Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462705	54.11027777777778	-165.6613888888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8700000000000045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bight	AK
66484	Surf Bay, Akutan Bay, Alaska	NOS	9462711	54.15083333333333	-165.615	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surf Bay, Akutan Bay	AK
66485	Akun Cove, Akun Island, Aleutian Islands, Alaska	NOS	9462719	54.2333	-165.533	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Cove, Akun Island	AK
66486	Trident Bay, Akun Island, Aleutian Islands, Alaska	NOS	9462721	54.14	-165.527	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Bay, Akun Island	AK
66487	Rootok Island, Rootok Strait, Alaska	NOS	9462723	54.05222222222222	-165.5141666666667	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.830000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rootok Island	AK
66488	Tigalda Bay, Tigalda Island, Alaska	NOS	9462782	54.12	-164.977	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6199999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tigalda Bay, Tigalda Island	AK
66489	SE Tigalda Island, Aleutian Islands, Alaska	NOS	9462786	54.10180555555556	-164.9415833333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.960000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SE Tigalda Island, Pacific Ocean	AK
66490	Cape Sarichef, Unimak Island, Alaska	NOS	9462787	54.6	-164.928	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sarichef, Unimak Island	AK
66491	Scotch Cap, Unimak Island, Alaska	NOS	9462808	54.39363888888889	-164.7457222222222	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotch Cap, Unimak Island, AK	AK
66515	Eastern Nunivak Island, Alaska	NOS	9466012	60.04294	-165.680583	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7700000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastern Nunivak Island	AK
66516	Popokamute (Kokokamute), Kuskokwim River, Alaska	NOS	9466057	60.12327777777778	-162.5003611111111	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Popokamute (Kokokamute), Kuskokwim River	AK
66492	Cape Chunak, Unimak Island, Alaska	NOS	9462941	55.06427777777778	-163.5341666666667	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.289999999999992	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chunak, AK	AK
66493	Neumans Cove, Bechevin Bay, Aleutian Islands, Alaska	NOS	9462948	54.9667	-163.44	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEUMANS COVE	AK
66494	False Pass, Isanotski Strait, Unimak Island, Alaska	NOS	9462955	54.8583	-163.407	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Pass, Unimak Island	AK
66496	Port Moller, Bristol Bay, Alaska	NOS	9463502	55.98569444444445	-160.5738888888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.830000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Moller	AK
66498	Meshik, Port Heiden, Bristol Bay, Alaska	NOS	9464075	56.90829849243164	-158.68490600585938	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.420000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Meshik, Port Heiden	AK
66499	Village Cove, St. Paul Island, Bering Sea, Alaska	NOS	9464212	57.125301361083984	-170.2852020263672	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Cove, St Paul Island	AK
66500	Cape Constantine, Nushagak Peninsula, Alaska	NOS	9464961	58.52170181274414	-159.15199279785156	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CONSTANTINE, NUSHAGAK PENINSULA	AK
66501	Protection Point, Nushagak Bay, Alaska	NOS	9465056	58.5	-158.712	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PROTECTION POINT, NUSHAGAK BAY	AK
66506	Clarks Point, Nushagak Bay, Alaska	NOS	9465261	58.8483	-158.552	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.97	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLARKS POINT, NUSHAGAK BAY	AK
66507	Kulukak Point, Alaska	NOS	9465265	58.84000015258789	-159.64700317382812	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.909999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KULUKAK POINT	AK
66508	Summit Island, NE side, Togiak Bay, Alaska	NOS	9465283	58.8467	-160.21	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.\nNOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.6899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE SIDE SUMMIT ISLAND, TOGIAK BAY A	AK
66509	Snag Point, Dillingham, Alaska	NOS	9465374	59.04	-158.447	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.839999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snag Point, Dillingham	AK
66510	Platinum, Alaska	NOS	9465396	59.0467	-161.818	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Platinum, AK	AK
66511	Carter Bay, Kuskokwim Bay, Alaska	NOS	9465601	59.37801666666667	-162.0293333333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carter Bay, Kuskokwim Bay	AK
66512	Quinhagak (Kwinak), Kushkokwin River, Alaska	NOS	9465831	59.75055277777778	-161.9154361111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.449999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quinhagak (Kwinak), Kushkokwin River	AK
66517	Helmick Point (SE of), Kuskokwim River, Alaska	NOS	9466153	60.270301818847656	-162.4102020263672	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.760000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helmick Point	AK
66519	Tooksook Bay, Nelson Island, Alaska	NOS	9466298	60.5167	-165.133	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.169999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nelson Island, Tooksook Bay	AK
66520	Lomavik, Alaska	NOS	9466328	60.554298400878906	-162.29710388183594	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lomavik	AK
66521	Bethel, Kuskokwim River, Alaska	NOS	9466477	60.8	-161.75	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bethel, Kuskokwim River, AK	AK
66522	Dall Point, Hooper Bay, Alaska	NOS	9466931	61.5317	-166.148	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dall Point	AK
66523	Nunam Iqua (Sheldon Point), Alaska	NOS	9467551	62.53294444444445	-164.8452777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nunam Iqua (Sheldon Point)	AK
66524	Northeast Cape, St. Lawrence Island, Alaska	NOS	9468039	63.3167	-168.967	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Cape, St. Lawrence Island	AK
66526	Savoonga, St. Lawrence Island, Alaska	NOS	9468258	63.67908333333333	-170.5371111111111	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savoonga	AK
66529	Unalakleet, Alaska	NOS	9468333	63.875	-160.78799438476562	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalakleet	AK
66530	Shaktoolik, Alaska	NOS	9468691	64.38022222222222	-161.2351388888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6699999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shaktoolik	AK
66531	Nome, Norton Sound, Alaska	NOS	9468756	64.49461111111111	-165.4396388888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nome, Norton Sound	AK
66532	Elim, Norton Bay, Alaska	NOS	9468863	64.6167	-162.248	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.\nNOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELIM, NORTON BAY	AK
66533	Point Spencer, Port Clarence, Norton Sound, Alaska	NOS	9469237	65.2567	-166.847	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Spencer, Port Clarence	AK
66534	Teller, Port Clarence, Alaska	NOS	9469239	65.2667	-166.353	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TELLER, PORT CLARENCE	AK
66535	Lost River, Seward Peninsula, Alaska	NOS	9469338	65.39	-167.145	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOST RIVER, SEWARD PENINSULA	AK
66536	Tin City, Bering Sea, Alaska	NOS	9469439	65.55833333333334	-167.975	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.46999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tin City, Bering Sea	AK
66537	Outside Lopp Lagoon, Alaska	NOS	9469515	65.728806	-168.032139	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.480000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outside Lopp Lagoon	AK
66538	Deering, Kotzebue Sound, Alaska	NOS	9469751	66.09716666666667	-162.7404722222222	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deering	AK
66562	Charlotte Amalie, St. Thomas, Virgin Islands	NOS	9751639	18.33583333333333	-64.92	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlotte Amalie	VI
66539	Goodhope Bay, Kotzebue Sound, Alaska	NOS	9469833	66.23030090332031	-163.9040985107422	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8800000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goodhope Bay	AK
66540	Shishmaref Inlet 2, Alaska	NOS	9469854	66.2633	-166.02	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shishmaref Inlet 2	AK
66541	Cape Espenberg, Kotzebue Sound, Alaska	NOS	9490096	66.58569444444444	-164.2508333333333	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5300000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Espenberg, Kotzebue Sound	AK
66542	Kotzebue, Kotzebue Sound, Alaska	NOS	9490424	66.9017	-162.582	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kotzebue	AK
66543	Cape Krusenstern, Kotzebue Sound, Alaska	NOS	9490571	67.05419444444445	-163.3212777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.23000000000000398	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Krusenstern	AK
66544	Red Dog Dock, Alaska	NOS	9491094	67.57580555555556	-164.0643888888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Dog Dock	AK
66545	Kivalina, Alaska	NOS	9491253	67.7267	-164.592	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kivalina	AK
66546	Point Hope, Alaska	NOS	9491873	68.3417	-166.808	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3299999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hope	AK
66547	Barrow (offshore), Alaska	NOS	9494935	71.36011111111111	-156.7298611111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barrow Offshore	AK
66548	Prudhoe Bay, Alaska	NOS	9497645	70.41141666666667	-148.5317777777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prudhoe Bay	AK
66551	Barter Island, Alaska	NOS	9499176	70.12855555555555	-143.6110277777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.28000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barter Island	AK
66552	Leinster Point, Leinster Bay, St. John, Virgin Islands	NOS	9751309	18.36761111111111	-64.72072222222222	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Leinster Point, Leinster Bay, St. John's	VI
66553	Christiansted Harbor, St. Croix, Virgin Islands	NOS	9751364	17.74769444444445	-64.69838888888889	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Christiansted Harbor, St Croix	VI
66554	Coral Harbor, St. John, Virgin Islands	NOS	9751373	18.3483	-64.7167	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST JOHN'S ISLAND, CORAL HARBOR	VI
66555	Lameshur Bay, St. John, Virgin Islands	NOS	9751381	18.31824999994702	-64.72422222243415	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lameshur Bay, St John	VI
66556	Lime Tree Bay, St. Croix, Virgin Islands	NOS	9751401	17.694700241088867	-64.75379943847656	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.37000000000000455	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lime Tree Bay	VI
66557	Lovango Cay, St. John, Virgin Islands	NOS	9751467	18.36066666666667	-64.80352777777777	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovango Cay, St. John	VI
66558	Dog Island, St. Thomas, Virgin Islands	NOS	9751494	18.29713888888889	-64.81775	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog Island, St. Thomas	VI
66560	Water Bay, St. Thomas, Virgin Islands	NOS	9751583	18.34894444444445	-64.86416666666666	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5599999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Water Bay	VI
66561	Fredericksted, St. Croix, Virgin Islands	NOS	9751584	17.7133	-64.8833	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fredericksted, St. Croix	VI
66563	Dorothea Bay, St. Thomas, Virgin Islands	NOS	9751768	18.37125	-64.96347222222222	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dorothea Bay, Saint Thomas	VI
66564	Botany Bay, St. Thomas, Virgin Islands	NOS	9751774	18.3633	-65.035	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Botany Bay, St. Thomas	VI
66565	Culebra, Puerto Rico	NOS	9752235	18.30086111111111	-65.30247222222222	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Culebra	PR
66566	Isabel Segunda, Vieques Island, Puerto Rico	NOS	9752619	18.15252777777778	-65.44380555555556	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isabel Segunda, Vieques Island	PR
66567	Esperanza, Vieques Island, Puerto Rico	NOS	9752695	18.09386111111111	-65.47136111111111	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Esperanza, Vieques Island	PR
66568	Isla Palominos, Puerto Rico	NOS	9752962	18.34497222222222	-65.5695	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7099999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isla Palominos	PR
66569	Fajardo, Puerto Rico	NOS	9753216	18.33522222222222	-65.63111111111111	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fajardo	PR
66570	Naguabo, Puerto Rico	NOS	9753641	18.18705555555556	-65.71138888888889	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naguabo	PR
66571	Yabucoa Harbor, Puerto Rico	NOS	9754228	18.05508333333333	-65.833	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.34999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yabucoa Harbor	PR
66572	San Juan, La Puntilla, San Juan Bay, Puerto Rico	NOS	9755371	18.45916666666667	-66.11638888888889	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan, La Puntilla, San Juan Bay	PR
66573	Las Mareas, Puerto Rico	NOS	9755679	17.9283	-66.1583	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Las Mareas	PR
66574	Santa Isabel, Puerto Rico	NOS	9756639	17.955	-66.4067	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Isabel	PR
66575	Arecibo, Puerto Rico	NOS	9757809	18.48052777777778	-66.70236111111112	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arecibo	PR
66684	Long Island, Casco Bay, Maine	NOS	8417941	43.69	-70.17	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Long Island	ME
66576	Peuelas (Punta Guayanilla), Puerto Rico	NOS	9758053	17.97252777777778	-66.76177777777778	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penuelas (Punta Guayanilla)	PR
66577	Magueyes Island, Caribbean Sea, Puerto Rico	NOS	9759110	17.97010040283203	-67.04640197753906	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magueyes Island	PR
66578	Puerto Real, Puerto Rico	NOS	9759189	18.07480555555556	-67.18877777777777	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puerto Real	PR
66579	Baha Salinas, Puerto Rico	NOS	9759197	17.95144444444444	-67.19658333333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bahia Salinas	PR
66580	Mayagez, Puerto Rico	NOS	9759394	18.21888888888889	-67.1625	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayaguez	PR
66581	Aguadilla, Crashboat Beach, Puerto Rico	NOS	9759412	18.45663888888889	-67.16458333333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aguadilla, Crashboat Beach	PR
66582	Punta Guanajibo, Mayagez, Puerto Rico	NOS	9759421	18.165	-67.1817	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA GUANAJABO, MAYAGUES	PR
66583	Mona Island, Puerto Rico	NOS	9759938	18.08991666687859	-67.93850000010596	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mona Island	PR
66160	Galveston Bay entrance, south jetty, Texas	NOS	8771416	29.32670021057129	-94.69329833984375	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.169999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance, South Jetty	TX
65544	Augusta, MCRR Bridge, Kennebec River, Maine	NOS	8417144	44.32	-69.77028	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augusta, MCRR Bridge, Kennebec River	ME
65618	Sandy Point, Block Island Sound, Rhode Island	NOS	8459479	41.2283	-71.58	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT, BLOCK IS, SOUND	RI
65632	Montauk Point Light, Long Island Sound, New York	NOS	8510321	41.0717	-71.8567	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MONTAUK POINT LIGHT	NY
65636	Threemile Harbor entrance, Gardiners Bay, Long Island, New York	NOS	8511171	41.035	-72.19	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREEMILE HARBOR ENTRANCE	NY
65674	College Pt, Ft. of 110th Street, Long Island, New York	NOS	8517276	40.7833	-73.8567	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLLEGE PT, FT. OF 110TH ST, LI	NY
65687	Riverdale, Hudson River, New York	NOS	8518905	40.9033	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERDALE, HUDSON RIVER	NY
65698	South Amboy, Raritan River, New Jersey	NOS	8531232	40.4917	-74.2817	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH AMBOY  RARITAN RIVER	NJ
65755	St. Michaels, Miles River, Chesapeake Bay, Maryland	NOS	8572342	38.7867	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAELS, MILES RIVER	MD
65781	Cape Charles Harbor (USCG Wharf), Chesapeake Bay, Virginia	NOS	8632366	37.2633	-76.02	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CHARLES HBR (U.S. G. WHARF)	VA
65794	New Point, Virginia	NOS	8637289	37.3467	-76.2733	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT	VA
65795	New Point (Comfort Shoal), Virginia	NOS	8637590	37.2567	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT, COMFORT SHOAL	VA
65801	Burwell Bay, James River, Virginia	NOS	8638421	37.0567	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BURWELL BAY, JAMES RIVER	VA
65866	Savannah (Bull Street), Georgia	NOS	8670681	32.0817	-81.0917	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BULL STREET, SAVANNAH RIVER	GA
65868	Palmer Johnson Shipyard, Wilmington River, Georgia	NOS	8670893	32.0233	-81.0467	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PALMER JOHNSON SHIPYARD, WILMINGTON R.	GA
65888	Cut 2N front range, St. Marys River, Florida	NOS	8720012	30.7167	-81.3017	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 2N FRONT RANGE, ST MARYS RIVER ENTR	FL
65923	Daytona Beach (ocean), Florida	NOS	8721020	29.2283	-81.005	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH (OCEAN)	FL
65940	Boynton Beach, Lake Worth, Florida	NOS	8722706	26.54829978942871	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOYNTON BEACH	FL
66037	Richardson Hammock, St. Joseph Bay, Florida	NOS	8728949	29.69	-85.3633	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RICHARDSON HAMMOCK, ST. JOSEPH BAY	FL
66046	Upper Blackwater River, Florida	NOS	8729738	30.6583	-86.9883	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER BLACKWATER RIVER	FL
66091	Keesler AFB, Back Bay, Biloxi, Mississippi	NOS	8744284	30.4183	-88.925	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEESLER AFB, BACK BAY OF BILOXI	MS
66106	Venice, Grand Pass, Louisiana	NOS	8760849	29.2733	-89.3517	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GRAND PASS	LA
66114	Grand Isle, Mississippi River Delta, Louisiana	NOS	8761720	29.255	-89.9683	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND ISLE	LA
66133	Eugene Island, Atchafalaya Bay, Louisiana	NOS	8764311	29.3717	-91.385	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island	LA
66216	North Point, Pier 41, San Francisco, San Francisco Bay, California	NOS	9414305	37.81	-122.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH POINT [PIER 41] S.F.BAY	CA
66221	Redwood Creek Marker 8, San Francisco Bay, California	NOS	9414501	37.5333	-122.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REDWOOD CREEK,C.M. NO. 8,S.F.BAY	CA
66262	Requa Dock, California	NOS	9419551	41.545	-124.07	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Requa Dock	CA
66306	Taholah, Washington	NOS	9441644	47.34817	-124.28475	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Taholah	WA
66332	Yokeko Point, Deception Pass, Washington	NOS	9448601	48.4133	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOKEKO POINT	WA
66357	Big Salt Lake, Alaska	NOS	9450623	55.6	-132.95	:America/Juneau	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Salt Lake	AK
66401	Muir Inlet, Glacier Bay, Alaska	NOS	9452584	58.9133	-136.108	:America/Juneau	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	8.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Muir Inlet, Glacier Bay	AK
66411	Storey Island (north side), Alaska	NOS	9454571	60.7317	-147.437	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	6.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STOREY ISLAND NORTH SIDE	AK
66449	Dovolno Point, Kizhuyak Bay, Alaska	NOS	9457393	57.7394	-152.87472	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dovolno Point, Kizhuyak Bay	AK
66458	Uyak, Uyak Bay, Alaska	NOS	9457728	57.635	-154.007	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	7.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak	AK
66463	Sutwik Island, West End, Alaska	NOS	9458665	56.54	-157.327	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.91	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST END, SUTWIK ISLAND	AK
66497	Zapadni Bay, St. George Island, Alaska	NOS	9463885	56.57	-169.7	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZAPADNI BAY, ST. GEORGE ISLAND	AK
66502	Pyrite Point, Bristol Bay, Alaska	NOS	9465123	58.62	-161.542	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PYRITE POINT, BRISTOL BAY	AK
66503	High Island, Bristol Bay, Alaska	NOS	9465173	58.721699	-160.427	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.61	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HIGH ISLAND, BRISTOL BAY	AK
66504	Hagemeister Island (north end), Alaska	NOS	9465234	58.7767	-160.777	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH END, HAGEMEISTER ISLAND	AK
66505	Estus Point, Hagemeister Strait, Alaska	NOS	9465249	58.8083	-161.1	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.94	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTUS POINT, HAGEMEISTER STRAIT	AK
66525	St. Michael, Norton Sound, Alaska	NOS	9468132	63.475	-162.027	:America/Nome	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAEL, NORTON SOUND	AK
66513	Kwigillingok, Alaska	NOS	9465911	59.87975	-163.166361	:America/Nome	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kwigillinok	AK
66528	Akeftapak, St. Lawrence Island, Alaska	NOS	9468283	63.7185	-171.6447	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM HST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akeftapak, St. Lawrence Island	AK
66549	Prudhoe Bay #2, Alaska	NOS	9497649	70.3883	-148.51	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRUDHOE BAY #2	AK
66550	Cross Island (Dinkum Sands), Alaska	NOS	9497778	70.4917	-147.95	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROSS ISLAND, (DINKUM SANDS)	AK
66559	Benner Bay, St. Thomas, Virgin Islands	NOS	9751567	18.32	-64.87	:America/St_Thomas	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AST to 2002-01-01 12:00 AM AST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNER BAY	VI
66584	Nonopapa, Niihau Island, Hawaii	NOS	1610367	21.87	-160.235	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	-00:11:00	\N	0.77	-00:16:00	\N	0.77	\N	\N	Nonopapa, Niihau Island	HI
66585	Port Allen, Hanapepe Bay, Kauai Island, Hawaii (sub)	NOS	1611347	21.9033	-159.592	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65505	-00:10:00	\N	1	-00:15:00	\N	1.01	\N	\N	Port Allen, Hanapepe Bay	HI
66586	Waimea Bay, Kauai Island, Hawaii	NOS	1611401	21.9567	-159.673	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65505	00:18:00	\N	0.91	00:07:00	\N	0.86	\N	\N	Waimea Bay	HI
66587	Hanamaulu Bay, Kauai Island, Hawaii	NOS	1611443	21.995	-159.335	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65505	00:04:00	\N	0.91	00:10:00	\N	1	\N	\N	Hanamaulu Bay	HI
66588	Hanalei Bay, Kauai Island, Hawaii	NOS	1611683	22.215	-159.502	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65505	-01:22:00	\N	0.91	-01:01:00	\N	1.07	\N	\N	Hanalei Bay	HI
66589	Hanauma Bay, Oahu Island, Hawaii	NOS	1612301	21.275	-157.697	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	-00:45:00	\N	1	-00:59:00	\N	1	\N	\N	Hanauma Bay	HI
66590	Fort Kamehameha, Bishop Point, Pearl Harbor, Oahu Island, Hawaii (sub)	NOS	1612366	21.33	-157.967	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	00:06:00	\N	0.88	00:15:00	\N	1	\N	\N	Pearl Harbor Entrance, Bishop Point	HI
66591	Waimanalo, Oahu Island, Hawaii	NOS	1612376	21.335	-157.693	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65509	00:05:00	\N	0.75	00:11:00	\N	0.88	\N	\N	Waimanalo	HI
66592	Pearl Harbor, Ford Island Ferry Dock, Oahu Island, Hawaii (sub)	NOS	1612404	21.3683	-157.94	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	00:08:00	\N	0.88	00:16:00	\N	1.03	\N	\N	Pearl Harbor, Ford Island Ferry	HI
66593	Waianae, Oahu Island, Hawaii	NOS	1612482	21.445	-158.192	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	00:18:00	\N	1	00:20:00	\N	0.93	\N	\N	Waianae	HI
66594	Haleiwa, Waialua Bay, Oahu Island, Hawaii	NOS	1612668	21.5983	-158.108	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	-02:05:00	\N	0.8	-01:02:00	\N	0.8	\N	\N	Haleiwa, Waialua Bay	HI
66595	Kamalo Harbor, Molokai Island, Hawaii	NOS	1613077	21.0483	-156.877	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	-00:16:00	0	\N	-00:37:00	0.1	\N	\N	\N	Kamalo Harbor	HI
66596	Pukoo Harbor, Molokai Island, Hawaii	NOS	1613155	21.0717	-156.8	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	-00:48:00	0	\N	-01:03:00	0.1	\N	\N	\N	Pukoo Harbor	HI
66597	Kaunakakai Harbor, Molokai Island, Hawaii (sub)	NOS	1613198	21.085	-157.032	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	-00:14:00	\N	1.25	-00:10:00	\N	1.13	\N	\N	Kaunakakai	HI
66598	Kolo, Molokai Island, Hawaii	NOS	1613226	21.0933	-157.197	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	00:01:00	0	\N	00:05:00	0	\N	\N	\N	Kolo	HI
66599	Kaumalapau, Lanai Island, Hawaii	NOS	1614465	20.79	-156.995	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	00:03:00	0	\N	00:02:00	0.2	\N	\N	\N	Kaumalapau, Lanai Island	HI
66600	Makena, Maui Island, Hawaii	NOS	1615202	20.6567	-156.445	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65511	01:09:00	\N	0.54	01:21:00	\N	0.73	\N	\N	Makena	HI
66601	Hana, Maui Island, Hawaii	NOS	1615395	20.7617	-155.987	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65511	00:18:00	\N	0.54	00:40:00	\N	1.05	\N	\N	Hana	HI
66602	Kuheia Bay, Kahoolawe Island, Hawaii	NOS	1616696	20.595	-156.607	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	-00:09:00	0	\N	-00:09:00	0.2	\N	\N	\N	Kuheia Bay	HI
66603	Mahukona, Hawaii Island, Hawaii	NOS	1617277	20.1867	-155.903	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65513	00:42:00	\N	0.67	00:38:00	\N	0.8	\N	\N	Mahukona	HI
66604	Kawaihae, Hawaii Island, Hawaii (sub)	NOS	1617433	20.0366	-155.8294	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65513	00:57:00	\N	0.6	01:01:00	\N	0.83	\N	\N	Kawaihae	HI
66605	Kailua Kona, Hawaii Island, Hawaii	NOS	1617846	19.6433	-156	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65513	00:37:00	\N	0.67	00:38:00	\N	0.8	\N	\N	Kailua Kona	HI
66606	Napoopoo, Kealakekua Bay, Hawaii Island, Hawaii	NOS	1618021	19.4767	-155.922	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65513	00:47:00	\N	0.67	00:48:00	\N	0.8	\N	\N	Napoopoo, Kealakekua Bay	HI
66607	Honuapo, Hawaii Island, Hawaii	NOS	1618578	19.0883	-155.553	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65513	00:33:00	\N	1	00:38:00	\N	1.01	\N	\N	Honuapo	HI
66608	East Island, French Frigate Shoals, Hawaii	NOS	1619222	23.7833	-166.208	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	00:08:00	\N	0.73	00:03:00	\N	0.73	\N	\N	East Island, French Frigate Shoals	HI
66609	Laysan Island, Hawaii	NOS	1619645	25.7667	-171.75	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	01:12:00	\N	0.5	01:02:00	\N	0.53	\N	\N	Laysan Island	HI
66610	Coffin Point, Coffin Neck, Maine (sub)	NOS	8410714	44.87	-67.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65523	00:33:00	\N	0.77	00:31:00	\N	0.94	\N	\N	Coffins Point	ME
66611	Garnet Point, Hersey Neck, Pennamquan River, Cobscook Bay, Maine (sub)	NOS	8410715	44.9233	-67.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65523	00:14:00	\N	1	00:11:00	\N	1.04	\N	\N	Garnet Point, Pennamquan River	ME
66612	Birch Islands, Cobscook Bay, Maine	NOS	8410875	44.875	-67.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65523	01:13:00	\N	0.75	00:59:00	\N	0.94	\N	\N	Birch Islands	ME
66613	Cutler (Farris Wharf), Little River, Maine (sub)	NOS	8411060	44.65702819824219	-67.20466613769531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65523	-00:19:00	\N	0.74	-00:10:00	\N	0.74	\N	\N	Cutler, Little River	ME
66614	Cutler Naval Base, Machias Bay, Maine (sub)	NOS	8411250	44.6417	-67.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65523	-00:15:00	\N	0.7	-00:06:00	\N	0.7	\N	\N	Cutler, Naval Radio Station	ME
66685	Prince Point, Casco Bay, Maine	NOS	8417948	43.7617	-70.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:01:00	\N	0.99	00:00:00	\N	1	\N	\N	Prince Point	ME
66615	Stone Island, Machias Bay, Maine	NOS	8411411	44.6033	-67.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65523	-00:28:00	\N	0.68	-00:11:00	\N	0.68	\N	\N	Stone Island, Machias Bay	ME
66616	Machiasport, Machias River, Maine	NOS	8411467	44.6983	-67.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65523	-00:09:00	\N	0.69	00:01:00	\N	0.69	\N	\N	Machiasport, Machias River	ME
66617	Shoppee Point, Englishman Bay, Maine	NOS	8411696	44.615	-67.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65523	-00:13:00	\N	0.66	-00:05:00	\N	0.66	\N	\N	Shoppee Point, Englishman Bay	ME
66618	Steele Harbor Island, Maine	NOS	8411801	44.4933	-67.5433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:20:00	\N	1.27	-00:28:00	\N	1.27	\N	\N	Steele Harbor Island	ME
66619	Green Island, Petit Manan Bar, Maine	NOS	8412568	44.3717	-67.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:24:00	\N	1.16	-00:28:00	\N	1.16	\N	\N	Green Island, Petit Manan Bar	ME
66921	Gowanus Bay, New York	NOS	8517921	40.665	-74.0133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	-00:12:00	\N	0.95	-00:18:00	\N	1.03	\N	\N	Gowanus Bay	NY
66620	Milbridge, Narraguagus River, Maine (sub)	NOS	8412581	44.54	-67.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:05:00	\N	1.09	-00:15:00	\N	1.23	\N	\N	Millbridge, Narraguagus River, Maine	ME
66621	Prospect Harbor, Maine	NOS	8412932	44.4	-68.0217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:15:00	\N	1.15	-00:24:00	\N	1.15	\N	\N	Prospect Harbor	ME
66622	Winter Harbor, Frenchman Bay, Maine	NOS	8413079	44.3883	-68.0867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:10:00	\N	0.95	-00:01:00	\N	0.95	\N	\N	Winter Harbor, Frenchman Bay	ME
66623	Southwest Harbor, Mount Desert Island, Maine	NOS	8413564	44.275	-68.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	-00:27:00	\N	0.95	00:00:00	\N	0.96	\N	\N	Southwest Harbor	ME
66624	Bass Harbor, Mount Desert Island, Maine	NOS	8413651	44.2417	-68.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	-00:27:00	\N	0.93	00:04:00	\N	0.93	\N	\N	Bass Harbor	ME
66625	Ellsworth, Union River, Blue Hill Bay, Maine (sub)	NOS	8413801	44.535	-68.4217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:16:00	\N	0.97	00:15:00	\N	1	\N	\N	Ellsworth, Union River	ME
66626	Mackerel Cove, Swans Island, Blue Hill Bay, Maine (sub)	NOS	8413825	44.17	-68.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	-00:27:00	\N	0.93	00:02:00	\N	0.94	\N	\N	Mackerel Cove	ME
66627	Burnt Coat Harbor, Swans Island, Maine	NOS	8413857	44.145	-68.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:06:00	\N	0.88	-00:01:00	\N	0.89	\N	\N	Burnt Coat Harbor, Swans Island	ME
66628	Blue Hill Harbor, Blue Hill Bay, Maine	NOS	8414112	44.4083	-68.5633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:11:00	\N	0.95	00:09:00	\N	0.95	\N	\N	Blue Hill Harbor	ME
66629	Center Harbor, Eggemoggin Reach, Maine	NOS	8414168	44.2633	-68.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:12:00	\N	0.95	00:09:00	\N	0.95	\N	\N	Center Harbor	ME
66630	Isle Au Haut, Penobscot Bay, Maine	NOS	8414288	44.0733	-68.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	-00:27:00	\N	0.88	-00:01:00	\N	0.87	\N	\N	Isle Au Haut	ME
66631	Stonington, Deer Isle, Penobscot Bay, Maine	NOS	8414348	44.1533	-68.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:06:00	\N	0.9	00:08:00	\N	0.91	\N	\N	Stonington, Deer Isle	ME
66632	Little Deer Isle, Eggemoggin Reach, Maine	NOS	8414424	44.2917	-68.6933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:14:00	\N	0.93	00:16:00	\N	0.94	\N	\N	Little Deer Isle	ME
66633	Gross Point, Eastern Channel, Penobscot River, Maine	NOS	8414581	44.5367	-68.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:10:00	\N	0.98	-00:06:00	\N	0.99	\N	\N	Gross Point, Eastern Channel	ME
66634	Bangor, Penobscot River, Maine (sub)	NOS	8414612	44.785	-68.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:18:00	\N	0.87	-00:06:00	\N	1.25	\N	\N	Bangor	ME
66635	Castine, Penobscot Bay, Maine	NOS	8414672	44.3867	-68.7967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:11:00	\N	1	00:15:00	\N	0.95	\N	\N	Castine	ME
66636	Bucksport, Penobscot River, Maine	NOS	8414684	44.5717	-68.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:11:00	\N	1	-00:04:00	\N	1.01	\N	\N	Bucksport	ME
66637	Sandy Point, Penobscot River, Maine	NOS	8414692	44.505	-68.805	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:08:00	\N	0.98	00:06:00	\N	0.99	\N	\N	Sandy Point	ME
66638	Vinalhaven, Vinalhaven Island, Penobscot Bay, Maine	NOS	8414776	44.0433	-68.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:10:00	\N	0.88	00:09:00	\N	0.87	\N	\N	Vinalhaven, Vinalhaven Island	ME
66639	Winterport, Penobscot River, Maine	NOS	8414781	44.6367	-68.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:04:00	\N	0.92	-00:09:00	\N	1.11	\N	\N	Winterport	ME
66640	North Haven, Penobscot Bay, Maine	NOS	8414856	44.1267	-68.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:10:00	\N	0.9	00:13:00	\N	0.91	\N	\N	North Haven	ME
66641	Matinicus Harbor, Wheaton Island, Penobscot Bay, Maine	NOS	8414876	43.8617	-68.8817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	-00:27:00	\N	0.85	00:05:00	\N	0.85	\N	\N	Matinicus Harbor, Wheaton Island	ME
66642	Belfast, Penobscot Bay, Maine	NOS	8415191	44.4267	-69.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:04:00	\N	1.03	00:09:00	\N	0.97	\N	\N	Belfast	ME
66643	Rockland, Penobscot River, Maine (sub)	NOS	8415490	44.105	-69.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65531	00:06:00	\N	1.03	00:09:00	\N	0.93	\N	\N	Rockland	ME
66644	Thomaston, St. George River, Maine (sub)	NOS	8415709	44.0717	-69.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:03:00	\N	1.03	-00:04:00	\N	1.03	\N	\N	Thomaston	ME
66645	Tenants Harbor, Maine	NOS	8415809	43.965	-69.2167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:11:00	\N	1.02	-00:11:00	\N	1.02	\N	\N	Tenants Harbor	ME
66646	Otis Cove, St. George River, Maine	NOS	8415867	43.9867	-69.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:14:00	\N	1	-00:15:00	\N	1	\N	\N	Otis Cove	ME
66647	Port Clyde, St. George River, Maine	NOS	8415933	43.925	-69.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:07:00	\N	0.98	-00:11:00	\N	0.98	\N	\N	Port Clyde	ME
66648	Burnt Island, Georges Islands, Maine	NOS	8416028	43.8717	-69.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:12:00	\N	0.98	-00:13:00	\N	0.98	\N	\N	Burnt Island, Georges Islands	ME
66649	Monhegan Island, Maine	NOS	8416092	43.765	-69.3217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:09:00	\N	0.97	-00:13:00	\N	0.97	\N	\N	Monhegan Island	ME
66650	Friendship Harbor, Maine	NOS	8416141	43.97	-69.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:11:00	\N	0.99	-00:18:00	\N	0.99	\N	\N	Friendship Harbor	ME
66651	Waldoboro, Medomak River, Maine	NOS	8416224	44.0933	-69.3767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:04:00	\N	1.04	-00:16:00	\N	1.04	\N	\N	Waldoboro	ME
66652	Jones Neck, Medomak River, Maine	NOS	8416232	44.015	-69.38	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:05:00	\N	1	-00:10:00	\N	1	\N	\N	Jones Neck	ME
66653	Muscongus Harbor, Muscongus Sound, Maine	NOS	8416381	43.9667	-69.4417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:03:00	\N	0.99	-00:09:00	\N	0.99	\N	\N	Muscongus Harbor, Muscongus Sound	ME
66654	New Harbor, Muscongus Bay, Maine	NOS	8416501	43.875	-69.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:08:00	\N	0.97	-00:10:00	\N	0.97	\N	\N	New Harbor, Muscongus Bay	ME
66655	Pemaquid Harbor, Johns Bay, Maine	NOS	8416581	43.8767	-69.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:04:00	\N	0.97	-00:05:00	\N	0.97	\N	\N	Pemaquid Harbor, Johns Bay	ME
66656	Newcastle, Damariscotta River, Maine	NOS	8416608	44.0333	-69.5367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:25:00	\N	1.02	00:16:00	\N	1.02	\N	\N	Newcastle	ME
66657	East Boothbay, Damariscotta River, Maine	NOS	8416721	43.865	-69.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:01:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	East Boothbay	ME
66658	Damariscove Harbor, Damariscove Island, Maine	NOS	8416796	43.7583	-69.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:10:00	\N	0.97	-00:09:00	\N	0.97	\N	\N	Damariscove Harbor, Damariscove Island	ME
66659	Sheepscot (below rapids), Sheepscot River, Maine	NOS	8416804	44.05	-69.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:20:00	\N	1.05	00:20:00	\N	1.05	\N	\N	Sheepscot (below rapids)	ME
66660	Boothbay Harbor, Maine	NOS	8416828	43.85	-69.6283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:08:00	\N	0.97	-00:06:00	\N	0.97	\N	\N	Boothbay Harbor	ME
66661	Southport, Townsend Gut, Maine	NOS	8416908	43.8467	-69.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:01:00	\N	0.98	00:01:00	\N	0.98	\N	\N	Southport, Townsend Gut	ME
66662	Wiscasset, Sheepscot River, Maine (sub)	NOS	8416921	44	-69.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:04:00	\N	1.03	00:16:00	\N	1.03	\N	\N	Wiscasset	ME
66663	Cross River entrance, Sheepscot River, Maine	NOS	8416928	43.925	-69.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:04:00	\N	1	00:07:00	\N	1	\N	\N	Cross River entrance	ME
66664	Back River, Sheepscot River, Maine	NOS	8416961	43.9583	-69.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:31:00	\N	1	00:34:00	\N	1	\N	\N	Back River	ME
66665	Isle of Springs, Sheepscot River, Maine	NOS	8416968	43.86	-69.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:04:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	Isle of Springs	ME
68141	Bay Gardene, Louisiana	NOS	8761108	29.5983	-89.6183	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	04:04:00	\N	1.16	04:04:00	\N	1.16	\N	\N	Bay Gardene	LA
66666	Robinhood, Sasanoa River, Sheepscot River, Maine	NOS	8417067	43.8533	-69.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:14:00	\N	0.97	00:14:00	\N	0.97	\N	\N	Robinhood, Sasanoa River	ME
66667	Mill Point, Sasanoa River, Sheepscot River, Maine	NOS	8417127	43.8867	-69.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:43:00	\N	0.97	00:35:00	\N	0.97	\N	\N	Mill Point, Sasanoa River	ME
66668	Fort Popham, Hunniwell Point, Kennebec River, Maine (sub)	NOS	8417177	43.755	-69.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:04:00	\N	0.92	00:09:00	\N	0.92	\N	\N	Fort Popham, Hunniwell Point	ME
66669	Phippsburg, Kennebec River, Maine	NOS	8417221	43.8183	-69.81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:28:00	\N	0.88	00:26:00	\N	0.88	\N	\N	Phippsburg	ME
66670	Bath, Kennebec River, Maine (sub)	NOS	8417227	43.925	-69.815	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	01:17:00	\N	0.7	01:01:00	\N	0.7	\N	\N	Bath	ME
66671	Sturgeon Island, Merrymeeting Bay, Kennebec River, Maine	NOS	8417271	43.9817	-69.835	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	02:04:00	\N	0.58	02:00:00	\N	0.58	\N	\N	Sturgeon Island, Merrymeeting Bay	ME
66672	Howard Point, New Meadows River, Casco Bay, Maine	NOS	8417367	43.89	-69.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:01:00	\N	0.99	-00:05:00	\N	0.99	\N	\N	Howard Point, New Meadows River	ME
66673	Androscoggin River entrance, Kennebec River, Maine	NOS	8417377	43.95	-69.8883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	03:26:00	\N	0.52	02:24:00	\N	0.52	\N	\N	Androscoggin River entrance	ME
66674	Cundy Harbor, New Meadows River, Casco Bay, Maine	NOS	8417387	43.7883	-69.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:02:00	\N	0.98	-00:01:00	\N	0.98	\N	\N	Cundy Harbor, New Meadows River	ME
66675	Bowdoinham, Cathance River, Kennebec River, Maine	NOS	8417391	44.0083	-69.895	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	02:42:00	\N	0.63	02:34:00	\N	0.63	\N	\N	Bowdoinham, Cathance River	ME
66676	Brunswick, Androscoggin River, Kennebec River, Maine	NOS	8417527	43.9217	-69.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	04:36:00	\N	0.42	02:35:00	\N	0.42	\N	\N	Brunswick, Androscoggin River	ME
66677	Wilson Cove, Middle Bay, Casco Bay, Maine	NOS	8417553	43.825	-69.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:02:00	\N	1	00:02:00	\N	1	\N	\N	Wilson Cove, Middle Bay	ME
66678	South Harpswell, Potts Harbor, Casco Bay, Maine	NOS	8417647	43.7383	-70.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:01:00	\N	0.98	00:02:00	\N	0.98	\N	\N	South Harpswell, Potts Harbor	ME
66679	South Freeport, Casco Bay, Maine	NOS	8417801	43.82	-70.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:10:00	\N	0.99	00:12:00	\N	0.99	\N	\N	South Freeport	ME
66680	Cliff Island, Luckse Sound, Casco Bay, Maine	NOS	8417821	43.695	-70.11	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:02:00	\N	1	-00:02:00	\N	1	\N	\N	Cliff Island, Luckse Sound	ME
66681	Doyle Point, Casco Bay, Maine	NOS	8417874	43.7517	-70.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:03:00	\N	0.88	-00:02:00	\N	1	\N	\N	Doyle Point	ME
66682	Great Chebeague Island, Casco Bay, Maine	NOS	8417881	43.7217	-70.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:02:00	\N	1.03	00:02:00	\N	1	\N	\N	Great Chebeague Island	ME
66683	Vaill Island, Casco Bay, Maine	NOS	8417911	43.6767	-70.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:01:00	\N	1.03	00:05:00	\N	0.98	\N	\N	Vaill Island	ME
66686	Great Diamond Island, Casco Bay, Maine	NOS	8417988	43.67	-70.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:00:00	\N	1.03	00:00:00	\N	1	\N	\N	Great Diamond Island	ME
66687	Cushing Island, Casco Bay, Maine	NOS	8417997	43.645	-70.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:01:00	\N	1.03	00:01:00	\N	0.99	\N	\N	Cushing Island	ME
66688	Peak Island, Casco Bay, Maine	NOS	8418001	43.655	-70.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:08:00	\N	0.99	-00:04:00	\N	0.99	\N	\N	Peak Island	ME
66689	Cow Island, Casco Bay, Maine	NOS	8418009	43.69	-70.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:00:00	\N	1	-00:01:00	\N	1	\N	\N	Cow Island	ME
66690	Falmouth Foreside, Casco Bay, Maine	NOS	8418015	43.7317	-70.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:01:00	\N	0.97	00:01:00	\N	1	\N	\N	Falmouth Foreside	ME
66691	Portland Head Light, Casco Bay, Maine	NOS	8418031	43.6233	-70.2067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:01:00	\N	1	-00:02:00	\N	0.97	\N	\N	Portland Head Light	ME
66692	Presumpscot River Bridge, Casco Bay, Maine	NOS	8418137	43.6867	-70.2467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:04:00	\N	1.06	00:01:00	\N	1.01	\N	\N	Presumpscot River Bridge	ME
66693	Back Cove, Casco Bay, Maine	NOS	8418175	43.6767	-70.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:06:00	\N	0.97	00:02:00	\N	0.97	\N	\N	Back Cove	ME
66694	Fore River, Casco Bay, Maine	NOS	8418268	43.6417	-70.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:02:00	\N	1.03	00:02:00	\N	1	\N	\N	Fore River	ME
66695	Old Orchard Beach, Maine	NOS	8418557	43.5167	-70.3667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:06:00	\N	0.97	00:00:00	\N	0.97	\N	\N	Old Orchard Beach	ME
66697	Cape Porpoise, Maine	NOS	8418772	43.3667	-70.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:14:00	\N	0.95	00:12:00	\N	0.95	\N	\N	Cape Porpoise	ME
66698	Biddeford, Saco River, Maine (sub)	NOS	8418828	43.4917	-70.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:26:00	\N	0.97	00:12:00	\N	0.99	\N	\N	Biddeford, Saco River	ME
66699	Kennebunkport, Kennebunk River, Maine (sub)	NOS	8418911	43.3583	-70.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:05:00	\N	1	00:07:00	\N	0.97	\N	\N	Kennebunkport	ME
66700	Wells, Webhannet River, Maine (sub)	NOS	8419317	43.32	-70.56330555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:02:00	\N	0.97	00:06:00	\N	0.96	\N	\N	Wells, Webhannet River	ME
66701	Cape Neddick, Maine	NOS	8419399	43.1667	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:08:00	\N	1	00:02:00	\N	0.95	\N	\N	Cape Neddick	ME
66702	York Harbor, Maine	NOS	8419518	43.1317	-70.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:13:00	\N	0.95	00:03:00	\N	0.95	\N	\N	York Harbor	ME
66703	Fort Point, York Harbor, Maine	NOS	8419528	43.13	-70.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:10:00	\N	0.94	-00:04:00	\N	0.95	\N	\N	Fort Point, York Harbor	ME
66704	Seapoint, Cutts Island, Maine	NOS	8419590	43.085	-70.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:04:00	\N	0.96	00:01:00	\N	0.96	\N	\N	Seapoint, Cutts Island	ME
66705	Gerrish Island, Portsmouth Harbor, New Hampshire	NOS	8419688	43.0667	-70.6967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:03:00	\N	0.95	-00:02:00	\N	0.95	\N	\N	Gerrish Island	NH
66706	Kittery Point, Portsmouth Harbor, New Hampshire	NOS	8419807	43.0817	-70.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:01:00	\N	0.96	-00:07:00	\N	0.96	\N	\N	Kittery Point	NH
66707	Seavey Island, Portsmouth Harbor, New Hampshire (sub)	NOS	8419870	43.08	-70.7417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:18:00	\N	0.89	00:20:00	\N	0.89	\N	\N	Seavey Island	NH
66708	Salmon Falls River, Piscataqua River, New Hampshire	NOS	8419997	43.1917	-70.825	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	01:52:00	\N	0.75	01:35:00	\N	0.75	\N	\N	Salmon Falls River	NH
66709	Dover, Cocheco River, Piscataqua River, New Hampshire (sub)	NOS	8420411	43.1983	-70.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	01:39:00	\N	0.76	01:45:00	\N	0.77	\N	\N	Dover, Cocheco River	NH
66710	Dover Point, Piscataqua River, New Hampshire	NOS	8421897	43.1217	-70.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	01:27:00	\N	0.7	01:33:00	\N	0.7	\N	\N	Dover Point	NH
66711	Squamscott River RR. Bridge, Piscataqua River, New Hampshire	NOS	8422687	43.0533	-70.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	02:41:00	\N	0.75	02:19:00	\N	0.75	\N	\N	Squamscott River RR. Bridge	NH
66712	Atlantic Heights, Piscataqua River, New Hampshire	NOS	8423635	43.09	-70.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:28:00	\N	0.82	00:37:00	\N	0.82	\N	\N	Atlantic Heights	NH
66713	Portsmouth, Portsmouth Harbor, New Hampshire	NOS	8423745	43.0783	-70.7517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:17:00	\N	0.86	00:22:00	\N	0.86	\N	\N	Portsmouth	NH
66714	Fort Point, Portsmouth Harbor, New Hampshire (sub)	NOS	8423898	43.071388244628906	-70.71055603027344	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:07:00	\N	0.94	00:03:00	\N	0.94	\N	\N	Fort Point	NH
66715	Jaffrey Point, Portsmouth Harbor, New Hampshire	NOS	8424601	43.0567	-70.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:05:00	\N	0.95	-00:03:00	\N	0.95	\N	\N	Jaffrey Point	NH
66716	Gosport Harbor, Isles of Shoals, New Hampshire	NOS	8427031	42.9783	-70.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	-00:02:00	\N	0.93	00:02:00	\N	0.93	\N	\N	Gosport Harbor, Isles of Shoals	NH
66717	Hampton Harbor, New Hampshire	NOS	8429489	42.895	-70.8167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:32:00	\N	0.91	00:14:00	\N	0.91	\N	\N	Hampton Harbor	NH
66718	Salisbury Point, Merrimack River, Massachusetts (sub)	NOS	8440273	42.8383	-70.9083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	01:18:00	\N	0.56	00:55:00	\N	0.83	\N	\N	Salisbury Point	MA
66719	Merrimacport, Merrimack River, Massachusetts (sub)	NOS	8440369	42.825	-70.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	02:08:00	\N	0.5	01:26:00	\N	0.76	\N	\N	Merrimacport	MA
66721	Newburyport, Merrimack River, Massachusetts (sub)	NOS	8440466	42.815	-70.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	01:11:00	\N	0.86	00:31:00	\N	0.86	\N	\N	Newburyport	MA
66722	Riverside, Merrimack River, Massachusetts (sub)	NOS	8440889	42.7633	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	03:30:00	\N	0.35	01:56:00	\N	0.62	\N	\N	Riverside	MA
66723	Plum Island Sound (south end), Massachusetts (sub)	NOS	8441241	42.71013888888889	-70.78861111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:37:00	\N	0.94	00:12:00	\N	0.94	\N	\N	Plum Island Sound (south end)	MA
66724	Rockport Harbor, Massachusetts (sub)	NOS	8441551	42.6583	-70.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:06:00	\N	0.97	00:06:00	\N	0.95	\N	\N	Rockport	MA
66725	Annisquam, Lobster Cove, Massachusetts	NOS	8441571	42.655	-70.6767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:03:00	\N	0.97	00:11:00	\N	0.97	\N	\N	Annisquam, Lobster Cove	MA
66726	Essex, Essex River, Massachusetts (sub)	NOS	8441771	42.6317	-70.7767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:31:00	\N	0.94	00:22:00	\N	1	\N	\N	Essex	MA
66727	Gloucester Harbor, Massachusetts	NOS	8441841	42.61	-70.66	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:04:00	\N	0.97	00:00:00	\N	0.93	\N	\N	Gloucester Harbor	MA
66728	Salem, Salem Harbor, Massachusetts (sub)	NOS	8442645	42.5233	-70.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:05:00	\N	0.97	-00:02:00	\N	0.94	\N	\N	Salem, Salem Harbor	MA
66729	Lynn, Lynn Harbor, Massachusetts (sub)	NOS	8443187	42.4583	-70.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:03:00	\N	1	00:01:00	\N	0.97	\N	\N	Lynn, Lynn Harbor	MA
66730	Amelia Earhart Dam, Mystic River, Boston Harbor, Massachusetts (sub)	NOS	8443662	42.395	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:02:00	\N	0.97	00:01:00	\N	1.01	\N	\N	Amelia Earhart Dam, Mystic River	MA
66731	Chelsea St. Bridge, Chelsea River, Boston Harbor, Massachusetts (sub)	NOS	8443725	42.3867	-71.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:06:00	\N	1.01	00:01:00	\N	1.01	\N	\N	Chelsea St. Bridge, Chelsea River	MA
66776	Cotuit Highlands, Nantucket Sound, Massachusetts	NOS	8447675	41.6083	-70.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:47:00	\N	0.26	01:17:00	\N	0.26	\N	\N	Cotuit Highlands	MA
66732	Charlestown, Charles River entrance, Boston Harbor, Massachusetts	NOS	8443838	42.3717	-71.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:01:00	\N	1	00:00:00	\N	1	\N	\N	Charlestown, Charles River entrance	MA
66733	Deer Island (south end), Boston Harbor, Massachusetts	NOS	8444012	42.3483	-70.96	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:00:00	\N	0.97	00:01:00	\N	0.97	\N	\N	Deer Island (south end)	MA
66734	Boston Light, Boston Harbor, Massachusetts (sub)	NOS	8444162	42.3283	-70.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:02:00	\N	0.97	-00:01:00	\N	0.95	\N	\N	Boston Light	MA
66735	Moon Head, Boston Harbor, Massachusetts	NOS	8444312	42.3083	-70.9917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:04:00	\N	0.99	00:01:00	\N	0.99	\N	\N	Moon Head	MA
66736	Hull, Massachusetts	NOS	8444351	42.3033	-70.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:07:00	\N	0.97	00:05:00	\N	0.97	\N	\N	Hull	MA
66737	Neponset, Neponset River, Boston Harbor, Massachusetts	NOS	8444488	42.285	-71.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:03:00	\N	1	-00:02:00	\N	1	\N	\N	Neponset, Neponset River	MA
66738	Nut Island, Quincy Bay, Massachusetts (sub)	NOS	8444525	42.28	-70.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:01:00	\N	1	00:01:00	\N	0.99	\N	\N	Nut Island, Quincy Bay	MA
66739	Nantasket Beach, Weir River, Massachusetts	NOS	8444601	42.27	-70.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:07:00	\N	0.99	00:06:00	\N	0.99	\N	\N	Nantasket Beach, Weir River	MA
66740	Crow Point, Hingham Harbor entrance, Massachusetts	NOS	8444662	42.2617	-70.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:05:00	\N	0.99	00:02:00	\N	0.99	\N	\N	Crow Point, Hingham Harbor entrance	MA
66741	Cohasset Harbor (White Head), Massachusetts	NOS	8444762	42.2483	-70.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:02:00	\N	0.92	00:04:00	\N	0.92	\N	\N	Cohasset Harbor (White Head)	MA
66742	Hingham, Massachusetts	NOS	8444775	42.2467	-70.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:08:00	\N	1	00:09:00	\N	1	\N	\N	Hingham	MA
66743	Shipyard Point, Weymouth Fore River, Massachusetts (sub)	NOS	8444788	42.2483	-70.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:06:00	\N	1	00:09:00	\N	1	\N	\N	Weymouth Fore River Bridge	MA
66744	Scituate, Scituate Harbor, Massachusetts (sub)	NOS	8445138	42.2017	-70.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:01:00	\N	1.03	00:03:00	\N	0.95	\N	\N	Scituate, Scituate Harbor	MA
66745	Damons Point, North River, Massachusetts	NOS	8445425	42.16	-70.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:36:00	\N	0.89	00:20:00	\N	0.89	\N	\N	Damons Point, North River	MA
66746	Brant Rock, Green Harbor River, Massachusetts (sub)	NOS	8446009	42.0833	-70.6467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:03:00	\N	1.03	00:05:00	\N	0.96	\N	\N	Brant Rock, Green Harbor River	MA
66747	Provincetown, Cape Cod, Massachusetts (sub)	NOS	8446121	42.04959166666666	-70.18215833333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:18:00	\N	0.95	00:16:00	\N	0.95	\N	\N	Provincetown	MA
66748	Duxbury, Duxbury Harbor, Cape Cod Bay, Massachusetts (sub)	NOS	8446166	42.0383	-70.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:33:00	\N	1.03	00:06:00	\N	1.04	\N	\N	Duxbury, Duxbury Harbor	MA
66749	Plymouth Harbor, Plymouth, Cape Cod Bay, Massachusetts (sub)	NOS	8446493	41.96	-70.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:18:00	\N	1	00:04:00	\N	1.03	\N	\N	Plymouth	MA
66750	Wellfleet, Cape Cod Bay, Massachusetts	NOS	8446613	41.93	-70.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:30:00	\N	1.05	00:14:00	\N	1.05	\N	\N	Wellfleet	MA
66751	Cape Cod Canal (Sta. 115), Sagamore, Cape Cod Bay, Massachusetts (sub)	NOS	8447173	41.775	-70.535	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:06:00	\N	0.88	-00:15:00	\N	0.83	\N	\N	Cape Cod Canal, Sagamore	MA
66752	Cape Cod Canal, Sandwich, Cape Cod Bay, Massachusetts (sub)	NOS	8447180	41.7717	-70.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:03:00	\N	0.68	-00:01:00	\N	0.91	\N	\N	Sandwich Marina, Cape Cod Canal, east entrance	MA
66753	Cape Cod Canal (Sta. 200), Bournedale, Cape Cod Bay, Massachusetts (sub)	NOS	8447191	41.77	-70.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:21:00	\N	0.79	-00:29:00	\N	0.66	\N	\N	Cape Cod Canal, Bournedale	MA
66754	Sesuit Harbor, East Dennis, Cape Cod Bay, Massachusetts (sub)	NOS	8447241	41.7517	-70.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:01:00	\N	0.82	00:02:00	\N	1.02	\N	\N	Sesuit Harbor, East Dennis	MA
66755	Cape Cod Canal (Sta. 320), Bourne Bridge, Cape Cod Bay, Massachusetts (sub)	NOS	8447259	41.745	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:24:00	\N	0.79	-01:13:00	\N	0.46	\N	\N	Cape Cod Canal, Bourne Bridge	MA
66756	Cape Cod Canal, RR. bridge, Buzzards Bay, Massachusetts (sub)	NOS	8447270	41.7417	-70.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	02:50:00	\N	1.01	01:17:00	\N	1.01	\N	\N	Cape Cod Canal, RR. bridge	MA
66757	Onset Beach, Onset Bay, Buzzards Bay, Massachusetts	NOS	8447277	41.7417	-70.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	01:25:00	\N	1.03	00:41:00	\N	1.03	\N	\N	Onset Beach, Onset Bay	MA
66758	Steep Brook, Taunton River, Narragansett Bay, Rhode Island	NOS	8447281	41.74	-71.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:05:00	\N	1.29	00:26:00	\N	1.3	\N	\N	Steep Brook, Taunton River	RI
66759	Pleasant Bay, Cape Cod, Massachusetts	NOS	8447291	41.7367	-69.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	03:27:00	\N	0.34	02:28:00	\N	0.34	\N	\N	Pleasant Bay	MA
66760	Gray Gables, Buzzards Bay, Massachusetts (sub)	NOS	8447295	41.735	-70.6233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	01:16:00	\N	1.21	00:37:00	\N	1.05	\N	\N	Gray Gables	MA
66761	Barnstable Harbor, Beach Point, Cape Cod Bay, Massachusetts	NOS	8447335	41.7217	-70.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:30:00	\N	1	00:11:00	\N	1	\N	\N	Barnstable Harbor, Beach Point	MA
66762	Monument Beach, Buzzards Bay, Massachusetts	NOS	8447355	41.715	-70.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:30:00	\N	1.15	00:16:00	\N	1.15	\N	\N	Monument Beach	MA
66763	Great Hill, Buzzards Bay, Massachusetts (sub)	NOS	8447368	41.7117	-70.715	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:12:00	\N	1.21	00:12:00	\N	1.14	\N	\N	Great Hill	MA
66764	Marion, Sippican Harbor, Buzzards Bay, Massachusetts	NOS	8447385	41.705	-70.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:12:00	\N	1.29	00:10:00	\N	1.13	\N	\N	Marion, Sippican Harbor	MA
66765	Fall River, Narragansett Bay, Massachusetts (sub)	NOS	8447386	41.70430555555556	-71.16411111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:03:00	\N	1.21	00:18:00	\N	1.25	\N	\N	Fall River, Massachusetts	MA
66766	Piney Point, Buzzards Bay, Massachusetts (sub)	NOS	8447416	41.695	-70.72	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:10:00	\N	1.21	00:10:00	\N	1.13	\N	\N	Piney Point	MA
66767	Chatham, Cape Cod, Massachusetts (sub)	NOS	8447435	41.68847222222222	-69.95108333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	01:57:00	\N	0.35	01:08:00	\N	0.48	\N	\N	Chatham Harbor, Aunt Lydias Cove	MA
66768	Texas Tower, Georges Shoal	NOS	8447436	41.6883	-67.76	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:43:00	\N	0.44	-00:47:00	\N	0.44	\N	\N	Georges Shoal, Texas Tower	\N
66769	Saquatucket Harbor, Nantucket Sound, Massachusetts (sub)	NOS	8447495	41.6683	-70.0567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:16:00	\N	0.41	00:46:00	\N	0.41	\N	\N	Saquatucket Harbor	MA
66770	South Yarmouth, Bass River, Nantucket Sound, Massachusetts	NOS	8447504	41.665	-70.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	01:46:00	\N	0.29	01:48:00	\N	0.29	\N	\N	South Yarmouth, Bass River	MA
66771	Chatham, Stage Harbor, Cape Cod, Massachusetts (sub)	NOS	8447505	41.6667	-69.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:19:00	\N	0.43	00:46:00	\N	0.43	\N	\N	Chatham, Stage Harbor	MA
66772	Wychmere Harbor, Nantucket Sound, Massachusetts	NOS	8447506	41.665	-70.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:25:00	\N	0.39	00:52:00	\N	0.39	\N	\N	Wychmere Harbor	MA
66773	Dennisport, Nantucket Sound, Massachusetts	NOS	8447525	41.6583	-70.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:38:00	\N	0.36	01:03:00	\N	0.36	\N	\N	Dennisport	MA
66774	Mattapoisett, Mattapoisett Harbor, Buzzards Bay, Massachusetts	NOS	8447531	41.6567	-70.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:20:00	\N	1	00:11:00	\N	1.09	\N	\N	Mattapoisett, Mattapoisett Harbor	MA
66775	New Bedford, Buzzards Bay, Massachusetts	NOS	8447584	41.64	-70.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:07:00	\N	1.05	00:07:00	\N	1.05	\N	\N	New Bedford	MA
66777	Clarks Point, New Bedford, Buzzards Bay, Massachusetts (sub)	NOS	8447712	41.5933	-70.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:23:00	\N	1.07	00:14:00	\N	1.03	\N	\N	Clarks Point	MA
66778	Poponesset Island, Poponesset Bay, Nantucket Sound, Massachusetts	NOS	8447742	41.5867	-70.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	01:52:00	\N	0.24	02:03:00	\N	0.24	\N	\N	Poponesset Island, Poponesset Bay	MA
66779	Hix Bridge, East Branch, Westport River, Massachusetts	NOS	8447791	41.57	-71.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	02:30:00	\N	0.77	01:40:00	\N	0.77	\N	\N	Hix Bridge, East Branch	MA
66780	Round Hill Point, Buzzards Bay, Massachusetts (sub)	NOS	8447842	41.5383	-70.9283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:22:00	\N	1	00:14:00	\N	0.99	\N	\N	Round Hill Point	MA
66781	Falmouth Heights, Nantucket Sound, Massachusetts	NOS	8447865	41.545	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	-00:09:00	\N	0.14	-00:16:00	\N	0.14	\N	\N	Falmouth Heights	MA
66782	Little Harbor, Woods Hole, Massachusetts	NOS	8447939	41.52	-70.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	02:21:00	\N	0.4	00:32:00	\N	0.4	\N	\N	Little Harbor	MA
66783	Uncatena Island (south side), Woods Hole, Massachusetts	NOS	8447941	41.52	-70.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:22:00	\N	1.02	00:12:00	\N	1.02	\N	\N	Uncatena Island (south side)	MA
66784	Westport Harbor, Westport River, Massachusetts	NOS	8447975	41.5083	-71.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:33:00	\N	0.85	00:09:00	\N	0.85	\N	\N	Westport Harbor	MA
66785	Oak Bluffs, Martha's Vineyard, Massachusetts	NOS	8448208	41.4583	-70.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	03:47:00	\N	0.71	03:59:00	\N	0.5	\N	\N	Oak Bluffs	MA
66786	Penikese Island, Buzzards Bay, Massachusetts (sub)	NOS	8448248	41.45	-70.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	-00:16:00	\N	0.97	-00:17:00	\N	0.97	\N	\N	Penikese Island	MA
66787	Quicks Hole, North side, Massachusetts	NOS	8448251	41.4483	-70.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	-00:08:00	\N	0.99	-00:08:00	\N	0.99	\N	\N	Quicks Hole, North side	MA
66788	Cedar Tree Neck, Martha's Vineyard, Massachusetts	NOS	8448325	41.435	-70.6967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	01:32:00	\N	0.62	00:10:00	\N	0.62	\N	\N	Cedar Tree Neck	MA
66789	Cuttyhunk, Massachusetts	NOS	8448376	41.425	-70.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	01:15:00	\N	0.93	01:20:00	\N	0.97	\N	\N	Cuttyhunk	MA
66790	Edgartown, Martha's Vineyard, Massachusetts (sub)	NOS	8448558	41.3883	-70.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:18:00	\N	0.2	00:57:00	\N	0.2	\N	\N	Edgartown	MA
66791	Great Point, Nantucket Island, Massachusetts	NOS	8448566	41.3867	-70.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:28:00	\N	0.32	00:43:00	\N	0.32	\N	\N	Great Point	MA
66792	Wasque Point, Chappaquiddick Island, Martha's Vineyard, Massachusetts	NOS	8448683	41.3633	-70.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	03:20:00	\N	0.31	02:02:00	\N	0.31	\N	\N	Wasque Point, Chappaquiddick Island	MA
66793	Gay Head, Martha's Vineyard, Massachusetts	NOS	8448733	41.3533	-70.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:45:00	\N	0.82	-00:06:00	\N	0.82	\N	\N	Gay Head	MA
66794	Muskeget Island, north side, Nantucket Island, Massachusetts	NOS	8448817	41.3367	-70.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:15:00	\N	0.21	00:25:00	\N	0.21	\N	\N	Muskeget Island, north side	MA
66795	Squibnocket Point, Martha's Vineyard, Massachusetts	NOS	8448942	41.3117	-70.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	-00:02:00	\N	0.82	-00:45:00	\N	0.82	\N	\N	Squibnocket Point	MA
66796	Eel Point, Nantucket Island, Massachusetts	NOS	8449062	41.2917	-70.2083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65570	00:07:00	\N	0.24	00:39:00	\N	0.24	\N	\N	Eel Point	MA
66797	Nomans Land, Martha's Vineyard, Massachusetts	NOS	8449287	41.2617	-70.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:18:00	\N	0.85	-00:19:00	\N	0.85	\N	\N	Nomans Land	MA
66798	North End, Bay Oil pier, Sakonnet River, Rhode Island	NOS	8450898	41.6517	-71.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:01:00	\N	1.07	00:20:00	\N	1.2	\N	\N	North End, Bay Oil pier	RI
66799	Anthony Point, Sakonnet River, Rhode Island	NOS	8450948	41.6383	-71.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	-00:01:00	\N	1.09	00:00:00	\N	1.09	\N	\N	Anthony Point	RI
66800	Nannaquaket Neck, Sakonnet River, Rhode Island	NOS	8450954	41.6183	-71.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	-00:13:00	\N	1.01	-00:12:00	\N	1.01	\N	\N	Nannaquaket Neck	RI
66801	The Glen, Sakonnet River, Rhode Island	NOS	8451301	41.5583	-71.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	-00:03:00	\N	1	-00:13:00	\N	0.98	\N	\N	The Glen	RI
66802	Sachuest, Flint Point, Sakonnet River, Rhode Island	NOS	8451351	41.4867	-71.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:15:00	\N	0.93	-00:05:00	\N	0.9	\N	\N	Sachuest, Flint Point	RI
66803	Bristol Ferry, Narragansett Bay, Rhode Island (sub)	NOS	8451552	41.6367	-71.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:00:00	\N	1.14	00:15:00	\N	1.17	\N	\N	Bristol Ferry	RI
66804	Bristol, Bristol Harbor, Narragansett Bay, Rhode Island	NOS	8451929	41.6683	-71.28	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:00:00	\N	1.14	00:13:00	\N	1.16	\N	\N	Bristol, Bristol Harbor	RI
66805	Prudence Island, (south end), Narragansett Bay, Rhode Island	NOS	8452555	41.58	-71.3217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	-00:03:00	\N	1.14	00:08:00	\N	1.08	\N	\N	Prudence Island, (south end)	RI
66806	Bay Spring, Bullock Cove, Narragansett Bay, Rhode Island	NOS	8453033	41.7517	-71.3517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:01:00	\N	1.21	00:12:00	\N	1.22	\N	\N	Bay Spring, Bullock Cove	RI
66807	Castle Hill, Narragansett Bay, Rhode Island	NOS	8453201	41.4633	-71.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:13:00	\N	1	-00:05:00	\N	0.94	\N	\N	Castle Hill	RI
66808	Rumford, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453433	41.84	-71.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:06:00	\N	1.29	00:12:00	\N	1.34	\N	\N	Rumford, Seekonk River	RI
66809	Conanicut Point, Conanicut Island, Rhode Island	NOS	8453465	41.5733	-71.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	-00:06:00	\N	1.07	00:07:00	\N	1.07	\N	\N	Conanicut Point	RI
66810	Pawtucket, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453611	41.8683	-71.38	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:09:00	\N	1.29	00:18:00	\N	1.31	\N	\N	Pawtucket, Seekonk River	RI
66811	West Jamestown, Dutch Island Harbor, Conanicut Island, Rhode Island (sub)	NOS	8453742	41.4967	-71.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:04:00	\N	1	00:05:00	\N	1	\N	\N	West Jamestown, Dutch Island Harbor	RI
66812	Pawtuxet, Pawtuxet Cove, Narragansett Bay, Rhode Island	NOS	8453767	41.7617	-71.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	-00:11:00	\N	1.29	00:06:00	\N	1.25	\N	\N	Pawtuxet, Pawtuxet Cove	RI
66813	Beavertail Point, Conanicut Island, Rhode Island	NOS	8453999	41.4517	-71.4017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:04:00	\N	0.98	-00:05:00	\N	0.98	\N	\N	Beavertail Point	RI
66814	Providence, State Pier no.1, Narragansett Bay, Rhode Island (sub)	NOS	8454000	41.8066667	-71.4005556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:00:00	\N	1.29	00:13:00	\N	1.27	\N	\N	Providence, State Pier no.1	RI
66815	Watson Pier, Boston Neck, Narragansett Bay, Rhode Island	NOS	8454341	41.46	-71.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:16:00	\N	0.93	-00:03:00	\N	0.96	\N	\N	Watson Pier, Boston Neck	RI
66816	Wickford, Narragansett Bay, Rhode Island (sub)	NOS	8454538	41.5717	-71.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	-00:06:00	\N	1.07	00:03:00	\N	1.07	\N	\N	Wickford	RI
66817	Narragansett Pier, Narragansett Bay, Rhode Island	NOS	8454658	41.4217	-71.455	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:11:00	\N	0.93	-00:11:00	\N	0.91	\N	\N	Narragansett Pier	RI
66818	Point Judith, Harbor of Refuge, Rhode Island (sub)	NOS	8455083	41.3633	-71.49	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:33:00	\N	0.93	00:00:00	\N	0.87	\N	\N	Point Judith, Harbor of Refuge	RI
66819	Westerly, Pawcatuck River, Rhode Island (sub)	NOS	8455189	41.3817	-71.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	00:03:00	\N	1	-00:21:00	\N	1.02	\N	\N	Westerly, Pawcatuck River	RI
66820	Weekapaug Point, Block Island Sound, Rhode Island (sub)	NOS	8458022	41.3283	-71.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	01:06:00	\N	0.93	00:41:00	\N	0.74	\N	\N	Weekapaug Point, Block Island Sound	RI
66821	Watch Hill Point, Rhode Island	NOS	8458694	41.305	-71.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	01:16:00	\N	0.71	00:41:00	\N	0.74	\N	\N	Watch Hill Point	RI
66822	Block Island (Old Harbor), Rhode Island (sub)	NOS	8459338	41.1733	-71.5567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:15:00	\N	0.86	-00:13:00	\N	0.82	\N	\N	Block Island (Old Harbor)	RI
66823	Block Island (SW end), Block Island Sound, Rhode Island (sub)	NOS	8459681	41.1633	-71.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65606	00:42:00	\N	0.79	00:05:00	\N	0.75	\N	\N	Southwest Point, Block Island	RI
66824	Norwich, Thames River, Connecticut	NOS	8461392	41.5233	-72.0783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	00:19:00	\N	1.21	00:24:00	\N	1.18	\N	\N	Norwich	CT
66825	Yale boathouse, Thames River, Connecticut	NOS	8461467	41.43	-72.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	00:10:00	\N	1.11	00:14:00	\N	1.07	\N	\N	Yale boathouse	CT
66826	Niantic, Niantic River, Connecticut	NOS	8461925	41.325	-72.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	00:57:00	\N	0.84	00:52:00	\N	0.99	\N	\N	Niantic, Niantic River	CT
66827	Saybrook Jetty, Connecticut River, Connecticut	NOS	8462723	41.2633	-72.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	00:45:00	\N	1.35	01:11:00	\N	1.36	\N	\N	Saybrook Jetty	CT
66828	Saybrook Point, Connecticut River, Connecticut	NOS	8462752	41.2833	-72.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	00:53:00	\N	1.25	01:11:00	\N	1.24	\N	\N	Saybrook Point	CT
66829	Lyme, highway bridge, Connecticut River, Connecticut	NOS	8462764	41.3217	-72.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	01:09:00	\N	0.95	01:36:00	\N	1.26	\N	\N	Lyme, highway bridge	CT
66830	Essex, Connecticut River, Connecticut	NOS	8462925	41.3483	-72.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	01:38:00	\N	1.15	01:39:00	\N	1.16	\N	\N	Essex	CT
66831	Hadlyme, Connecticut River, Connecticut	NOS	8463155	41.42	-72.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	02:23:00	\N	1.05	02:19:00	\N	1.05	\N	\N	Hadlyme	CT
66832	Tylerville, Connecticut River, Connecticut	NOS	8463348	41.4517	-72.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	02:51:00	\N	1.02	02:38:00	\N	1.02	\N	\N	Tylerville	CT
66833	Westbrook, Duck Island Roads, Connecticut	NOS	8463409	41.2733	-72.475	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:32:00	\N	0.6	-00:24:00	\N	0.61	\N	\N	Westbrook, Duck Island Roads	CT
66834	Haddam, Connecticut River, Connecticut	NOS	8463582	41.4817	-72.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	03:08:00	\N	0.95	02:48:00	\N	0.97	\N	\N	Haddam	CT
66835	Maromas, Connecticut River, Connecticut	NOS	8463827	41.5417	-72.5517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	04:01:00	\N	0.91	03:25:00	\N	0.91	\N	\N	Maromas	CT
66836	Higganum Creek, Connecticut River, Connecticut	NOS	8463836	41.5033	-72.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	03:40:00	\N	0.91	03:08:00	\N	0.91	\N	\N	Higganum Creek	CT
66837	Madison, Connecticut	NOS	8464041	41.27	-72.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:30:00	\N	0.72	-00:21:00	\N	0.73	\N	\N	Madison	CT
66838	Rocky Hill, Connecticut River, Connecticut	NOS	8464255	41.6633	-72.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	05:36:00	\N	0.63	04:30:00	\N	0.72	\N	\N	Rocky Hill	CT
66839	Middletown, Connecticut River, Connecticut	NOS	8464336	41.56	-72.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	04:39:00	\N	0.83	03:54:00	\N	0.83	\N	\N	Middletown	CT
66840	South Hartford, Connecticut River, Connecticut	NOS	8464418	41.755	-72.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	06:54:00	\N	0.58	05:24:00	\N	0.74	\N	\N	South Hartford	CT
66841	Guilford Harbor, Connecticut	NOS	8464445	41.2717	-72.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:21:00	\N	0.96	-00:11:00	\N	0.77	\N	\N	Guilford Harbor	CT
66842	Hartford, Connecticut River, Connecticut	NOS	8464464	41.77	-72.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	06:52:00	\N	0.75	05:30:00	\N	0.74	\N	\N	Hartford	CT
66843	Sachem Head, Connecticut	NOS	8464687	41.245	-72.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:15:00	\N	0.8	-00:11:00	\N	0.8	\N	\N	Sachem Head	CT
66844	Branford, Branford River, Connecticut	NOS	8465233	41.2617	-72.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:13:00	\N	0.96	-00:05:00	\N	0.87	\N	\N	Branford, Branford River	CT
66845	Lighthouse Point, New Haven Harbor, Connecticut	NOS	8465692	41.2517	-72.905	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:07:00	\N	0.96	-00:04:00	\N	0.91	\N	\N	Lighthouse Point, New Haven Harbor	CT
66846	New Haven Harbor, New Haven Reach, Connecticut (sub)	NOS	8465705	41.2833	-72.9083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:06:00	\N	1	-00:01:00	\N	0.92	\N	\N	New Haven Harbor, New Haven Reach	CT
66847	Gulf Beach, Connecticut	NOS	8466375	41.205	-73.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:08:00	\N	1.04	-00:05:00	\N	0.94	\N	\N	Gulf Beach	CT
66848	Milford Harbor, Connecticut	NOS	8466442	41.2183	-73.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:03:00	\N	1.04	-00:02:00	\N	0.94	\N	\N	Milford Harbor	CT
66849	Shelton, Housatonic River, Connecticut	NOS	8466573	41.3017	-73.0717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	01:19:00	\N	0.96	00:46:00	\N	1.04	\N	\N	Shelton	CT
66850	Long Hill, Housatonic River, Connecticut	NOS	8466664	41.275	-73.0883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	01:13:00	\N	1.04	00:43:00	\N	1.02	\N	\N	Long Hill	CT
66851	Sniffens Point, Housatonic River, Connecticut	NOS	8466791	41.1867	-73.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:09:00	\N	1	00:10:00	\N	0.96	\N	\N	Sniffens Point	CT
66852	Stratford, I-95 bridge, Housatonic River, Connecticut	NOS	8466797	41.2033	-73.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:23:00	\N	1	00:23:00	\N	0.98	\N	\N	Stratford, I-95 bridge	CT
66853	South Norwalk, Norwalk River, Connecticut (sub)	NOS	8468448	41.0967	-73.415	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:15:00	\N	1.04	00:09:00	\N	1.05	\N	\N	South Norwalk	CT
66854	Rowayton, Fivemile River, Connecticut	NOS	8468609	41.065	-73.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:05:00	\N	1.08	00:00:00	\N	1.05	\N	\N	Rowayton, Fivemile River	CT
66855	Long Neck Point, Long Island Sound, Connecticut (sub)	NOS	8468799	41.0383	-73.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:01:00	\N	0.96	-00:09:00	\N	1.06	\N	\N	Long Neck Point	CT
66856	Cos Cob Harbor, Connecticut	NOS	8469549	41.0167	-73.5967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:11:00	\N	1.08	00:05:00	\N	1.07	\N	\N	Cos Cob Harbor	CT
66857	Lake Montauk, Long Island, New York (sub)	NOS	8510448	41.0733	-71.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	-00:22:00	\N	0.89	-00:26:00	\N	0.77	\N	\N	Lake Montauk	NY
66858	Montauk Harbor entrance, Long Island, New York	NOS	8510502	41.075	-71.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	-00:16:00	\N	0.75	-00:24:00	\N	0.74	\N	\N	Montauk Harbor entrance	NY
66859	Silver Eel Pond, Fishers Island, New York (sub)	NOS	8510719	41.2567	-72.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	-00:04:00	\N	1	-00:04:00	\N	0.91	\N	\N	Silver Eel Pond, Fishers Island, N.Y.	NY
66860	Little Gull Island, Long Island, New York	NOS	8510884	41.2067	-72.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	-00:22:00	\N	0.85	00:13:00	\N	0.85	\N	\N	Little Gull Island	NY
66861	Threemile Harbor entrance, Gardiners Bay, Long Island, New York (sub)	NOS	8511171	41.035	-72.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	00:19:00	\N	1	00:39:00	\N	0.96	\N	\N	Threemile Harbor entrance, Gardiners Bay	NY
66862	Plum Gut Harbor, Plum Island, Long Island, New York (sub)	NOS	8511236	41.1717	-72.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	00:16:00	\N	1.01	00:28:00	\N	1.01	\N	\N	Plum Gut Harbor, Plum Island	NY
66863	Orient Harbor, Orient, Shelter Island Sound, New York (sub)	NOS	8511671	41.1367	-72.3067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	00:36:00	\N	0.97	00:37:00	\N	0.97	\N	\N	Orient	NY
66864	Noyack Bay, Shelter Island Sound, New York	NOS	8511779	40.995	-72.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	01:44:00	\N	0.89	02:06:00	\N	0.89	\N	\N	Noyack Bay	NY
66865	Hashamomuck Beach, Long Island, New York	NOS	8512053	41.095	-72.3983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:13:00	\N	0.64	00:03:00	\N	0.64	\N	\N	Hashamomuck Beach	NY
66866	Southold, Shelter Island Sound, New York	NOS	8512114	41.06	-72.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	01:33:00	\N	0.89	01:44:00	\N	0.89	\N	\N	Southold	NY
66867	New Suffolk, Peconic Bays, New York	NOS	8512328	40.9917	-72.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	02:11:00	\N	1	02:27:00	\N	1.01	\N	\N	New Suffolk	NY
66868	Shinnecock Bay entrance, Shinnecock Bay, New York	NOS	8512671	40.82	-72.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:51:00	\N	0.37	01:12:00	\N	0.51	\N	\N	Shinnecock Bay entrance	NY
66869	South Jamesport, Great Peconic Bay, New York (sub)	NOS	8512735	40.935	-72.5817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65621	02:43:00	\N	0.95	02:34:00	\N	1.07	\N	\N	South Jamesport	NY
66870	Shinnecock Yacht Club, Penniman Creek, Shinnecock Bay, New York (sub)	NOS	8512769	40.81855555555556	-72.58661111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:45:00	\N	0.55	01:01:00	\N	0.55	\N	\N	Shinnecock Yacht Club, Penniman Creek	NY
66871	Northville, Long Island, New York (sub)	NOS	8512987	40.9817	-72.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	-00:03:00	\N	0.92	00:05:00	\N	0.8	\N	\N	Northville	NY
66872	Smith Point Bridge, Narrow Bay, Long Island, New York (sub)	NOS	8513825	40.7383	-72.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:34:00	\N	0.6	01:58:00	\N	0.27	\N	\N	Smith Point Bridge, Narrow Bay	NY
66873	Patchogue, Patchogue River, Great South Bay, New York (sub)	NOS	8514322	40.75	-73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:33:00	\N	0.53	03:14:00	\N	0.25	\N	\N	Patchogue	NY
68142	Empire Jetty, Louisiana	NOS	8761212	29.25	-89.6083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	-01:45:00	\N	1.23	-01:03:00	\N	1.23	\N	\N	Empire Jetty	LA
66874	Mount Sinai Harbor, Long Island, New York	NOS	8514421	40.9633	-73.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:18:00	\N	0.88	00:04:00	\N	0.89	\N	\N	Mount Sinai Harbor	NY
66875	Cedar Beach, Long Island, New York (sub)	NOS	8514422	40.965	-73.0433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:05:00	\N	1	00:07:00	\N	0.96	\N	\N	Cedar Beach	NY
66876	Port Jefferson, Long Island, New York	NOS	8514560	40.95	-73.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:05:00	\N	0.92	00:04:00	\N	0.98	\N	\N	Port Jefferson	NY
66877	Port Jefferson Harbor entrance, Long Island, New York	NOS	8514594	40.9717	-73.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:01:00	\N	0.98	00:02:00	\N	0.98	\N	\N	Port Jefferson Harbor entrance	NY
66878	Great River, Connetquot River, Great South Bay, New York	NOS	8514783	40.7233	-73.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:32:00	\N	0.15	03:19:00	\N	0.15	\N	\N	Great River, Connetquot River	NY
66879	West Fire Island, Great South Bay, New York	NOS	8514961	40.6567	-73.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:18:00	\N	0.13	02:10:00	\N	0.13	\N	\N	West Fire Island	NY
66880	Fire Island Light, Great South Bay, New York	NOS	8515014	40.635	-73.22	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:22:00	\N	0.15	00:46:00	\N	0.15	\N	\N	Fire Island Light	NY
66882	Democrat Point, Fire Island Inlet, Long Island, New York	NOS	8515228	40.6333	-73.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:27:00	\N	0.55	-00:39:00	\N	0.56	\N	\N	Democrat Point, Fire Island Inlet	NY
66883	Oak Beach, Great South Bay, New York	NOS	8515336	40.64	-73.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:58:00	\N	0.15	02:23:00	\N	0.15	\N	\N	Oak Beach	NY
66884	Babylon, Great South Bay, New York	NOS	8515421	40.685	-73.315	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:41:00	\N	0.15	02:11:00	\N	0.13	\N	\N	Babylon	NY
66885	Northport, Northport Bay, Long Island, New York (sub)	NOS	8515586	40.9	-73.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:04:00	\N	0.92	-00:05:00	\N	1.07	\N	\N	Northport, Northport Bay	NY
66886	Gilgo Heading, Great South Bay, New York	NOS	8515764	40.62	-73.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:58:00	\N	0.25	02:22:00	\N	0.24	\N	\N	Gilgo Heading	NY
66887	Eatons Neck Point, Long Island, New York (sub)	NOS	8515786	40.9533	-73.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:08:00	\N	1.04	00:02:00	\N	1.05	\N	\N	Eatons Neck Point	NY
66888	Amityville, Great South Bay, New York	NOS	8515864	40.655	-73.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:05:00	\N	0.25	02:20:00	\N	0.26	\N	\N	Amityville	NY
66889	Huntington Harbor Lighthouse, Huntington Bay, Long Island, New York (sub)	NOS	8515921	40.91	-73.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:07:00	\N	0.88	-00:01:00	\N	1.04	\N	\N	Lloyd Harbor, Huntington Bay	NY
66890	Biltmore Shores, South Oyster Bay, Long Island, New York	NOS	8516055	40.6667	-73.4683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:32:00	\N	0.3	02:04:00	\N	0.3	\N	\N	Biltmore Shores, South Oyster Bay	NY
66891	Cold Spring Harbor, Oyster Bay, New York (sub)	NOS	8516061	40.8733	-73.47	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:02:00	\N	0.92	-00:07:00	\N	1.07	\N	\N	Cold Spring Harbor	NY
66892	Green Island, Hempstead Bay, New York (sub)	NOS	8516155	40.6233	-73.5017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:31:00	\N	0.4	01:21:00	\N	0.41	\N	\N	Green Island	NY
66893	Oyster Bay Harbor, Oyster Bay, New York	NOS	8516201	40.8667	-73.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:13:00	\N	1.08	00:07:00	\N	1.08	\N	\N	Oyster Bay Harbor	NY
66894	Bellmore, Bellmore Creek, Hempstead Bay, New York	NOS	8516211	40.6633	-73.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:58:00	\N	0.45	01:28:00	\N	0.43	\N	\N	Bellmore, Bellmore Creek	NY
66895	Cuba Island, Hempstead Bay, New York	NOS	8516221	40.62	-73.5233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:22:00	\N	0.5	01:07:00	\N	0.49	\N	\N	Cuba Island	NY
66896	Deep Creek Meadow, Hempstead Bay, New York	NOS	8516225	40.6033	-73.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:11:00	\N	0.5	01:01:00	\N	0.51	\N	\N	Deep Creek Meadow	NY
66897	Bayville Bridge, Oyster Bay, New York (sub)	NOS	8516299	40.9033	-73.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65624	00:04:00	\N	1.04	-00:06:00	\N	1.09	\N	\N	Bayville Bridge	NY
66898	Neds Creek, Hempstead Bay, New York	NOS	8516315	40.6233	-73.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:54:00	\N	0.6	00:49:00	\N	0.58	\N	\N	Neds Creek	NY
66899	Jones Inlet (Point Lookout), Long Island, New York	NOS	8516385	40.5867	-73.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:25:00	\N	0.75	-00:20:00	\N	0.77	\N	\N	Jones Inlet (Point Lookout)	NY
66900	Freeport, Baldwin Bay, Hempstead Bay, New York	NOS	8516411	40.6333	-73.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:55:00	\N	0.65	00:37:00	\N	0.64	\N	\N	Freeport, Baldwin Bay	NY
66901	Long Beach (Inside), Hempstead Bay, New York	NOS	8516601	40.6	-73.65	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:02:00	\N	0.85	00:18:00	\N	0.84	\N	\N	Long Beach (Inside)	NY
66902	Glen Cove Yacht Club, Hempstead Harbor, Long Island, New York (sub)	NOS	8516614	40.8633	-73.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65669	-00:26:00	\N	0.82	-00:22:00	\N	1.01	\N	\N	Glen Cove, Hempstead Harbor	NY
66903	Woodmere, Brosewere Bay, Hempstead Bay, New York	NOS	8516745	40.62	-73.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:50:00	\N	0.85	00:34:00	\N	0.84	\N	\N	Woodmere, Brosewere Bay	NY
66904	Port Washington, Manhasset Bay, Long Island, New York (sub)	NOS	8516761	40.8317	-73.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65669	-00:12:00	\N	0.96	-00:12:00	\N	1.02	\N	\N	Port Washington, Manhasset Bay	NY
66905	Motts Basin, Jamaica Bay, New York	NOS	8516925	40.6167	-73.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:48:00	\N	1.15	00:39:00	\N	1.16	\N	\N	Motts Basin	NY
66906	Willets Point, Little Bay, East River, New York (sub)	NOS	8516990	40.7933	-73.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65669	00:00:00	\N	1.04	-00:01:00	\N	1	\N	\N	Willets Point	NY
66907	J.F.K. International Airport, Jamaica Bay, New York	NOS	8516999	40.6233	-73.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:45:00	\N	1.15	00:25:00	\N	1.14	\N	\N	J.F.K. International Airport	NY
66908	Whitestone, East River, New York	NOS	8517125	40.7983	-73.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65669	00:09:00	\N	1.04	00:07:00	\N	1	\N	\N	Whitestone	NY
66909	Beach Channel (bridge), Jamaica Bay, New York (sub)	NOS	8517137	40.5883	-73.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:24:00	\N	1.1	00:37:00	\N	1.09	\N	\N	Beach Channel (bridge)	NY
66910	College Pt, Ft. of 110th Street, Long Island, New York (sub)	NOS	8517276	40.7833	-73.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65669	00:16:00	\N	1.04	00:17:00	\N	0.95	\N	\N	College Point, Flushing Bay	NY
66911	Canarsie, Jamaica Bay, New York	NOS	8517381	40.63	-73.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:08:00	\N	1.1	00:27:00	\N	1.12	\N	\N	Canarsie	NY
66912	Barren Island, Rockaway Inlet, Jamaica Bay, New York	NOS	8517394	40.5783	-73.8883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:04:00	\N	1.05	-00:01:00	\N	1.07	\N	\N	Barren Island, Rockaway Inlet	NY
66913	Hell Gate, Wards Island, East River, New York	NOS	8517401	40.7867	-73.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	03:45:00	\N	1.59	02:58:00	\N	1.33	\N	\N	Hell Gate, Wards Island	NY
66914	Mill Basin, Jamaica Bay, New York	NOS	8517519	40.6083	-73.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:04:00	\N	1.1	00:28:00	\N	1.12	\N	\N	Mill Basin	NY
66915	Plumb Beach Channel, Jamaica Bay, New York	NOS	8517531	40.585	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:03:00	\N	1.05	00:02:00	\N	1.05	\N	\N	Plumb Beach Channel	NY
66916	Hunters Point, Newtown Creek, East River, New York	NOS	8517673	40.74	-73.9617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:56:00	\N	0.9	01:22:00	\N	0.89	\N	\N	Hunters Point, Newtown Creek	NY
66917	Wallabout Bay, Brooklyn Navy Yard, East River, New York	NOS	8517732	40.7067	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:22:00	\N	1.05	00:32:00	\N	0.94	\N	\N	Wallabout Bay, Brooklyn Navy Yard	NY
66918	Coney Island, New York	NOS	8517741	40.57	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:17:00	\N	1	-00:04:00	\N	1.01	\N	\N	Coney Island	NY
66919	Norton Point, Gravesend Bay, New York	NOS	8517811	40.59	-73.9983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:03:00	\N	1.15	-00:01:00	\N	1.02	\N	\N	Norton Point, Gravesend Bay	NY
66920	Brooklyn Bridge, East River, New York (sub)	NOS	8517847	40.7033	-73.995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	-00:04:00	\N	1	00:24:00	\N	0.99	\N	\N	Brooklyn Bridge	NY
66922	Fort Hamilton, The Narrows, New York	NOS	8517942	40.6083	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:07:00	\N	1	00:02:00	\N	1.01	\N	\N	Fort Hamilton, The Narrows	NY
66923	Rye Beach (Amusement Park), New York (sub)	NOS	8518091	40.9617	-73.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65669	-00:27:00	\N	0.86	-00:20:00	\N	1	\N	\N	Rye Beach	NY
66924	New Rochelle, New York	NOS	8518490	40.8933	-73.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65669	-00:18:00	\N	0.93	-00:16:00	\N	1.01	\N	\N	New Rochelle	NY
66925	Hunts Point, East River, New York	NOS	8518621	40.8	-73.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65669	00:10:00	\N	1.07	00:12:00	\N	0.97	\N	\N	Hunts Point	NY
66926	North Brother Island, East River, New York	NOS	8518635	40.7983	-73.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65669	00:18:00	\N	1.11	00:18:00	\N	0.93	\N	\N	North Brother Island	NY
66927	Port Morris (Stony Point), East River, New York (sub)	NOS	8518639	40.8017	-73.9067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65669	00:10:00	\N	0.96	00:07:00	\N	0.87	\N	\N	Port Morris (Stony Point)	NY
66928	Horns Hook, East 90th Street, East River, New York, New York (sub)	NOS	8518668	40.7767	-73.9417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	01:34:00	\N	0.9	01:54:00	\N	1.03	\N	\N	Horns Hook, East 90th Street	NY
66929	Queensboro Bridge, East River, New York (sub)	NOS	8518687	40.7583	-73.9583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:57:00	\N	1	01:23:00	\N	0.96	\N	\N	Queensboro Bridge	NY
66930	East 41st Street, New York City, East River, New York	NOS	8518695	40.7467	-73.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:46:00	\N	1.09	01:03:00	\N	0.95	\N	\N	East 41st Street, New York City	NY
66931	Williamsburg Bridge, East River, New York (sub)	NOS	8518699	40.7117	-73.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:28:00	\N	0.95	00:45:00	\N	0.93	\N	\N	Williamsburg Bridge	NY
66933	Riverdale, Hudson River, New York (sub)	NOS	8518905	40.9033	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:49:00	\N	0.85	00:48:00	\N	0.85	\N	\N	Riverdale, N.Y.	NY
66934	Tarrytown, Hudson River, New York	NOS	8518919	41.0783	-73.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	01:57:00	\N	0.7	01:49:00	\N	0.7	\N	\N	Tarrytown	NY
66935	Haverstraw Bay, Hudson River, New York (sub)	NOS	8518924	41.2183	-73.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	02:42:00	\N	0.81	02:15:00	\N	0.72	\N	\N	Haverstraw	NY
66936	Newburgh, Hudson River, New York	NOS	8518935	41.5	-74.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	04:03:00	\N	0.64	03:46:00	\N	0.62	\N	\N	Newburgh	NY
66937	New Hamburg, Hudson River, New York	NOS	8518939	41.5833	-73.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	04:28:00	\N	0.64	04:04:00	\N	0.64	\N	\N	New Hamburg	NY
66938	Poughkeepsie, Hudson River, New York	NOS	8518945	41.7	-73.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	04:46:00	\N	0.68	04:34:00	\N	0.68	\N	\N	Poughkeepsie	NY
66939	Peekskill, Hudson River, New York	NOS	8518949	41.2883	-73.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	03:03:00	\N	0.64	02:28:00	\N	0.64	\N	\N	Peekskill	NY
66940	Tivoli, Hudson River, New York	NOS	8518964	42.0583	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	06:04:00	\N	0.86	05:50:00	\N	0.86	\N	\N	Tivoli	NY
66941	Hudson, Hudson River, New York	NOS	8518974	42.25	-73.8	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	07:12:00	\N	0.86	06:58:00	\N	0.88	\N	\N	Hudson	NY
66942	Castleton, Hudson River, New York	NOS	8518989	42.5333	-73.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65692	-00:29:00	0.1	\N	-00:17:00	-0.2	\N	\N	\N	Castleton	NY
66943	Kingston, Hudson River, New York	NOS	8518993	41.9183	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	05:34:00	\N	0.82	05:20:00	\N	0.81	\N	\N	Kingston	NY
66944	Fort Wadsworth, The Narrows, Staten Island, New York	NOS	8519024	40.6067	-74.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:06:00	\N	1.05	00:06:00	\N	0.98	\N	\N	Fort Wadsworth, The Narrows	NY
66945	St. George, Staten Island, New York	NOS	8519112	40.6433	-74.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	-00:15:00	\N	0.99	-00:17:00	\N	0.99	\N	\N	St. George, Staten Island	NY
66946	Port Ivory, Howland Hook, Arthur Kill, New York	NOS	8519200	40.645	-74.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:39:00	\N	1.09	00:27:00	\N	1.09	\N	\N	Port Ivory, Howland Hook, N.Y.	NY
66947	Princes Bay, New Jersey	NOS	8519726	40.5117	-74.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:06:00	\N	1.05	00:00:00	\N	1.05	\N	\N	Princes Bay	NJ
66948	Rossville, Arthur Kill, New York	NOS	8519789	40.5567	-74.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:29:00	\N	1.12	00:20:00	\N	1.12	\N	\N	Rossville, N.Y.	NY
66949	Alpine, Hudson River, New Jersey	NOS	8530095	40.945	-73.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	01:02:00	\N	0.9	01:05:00	\N	0.83	\N	\N	Alpine, N.J.	NJ
66950	New Millford, Hackensack River, New Jersey	NOS	8530186	40.935	-74.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	02:49:00	\N	1.02	01:17:00	\N	1.02	\N	\N	New Millford	NJ
66951	Hackensack, Hackensack River, New Jersey	NOS	8530278	40.88	-74.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	01:00:00	\N	1.38	01:06:00	\N	1.33	\N	\N	Hackensack	NJ
66952	Ridgefield Park, Hackensack River, New Jersey	NOS	8530398	40.85	-74.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	01:00:00	\N	1.26	01:00:00	\N	1.26	\N	\N	Ridgefield Park	NJ
66953	East Rutherford, Passaic River, New Jersey	NOS	8530403	40.8467	-74.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	01:06:00	\N	1.29	00:09:00	\N	1.29	\N	\N	East Rutherford	NJ
66954	Edgewater, Hudson River, New Jersey	NOS	8530505	40.8133	-73.9783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:28:00	\N	0.93	00:31:00	\N	0.93	\N	\N	Edgewater, N.J.	NJ
66955	Carlstadt, Garretts Reach, Hackensack River, New Jersey	NOS	8530528	40.8067	-74.06	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:45:00	\N	1.29	00:59:00	\N	1.26	\N	\N	Carlstadt, Garretts Reach	NJ
66956	North Secaucus, Garretts Reach, Hackensack River, New York	NOS	8530531	40.805	-74.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:57:00	\N	1.23	00:57:00	\N	1.23	\N	\N	North Secaucus, Garretts Reach	NY
66957	Fish Creek, Berrys Creek, Hackensack River, New Jersey	NOS	8530586	40.7933	-74.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	01:00:00	\N	1	01:02:00	\N	1.16	\N	\N	Fish Creek, Berrys Creek	NJ
66958	Belleville, Passaic River, New Jersey	NOS	8530591	40.7867	-74.1467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:49:00	\N	1.19	00:09:00	\N	1.23	\N	\N	Belleville	NJ
66959	Weehawken, Union City, Hudson River, New Jersey	NOS	8530645	40.765	-74.0183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:15:00	\N	0.96	00:13:00	\N	0.96	\N	\N	Weehawken, Union City, N.J.	NJ
66960	Amtrak RR. swing bridge, Hackensack River, New Jersey	NOS	8530696	40.7517	-74.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:39:00	\N	1.1	00:33:00	\N	1.16	\N	\N	Amtrak RR. swing bridge	NJ
66961	Point No Point, Passaic River, New Jersey	NOS	8530743	40.7317	-74.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:22:00	\N	1.04	00:00:00	\N	1.15	\N	\N	Point No Point	NJ
66962	Kearny Point, Hackensack River, New Jersey	NOS	8530772	40.7283	-74.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:22:00	\N	1.14	00:11:00	\N	1.15	\N	\N	Kearny Point	NJ
66963	Port Elizabeth, New Jersey	NOS	8530882	40.6733	-74.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:13:00	\N	0.95	-00:02:00	\N	1.11	\N	\N	Port Elizabeth	NJ
66964	Port Newark Terminal, New Jersey	NOS	8530884	40.69	-74.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:21:00	\N	1.12	00:03:00	\N	1.12	\N	\N	Port Newark Terminal	NJ
66965	Constable Hook, Kill Van Kull, New York	NOS	8530985	40.655	-74.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	-00:08:00	\N	1.02	-00:18:00	\N	1.02	\N	\N	Constable Hook	NY
66966	Rahway River, RR. Bridge, Arthur Kill, New Jersey	NOS	8531077	40.5983	-74.2317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:30:00	\N	1.16	00:17:00	\N	1.14	\N	\N	Rahway River, RR. Bridge	NJ
66967	Carteret, Arthur Kill, New Jersey	NOS	8531095	40.5867	-74.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:33:00	\N	1.09	00:22:00	\N	1.09	\N	\N	Carteret	NJ
66968	Woodbridge Creek, 0.8 n.mi. above entrance, Arthur Kill, New Jersey	NOS	8531156	40.545	-74.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:21:00	\N	1	00:09:00	\N	1.1	\N	\N	Woodbridge Creek, 0.8 n.mi. above entrance	NJ
66969	South Amboy, Raritan River, New Jersey (sub)	NOS	8531232	40.4917	-74.2817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:08:00	\N	1.09	-00:04:00	\N	1.09	\N	\N	South Amboy	NJ
66970	Matawan Creek, Route 35 bridge, New Jersey	NOS	8531526	40.4333	-74.2183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:07:00	\N	1.08	-00:01:00	\N	1.08	\N	\N	Matawan Creek, Route 35 bridge	NJ
66971	Keyport, New Jersey	NOS	8531545	40.44	-74.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:06:00	\N	1.1	-00:04:00	\N	1.08	\N	\N	Keyport	NJ
66972	Waackaack Creek, New Jersey	NOS	8531592	40.4483	-74.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:21:00	\N	0.99	-00:06:00	\N	0.99	\N	\N	Waackaack Creek	NJ
66973	Atlantic Highlands, Sandy Hook Bay, New Jersey	NOS	8531662	40.4183	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:10:00	\N	1.01	-00:10:00	\N	1.01	\N	\N	Atlantic Highlands	NJ
66974	Highlands, Route 36 bridge, Shrewsbury River, New Jersey	NOS	8531712	40.3967	-73.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:14:00	\N	0.9	00:17:00	\N	0.9	\N	\N	Highlands, Route 36 bridge	NJ
66975	Oceanic Bridge, Navesink River, Shrewsbury River, New Jersey	NOS	8531753	40.3767	-74.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:45:00	\N	0.63	01:13:00	\N	0.72	\N	\N	Oceanic Bridge, Navesink River	NJ
66976	Sea Bright, Shrewsbury River, New Jersey (sub)	NOS	8531804	40.365	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:07:00	\N	0.68	01:15:00	\N	0.68	\N	\N	Sea Bright	NJ
66977	Red Bank, Navesink River, Shrewsbury River, New Jersey	NOS	8531833	40.355	-74.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:57:00	\N	0.63	01:17:00	\N	0.74	\N	\N	Red Bank, Navesink River	NJ
66978	Gooseneck Point, bridge, Shrewsbury River, New Jersey	NOS	8531925	40.3267	-74.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:41:00	\N	0.55	02:18:00	\N	0.55	\N	\N	Gooseneck Point, bridge	NJ
66979	Long Branch Reach, Shrewsbury River, New Jersey	NOS	8531942	40.325	-73.9967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:41:00	\N	0.63	02:18:00	\N	0.56	\N	\N	Long Branch Reach	NJ
66980	Long Branch (fishing pier), New Jersey	NOS	8531991	40.3033	-73.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:36:00	\N	1	-00:26:00	\N	0.94	\N	\N	Long Branch (fishing pier)	NJ
66981	Shark River Hills, Shark River, New Jersey	NOS	8532322	40.1917	-74.0383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:09:00	\N	0.94	-00:13:00	\N	0.94	\N	\N	Shark River Hills	NJ
66982	Belmar (ocean), New Jersey	NOS	8532337	40.185	-74.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:45:00	\N	0.95	-00:35:00	\N	0.95	\N	\N	Belmar, Atlantic Ocean	NJ
66983	Shark River Island, fixed RR. bridge, Shark River, New Jersey	NOS	8532339	40.1867	-74.0267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:08:00	\N	0.93	-00:13:00	\N	0.93	\N	\N	Shark River Island, fixed RR. bridge	NJ
66984	New Bedford, Shark River, New Jersey	NOS	8532371	40.1783	-74.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:07:00	\N	0.95	-00:13:00	\N	0.95	\N	\N	New Bedford	NJ
66985	Brielle, Route 35 bridge, Manasquan River, New Jersey	NOS	8532585	40.105	-74.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:20:00	\N	0.83	-00:06:00	\N	0.83	\N	\N	Brielle, Route 35 bridge	NJ
66986	Manasquan Inlet, USCG Station, New Jersey	NOS	8532591	40.1017	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:24:00	\N	0.95	-00:12:00	\N	0.86	\N	\N	Manasquan Inlet, USCG Station	NJ
66987	Riviera Beach, Manasquan River, New Jersey	NOS	8532611	40.0967	-74.0867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:38:00	\N	0.73	00:08:00	\N	0.73	\N	\N	Riviera Beach	NJ
66988	Forge Pond, Metedeconk River, New Jersey	NOS	8532703	40.065	-74.135	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:07:00	\N	0.07	02:17:00	\N	0.07	\N	\N	Forge Pond	NJ
66989	Beaverdam Creek entrance, Metedeconk River, New Jersey	NOS	8532715	40.0617	-74.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:40:00	\N	0.37	02:41:00	\N	0.07	\N	\N	Beaverdam Creek entrance	NJ
66990	Beaverdam Creek, inside, Metedeconk River, New Jersey	NOS	8532716	40.0617	-74.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:47:00	\N	0.06	02:49:00	\N	0.06	\N	\N	Beaverdam Creek, inside	NJ
66991	Tall Pines Camp, Metedeconk River, New Jersey	NOS	8532721	40.0583	-74.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:24:00	\N	0.06	02:23:00	\N	0.06	\N	\N	Tall Pines Camp	NJ
66992	Mantoloking, Barnegat Bay, New Jersey	NOS	8532786	40.0367	-74.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:39:00	\N	0.07	04:28:00	\N	0.07	\N	\N	Mantoloking	NJ
66993	Kettle Creek, Green Island, Barnegat Bay, New Jersey	NOS	8532835	40.0133	-74.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:41:00	\N	0.08	04:23:00	\N	0.08	\N	\N	Kettle Creek, Green Island	NJ
66994	Ocean Beach, Barnegat Bay, New Jersey	NOS	8532885	39.9883	-74.0683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:36:00	\N	0.08	04:17:00	\N	0.08	\N	\N	Ocean Beach	NJ
66995	Silver Bay, Silver Bay Marina, Barnegat Bay, New Jersey	NOS	8532921	39.9967	-74.1483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:39:00	\N	0.08	04:26:00	\N	0.08	\N	\N	Silver Bay, Silver Bay Marina	NJ
66996	Goose Creek entrance, Barnegat Bay, New Jersey	NOS	8533005	39.9633	-74.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:29:00	\N	0.08	04:06:00	\N	0.08	\N	\N	Goose Creek entrance	NJ
66997	Coates Point, Barnegat Bay, New Jersey	NOS	8533055	39.9483	-74.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:21:00	\N	0.08	04:00:00	\N	0.08	\N	\N	Coates Point	NJ
66998	Seaside Heights, ocean, New Jersey	NOS	8533071	39.9433	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	-00:32:00	\N	0.92	-00:30:00	\N	0.92	\N	\N	Seaside Heights, ocean	NJ
66999	Seaside Park, Barnegat Bay, New Jersey	NOS	8533135	39.9217	-74.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:05:00	\N	0.08	03:40:00	\N	0.08	\N	\N	Seaside Park	NJ
67000	Barnegat Pier, Barnegat Bay, New Jersey	NOS	8533141	39.9183	-74.11	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:55:00	\N	0.08	03:35:00	\N	0.08	\N	\N	Barnegat Pier	NJ
67001	Sloop Creek, Barnegat Bay, New Jersey	NOS	8533185	39.905	-74.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:01:00	\N	0.08	03:38:00	\N	0.08	\N	\N	Sloop Creek	NJ
67002	Cedar Creek, Barnegat Bay, New Jersey	NOS	8533295	39.87	-74.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:45:00	\N	0.08	03:23:00	\N	0.08	\N	\N	Cedar Creek	NJ
67003	Island Beach, Barnegat Bay, New Jersey	NOS	8533345	39.8517	-74.0883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:28:00	\N	0.08	03:04:00	\N	0.08	\N	\N	Island Beach	NJ
67004	Stouts Creek, Barnegat Bay, New Jersey (sub)	NOS	8533365	39.845	-74.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:33:00	\N	0.06	03:16:00	\N	0.06	\N	\N	Stouts Creek	NJ
67005	Forked River, Barnegat Bay, New Jersey	NOS	8533391	39.825	-74.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:20:00	\N	0.07	03:08:00	\N	0.07	\N	\N	Forked River	NJ
67006	Oyster Creek, Barnegat Bay, New Jersey	NOS	8533465	39.8083	-74.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:36:00	\N	0.06	03:30:00	\N	0.06	\N	\N	Oyster Creek	NJ
67007	Island Beach, Sedge Islands, Barnegat Bay, New Jersey	NOS	8533535	39.7883	-74.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:56:00	\N	0.07	03:00:00	\N	0.07	\N	\N	Island Beach, Sedge Islands	NJ
67008	Waretown, Barnegat Bay, New Jersey	NOS	8533541	39.7917	-74.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:00:00	\N	0.07	02:43:00	\N	0.07	\N	\N	Waretown	NJ
67009	High Bar, Barnegat Bay, New Jersey	NOS	8533631	39.7567	-74.1283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:55:00	\N	0.12	01:04:00	\N	0.12	\N	\N	High Bar	NJ
67010	Double Creek, Barnegat Bay, New Jersey	NOS	8533665	39.745	-74.2017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:33:00	\N	0.07	03:03:00	\N	0.07	\N	\N	Double Creek	NJ
67011	Loveladies Harbor, Barnegat Bay, New Jersey	NOS	8533738	39.725	-74.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:39:00	\N	0.1	03:02:00	\N	0.1	\N	\N	Loveladies Harbor	NJ
67012	Flat Creek, Manahawkin Bay, New Jersey	NOS	8533780	39.7067	-74.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:35:00	\N	0.18	03:33:00	\N	0.18	\N	\N	Flat Creek	NJ
67013	North Beach, Manahawkin Bay, New Jersey	NOS	8533862	39.675	-74.16	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:07:00	\N	0.22	03:02:00	\N	0.22	\N	\N	North Beach	NJ
67014	Mill Creek, 1 n.mi. above entrance, Little Egg Harbor, New Jersey	NOS	8533905	39.665	-74.2317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:33:00	\N	0.35	02:32:00	\N	0.35	\N	\N	Mill Creek, 1 n.mi. above entrance	NJ
67015	Manahawkin Creek, Manahawkin Bay, New Jersey	NOS	8533909	39.6667	-74.215	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:51:00	\N	0.27	02:50:00	\N	0.27	\N	\N	Manahawkin Creek	NJ
67016	Manahawkin Drawbridge, Manahawkin Bay, New Jersey	NOS	8533935	39.6533	-74.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:39:00	\N	0.27	02:47:00	\N	0.27	\N	\N	Manahawkin Drawbridge	NJ
67017	Cedar Run, Little Egg Harbor, New Jersey	NOS	8533941	39.6533	-74.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:56:00	\N	0.4	02:10:00	\N	0.4	\N	\N	Cedar Run	NJ
67018	Dinner Point Creek, upper end, Little Egg Harbor, New Jersey	NOS	8533982	39.6567	-74.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:17:00	\N	0.4	02:41:00	\N	0.4	\N	\N	Dinner Point Creek, upper end	NJ
67019	West Creek, Westecunk Creek, Little Egg Harbor, New Jersey	NOS	8533987	39.6317	-74.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:40:00	\N	0.47	02:10:00	\N	0.44	\N	\N	West Creek, Westecunk Creek	NJ
67020	Sweetwater, Mullica River Marina, Mullica River, New Jersey	NOS	8534002	39.625	-74.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	04:21:00	\N	0.56	03:23:00	\N	0.56	\N	\N	Sweetwater, Mullica River Marina	NJ
67021	Wading River (town), Wading River, Mullica River, New Jersey	NOS	8534043	39.6183	-74.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:44:00	\N	0.79	02:48:00	\N	0.64	\N	\N	Wading River (town), Wading River	NJ
67022	Westecunk Creek entrance, Little Egg Harbor, New Jersey	NOS	8534044	39.6133	-74.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:40:00	\N	0.47	02:00:00	\N	0.42	\N	\N	Westecunk Creek entrance	NJ
67023	Beach Haven Crest, Little Egg Harbor, New Jersey	NOS	8534048	39.6133	-74.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:59:00	\N	0.32	02:13:00	\N	0.38	\N	\N	Beach Haven Crest	NJ
67024	Parker Run, upper end, Little Egg Harbor, New Jersey	NOS	8534049	39.6167	-74.31	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:39:00	\N	0.47	02:05:00	\N	0.45	\N	\N	Parker Run, upper end	NJ
67025	Tuckerton, Tuckerton Creek, Little Egg Harbor, New Jersey	NOS	8534080	39.6017	-74.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:15:00	\N	0.47	01:45:00	\N	0.45	\N	\N	Tuckerton, Tuckerton Creek	NJ
67026	New Gretna, Bass River, Mullica River, New Jersey	NOS	8534104	39.5917	-74.4417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:06:00	\N	0.74	01:52:00	\N	0.66	\N	\N	New Gretna, Bass River	NJ
67027	Green Bank, Mullica River, New Jersey	NOS	8534117	39.6117	-74.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	03:16:00	\N	0.66	02:59:00	\N	0.66	\N	\N	Green Bank	NJ
67028	Tuckerton Creek entrance, Little Egg Harbor, New Jersey	NOS	8534139	39.5767	-74.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:59:00	\N	0.45	01:32:00	\N	0.45	\N	\N	Tuckerton Creek entrance	NJ
67029	Beach Haven Coast Guard Station, Little Egg Harbor, New Jersey	NOS	8534208	39.5483	-74.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:23:00	\N	0.58	01:18:00	\N	0.46	\N	\N	Beach Haven Coast Guard Station	NJ
67030	Cramers Boatyard, Mullica River, New Jersey	NOS	8534212	39.5483	-74.4617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:01:00	\N	0.79	01:27:00	\N	0.63	\N	\N	Chestnut Neck Boat Yard	NJ
67031	Graveling Point, Great Bay, New Jersey	NOS	8534244	39.54	-74.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:14:00	\N	0.68	00:44:00	\N	0.68	\N	\N	Graveling Point	NJ
67032	Nacote Creek, U.S. Highway 9 bridge, Mullica River, New Jersey	NOS	8534256	39.535	-74.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	01:55:00	\N	0.68	01:34:00	\N	0.66	\N	\N	Nacote Creek, U.S. Highway 9 bridge	NJ
67033	Little Sheepshead Creek, Great Bay, New Jersey	NOS	8534287	39.5217	-74.32	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:44:00	\N	0.68	00:35:00	\N	0.66	\N	\N	Little Sheepshead Creek	NJ
67034	Seven Island, Newmans Thorofare, Great Bay, New Jersey	NOS	8534296	39.5167	-74.3367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:28:00	\N	0.73	00:32:00	\N	0.73	\N	\N	Seven Island, Newmans Thorofare	NJ
67035	Main Marsh Thorofare, New Jersey	NOS	8534393	39.4783	-74.3833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:52:00	\N	0.76	01:10:00	\N	0.8	\N	\N	Main Marsh Thorofare	NJ
67036	Mays Landing, Great Egg Harbor River, New Jersey (sub)	NOS	8534468	39.4483	-74.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	03:10:00	\N	1.12	02:50:00	\N	1.01	\N	\N	Mays Landing, Great Egg Harbor River	NJ
67037	Brigantine Channel @ Hoffman Thorofare, New Jersey	NOS	8534496	39.435	-74.3633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:58:00	\N	0.88	00:59:00	\N	0.9	\N	\N	Brigantine Channel @ Hoffman Thorofare	NJ
67038	Absecon, Absecon Creek, U.S. Hwy. 30 bridge, New Jersey	NOS	8534540	39.4233	-74.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:37:00	\N	0.94	01:28:00	\N	0.96	\N	\N	Absecon, Absecon Creek, U.S. Hwy. 30 bridge	NJ
67039	Absecon Channel, State Route 87 bridge, New Jersey	NOS	8534638	39.385	-74.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:26:00	\N	1.13	00:38:00	\N	0.96	\N	\N	Absecon Channel, State Route 87 bridge	NJ
67040	Pleasantville, Lakes Bay, Great Egg Harbor Inlet, New Jersey	NOS	8534657	39.3817	-74.5183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:37:00	\N	0.82	01:00:00	\N	0.98	\N	\N	Pleasantville, Lakes Bay, Great Egg Harbor Inlet	NJ
67041	River Bend Marina, Great Egg Harbor River, New Jersey	NOS	8534691	39.3683	-74.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	02:25:00	\N	1	02:12:00	\N	0.87	\N	\N	River Bend Marina, Great Egg Harbor River	NJ
67042	Dock Thorofare, Risley Channel, New Jersey	NOS	8534739	39.3517	-74.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:00:00	\N	0.94	00:55:00	\N	0.98	\N	\N	Dock Thorofare, Risley Channel	NJ
67043	Ventnor City, ocean pier, New Jersey (sub)	NOS	8534770	39.335	-74.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	-00:02:00	\N	1	-00:02:00	\N	1	\N	\N	Ventnor City, ocean pier	NJ
67044	Steelmanville, Patcong Ck., 2.5 n.mi. above ent, Great Egg Harbor Bay, New Jersey	NOS	8534778	39.335	-74.5967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:50:00	\N	0.94	01:28:00	\N	0.92	\N	\N	Steelmanville, Patcong Ck., 2.5 nm above ent.	NJ
67045	Longport, Risely Channel, New Jersey (sub)	NOS	8534836	39.3083	-74.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:32:00	\N	0.88	00:26:00	\N	0.94	\N	\N	Longport (inside), Great Egg Harbor Inlet	NJ
67046	Tuckahoe, Tuckahoe River, Great Egg Harbor Bay, New Jersey (sub)	NOS	8534883	39.295	-74.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	02:40:00	\N	1.25	02:12:00	\N	0.86	\N	\N	Tuckahoe, Tuckahoe River	NJ
67047	Beesleys Point, Great Egg Harbor Bay, New Jersey	NOS	8534975	39.2883	-74.6283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:32:00	\N	1	00:55:00	\N	0.87	\N	\N	Beesleys Point	NJ
67048	Cedar Swamp Creek, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8535001	39.2467	-74.7183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	03:03:00	\N	1.53	03:14:00	\N	0.78	\N	\N	Cedar Swamp Creek, Tuckahoe River	NJ
67136	Edgely, Pennsylvania	NOS	8549424	40.1283	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	01:28:00	\N	1.15	01:08:00	\N	1.27	\N	\N	Edgely, Pa.	PA
67049	Middle Thorofare, Ocean Drive bridge, Corson Inlet, New Jersey	NOS	8535101	39.215	-74.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:30:00	\N	0.94	00:31:00	\N	0.95	\N	\N	Middle Thorofare, Ocean Drive bridge	NJ
67050	Strathmere, Strathmere Bay, Corson Inlet, New Jersey	NOS	8535163	39.2	-74.6567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:38:00	\N	1	00:31:00	\N	0.95	\N	\N	Strathmere, Strathmere Bay	NJ
67051	Ludlam Bay, west side, Corson Inlet, New Jersey	NOS	8535221	39.1767	-74.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:12:00	\N	0.94	00:56:00	\N	0.98	\N	\N	Ludlam Bay, west side	NJ
67052	Townsend Sound, Townsends Inlet, New Jersey	NOS	8535309	39.1467	-74.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:39:00	\N	0.59	01:08:00	\N	0.9	\N	\N	Townsend Sound	NJ
67053	Stites Sound, Townsends Inlet, New Jersey	NOS	8535357	39.12	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:04:00	\N	1	00:49:00	\N	0.97	\N	\N	Stites Sound	NJ
67054	Ingram Thorofare, Townsends Inlet, New Jersey (sub)	NOS	8535419	39.11	-74.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:50:00	\N	1	00:44:00	\N	0.96	\N	\N	Ingram Thorofare	NJ
67055	Long Reach, Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535451	39.1017	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:11:00	\N	1.06	01:06:00	\N	0.98	\N	\N	Long Reach, Ingram Thorofare	NJ
67056	Nummy Island, Grassy Sound Channel, Hereford Inlet, New Jersey	NOS	8535661	39.0283	-74.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:45:00	\N	1	00:32:00	\N	1	\N	\N	Nummy Island, Grassy Sound Channel	NJ
67057	Old Turtle Thorofare, RR. bridge, Hereford Inlet, New Jersey	NOS	8535695	39.0183	-74.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:10:00	\N	1	00:56:00	\N	1.06	\N	\N	Old Turtle Thorofare, RR. bridge	NJ
67058	West Wildwood, Grassy Sound, Hereford Inlet, New Jersey	NOS	8535726	39.005	-74.8267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	01:11:00	\N	1	00:57:00	\N	1.04	\N	\N	West Wildwood, Grassy Sound	NJ
67059	Swain Channel, Taylor Sound, Cape May Inlet, New Jersey	NOS	8535805	38.98	-74.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:40:00	\N	1.06	00:55:00	\N	1.09	\N	\N	Swain Channel, Taylor Sound	NJ
67060	Wildwood Crest, Sunset Lake, Cape May Inlet, New Jersey	NOS	8535838	38.9783	-74.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:47:00	\N	1.06	00:52:00	\N	1.1	\N	\N	Wildwood Crest, Sunset Lake	NJ
67061	Cape May Harbor, Cape May Inlet, New Jersey	NOS	8535901	38.9483	-74.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:19:00	\N	1.06	00:33:00	\N	1.1	\N	\N	Cape May Harbor	NJ
67062	Cape Island Creek, Cape May, New Jersey	NOS	8535902	38.9467	-74.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:20:00	\N	1.19	00:40:00	\N	1.11	\N	\N	Cape Island Creek, Cape May	NJ
67063	Cape May (ocean), New Jersey	NOS	8535962	38.93	-74.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65710	00:21:00	\N	1.06	00:34:00	\N	1.12	\N	\N	Cape May, Atlantic Ocean	NJ
67064	Cape May Point, Sunset Beach, Delaware Bay, New Jersey	NOS	8536021	38.9467	-74.9717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	-00:08:00	\N	1.16	-00:05:00	\N	1.16	\N	\N	Cape May Point, Sunset Beach	NJ
67065	Cape May Canal, Cape May, Delaware Bay, New Jersey (sub)	NOS	8536110	38.96777777777778	-74.95972222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	-00:05:00	\N	1	-00:06:00	\N	1.18	\N	\N	Cape May, ferry terminal	NJ
67066	North Highlands Beach, Delaware Bay, New Jersey	NOS	8536271	39.0183	-74.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	00:14:00	\N	1.26	00:04:00	\N	1.26	\N	\N	North Highlands Beach	NJ
67067	Dias Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536449	39.0833	-74.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	03:18:00	\N	0.46	01:09:00	\N	0.46	\N	\N	Dias Creek, Route 47 bridge	NJ
67068	Bidwell Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536551	39.1183	-74.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	00:48:00	\N	1.36	00:36:00	\N	1.36	\N	\N	Bidwell Creek, Route 47 bridge	NJ
67069	Bidwell Creek entrance, Delaware Bay, New Jersey (sub)	NOS	8536581	39.1283	-74.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	00:46:00	\N	1.19	00:15:00	\N	1.39	\N	\N	Bidwell Creek entrance	NJ
67070	Sluice Creek, Route 47 bridge, Dennis Creek, Delaware Bay, New Jersey	NOS	8536687	39.1617	-74.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	01:36:00	\N	1.22	01:49:00	\N	1.22	\N	\N	Sluice Creek, Route 47 bridge, Dennis Creek	NJ
67071	Dennis Creek, 2.5 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536736	39.1783	-74.8517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	01:17:00	\N	1.26	00:55:00	\N	1.26	\N	\N	Dennis Creek, 2.5 n.mi. above entrance	NJ
67072	Dennis Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536752	39.1833	-74.8217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	01:30:00	\N	1.2	02:01:00	\N	1.2	\N	\N	Dennis Creek, Route 47 bridge	NJ
67073	West Creek, 0.7 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536764	39.1883	-74.915	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	01:31:00	\N	1.15	00:20:00	\N	1.15	\N	\N	West Creek, 0.7 n.mi. above entrance	NJ
67074	East Point, Maurice River Cove, Delaware Bay, New Jersey	NOS	8536780	39.2	-75.02	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	01:08:00	\N	1.39	00:40:00	\N	1.39	\N	\N	East Point, Maurice River Cove	NJ
67075	Riggins Ditch, 0.5 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536801	39.2	-74.97	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	01:29:00	\N	1.24	00:29:00	\N	1.24	\N	\N	Riggins Ditch, 0.5 n.mi. above entrance	NJ
67076	East Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536823	39.2083	-74.9017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	02:24:00	\N	0.94	01:46:00	\N	0.94	\N	\N	East Creek, Route 47 bridge	NJ
67077	Fishing Creek entrance, Delaware Bay, New Jersey	NOS	8536848	39.2167	-75.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-02:10:00	\N	1.02	-01:51:00	\N	1.02	\N	\N	Fishing Creek entrance	NJ
67078	Dividing Creek entrance, Delaware Bay, New Jersey	NOS	8536849	39.2167	-75.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	01:05:00	\N	1.35	00:29:00	\N	1.35	\N	\N	Dividing Creek entrance	NJ
67079	West Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536851	39.2167	-74.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	03:17:00	\N	0.58	02:20:00	\N	0.58	\N	\N	West Creek, Route 47 bridge	NJ
67080	Riggins Ditch, Heislerville, Delaware Bay, New Jersey	NOS	8536855	39.2183	-74.98	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	01:40:00	\N	1.12	01:36:00	\N	1.12	\N	\N	Riggins Ditch, Heislerville	NJ
67081	Weir Creek bridge, Dividing Creek, Delaware Bay, New Jersey	NOS	8536935	39.25	-75.1283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	02:33:00	\N	0.71	01:38:00	\N	0.71	\N	\N	Weir Creek bridge, Dividing Creek	NJ
67082	Hollywood Beach, The Glades, Delaware Bay, New Jersey	NOS	8537026	39.275	-75.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	01:13:00	\N	0.21	01:45:00	\N	0.21	\N	\N	Hollywood Beach, The Glades	NJ
67083	Money Island, Nantuxent Creek entrance, Delaware Bay, New Jersey	NOS	8537052	39.285	-75.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-01:58:00	\N	1.1	-01:43:00	\N	1.1	\N	\N	Money Island, Nantuxent Creek entrance	NJ
67084	Mauricetown, Maurice River, New Jersey	NOS	8537059	39.285	-74.9917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	02:30:00	\N	1.05	02:17:00	\N	1.05	\N	\N	Mauricetown	NJ
67085	Newport Landing, Nantuxent Creek, Delaware Bay, New Jersey	NOS	8537079	39.2917	-75.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:28:00	\N	0.74	-00:03:00	\N	0.74	\N	\N	Newport Landing, Nantuxent Creek	NJ
67086	Cedar Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537101	39.2983	-75.2467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-01:51:00	\N	1.08	-01:37:00	\N	1.08	\N	\N	Cedar Creek entrance, Nantuxent Cove	NJ
67087	Back Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537116	39.305	-75.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-01:34:00	\N	1.07	-01:29:00	\N	1.07	\N	\N	Back Creek entrance, Nantuxent Cove	NJ
67088	Port Elizabeth, Manumuskin River, Maurice River, New Jersey	NOS	8537147	39.3133	-74.985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	02:58:00	\N	1.05	02:52:00	\N	1.05	\N	\N	Port Elizabeth, Manumuskin River	NJ
67089	Menantico Creek entrance, Maurice River, New Jersey	NOS	8537242	39.3433	-75.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	03:09:00	\N	1.1	03:06:00	\N	1.1	\N	\N	Menantico Creek entrance	NJ
67090	Tindalls Wharf, Cohansey River, Delaware Bay, New Jersey	NOS	8537353	39.3783	-75.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:02:00	\N	1.09	01:01:00	\N	1.09	\N	\N	Tindalls Wharf, Cohansey River	NJ
67091	Millville, Maurice River, New Jersey	NOS	8537359	39.3917	-75.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	03:36:00	\N	1.21	03:33:00	\N	1.21	\N	\N	Millville	NJ
67137	Edgemoor, Delaware River, Delaware	NOS	8550438	39.75	-75.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	01:11:00	\N	1.17	00:52:00	\N	1.02	\N	\N	Edgemoor, Del.	DE
67092	Greenwich Pier, Cohansey River, Delaware Bay, New Jersey	NOS	8537374	39.3833	-75.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:54:00	\N	0.99	-00:42:00	\N	0.99	\N	\N	Greenwich Pier, Cohansey River	NJ
67093	Stathems Neck, Stow Creek, Delaware River, New Jersey	NOS	8537416	39.4067	-75.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:37:00	\N	0.88	-00:22:00	\N	0.88	\N	\N	Stathems Neck, Stow Creek, N.J.	NJ
67094	Pine Island, Malapartis Creek, Mad Horse Creek, New Jersey	NOS	8537488	39.4217	-75.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:18:00	\N	0.92	00:21:00	\N	0.92	\N	\N	Pine Island, Malapartis Creek, N.J.	NJ
67095	Raccoon Ditch, Newport Meadows, Stow Creek, Delaware River, New Jersey	NOS	8537489	39.4217	-75.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:33:00	\N	0.76	01:08:00	\N	0.76	\N	\N	Raccoon Ditch, Newport Meadows, Stow Creek, N.J.	NJ
67096	1 n.mi. above entrance, Mad Horse Creek, New Jersey	NOS	8537535	39.4317	-75.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:47:00	\N	1.07	-00:20:00	\N	1.07	\N	\N	1 n.mi. above entrance, N.J.	NJ
67097	Canton, Stow Creek, Delaware River, New Jersey	NOS	8537562	39.4617	-75.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:45:00	\N	0.8	01:36:00	\N	0.8	\N	\N	Canton, Stow Creek, N.J.	NJ
67098	Artificial Island, Salem Nuclear Plant, Delaware River, New Jersey	NOS	8537614	39.46	-75.5317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:33:00	\N	1.08	-00:35:00	\N	1.08	\N	\N	Artificial Island, Salem Nuclear Plant, N.J.	NJ
67099	Hope Creek, 0.6 n.mi. above entrance, Delaware River, New Jersey	NOS	8537667	39.4583	-75.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:36:00	\N	1.05	-00:25:00	\N	1.05	\N	\N	Hope Creek, 0.6 n.mi. above entrance, N.J.	NJ
68143	Bastian Island, Louisiana	NOS	8761289	29.2867	-89.6633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	00:12:00	\N	1.13	00:41:00	\N	1.13	\N	\N	Bastian Island	LA
67100	0.8 n.mi. above entrance, Alloway Creek, New Jersey	NOS	8537731	39.4967	-75.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:10:00	\N	0.99	00:21:00	\N	0.99	\N	\N	0.8 n.mi. above entrance	NJ
67101	2.5 n.mi. above entrance, Alloway Creek, New Jersey	NOS	8537753	39.505	-75.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:15:00	\N	0.9	00:51:00	\N	0.9	\N	\N	2.5 n.mi. above entrance	NJ
67102	Abbots Meadow, Alloway Creek, New Jersey	NOS	8537774	39.5117	-75.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:12:00	\N	0.94	00:44:00	\N	0.94	\N	\N	Abbots Meadow	NJ
67103	Coopers Creek bridge, Alloway Creek, New Jersey	NOS	8537779	39.5133	-75.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	01:00:00	\N	0.78	01:51:00	\N	0.78	\N	\N	Coopers Creek bridge	NJ
67104	Quinton, Alloway Creek, New Jersey	NOS	8537889	39.5483	-75.415	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	01:30:00	\N	0.69	02:24:00	\N	0.69	\N	\N	Quinton	NJ
67105	Sinnickson Landing, Salem River, New Jersey	NOS	8537961	39.57	-75.4983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:19:00	\N	0.97	00:04:00	\N	0.97	\N	\N	Sinnickson Landing	NJ
67106	Salem, Salem River, New Jersey	NOS	8537979	39.5767	-75.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:41:00	\N	0.76	00:49:00	\N	0.76	\N	\N	Salem	NJ
67107	Salem Canal entrance, Delaware River, New Jersey	NOS	8538231	39.6833	-75.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:52:00	\N	1	00:36:00	\N	1	\N	\N	Salem Canal entrance, N.J.	NJ
67108	Auburn, Oldmans Creek, Delaware River, New Jersey	NOS	8538274	39.715	-75.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	03:30:00	\N	0.55	04:12:00	\N	0.55	\N	\N	Auburn, Oldmans Creek, N.J.	NJ
67109	Pedricktown, Oldmans Creek, Delaware River, New Jersey	NOS	8538369	39.7617	-75.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	02:07:00	\N	0.75	02:11:00	\N	0.75	\N	\N	Pedricktown, Oldmans Creek, N.J.	NJ
67110	Mantua, Mantua Creek, New Jersey	NOS	8538438	39.795	-75.1767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	00:56:00	\N	0.71	01:28:00	\N	0.71	\N	\N	Mantua, Mantua Creek, N.J.	NJ
67111	Bridgeport, Raccoon Creek, New Jersey	NOS	8538449	39.8067	-75.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	-00:50:00	\N	1	-01:11:00	\N	0.91	\N	\N	Bridgeport, Raccoon Creek, N.J.	NJ
67112	Woodbury Creek, New Jersey	NOS	8538548	39.86	-75.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	-00:14:00	\N	0.95	-00:13:00	\N	0.96	\N	\N	Woodbury Creek, N.J.	NJ
67113	Billingsport, New Jersey	NOS	8538552	39.85	-75.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	-00:28:00	\N	0.95	-00:35:00	\N	0.93	\N	\N	Billingsport, N.J.	NJ
67114	Westville, Rt. 47 bridge, Big Timber Creek, New Jersey	NOS	8538601	39.8733	-75.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	00:03:00	\N	1	00:02:00	\N	0.97	\N	\N	Westville, Rt. 47 bridge, Big Timber Creek, N.J.	NJ
67115	Pavonia, Cooper River, RR. bridge, New Jersey	NOS	8538752	39.9467	-75.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	00:23:00	\N	1	00:14:00	\N	1.04	\N	\N	Pavonia, Cooper River, RR. bridge, N.J.	NJ
67116	Hainesport, South Branch, Rancocas Creek, New Jersey	NOS	8538824	39.9783	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	03:05:00	\N	0.62	02:58:00	\N	0.62	\N	\N	Hainesport, South Branch	NJ
67117	North Branch, Rancocas Creek, New Jersey	NOS	8538848	39.9983	-74.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	03:29:00	\N	0.6	02:58:00	\N	0.48	\N	\N	North Branch	NJ
67118	Palmyra, Pennsauken Creek, Route 73 bridge, New Jersey	NOS	8538853	39.9933	-75.0283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	01:03:00	\N	0.89	00:51:00	\N	0.89	\N	\N	Palmyra, Pennsauken Creek, Route 73 bridge, N.J.	NJ
67119	Pompeston Creek, New Jersey	NOS	8538875	40.0133	-75.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	00:43:00	\N	1.05	00:21:00	\N	1.05	\N	\N	Pompeston Creek, N.J.	NJ
67120	Bridgeboro, Rancocas Creek, New Jersey	NOS	8538921	40.0283	-74.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	01:18:00	\N	1	01:15:00	\N	1.06	\N	\N	Bridgeboro	NJ
67121	Assiscunk Creek, Route 130 bridge, New Jersey	NOS	8539058	40.0733	-74.8483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	01:31:00	\N	0.85	01:04:00	\N	1.12	\N	\N	Assiscunk Creek, Route 130 bridge, N.J.	NJ
67122	Burlington, Delaware River, New Jersey (sub)	NOS	8539094	40.08	-74.87333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	01:07:00	\N	1	00:53:00	\N	1.2	\N	\N	Burlington, N.J.	NJ
67123	Fieldsboro, Delaware River, New Jersey (sub)	NOS	8539487	40.1367	-74.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	01:39:00	\N	1.1	01:07:00	\N	1.29	\N	\N	Fieldsboro, N.J.	NJ
67124	Trenton Marine Terminal, Trenton, New Jersey (sub)	NOS	8539993	40.1883	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	01:54:00	\N	1	01:13:00	\N	1.35	\N	\N	Trenton, N.J.	NJ
67125	Marcus Hook, Pennsylvania (sub)	NOS	8540433	39.8116667	-75.4094444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	-01:07:00	\N	0.95	-01:23:00	\N	0.92	\N	\N	Marcus Hook, Pa.	PA
67126	Wanamaker Bridge, Darby Creek, Pennsylvania	NOS	8542425	39.8767	-75.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	-00:34:00	\N	0.95	-00:46:00	\N	0.95	\N	\N	Wanamaker Bridge	PA
67127	Norwood City, Darby Creek, Pennsylvania	NOS	8542699	39.88	-75.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	-00:35:00	\N	1	-00:42:00	\N	0.97	\N	\N	Norwood City	PA
67128	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania	NOS	8542885	39.8783	-75.2767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	-00:08:00	\N	0.9	-00:22:00	\N	0.91	\N	\N	Tinicum National Wildlife Refuge	PA
67129	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania (2)	NOS	8543024	39.8867	-75.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	00:27:00	\N	0.74	-00:24:00	\N	0.74	\N	\N	Tinicum National Wildlife Refuge	PA
67130	Penrose Avenue Bridge, Schuylkill River, Pennsylvania	NOS	8543925	39.8983	-75.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	-00:11:00	\N	0.85	-00:22:00	\N	0.96	\N	\N	Penrose Avenue Bridge	PA
67131	Market Street Bridge, Schuylkill River, Pennsylvania	NOS	8545120	39.955	-75.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	00:00:00	\N	0.8	-00:20:00	\N	0.99	\N	\N	Market Street Bridge	PA
67132	Philadelphia, Municipal Pier 11, Pennsylvania (sub)	NOS	8545530	39.9533	-75.1383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	00:05:00	\N	0.95	00:02:00	\N	1.04	\N	\N	Philadelphia, Municipal Pier 11, Pa.	PA
67133	Bridesburg, Philadelphia, Pennsylvania (sub)	NOS	8546252	39.98333333333333	-75.075	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	00:15:00	\N	0.9	00:12:00	\N	1.06	\N	\N	Bridesburg, Philadelphia, Pa.	PA
67134	Cornwells Heights, Pennsylvania	NOS	8547333	40.0683	-74.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	00:58:00	\N	1	00:46:00	\N	1.17	\N	\N	Cornwells Heights, Pa.	PA
67135	Newbold, Delaware River, Pennsylvania (sub)	NOS	8548989	40.13730555555556	-74.75188888888889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65729	01:31:00	\N	1	01:10:00	\N	1.3	\N	\N	Newbold, Pa.	PA
67138	Millside, RR. bridge, Christina River, Delaware	NOS	8550658	39.725	-75.56	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	01:19:00	\N	1.06	01:08:00	\N	0.99	\N	\N	Millside, RR. bridge	DE
67139	Wilmington Marine Terminal, Christina River, Delaware	NOS	8550714	39.7183	-75.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	01:06:00	\N	1.11	00:50:00	\N	0.99	\N	\N	Wilmington Marine Terminal	DE
67140	New Castle, Delaware River, Delaware	NOS	8551201	39.6567	-75.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:40:00	\N	1	00:29:00	\N	0.98	\N	\N	New Castle, Delaware	DE
67141	Pea Patch Island, Bulkhead Shoal Channel, Delaware River, Delaware	NOS	8551702	39.5833	-75.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:00:00	\N	1	00:03:00	\N	1.05	\N	\N	Pea Patch Island, Bulkhead Shoal Channel, Del.	DE
67142	Delaware City, Delaware River, Delaware (sub)	NOS	8551762	39.5817	-75.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:14:00	\N	1	00:11:00	\N	0.99	\N	\N	Delaware City	DE
67143	Delaware City Branch Channel bridge, Delaware River, Delaware	NOS	8551851	39.57	-75.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:05:00	\N	0.89	00:00:00	\N	1.02	\N	\N	Delaware City Branch Channel bridge	DE
67144	St. Georges, Chesapeake and Delaware Canal, Delaware	NOS	8551973	39.555	-75.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:17:00	\N	1	-00:16:00	\N	0.83	\N	\N	St. Georges, Delaware	DE
67145	Summit Bridge, Chesapeake and Delaware Canal, Delaware	NOS	8552125	39.5333	-75.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-00:52:00	\N	0.56	-00:28:00	\N	0.65	\N	\N	Summit Bridge, Delaware	DE
67146	Taylors Bridge, Blackbird Creek, Delaware River, Delaware	NOS	8553069	39.405	-75.5983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	00:57:00	\N	0.56	01:53:00	\N	0.54	\N	\N	Taylors Bridge, Blackbird Creek, Del.	DE
67147	Woodland Beach, Delaware River, Delaware	NOS	8553501	39.3333	-75.4667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-01:10:00	\N	1.11	-01:07:00	\N	1.11	\N	\N	Woodland Beach, Del.	DE
67148	Leipsic, Leipsic River, Delaware Bay, Delaware	NOS	8554038	39.245	-75.5183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	03:49:00	\N	0.63	03:35:00	\N	0.85	\N	\N	Leipsic, Leipsic River	DE
67149	Mahon River entrance, Delaware Bay, Delaware (sub)	NOS	8554399	39.185	-75.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	01:29:00	\N	1.13	00:58:00	\N	1.3	\N	\N	Mahon River entrance	DE
67150	Murderkill River entrance, Delaware Bay, Delaware	NOS	8555388	39.0583	-75.3967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	01:11:00	\N	0.94	00:39:00	\N	1.25	\N	\N	Murderkill River entrance	DE
67151	Brandywine Shoal Light, Delaware Bay, New Jersey (sub)	NOS	8555889	38.98667	-75.11333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	00:23:00	\N	1.06	-00:01:00	\N	1.16	\N	\N	Brandywine Shoal Light	NJ
67152	Mispillion River entrance, Delaware Bay, Delaware	NOS	8556198	38.945	-75.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65737	00:50:00	\N	1	00:22:00	\N	1.13	\N	\N	Mispillion River entrance	DE
67153	Rehoboth Beach, Delaware	NOS	8557863	38.72	-75.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:08:00	\N	1.33	00:15:00	\N	1.13	\N	\N	Rehoboth Beach	DE
67154	Inlet (Coast Guard Station), Indian River, Delaware (sub)	NOS	8558690	38.61	-75.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:45:00	\N	1	01:14:00	\N	0.76	\N	\N	Indian River Inlet (Coast Guard Station)	DE
67155	Keydash, Isle of Wight Bay, Maryland	NOS	8570255	38.3417	-75.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:54:00	\N	0.81	-00:57:00	\N	0.47	\N	\N	Keydash, Isle of Wight Bay	MD
67156	Ocean City (Isle of Wight Bay), Maryland	NOS	8570282	38.3317	-75.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:23:00	\N	0.94	00:25:00	\N	0.67	\N	\N	Ocean City (Isle of Wight Bay)	MD
67157	Ocean City Inlet, Maryland (sub)	NOS	8570283	38.32833	-75.09166666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:14:00	\N	1	00:28:00	\N	0.65	\N	\N	Ocean City Inlet	MD
67158	South Point, Sinepuxent Neck, Chincoteague Bay, Maryland (sub)	NOS	8570536	38.215	-75.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	05:02:00	\N	0.16	05:16:00	\N	0.16	\N	\N	South Point, Sinepuxent Neck	MD
67159	Public Landing, Chincoteague Bay, Maryland (sub)	NOS	8570649	38.1483	-75.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	05:21:00	\N	0.18	04:41:00	\N	0.18	\N	\N	Public Landing	MD
67160	Ape Hole Creek, Pocomoke Sound, Chesapeake Bay, Maryland	NOS	8571072	37.9617	-75.8217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:58:00	\N	0.83	04:27:00	\N	0.9	\N	\N	Ape Hole Creek, Pocomoke Sound	MD
67161	Crisfield, Little Annemessex River, Chesapeake Bay, Maryland (sub)	NOS	8571091	37.9767	-75.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:51:00	\N	1	04:34:00	\N	0.75	\N	\N	Crisfield, Little Annemessex River	MD
67162	Shelltown, Pocomoke River, Maryland	NOS	8571097	37.98	-75.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	05:16:00	\N	1	04:32:00	\N	0.94	\N	\N	Shelltown	MD
67163	Ewell, Smith Island, Chesapeake Bay, Maryland (sub)	NOS	8571117	37.995	-76.0317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	05:19:00	\N	1	04:56:00	\N	0.61	\N	\N	Ewell, Smith Island	MD
67164	Colburn Creek, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571181	38.0483	-75.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	05:30:00	\N	1.17	04:59:00	\N	0.78	\N	\N	Colburn Creek, Big Annemessex River	MD
67165	Long Point, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571201	38.0567	-75.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	05:47:00	\N	0.83	05:19:00	\N	0.82	\N	\N	Long Point, Big Annemessex River	MD
67166	Holland Island Bar Light, Chesapeake Bay, Maryland	NOS	8571214	38.0683	-76.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	05:30:00	\N	0.58	05:16:00	\N	0.56	\N	\N	Holland Island Bar Light	MD
67167	Teague Creek, Manokin River, Chesapeake Bay, Maryland	NOS	8571269	38.1083	-75.8383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	06:05:00	\N	0.83	05:38:00	\N	0.82	\N	\N	Teague Creek, Manokin River	MD
67168	Chance, Chesapeake Bay, Maryland	NOS	8571351	38.1717	-75.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	05:57:00	\N	1.17	05:29:00	\N	0.78	\N	\N	Chance	MD
67169	Snow Hill, city park, Pocomoke River, Maryland (sub)	NOS	8571359	38.17833	-75.39666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	08:54:00	\N	1.33	08:44:00	\N	0.58	\N	\N	Snowhill, city park	MD
67170	Sharkfin Shoal Light, Chesapeake Bay, Maryland	NOS	8571396	38.2017	-75.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	06:06:00	\N	0.92	05:46:00	\N	0.86	\N	\N	Sharkfin Shoal Light	MD
67171	Hooper Strait Light, Chesapeake Bay, Maryland	NOS	8571402	38.2267	-76.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	05:51:00	\N	1.17	05:26:00	\N	0.61	\N	\N	Hooper Strait Light	MD
67172	Great Shoals Light, Monie Bay, Chesapeake Bay, Maryland	NOS	8571416	38.2167	-75.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	06:22:00	\N	0.92	06:00:00	\N	0.9	\N	\N	Great Shoals Light, Monie Bay	MD
67173	Bishops Head, Hooper Strait, Maryland (sub)	NOS	8571421	38.22038888888889	-76.03866666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	06:04:00	\N	1.08	05:32:00	\N	0.7	\N	\N	Bishops Head, Hooper Strait	MD
67174	Roaring Point, Nanticoke River, Maryland	NOS	8571476	38.2617	-75.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	06:35:00	\N	0.92	06:00:00	\N	0.9	\N	\N	Roaring Point	MD
67175	Whitehaven, Wicomico River, Maryland	NOS	8571485	38.2683	-75.7883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	06:46:00	\N	1	06:26:00	\N	0.94	\N	\N	Whitehaven	MD
67176	Middle Hooper Island, Chesapeake Bay, Maryland	NOS	8571519	38.2967	-76.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-04:39:00	\N	1.5	-04:40:00	\N	1.32	\N	\N	Middle Hooper Island	MD
67177	McCready's Creek, Fishing Bay, Chesapeake Bay, Maryland (sub)	NOS	8571559	38.3	-76.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	06:22:00	\N	1.17	05:49:00	\N	0.82	\N	\N	McCreedy's Creek, Fishing Bay	MD
67178	Barren Island, Chesapeake Bay, Maryland (sub)	NOS	8571579	38.3417	-76.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-04:56:00	\N	0.68	-04:45:00	\N	1.01	\N	\N	Barren Island	MD
67179	Smithville Road Bridge, Beaverdam Creek, Little Choptank River, Maryland (sub)	NOS	8571702	38.42833	-76.23666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:49:00	\N	0.82	-02:26:00	\N	1.01	\N	\N	Smithville Road Bridge, Beaverdam Creek	MD
67180	Taylors Island, Slaughter Creek, Little Choptank River, Maryland	NOS	8571752	38.4667	-76.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-03:00:00	\N	1.18	-03:15:00	\N	1.1	\N	\N	Taylors Island, Slaughter Creek	MD
67181	Vienna, Nanticoke River, Maryland (sub)	NOS	8571773	38.48333	-75.81833333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	08:32:00	\N	1.33	08:25:00	\N	0.79	\N	\N	Vienna	MD
67182	Woolford, Church Creek, Little Choptank River, Maryland	NOS	8571807	38.5067	-76.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:55:00	\N	1.41	-03:11:00	\N	1.25	\N	\N	Woolford, Church Creek	MD
67183	Sharptown, Nanticoke River, Maryland	NOS	8571858	38.545	-75.72330555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	09:28:00	\N	1	09:19:00	\N	0.97	\N	\N	Sharptown	MD
67184	Cherry Island, Beckwiths Creek, Little Choptank River, Maryland	NOS	8571881	38.5617	-76.2083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:57:00	\N	1.27	-03:07:00	\N	1.18	\N	\N	Cherry Island, Beckwiths Creek	MD
67185	Cambridge, Choptank River, Maryland (sub)	NOS	8571892	38.5741667	-76.0722222	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:28:00	\N	0.95	-02:42:00	\N	1.23	\N	\N	Cambridge	MD
67186	Avalon, Dogwood Harbor, Chesapeake Bay, Maryland	NOS	8571901	38.71	-76.335	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:48:00	\N	1.36	-02:54:00	\N	1.18	\N	\N	Avalon, Dogwood Harbor	MD
67187	Dover Bridge, Choptank River, Maryland	NOS	8571944	38.7567	-75.9983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:41:00	\N	1.68	-00:18:00	\N	1.54	\N	\N	Dover Bridge	MD
67188	Ferry Cove, Tilghman Island, Chesapeake Bay, Maryland	NOS	8571979	38.765	-76.3283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:42:00	\N	1	-02:33:00	\N	0.98	\N	\N	Tilghman Island, Ferry Cove, Eastern Bay	MD
67189	Oxford, Tred Avon River, Maryland	NOS	8572108	38.6933	-76.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:45:00	\N	1.41	-02:50:00	\N	1.25	\N	\N	Oxford	MD
67190	Deep Neck Point, Broad Creek, Chesapeake Bay, Maryland	NOS	8572204	38.7317	-76.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:47:00	\N	1.41	-02:57:00	\N	1.25	\N	\N	Deep Neck Point, Broad Creek	MD
67191	Easton Point, Tred Avon River, Maryland	NOS	8572296	38.7683	-76.095	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:35:00	\N	1.59	-02:45:00	\N	1.47	\N	\N	Easton Point	MD
67192	St. Michaels, San Domingo Creek, Chesapeake Bay, Maryland	NOS	8572313	38.775	-76.2333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:52:00	\N	1.41	-02:55:00	\N	1.25	\N	\N	St. Michaels, San Domingo Creek	MD
67193	St. Michaels, Miles River, Chesapeake Bay, Maryland (sub)	NOS	8572342	38.7867	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:02:00	\N	1.18	-02:12:00	\N	1.22	\N	\N	St. Michaels, Miles River	MD
67194	Kent Point Marina, Chesapeake Bay, Maryland (sub)	NOS	8572467	38.8367	-76.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:29:00	\N	0.95	-02:21:00	\N	0.97	\N	\N	Kent Point Marina	MD
67195	Claiborne, Eastern Bay, Chesapeake Bay, Maryland	NOS	8572468	38.8367	-76.28	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:28:00	\N	1.09	-02:26:00	\N	0.96	\N	\N	Claiborne, Eastern Bay	MD
67196	Hillsboro, Tuckahoe Creek, Maryland (sub)	NOS	8572669	38.9167	-75.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	01:18:00	\N	0.86	01:21:00	\N	1.83	\N	\N	Hillsboro, Tuckahoe Creek	MD
67197	Matapeake, Kent Island, Chesapeake Bay, Maryland (sub)	NOS	8572770	38.9567	-76.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-01:49:00	\N	0.95	-01:30:00	\N	0.9	\N	\N	Matapeake, Kent Island	MD
67198	Kent Island Narrows, Chesapeake Bay, Maryland	NOS	8572792	38.9667	-76.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-01:23:00	\N	1.18	-01:30:00	\N	1.1	\N	\N	Kent Island Narrows	MD
67199	Queenstown, Chester River, Maryland	NOS	8572867	38.9967	-76.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:08:00	\N	1.27	00:05:00	\N	1.18	\N	\N	Queenstown	MD
67200	Love Point, Chester River, Maryland (sub)	NOS	8572955	39.0317	-76.3017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:41:00	\N	0.95	-00:25:00	\N	1.03	\N	\N	Love Point	MD
67201	Centreville Landing, Corsica River, Chester River, Maryland	NOS	8573006	39.0533	-76.075	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	00:14:00	\N	1.89	00:20:00	\N	1.47	\N	\N	Centreville Landing, Corsica River	MD
67202	Cliffs Point, Chester River, Maryland	NOS	8573125	39.1067	-76.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:02:00	\N	1.5	00:12:00	\N	1.32	\N	\N	Cliffs Point	MD
67203	Cliffs Wharf, Chester River, Maryland	NOS	8573137	39.11	-76.1383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:08:00	\N	1.27	00:09:00	\N	1.33	\N	\N	Cliffs Wharf	MD
67204	Deep Landing, Swan Creek, Chesapeake Bay, Maryland	NOS	8573211	39.145	-76.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:04:00	\N	1.09	00:02:00	\N	0.96	\N	\N	Deep Landing, Swan Creek	MD
67205	Chestertown, Chester River, Maryland	NOS	8573343	39.2067	-76.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	00:36:00	\N	1.77	01:03:00	\N	1.62	\N	\N	Chestertown	MD
67206	Crumpton, Chester River, Maryland (sub)	NOS	8573349	39.245	-75.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	01:04:00	\N	0.91	01:10:00	\N	1.82	\N	\N	Crumpton	MD
67207	Tolchester Beach, Chesapeake Bay, Maryland (sub)	NOS	8573364	39.21333	-76.245	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	00:11:00	\N	0.95	00:18:00	\N	1.04	\N	\N	Tolchester Beach	MD
67208	Worton Creek entrance, Chesapeake Bay, Maryland	NOS	8573442	39.2967	-76.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	01:19:00	\N	1.27	01:22:00	\N	1.18	\N	\N	Worton Creek entrance	MD
67209	Sassafras River, Betterton, Chesapeake Bay, Maryland (sub)	NOS	8573704	39.3717	-76.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	02:15:00	\N	1	02:35:00	\N	1.34	\N	\N	Sassafras River, Betterton	MD
67210	Saxis, Starling Creek, Pocomoke Sound, Chesapeake Bay, Maryland	NOS	8573777	37.92166666666701	-75.728333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:36:00	\N	1.17	03:52:00	\N	0.89	\N	\N	Saxis, Starling Creek, Pocomoke Sound	MD
67211	Town Point Wharf, Elk River, Maryland (sub)	NOS	8573903	39.5033	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	02:59:00	\N	0.86	03:18:00	\N	1.74	\N	\N	Town Point Wharf	MD
67212	Chesapeake City, Chesapeake and Delaware Canal, Maryland (sub)	NOS	8573927	39.5267	-75.81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65734	-01:12:00	\N	1.28	-00:45:00	\N	0.56	\N	\N	Chesapeake City, Maryland	MD
67235	Cove Point, Chesapeake Bay, Maryland (sub)	NOS	8577188	38.3917	-76.3983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-04:25:00	\N	0.83	-04:10:00	\N	0.83	\N	\N	Cove Point	MD
67213	Charlestown, Northeast River, Chesapeake Bay, Maryland	NOS	8573968	39.5733	-75.97	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	04:03:00	\N	1.86	03:52:00	\N	1.69	\N	\N	Charlestown, Northeast River	MD
67214	Old Frenchtown Wharf, Elk River, Maryland	NOS	8573969	39.575	-75.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	03:00:00	\N	2.27	03:13:00	\N	2.06	\N	\N	Old Frenchtown Wharf	MD
67215	Port Deposit, Susquehanna River, Maryland	NOS	8574008	39.6033	-76.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	03:49:00	\N	1.14	03:24:00	\N	1.51	\N	\N	Port Deposit	MD
67216	Havre de Grace, Susquehanna River, Maryland (sub)	NOS	8574070	39.5367	-76.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	03:27:00	\N	0.95	03:13:00	\N	1.55	\N	\N	Havre de Grace	MD
67217	Pond Point (Aberdeen P.G.), Bush River, Chesapeake Bay, Maryland (sub)	NOS	8574459	39.3883	-76.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	01:31:00	\N	0.86	01:52:00	\N	1.06	\N	\N	Pond Point, Bush River	MD
67218	Fort McHenry Marsh, Patapsco River, Maryland (sub)	NOS	8574683	39.2617	-76.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Fort McHenry Marsh	MD
67219	Hawkins Point, Patapsco River, Maryland	NOS	8574821	39.2083	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	00:06:00	\N	0.95	00:00:00	\N	1.03	\N	\N	Hawkins Point	MD
67220	North Point, Patapsco River, Maryland	NOS	8574857	39.1967	-76.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	00:04:00	\N	1.09	00:12:00	\N	0.93	\N	\N	North Point	MD
67221	Stony Creek, Patapsco River, Maryland	NOS	8574931	39.1633	-76.5267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:05:00	\N	0.91	00:03:00	\N	0.95	\N	\N	Stony Creek	MD
67222	Cornfield Creek, Magothy River, Chesapeake Bay, Maryland	NOS	8575109	39.1	-76.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:38:00	\N	0.95	-00:29:00	\N	0.89	\N	\N	Cornfield Creek, Magothy River	MD
67223	Mountain Point, Magothy River, Chesapeake Bay, Maryland	NOS	8575229	39.0617	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:04:00	\N	0.77	-00:04:00	\N	0.74	\N	\N	Mountain Point, Magothy River	MD
67224	Brewer Point, Severn River, Maryland	NOS	8575331	39.0267	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-00:54:00	\N	0.91	-00:45:00	\N	0.74	\N	\N	Brewer Point	MD
67225	Annapolis (US Naval Academy), Severn River, Maryland (sub)	NOS	8575512	38.98328	-76.4815555551317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-01:44:00	\N	1	-01:30:00	\N	0.88	\N	\N	Annapolis (US Naval Academy)	MD
67226	Gingerville Creek, South River, Chesapeake Bay, Maryland	NOS	8575550	38.9583	-76.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:06:00	\N	1	-02:01:00	\N	0.92	\N	\N	Gingerville Creek, South River	MD
67273	Oyster Harbor, Virginia	NOS	8631591	37.2883	-75.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:36:00	\N	1.13	01:00:00	\N	1.34	\N	\N	Oyster Harbor	VA
67227	Edgewater, South River, Chesapeake Bay, Maryland	NOS	8575579	38.95	-76.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:07:00	\N	0.91	-01:51:00	\N	0.81	\N	\N	Edgewater, South River	MD
67228	Thomas Point Shoal Light, Chesapeake Bay, Maryland	NOS	8575737	38.9	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:11:00	\N	0.91	-01:56:00	\N	0.81	\N	\N	Thomas Point Shoal Light	MD
67229	Rhode River (County Wharf), Chesapeake Bay, Maryland	NOS	8575787	38.8867	-76.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:17:00	\N	1	-02:07:00	\N	0.88	\N	\N	Rhode River (County Wharf)	MD
67230	Galesville, West River, Chesapeake Bay, Maryland	NOS	8575923	38.8417	-76.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-01:34:00	\N	0.91	-01:39:00	\N	0.81	\N	\N	Galesville, West River	MD
67231	Rose Haven, Chesapeake Bay, Maryland	NOS	8576256	38.725	-76.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:44:00	\N	0.91	-02:37:00	\N	0.81	\N	\N	Rose Haven	MD
67232	Chesapeake Beach, Chesapeake Bay, Maryland	NOS	8576363	38.7	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-03:05:00	\N	1	-02:47:00	\N	0.88	\N	\N	Chesapeake Beach	MD
67233	Long Beach, Chesapeake Bay, Maryland (sub)	NOS	8577004	38.465	-76.4733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-04:04:00	\N	0.77	-03:47:00	\N	0.87	\N	\N	Long Beach	MD
67234	Broomes Island, Patuxent River, Maryland	NOS	8577123	38.415	-76.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-04:19:00	\N	1.36	-04:13:00	\N	1.18	\N	\N	Broomes Island	MD
67236	Solomons Island, Patuxent River, Maryland (sub)	NOS	8577330	38.3172222	-76.4508333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-04:46:00	\N	0.73	-04:38:00	\N	0.98	\N	\N	Solomons Island	MD
67237	Cornfield Harbor, Potomac River, Maryland	NOS	8577940	38.06	-76.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-07:35:00	\N	0.53	-06:16:00	\N	0.48	\N	\N	Cornfield Harbor, Md.	MD
67238	Point Lookout, Chesapeake Bay, Maryland	NOS	8578002	38.04	-76.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-05:37:00	\N	0.77	-05:28:00	\N	1.02	\N	\N	Point Lookout	MD
67239	Piney Point, Potomac River, Maryland	NOS	8578240	38.1333	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-07:16:00	\N	0.6	-05:54:00	\N	0.51	\N	\N	Piney Point, Md.	MD
67240	Colton Point, Potomac River, Maryland	NOS	8578465	38.2233	-76.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-06:43:00	\N	0.73	-05:18:00	\N	0.65	\N	\N	Colton Point, Md.	MD
67241	Mills Point (south of), Wicomico River, Maryland	NOS	8578551	38.3267	-76.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-06:05:00	\N	0.73	-05:05:00	\N	0.65	\N	\N	Mills Point (south of), Wicomico Riv., Md.	MD
67242	Lower Cedar Point, Potomac River, Maryland	NOS	8578693	38.3417	-76.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-05:56:00	\N	0.6	-04:48:00	\N	0.54	\N	\N	Lower Cedar Point, Md.	MD
67243	Goose Creek, Port Tobacco River, Potomac River, Maryland	NOS	8578769	38.4533	-77.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-05:07:00	\N	0.6	-04:08:00	\N	0.54	\N	\N	Goose Creek, Port Tobacco River, Md.	MD
67244	Riverside, Potomac River, Maryland	NOS	8578853	38.3867	-77.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-04:24:00	\N	0.53	-03:23:00	\N	0.48	\N	\N	Riverside, Md.	MD
67245	Clifton Beach, Smith Point, Potomac River, Maryland	NOS	8578931	38.41333333333299	-77.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-02:46:00	\N	0.67	-01:42:00	\N	0.41	\N	\N	Clifton Beach, Smith Point, Md.	MD
67246	Liverpool Point, Potomac River, Maryland	NOS	8578984	38.46	-77.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-01:58:00	\N	0.67	-00:39:00	\N	0.44	\N	\N	Liverpool Point, Md.	MD
67247	Benedict, Patuxent River, Maryland	NOS	8579135	38.5133	-76.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-03:54:00	\N	1.82	-03:54:00	\N	1.47	\N	\N	Benedict	MD
67248	Indian Head, Potomac River, Maryland	NOS	8579381	38.6017	-77.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-01:33:00	\N	0.73	-00:14:00	\N	0.65	\N	\N	Indian Head, Md.	MD
67249	Lower Marlboro, Patuxent River, Maryland (sub)	NOS	8579542	38.655	-76.68333333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65767	-02:51:00	\N	0.77	-02:44:00	\N	1.44	\N	\N	Lower Marlboro	MD
67250	Marshall Hall, Potomac River, Maryland	NOS	8579629	38.6867	-77.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-00:55:00	\N	0.93	00:10:00	\N	0.82	\N	\N	Marshall Hall, Md.	MD
67251	Bladensburg, Anacostia River, Maryland (sub)	NOS	8579997	38.9333	-76.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	00:25:00	\N	1.13	00:31:00	\N	1.06	\N	\N	Bladensburg, Md.	MD
67252	Bellevue, Potomac River, DC	NOS	8590111	38.8267	-77.0267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-00:11:00	\N	1.33	00:34:00	\N	1.02	\N	\N	Bellevue, D.C.	DC
67253	Washington Naval Yard, Anacostia River, DC	NOS	8593005	38.8717	-76.995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-00:06:00	\N	1.2	00:18:00	\N	1.01	\N	\N	Washington Naval Yard	DC
67254	Kingman Lake, Anacostia River, DC	NOS	8593545	38.895	-76.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	00:04:00	\N	1.2	00:22:00	\N	1.03	\N	\N	Kingman Lake	DC
67255	Kenilworth Aquatic Garden, Anacostia River, DC	NOS	8593909	38.91	-76.955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	00:10:00	\N	1.07	00:29:00	\N	1.05	\N	\N	Kenilworth Aquatic Garden	DC
67256	Franklin City, Virginia	NOS	8630055	38.0067	-75.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	03:00:00	\N	0.63	02:20:00	\N	0.22	\N	\N	Franklin City	VA
67257	Chincoteague Island, Blake Cove, Virginia	NOS	8630194	37.9517	-75.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	02:32:00	\N	0.56	01:51:00	\N	0.28	\N	\N	Chincoteague Island, Blake Cove	VA
67258	Chincoteague Island, Oyster Bay, Virginia	NOS	8630225	37.9417	-75.3467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	02:05:00	\N	0.56	01:44:00	\N	0.46	\N	\N	Chincoteague Island, Oyster Bay	VA
67259	Chincoteague Island, Lewis Creek, Virginia	NOS	8630229	37.9383	-75.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	01:38:00	\N	0.63	01:17:00	\N	0.4	\N	\N	Chincoteague Island, Lewis Creek	VA
67260	Chincoteague Channel (south end), Chincoteague Bay, Virginia (sub)	NOS	8630308	37.9067	-75.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:47:00	\N	0.69	00:39:00	\N	0.64	\N	\N	Chincoteague Channel (south end)	VA
67261	Harbor of Refuge, Virginia	NOS	8630316	37.9033	-75.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:35:00	\N	0.88	00:31:00	\N	0.73	\N	\N	Harbor of Refuge	VA
67262	Wishart Point, Bogues Bay, Virginia	NOS	8630371	37.8817	-75.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	01:13:00	\N	0.63	00:52:00	\N	0.77	\N	\N	Wishart Point, Bogues Bay	VA
67263	Assateague Beach, Toms Cove, Virginia	NOS	8630413	37.865	-75.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:48:00	\N	1.25	00:35:00	\N	1.08	\N	\N	Assateague Beach, Toms Cove	VA
67264	Wallops Island, Virginia	NOS	8630440	37.8417	-75.4783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	-00:04:00	\N	0.31	00:04:00	\N	1.06	\N	\N	Wallops Island	VA
67265	Gargathy Neck, Virginia	NOS	8630637	37.7767	-75.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	01:27:00	\N	0.63	01:31:00	\N	0.88	\N	\N	Gargathy Neck	VA
67266	Folly Creek, Metompkin Inlet, Virginia	NOS	8630839	37.6967	-75.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	01:12:00	\N	0.63	01:24:00	\N	0.97	\N	\N	Folly Creek, Metompkin Inlet	VA
67267	Metompkin Inlet, Virginia	NOS	8630901	37.6717	-75.595	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:44:00	\N	1.25	01:01:00	\N	1.08	\N	\N	Metompkin Inlet	VA
67268	Wachapreague, Wachapreague Channel, Virginia (sub)	NOS	8631044	37.60777777777778	-75.68583333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:56:00	\N	1.06	01:10:00	\N	1.19	\N	\N	Wachapreague, Wachapreague Channel	VA
67269	Revel Island, Revel Creek, Virginia	NOS	8631234	37.4967	-75.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:27:00	\N	1	00:35:00	\N	1.19	\N	\N	Revel Creek, Revel Island	VA
67270	Upshur Neck, south end, Virginia	NOS	8631287	37.4667	-75.8	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	01:14:00	\N	1.25	01:09:00	\N	1.31	\N	\N	Upshur Neck, south end	VA
67271	Great Machipongo Inlet (inside), Virginia	NOS	8631411	37.3933	-75.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:56:00	\N	1.25	01:05:00	\N	1.16	\N	\N	Great Machipongo Inlet (inside)	VA
67272	Sand Shoal Inlet (Coast Guard Station), Virginia	NOS	8631542	37.3017	-75.7783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	00:17:00	\N	1	00:32:00	\N	1.18	\N	\N	Sand Shoal Inlet (Coast Guard Station)	VA
67274	Smith Island (Coast Guard Station), Virginia	NOS	8631874	37.1233	-75.9117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65739	01:29:00	\N	1.25	00:52:00	\N	1.05	\N	\N	Smith Island (Coast Guard Station)	VA
67275	Fishermans Island, Chesapeake Bay, Virginia	NOS	8632085	37.0967	-75.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	00:11:00	\N	1.25	00:02:00	\N	1.19	\N	\N	Fishermans Island	VA
67276	Kiptopeke Beach, Chesapeake Bay, Virginia (sub)	NOS	8632200	37.16519	-75.98844444433848	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	00:32:00	\N	0.92	00:23:00	\N	1.01	\N	\N	Kiptopeke Beach	VA
67277	Old Plantation Light, Chesapeake Bay, Virginia	NOS	8632314	37.2333	-76.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	00:52:00	\N	0.83	00:33:00	\N	0.92	\N	\N	Old Plantation Light	VA
67278	Cape Charles Harbor (USCG Wharf), Chesapeake Bay, Virginia (sub)	NOS	8632366	37.2633	-76.02	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	01:03:00	\N	0.92	00:45:00	\N	0.9	\N	\N	Cape Charles Harbor	VA
67279	Gaskins Point, Occohannock Creek, Chesapeake Bay, Virginia (sub)	NOS	8632869	37.5567	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	03:13:00	\N	0.83	02:35:00	\N	0.66	\N	\N	Gaskins Point, Occohannock Creek	VA
67280	Harborton, Pungoteague Creek, Chesapeake Bay, Virginia	NOS	8633091	37.6667	-75.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	03:33:00	\N	0.83	03:11:00	\N	0.7	\N	\N	Harborton, Pungoteague Creek	VA
67281	Onancock, Onancock Creek, Chesapeake Bay, Virginia	NOS	8633214	37.7117	-75.7567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:19:00	\N	0.83	03:55:00	\N	0.71	\N	\N	Onancock, Onancock Creek	VA
67376	Davis Slough, North Carolina	NOS	8652737	35.7483	-75.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65821	-00:01:00	\N	0.29	00:09:00	\N	0.85	\N	\N	Davis Slough	NC
67282	Chesconessex Creek, Schooner Bay, Chesapeake Bay, Virginia	NOS	8633362	37.7633	-75.7733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	03:59:00	\N	1.25	03:41:00	\N	0.78	\N	\N	Chesconessex Creek, Schooner Bay	VA
67283	Watts Island, Chesapeake Bay, Virginia	NOS	8633451	37.7983	-75.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:12:00	\N	0.83	04:02:00	\N	0.64	\N	\N	Watts Island	VA
67284	Tangier Island, Chesapeake Bay, Virginia (sub)	NOS	8633532	37.8283	-75.9933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:16:00	\N	0.75	03:58:00	\N	0.6	\N	\N	Tangier Island	VA
67285	Guard Shore, Chesapeake Bay, Virginia	NOS	8633596	37.85	-75.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:47:00	\N	0.83	04:06:00	\N	0.9	\N	\N	Guard Shore	VA
67287	Alexandria, Potomac River, Virginia	NOS	8634214	38.805	-77.0383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-00:11:00	\N	1.33	00:18:00	\N	0.96	\N	\N	Alexandria, Va.	VA
67288	Quantico, Potomac River, Virginia	NOS	8634689	38.52	-77.2867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-02:04:00	\N	0.67	-00:52:00	\N	0.51	\N	\N	Quantico, Va.	VA
67289	Aquia Creek, Potomac River, Virginia	NOS	8634858	38.4183	-77.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-02:32:00	\N	0.67	-01:28:00	\N	0.48	\N	\N	Aquia Creek, Va.	VA
67290	Mathias Point, Potomac River, Virginia	NOS	8634892	38.3983	-77.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-04:56:00	\N	0.67	-04:00:00	\N	0.44	\N	\N	Mathias Point, Va.	VA
67291	Massaponax Sand & Gravel, Rappahannock River, Virginia	NOS	8635154	38.255	-77.41	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-00:41:00	\N	1.33	-00:39:00	\N	0.88	\N	\N	Massaponax	VA
67292	Hopyard Landing, Rappahannock River, Virginia	NOS	8635171	38.2433	-77.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-01:57:00	\N	0.67	-01:07:00	\N	0.75	\N	\N	Hopyard Landing	VA
67293	Rappahannock Bend, Virginia (sub)	NOS	8635257	38.2133	-77.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-02:30:00	\N	0.2	-01:35:00	\N	0.73	\N	\N	Park Turn	VA
67294	Port Royal, Rappahannock River, Virginia	NOS	8635299	38.1733	-77.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-03:02:00	\N	0.67	-02:19:00	\N	0.68	\N	\N	Port Royal	VA
67295	Mount Holly, Nomini Creek, Potomac River, Virginia	NOS	8635409	38.0983	-76.735	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-06:14:00	\N	0.67	-04:51:00	\N	0.54	\N	\N	Mount Holly, Nomini Creek, Va.	VA
67296	Ragged Point, Coles Neck, Potomac River, Virginia	NOS	8635485	38.1417	-76.6133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-07:03:00	\N	0.67	-05:35:00	\N	0.54	\N	\N	Ragged Point, Coles Neck, Va.	VA
67297	Saunders Wharf, Rappahannock River, Virginia	NOS	8635554	38.09	-77.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-04:41:00	\N	0.66	-03:53:00	\N	0.54	\N	\N	Saunders Wharf	VA
67298	Kinsale, Yeocomico River, Virginia	NOS	8635671	38.0317	-76.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-06:53:00	\N	0.67	-05:46:00	\N	0.44	\N	\N	Kinsale, Yeocomico River, Va.	VA
67299	Lewisetta, Potomac River, Virginia (sub)	NOS	8635750	37.99538888888889	-76.46461111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-07:31:00	\N	0.8	-06:19:00	\N	0.46	\N	\N	Lewisetta, Va.	VA
67300	Travis Point, Coan River, Potomac River, Virginia	NOS	8635762	37.9967	-76.4667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-07:05:00	\N	0.67	-06:00:00	\N	0.44	\N	\N	Travis Point, Coan River, Va.	VA
67301	Tappahannock, Rappahannock River, Virginia	NOS	8635881	37.93	-76.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	05:18:00	\N	0.83	04:40:00	\N	0.71	\N	\N	Tappahannock	VA
67302	Sunnybank, Little Wicomico River, Chesapeake Bay, Virginia	NOS	8635959	37.8867	-76.2667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	06:45:00	\N	0.3	06:41:00	\N	0.3	\N	\N	Sunnybank, Little Wicomico River	VA
67303	Wares Wharf, Rappahannock River, Virginia (sub)	NOS	8635985	37.8733	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	04:34:00	\N	0.33	04:04:00	\N	0.75	\N	\N	Wares Wharf	VA
67304	Glebe Point, Great Wicomico River, Chesapeake Bay, Virginia	NOS	8636046	37.8467	-76.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:37:00	\N	0.83	04:15:00	\N	0.49	\N	\N	Glebe Point, Great Wicomico River	VA
67305	Fleeton Point, Chesapeake Bay, Virginia	NOS	8636128	37.8133	-76.275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:14:00	\N	0.41	03:58:00	\N	0.41	\N	\N	Fleeton Point	VA
67306	Great Wicomico River Light, Chesapeake Bay, Virginia	NOS	8636142	37.805	-76.2683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:11:00	\N	0.41	03:58:00	\N	0.41	\N	\N	Great Wicomico River Light	VA
67307	Bayport, Rappahannock River, Virginia	NOS	8636261	37.755	-76.6733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	03:51:00	\N	0.83	03:22:00	\N	0.67	\N	\N	Bayport	VA
67308	Millenbeck, Corrotoman River, Rappahannock River, Virginia	NOS	8636458	37.6683	-76.4867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	03:05:00	\N	0.83	02:37:00	\N	0.55	\N	\N	Millenbeck, Corrotoman River	VA
67309	Wakema (Fraziers Ferry), Mattaponi River, Virginia	NOS	8636499	37.65	-76.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	03:57:00	\N	1.67	03:34:00	\N	1.41	\N	\N	Wakema (Fraziers Ferry), Mattaponi River	VA
67310	Urbanna, Rappahannock River, Virginia	NOS	8636522	37.65	-76.575	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	03:09:00	\N	0.83	02:50:00	\N	0.59	\N	\N	Urbanna	VA
67311	Northbury, Pamunkey River, Virginia	NOS	8636558	37.625	-77.1217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	06:18:00	\N	1.67	06:03:00	\N	1.37	\N	\N	Northbury	VA
67312	Windmill Point, Rappahannock River, Virginia (sub)	NOS	8636580	37.61611111111111	-76.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	02:14:00	\N	0.83	01:55:00	\N	0.49	\N	\N	Windmill Point	VA
67313	Windmill Point Light, Chesapeake Bay, Virginia	NOS	8636623	37.5967	-76.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	03:12:00	\N	0.41	02:48:00	\N	0.41	\N	\N	Windmill Point Light	VA
67314	Lester Manor, Pamunkey River, Virginia (sub)	NOS	8636653	37.5833	-76.99	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	05:00:00	\N	0.83	04:45:00	\N	1.05	\N	\N	Lester Manor	VA
67315	Mill Creek (Grey Point), Rappahannock River, Virginia	NOS	8636654	37.5833	-76.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	02:42:00	\N	0.83	02:28:00	\N	0.55	\N	\N	Mill Creek (Grey Point)	VA
67316	Jackson Creek, Deltaville, Piankatank River, Virginia	NOS	8636735	37.5483	-76.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	02:04:00	\N	0.83	01:36:00	\N	0.51	\N	\N	Jackson Creek, Deltaville	VA
67317	West Point, York River, Virginia	NOS	8636769	37.535	-76.7933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	02:38:00	\N	0.83	02:12:00	\N	1.14	\N	\N	West Point	VA
67318	Dixie, Piankatank River, Virginia	NOS	8636831	37.5067	-76.4167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	02:14:00	\N	0.83	01:34:00	\N	0.55	\N	\N	Dixie	VA
67319	Roane Point, York River, Virginia	NOS	8636969	37.4467	-76.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	01:50:00	\N	0.83	01:47:00	\N	1.14	\N	\N	Roane Point	VA
67320	Belleville, Mobjack Bay, Virginia	NOS	8637072	37.4117	-76.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:00:00	\N	0.83	-00:06:00	\N	1.02	\N	\N	Belleville	VA
67321	Wolf Trap Light, Chesapeake Bay, Virginia	NOS	8637144	37.39	-76.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:32:00	\N	0.83	-00:02:00	\N	0.67	\N	\N	Wolf Trap Light	VA
67322	Mobjack, East River, Mobjack Bay, Virginia	NOS	8637199	37.3733	-76.3467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:02:00	\N	0.83	-00:17:00	\N	0.98	\N	\N	Mobjack, East River	VA
67323	Browns Bay, Mobjack Bay, Virginia	NOS	8637444	37.3	-76.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	-00:03:00	\N	1.58	-00:11:00	\N	0.98	\N	\N	Browns Bay	VA
67324	Cheatham Annex, York River, Virginia	NOS	8637472	37.2917	-76.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:40:00	\N	0.83	00:48:00	\N	1.02	\N	\N	Cheatham Annex	VA
67325	Gloucester Point, York River, Virginia (sub)	NOS	8637624	37.2467	-76.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:11:00	\N	1	00:10:00	\N	0.98	\N	\N	Gloucester Point	VA
67326	Tue Marshes Light, York River, Virginia	NOS	8637663	37.235	-76.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:03:00	\N	0.83	00:03:00	\N	0.9	\N	\N	Tue Marshes Light	VA
67327	Goodwin Neck, Yorktown, York River, Virginia	NOS	8637686	37.23	-76.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:15:00	\N	0.83	00:18:00	\N	0.9	\N	\N	Yorktown, Goodwin Neck	VA
67328	Yorktown USCG Training Center, York River, Virginia (sub)	NOS	8637689	37.2265	-76.47880555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:15:00	\N	1.08	00:10:00	\N	0.95	\N	\N	Yorktown, USCG Training Center	VA
67329	Messick Point, Back River, Chesapeake Bay, Virginia	NOS	8638051	37.1083	-76.3183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:02:00	\N	0.97	-00:07:00	\N	0.97	\N	\N	Messick Point, Back River	VA
67330	Old Point Comfort, Hampton Roads, Virginia	NOS	8638288	37.0033	-76.315	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:09:00	\N	0.83	00:01:00	\N	1.02	\N	\N	Old Point Comfort	VA
67331	Newport News, James River, Virginia	NOS	8638379	36.9733	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:28:00	\N	0.83	00:29:00	\N	1.08	\N	\N	Newport News	VA
67332	Huntington Park, James River, Virginia	NOS	8638401	37.0133	-76.4583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:39:00	\N	0.92	00:38:00	\N	1.07	\N	\N	Huntington Park	VA
67333	Town Point, Nansemond River, Virginia	NOS	8638406	36.8833	-76.5083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:44:00	\N	0.83	00:37:00	\N	1.22	\N	\N	Town Point	VA
67334	Menchville, James River, Virginia	NOS	8638407	37.0817	-76.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	01:19:00	\N	0.83	01:03:00	\N	1.06	\N	\N	Menchville	VA
67335	Hollidays Point (Kings Highway bridge), Nansemond River, Virginia	NOS	8638409	36.8383	-76.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	01:03:00	\N	1.67	00:56:00	\N	1.25	\N	\N	Hollidays Point (Kings Highway bridge)	VA
67336	Smithfield, Pagan River, James River, Virginia	NOS	8638418	36.9833	-76.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	01:38:00	\N	0.83	01:34:00	\N	1.14	\N	\N	Smithfield, Pagan River	VA
67337	Burwell Bay, James River, Virginia (sub)	NOS	8638421	37.0567	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	01:39:00	\N	1.17	01:17:00	\N	1	\N	\N	Burwell Bay	VA
67338	Kingsmill, James River, Virginia (sub)	NOS	8638424	37.22	-76.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	02:26:00	\N	1.33	02:05:00	\N	0.94	\N	\N	Kingsmill	VA
67339	Scotland, James River, Virginia (sub)	NOS	8638433	37.185	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	03:13:00	\N	1.08	02:44:00	\N	0.78	\N	\N	Scotland	VA
67340	Wright Island Landing, Chickahominy River, Virginia	NOS	8638441	37.345	-76.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	05:03:00	\N	0.83	04:44:00	\N	0.9	\N	\N	Wright Island Landing	VA
67341	Ferry Point (bridge), Chickahominy River, Virginia	NOS	8638442	37.2633	-76.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	04:26:00	\N	0.83	04:01:00	\N	0.78	\N	\N	Ferry Point (bridge)	VA
67342	Claremont, James River, Virginia	NOS	8638449	37.2317	-76.9483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	04:25:00	\N	1.17	03:51:00	\N	0.76	\N	\N	Claremont	VA
67343	Sturgeon Point, James River, Virginia	NOS	8638455	37.3067	-77.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	05:09:00	\N	0.83	04:37:00	\N	0.86	\N	\N	Sturgeon Point	VA
67344	Jordan Point, James River, Virginia	NOS	8638476	37.3133	-77.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	06:39:00	\N	0.83	06:16:00	\N	1.02	\N	\N	Jordan Point	VA
67345	Haxall, James River, Virginia	NOS	8638478	37.3733	-77.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-04:53:00	\N	1.33	-04:10:00	\N	0.99	\N	\N	Haxall	VA
67346	Meadowville, James River, Virginia	NOS	8638486	37.3783	-77.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-04:17:00	\N	1.33	-03:46:00	\N	1.05	\N	\N	Meadowville	VA
67347	Puddledock Sand & Gravel, Appomattox River, Virginia (sub)	NOS	8638489	37.2667	-77.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-04:32:00	\N	1.07	-03:49:00	\N	1	\N	\N	Puddledock, Appomattox River	VA
67348	Chester, James River, Virginia	NOS	8638491	37.3833	-77.3783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-03:59:00	\N	0.67	-03:39:00	\N	1.02	\N	\N	Chester	VA
67349	Richmond River Locks, James River, Virginia (sub)	NOS	8638495	37.525	-77.42	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65775	-03:26:00	\N	1.33	-03:16:00	\N	1.16	\N	\N	Richmond (river locks)	VA
67350	Pig Point, Nansemond River, Virginia	NOS	8638514	36.9167	-76.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:40:00	\N	0.83	00:42:00	\N	1.05	\N	\N	Pig Point	VA
67351	Craney Island Light, Elizabeth River, Virginia	NOS	8638596	36.8917	-76.3383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:04:00	\N	0.83	00:18:00	\N	1.06	\N	\N	Craney Island Light	VA
67352	Norfolk, Elizabeth River, Virginia	NOS	8638654	36.8517	-76.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:20:00	\N	0.83	00:23:00	\N	1.14	\N	\N	Norfolk	VA
67353	Portsmouth, Naval Shipyard, Elizabeth River, Virginia (sub)	NOS	8638660	36.8217	-76.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:10:00	\N	1.17	00:08:00	\N	1.13	\N	\N	Portsmouth, Naval Shipyard	VA
67354	Little Creek NAB, Chesapeake Bay, Virginia	NOS	8638776	36.9117	-76.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	00:09:00	\N	1.17	00:08:00	\N	1.01	\N	\N	Little Creek, NAB	VA
67355	Buchanan Creek entrance, Lynnhaven Bay, Virginia	NOS	8638854	36.8617	-76.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	02:56:00	\N	0.83	02:02:00	\N	0.75	\N	\N	Buchanan Creek entrance	VA
67356	Bayville, Lynnhaven Bay, Virginia	NOS	8638867	36.8933	-76.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	02:48:00	\N	0.83	01:52:00	\N	0.67	\N	\N	Bayville	VA
67357	Virginia pilot's dock, Lynnhaven Inlet, Chesapeake Bay, Virginia	NOS	8638888	36.9067	-76.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	00:38:00	\N	1.08	00:40:00	\N	0.88	\N	\N	Lynnhaven Inlet, Virginia Pilots Dock	VA
67358	Long Creek, Lynnhaven Bay, Virginia	NOS	8638916	36.9033	-76.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	01:15:00	\N	1.08	01:15:00	\N	0.68	\N	\N	Long Creek	VA
67359	Brown Cove, Lynnhaven Bay, Virginia	NOS	8638922	36.875	-76.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	02:43:00	\N	0.83	02:05:00	\N	0.65	\N	\N	Brown Cove	VA
67360	Broad Bay Canal, Lynnhaven Bay, Virginia	NOS	8638923	36.9017	-76.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	02:00:00	\N	0.92	02:05:00	\N	0.56	\N	\N	Broad Bay Canal	VA
67361	Cape Henry, Virginia	NOS	8638999	36.93	-76.00669444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65817	00:36:00	\N	0.93	00:31:00	\N	0.96	\N	\N	Cape Henry	VA
67362	Virginia Beach, Virginia	NOS	8639168	36.8433	-75.9717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65817	00:16:00	\N	1.07	00:15:00	\N	1.07	\N	\N	Virginia Beach	VA
67363	Inside channel, Rudee Inlet, Virginia (sub)	NOS	8639207	36.8317	-75.9733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65817	00:16:00	\N	1	00:17:00	\N	1.02	\N	\N	Rudee Inlet, interior channel	VA
67364	Rudee Inlet entrance, Virginia	NOS	8639208	36.8317	-75.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65817	00:02:00	\N	0.86	00:02:00	\N	1.01	\N	\N	Rudee Inlet entrance	VA
67365	Rudee Heights, Lake Wesley, Virginia	NOS	8639214	36.825	-75.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65817	00:16:00	\N	1	00:18:00	\N	1.03	\N	\N	Rudee Heights, Lake Wesley	VA
67366	Lake Rudee, south end, Virginia	NOS	8639219	36.825	-75.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65817	00:19:00	\N	1.07	00:20:00	\N	1.05	\N	\N	Lake Rudee, south end	VA
67367	Money Point, South Bridge, Elizabeth River, Virginia (sub)	NOS	8639348	36.77830555555556	-76.30169444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:12:00	\N	1.17	00:16:00	\N	1.18	\N	\N	Money Point	VA
67369	Sandbridge, Virginia	NOS	8639428	36.6917	-75.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65817	00:07:00	\N	1.04	00:07:00	\N	1.04	\N	\N	Sandbridge	VA
67370	Kitty Hawk (ocean), North Carolina	NOS	8651605	36.1017	-75.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65817	00:02:00	\N	1.43	-00:01:00	\N	1.01	\N	\N	Kitty Hawk (ocean)	NC
67371	Jennettes Pier, Nags Head (ocean), North Carolina	NOS	8652226	35.91	-75.5917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65817	00:01:00	\N	1.43	-00:05:00	\N	1.04	\N	\N	Jennettes Pier, Nags Head (ocean)	NC
67372	Roanoke Sound Channel, North Carolina	NOS	8652591	35.7983	-75.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65821	01:17:00	\N	0.14	01:37:00	\N	0.47	\N	\N	Roanoke Sound Channel	NC
67373	Old House Channel, North Carolina	NOS	8652648	35.7767	-75.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65821	00:28:00	\N	0.21	00:34:00	\N	0.66	\N	\N	Old House Channel	NC
67374	Oregon Inlet Channel, North Carolina	NOS	8652657	35.7733	-75.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65821	-00:34:00	\N	0.43	-00:09:00	\N	1.23	\N	\N	Oregon Inlet Channel	NC
67375	Oregon Inlet Bridge, North Carolina	NOS	8652659	35.7733	-75.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65821	-00:55:00	\N	0.64	-00:17:00	\N	1.89	\N	\N	Oregon Inlet Bridge	NC
67377	Rodanthe, Pamlico Sound, North Carolina	NOS	8653215	35.595	-75.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65821	01:36:00	\N	0.69	02:03:00	\N	0.79	\N	\N	Rodanthe, Pamlico Sound	NC
67378	Hatteras (USCG Station), North Carolina (sub)	NOS	8654467	35.20863888888889	-75.70416666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	-00:13:00	\N	1.67	-00:15:00	\N	1.14	\N	\N	Hatteras (ocean)	NC
67379	Ocracoke, Ocracoke Island, North Carolina (sub)	NOS	8654792	35.115	-75.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:47:00	\N	0.5	00:15:00	\N	0.34	\N	\N	Ocracoke, Ocracoke Island	NC
67380	North River Bridge, North Carolina	NOS	8656225	34.7917	-76.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	03:08:00	\N	0.67	02:25:00	\N	0.59	\N	\N	North River Bridge	NC
67381	Newport River (Yacht Club), North Carolina	NOS	8656306	34.7683	-76.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	01:13:00	\N	1	01:03:00	\N	1.03	\N	\N	Newport River (Yacht Club)	NC
67382	Gallant Channel, North Carolina	NOS	8656451	34.7283	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:44:00	\N	1.25	00:49:00	\N	1.01	\N	\N	Gallant Channel	NC
67383	Duke Marine Lab, Beaufort, North Carolina (sub)	NOS	8656483	34.72	-76.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:36:00	\N	1.17	00:39:00	\N	1.05	\N	\N	Beaufort, Duke Marine Lab	NC
67384	Morehead City, North Carolina	NOS	8656496	34.7183	-76.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:27:00	\N	1.25	00:26:00	\N	1.04	\N	\N	Morehead City	NC
67385	Atlantic Beach Bridge, North Carolina	NOS	8656499	34.7183	-76.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	01:02:00	\N	0.83	00:48:00	\N	0.79	\N	\N	Atlantic Beach Bridge	NC
67386	Morehead City Harbor, North Carolina	NOS	8656502	34.72	-76.71083333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:37:00	\N	1.17	00:35:00	\N	1.04	\N	\N	Morehead City Harbor	NC
67387	Harkers Island Bridge, North Carolina	NOS	8656503	34.715	-76.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	02:31:00	\N	0.67	02:08:00	\N	0.52	\N	\N	Harkers Island Bridge	NC
67388	Beaufort, Taylor Creek, North Carolina	NOS	8656518	34.7117	-76.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:48:00	\N	1.17	00:52:00	\N	0.95	\N	\N	Beaufort, Taylor Creek	NC
67389	Lenoxville Point, North Carolina	NOS	8656539	34.7083	-76.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	01:11:00	\N	1	01:18:00	\N	0.8	\N	\N	Lenoxville Point	NC
67390	Channel Marker Lt. 59, North Carolina	NOS	8656554	34.7033	-76.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	01:27:00	\N	0.83	01:25:00	\N	0.66	\N	\N	Channel Marker Lt. 59	NC
67391	Coral Bay, Atlantic Beach, North Carolina	NOS	8656566	34.7	-76.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	02:14:00	\N	0.83	01:47:00	\N	0.53	\N	\N	Coral Bay, Atlantic Beach	NC
67392	Beaufort Inlet Channel Range, North Carolina	NOS	8656569	34.6983	-76.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:11:00	\N	1.67	00:07:00	\N	1.07	\N	\N	Beaufort Inlet Channel Range	NC
67393	Fort Macon, USCG Station, North Carolina	NOS	8656571	34.6983	-76.6817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:18:00	\N	1.25	00:17:00	\N	1.03	\N	\N	Fort Macon, USCG Station	NC
67394	Triple S Marina, Bogue Sd., North Carolina	NOS	8656583	34.695	-76.7117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:28:00	\N	1.17	00:35:00	\N	0.93	\N	\N	Triple ESS Marina, Bogue Sd.	NC
67395	Triple S Pier, Atlantic Beach, North Carolina (sub)	NOS	8656590	34.6933	-76.7117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:01:00	\N	1.25	-00:02:00	\N	1.23	\N	\N	Atlantic Beach	NC
67396	Cape Lookout (ocean), North Carolina	NOS	8656937	34.6083	-76.5283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	-00:22:00	\N	1.25	-00:22:00	\N	1.15	\N	\N	Cape Lookout (ocean)	NC
67397	New River Inlet, North Carolina	NOS	8657167	34.5333	-77.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:17:00	\N	0.83	00:16:00	\N	0.98	\N	\N	New River Inlet	NC
67398	Ocean City Beach (fishing pier), North Carolina	NOS	8657419	34.4517	-77.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	-00:01:00	\N	1.33	00:03:00	\N	1.4	\N	\N	Ocean City Beach (fishing pier)	NC
67399	Wrightsville Beach, North Carolina (sub)	NOS	8658163	34.21330555555556	-77.78669444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:23:00	\N	1.25	00:18:00	\N	1.27	\N	\N	Wrightsville Beach	NC
67400	Orton Point, Cape Fear River, North Carolina	NOS	8658501	34.0567	-77.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65834	-00:58:00	\N	1	-00:36:00	\N	0.98	\N	\N	Orton Point	NC
67401	Wilmington Beach, North Carolina	NOS	8658559	34.0317	-77.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:10:00	\N	1.25	00:18:00	\N	1.4	\N	\N	Wilmington Beach	NC
67402	Reaves Point, Cape Fear River, North Carolina	NOS	8658622	34.0033	-77.955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65834	-01:18:00	\N	1.07	-00:54:00	\N	0.96	\N	\N	Reaves Point	NC
67403	Sunny Point Army Base, Wharf no.1, Cape Fear River, North Carolina	NOS	8658654	33.99	-77.9567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65834	-01:45:00	\N	0.93	-01:03:00	\N	0.95	\N	\N	Sunny Point Army Base, Wharf no.1	NC
67404	Federal Point, Cape Fear River, North Carolina	NOS	8658715	33.9617	-77.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65834	-01:52:00	\N	0.93	-01:17:00	\N	0.94	\N	\N	Federal Point	NC
67405	Bald Head, Cape Fear River, North Carolina	NOS	8658901	33.88	-78.0017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65834	-02:43:00	\N	1.13	-02:06:00	\N	1.05	\N	\N	Bald Head	NC
67406	Southport, Cape Fear River, North Carolina (sub)	NOS	8659084	33.915	-78.0183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65834	-02:22:00	\N	1	-01:49:00	\N	0.99	\N	\N	Southport	NC
67407	Fort Caswell, Cape Fear River, North Carolina	NOS	8659086	33.8967	-78.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65834	-02:45:00	\N	1.25	-02:02:00	\N	1.03	\N	\N	Fort Caswell	NC
67408	Oak Island, Yaupon Beach, North Carolina (sub)	NOS	8659182	33.9017	-78.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	-00:05:00	\N	0.84	-00:05:00	\N	0.94	\N	\N	Oak Island, Yaupon Beach	NC
67409	Shallotte Inlet (Bowen Point), North Carolina	NOS	8659665	33.915	-78.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	00:55:00	\N	1	00:43:00	\N	0.91	\N	\N	Shallotte Inlet (Bowen Point)	NC
67410	Sunset Beach Pier, North Carolina (sub)	NOS	8659897	33.865	-78.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	-00:03:00	\N	1.11	00:02:00	\N	0.97	\N	\N	Sunset Beach Pier	NC
67411	Sunset Beach Bridge, North Carolina	NOS	8659899	33.88166666666701	-78.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	00:56:00	\N	0.84	00:34:00	\N	0.94	\N	\N	Sunset Beach Bridge	NC
67412	Little River Neck, north end, South Carolina	NOS	8660098	33.87	-78.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	00:46:00	\N	0.84	00:32:00	\N	0.92	\N	\N	Little River Neck, north end	SC
67413	Little River (town), South Carolina	NOS	8660121	33.87	-78.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:39:00	\N	0.79	00:13:00	\N	0.84	\N	\N	Little River (town)	SC
67414	Dunn Sound, north end, South Carolina	NOS	8660147	33.86	-78.58	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	00:40:00	\N	0.84	00:25:00	\N	0.93	\N	\N	Dunn Sound, north end	SC
67415	Dunn Sound, Little River Inlet, South Carolina	NOS	8660148	33.8583	-78.57	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	00:41:00	\N	0.8	00:15:00	\N	0.91	\N	\N	Dunn Sound, Little River Inlet	SC
67416	Nixon Crossroads, South Carolina	NOS	8660166	33.855	-78.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:51:00	\N	0.68	00:27:00	\N	0.78	\N	\N	Nixon Crossroads	SC
67417	Dunn Sound, west end, South Carolina	NOS	8660195	33.8517	-78.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	00:36:00	\N	1	00:29:00	\N	0.96	\N	\N	Dunn Sound, west end	SC
67418	Cherry Grove (inside), South Carolina	NOS	8660265	33.835	-78.6333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	00:44:00	\N	0.74	00:40:00	\N	0.92	\N	\N	Cherry Grove (inside)	SC
67419	Hog Inlet Pier, South Carolina	NOS	8660266	33.8367	-78.6067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	-00:07:00	\N	0.9	-00:06:00	\N	0.99	\N	\N	Hog Inlet Pier	SC
67420	Conway, RR. bridge, Waccamaw River, South Carolina	NOS	8660275	33.835	-79.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	07:28:00	\N	0.74	07:19:00	\N	0.25	\N	\N	Conway, RR. bridge	SC
67421	Grahamville, Waccamaw River, South Carolina	NOS	8660315	33.83	-78.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	08:32:00	\N	0.58	08:17:00	\N	0.2	\N	\N	Grahamville	SC
67422	Myrtle Beach Airport, South Carolina	NOS	8660401	33.82	-78.7183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:47:00	\N	0.84	01:09:00	\N	0.56	\N	\N	Myrtle Beach Airport	SC
67423	Pitch Landing, Waccamaw River, South Carolina	NOS	8660475	33.8	-79.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	07:30:00	\N	0.74	07:25:00	\N	0.2	\N	\N	Pitch Landing	SC
67424	North Myrtle Beach, South Carolina	NOS	8660642	33.766700744628906	-78.81500244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	03:12:00	\N	0.84	02:15:00	\N	0.36	\N	\N	North Myrtle Beach, ICWW	SC
67425	Keysfield, Waccamaw River, South Carolina	NOS	8660831	33.745	-79.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	06:20:00	\N	0.89	06:09:00	\N	0.28	\N	\N	Keysfield	SC
67426	Myrtle Beach, Combination Bridge, South Carolina	NOS	8660854	33.7133	-78.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	04:18:00	\N	0.89	02:56:00	\N	0.35	\N	\N	Myrtle Beach, Combination Bridge	SC
67427	Socastee Bridge, South Carolina	NOS	8660983	33.6867	-79.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	04:41:00	\N	0.74	03:27:00	\N	0.41	\N	\N	Socastee Bridge	SC
67428	Enterprise Landing, Waccamaw River, South Carolina	NOS	8661067	33.6667	-79.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	05:35:00	\N	0.37	05:01:00	\N	0.38	\N	\N	Enterprise Landing	SC
67429	Yauhannah Bridge, Great Pee Dee River, South Carolina	NOS	8661093	33.66	-79.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	05:24:00	\N	0.68	04:33:00	\N	0.33	\N	\N	Yauhannah Bridge	SC
67430	Little Bull Creek entrance, Bull Creek, Waccamaw River, South Carolina	NOS	8661119	33.6017	-79.1183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	04:43:00	\N	0.84	03:59:00	\N	0.46	\N	\N	Little Bull Creek entrance, Bull Creek	SC
67431	Lower Topsaw Landing, Great Pee Dee River, South Carolina	NOS	8661299	33.6083	-79.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	05:20:00	\N	0.53	04:48:00	\N	0.2	\N	\N	Lower Topsaw Landing	SC
67432	Bull Creek entrance, Waccamaw River, South Carolina	NOS	8661347	33.5967	-79.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	04:22:00	\N	0.79	03:36:00	\N	0.48	\N	\N	Bull Creek entrance	SC
67433	Rhems, Black Mingo Creek, Black River, Great Pee Dee River, South Carolina	NOS	8661367	33.6033	-79.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	06:13:00	\N	1.05	06:00:00	\N	0.36	\N	\N	Rhems, Black Mingo Creek, Black River	SC
67434	Wachesaw Landing, Waccamaw River, South Carolina	NOS	8661493	33.56	-79.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	04:00:00	\N	0.84	03:11:00	\N	0.53	\N	\N	Wachesaw Landing	SC
67435	Captain Alex's Marina, Parsonage Creek, Murrells Inlet, South Carolina	NOS	8661529	33.5517	-79.0367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	01:28:00	\N	0.68	00:57:00	\N	0.85	\N	\N	Captain Alex's Marina, Parsonage Creek	SC
67436	Holly Grove Plantation, Great Pee Dee River, South Carolina	NOS	8661558	33.5517	-79.1767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	04:12:00	\N	0.68	03:20:00	\N	0.5	\N	\N	Holly Grove Plantation	SC
67437	Smith's Dock, Murrells Inlet, South Carolina	NOS	8661559	33.545	-79.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	01:36:00	\N	0.95	01:01:00	\N	0.86	\N	\N	Smith's Dock	SC
67438	Divine's Dock, Murrells Inlet, South Carolina	NOS	8661582	33.5417	-79.0283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	01:18:00	\N	0.84	00:40:00	\N	0.84	\N	\N	Divine's Dock	SC
67439	Winea Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661593	33.535	-79.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	04:39:00	\N	0.84	04:23:00	\N	0.47	\N	\N	Winea Plantation, Black River	SC
67440	Allston Creek, Murrells Inlet, South Carolina	NOS	8661608	33.5317	-79.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	01:32:00	\N	0.95	00:52:00	\N	0.84	\N	\N	Allston Creek	SC
67441	Oaks Creek, 0.5 mi. above entrance, Murrells Inlet, South Carolina	NOS	8661609	33.53	-79.0433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	01:03:00	\N	0.95	00:38:00	\N	0.85	\N	\N	Oaks Creek, 0.5 mi. above entrance	SC
67442	Black River (south of Dunbar), Great Pee Dee River, South Carolina	NOS	8661686	33.5117	-79.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	04:09:00	\N	0.89	03:29:00	\N	0.47	\N	\N	Black River (south of Dunbar)	SC
67443	Mt. Pleasant Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661734	33.495	-79.4617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	06:04:00	\N	1.05	05:38:00	\N	0.37	\N	\N	Mt. Pleasant Plantation, Black River	SC
67444	Arundel Plantation, Great Pee Dee River, South Carolina	NOS	8661741	33.4833	-79.1783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	03:39:00	\N	0.79	02:38:00	\N	0.53	\N	\N	Arundel Plantation	SC
67445	South of Sam Worth Game Management Area, Great Pee Dee River, South Carolina	NOS	8661866	33.4683	-79.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	03:06:00	\N	0.68	02:21:00	\N	0.69	\N	\N	South of Sam Worth Game Management Area	SC
67446	Litchfield Beach bridge, South Carolina	NOS	8661867	33.4717	-79.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	03:02:00	\N	0.75	01:10:00	\N	0.58	\N	\N	Litchfield Beach bridge	SC
67447	Carr Creek, 1 mile above entrance, Great Pee Dee River, South Carolina	NOS	8661873	33.465	-79.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	03:00:00	\N	0.84	02:13:00	\N	0.69	\N	\N	Carr Creek, 1 mile above entrance	SC
67448	Weymouth Plantation, Great Pee Dee River, South Carolina	NOS	8661913	33.455	-79.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	03:02:00	\N	0.89	02:16:00	\N	0.68	\N	\N	Weymouth Plantation	SC
67449	Midway Inlet North, Pawleys Island, South Carolina	NOS	8661947	33.4483	-79.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	00:42:00	\N	1	00:16:00	\N	0.87	\N	\N	Midway Inlet North, Pawleys Island	SC
67450	Hagley Landing, Waccamaw River, South Carolina	NOS	8661991	33.435	-79.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	02:53:00	\N	0.79	01:58:00	\N	0.67	\N	\N	Hagley Landing	SC
67451	Cumberland, Sampit River, South Carolina	NOS	8662216	33.37	-79.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	02:29:00	\N	0.74	02:42:00	\N	0.77	\N	\N	Cumberland	SC
67452	Jacobs Wharf, Sampit River, South Carolina	NOS	8662237	33.3633	-79.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	02:22:00	\N	0.74	02:15:00	\N	0.73	\N	\N	Jacobs Wharf	SC
67453	Jamestown Bridge, Santee River, South Carolina	NOS	8662405	33.305	-79.6783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	06:30:00	\N	0.37	04:15:00	\N	0.22	\N	\N	Jamestown Bridge, Santee River	SC
67454	South Island Ferry, Intracoastal Waterway, South Carolina	NOS	8662549	33.2517	-79.2683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:25:00	\N	0.74	00:54:00	\N	0.71	\N	\N	South Island Ferry, Intracoastal Waterway	SC
67455	Pleasant Hill Landing, Santee River, South Carolina	NOS	8662670	33.245	-79.5217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	03:47:00	\N	0.74	02:28:00	\N	0.45	\N	\N	Pleasant Hill Landing, Santee River	SC
67456	South Island Plantation (C.G. Station), Winyah Bay, South Carolina (sub)	NOS	8662746	33.235	-79.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:36:00	\N	0.84	00:35:00	\N	0.74	\N	\N	South Island Plantation (C.G. Station)	SC
67457	Georgetown Lighthouse, South Carolina	NOS	8662747	33.2233	-79.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:25:00	\N	1.05	00:26:00	\N	0.75	\N	\N	Georgetown Lighthouse	SC
67458	North Santee Bridge, South Carolina	NOS	8662793	33.21	-79.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:54:00	\N	0.74	01:09:00	\N	0.72	\N	\N	North Santee Bridge	SC
67459	Minim Creek ent., ICWW, North Santee Bay, South Carolina	NOS	8662796	33.195	-79.275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:00:00	\N	0.95	00:16:00	\N	0.77	\N	\N	Minim Creek ent., ICWW, North Santee Bay	SC
67460	U.S. Highway 17 bridge, South Santee River, South Carolina	NOS	8662799	33.185	-79.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:43:00	\N	0.95	00:43:00	\N	0.78	\N	\N	U.S. Highway 17 bridge, South Santee River	SC
67461	Georgetown, Sampit River, South Carolina	NOS	8662926	33.3617	-79.28	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	02:09:00	\N	0.79	01:25:00	\N	0.71	\N	\N	Georgetown	SC
67462	Cape Romain, South Carolina	NOS	8663101	33.025	-79.3483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:17:00	\N	0.89	-00:22:00	\N	0.89	\N	\N	Cape Romain	SC
67463	Cedar Island, North Santee Bay, South Carolina	NOS	8663261	33.14	-79.245	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:17:00	\N	0.95	-00:03:00	\N	0.8	\N	\N	Cedar Island, North Santee Bay	SC
67464	Cedar Island Point, South Santee River, South Carolina	NOS	8663381	33.12	-79.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:08:00	\N	0.79	-00:16:00	\N	0.78	\N	\N	Cedar Island Point, South Santee River	SC
67465	Casino Creek, ICWW, South Carolina	NOS	8663461	33.1083	-79.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:53:00	\N	0.79	00:40:00	\N	0.87	\N	\N	Casino Creek, ICWW	SC
67466	Quinby Creek bridge, East Branch, Cooper River, South Carolina	NOS	8663535	33.095	-79.8083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	04:12:00	\N	1.42	04:37:00	\N	0.56	\N	\N	Quinby Creek bridge, East Branch	SC
67467	Pimlico, West Branch, Cooper River, South Carolina	NOS	8663539	33.095	-79.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	03:53:00	\N	0.89	03:19:00	\N	0.34	\N	\N	Pimlico, West Branch	SC
67468	McClellanville, Jeremy Creek, Bulls Bay, South Carolina	NOS	8663618	33.0783	-79.46	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:24:00	\N	0.89	00:31:00	\N	0.93	\N	\N	McClellanville, Jeremy Creek	SC
67469	Old Rice Mill, West Branch, Cooper River, South Carolina	NOS	8663631	33.0783	-79.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	02:51:00	\N	1.63	02:56:00	\N	0.53	\N	\N	Old Rice Mill, West Branch	SC
67470	Richmond Plantation, East Branch, Cooper River, South Carolina	NOS	8663665	33.0767	-79.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	03:43:00	\N	1.37	03:43:00	\N	0.54	\N	\N	Richmond Plantation, East Branch	SC
67471	Bonneau Ferry, East Branch, Cooper River, South Carolina	NOS	8663731	33.0717	-79.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	02:49:00	\N	1.79	03:14:00	\N	0.63	\N	\N	Bonneau Ferry, East Branch	SC
67472	Dupont, Dean Hall, Cooper River, South Carolina	NOS	8663757	33.0583	-79.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	02:07:00	\N	1.58	02:21:00	\N	0.68	\N	\N	Dupont, Dean Hall	SC
67473	Blessing Plantation, East Branch, Cooper River, South Carolina	NOS	8663781	33.055	-79.88	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	03:20:00	\N	1.32	03:24:00	\N	0.56	\N	\N	Blessing Plantation, East Branch	SC
67474	Buck Hall, Awendaw Creek, Bulls Bay, South Carolina	NOS	8663858	33.04	-79.56	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:37:00	\N	1	00:22:00	\N	0.95	\N	\N	Buck Hall, Awendaw Creek	SC
67475	Harbor River entrance, Bulls Bay, South Carolina	NOS	8663899	33.0333	-79.535	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:36:00	\N	0.95	00:03:00	\N	0.93	\N	\N	Harbor River entrance	SC
67476	General Dynamics Pier, Cooper River, South Carolina (sub)	NOS	8664022	33.0083	-79.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:24:00	\N	1.11	01:40:00	\N	0.84	\N	\N	General Dynamics Pier	SC
67477	Five Fathom Creek entrance, Bulls Bay, South Carolina	NOS	8664099	33	-79.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:07:00	\N	0.95	-00:06:00	\N	0.93	\N	\N	Five Fathom Creek entrance	SC
67478	Back River Reservoir, West Branch, Cooper River, South Carolina	NOS	8664131	32.995	-79.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	05:57:00	\N	0.79	05:44:00	\N	0.17	\N	\N	Back River Reservoir, West Branch	SC
67479	Moores Landing, ICWW, Sewee Bay, South Carolina	NOS	8664442	32.9367	-79.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:08:00	\N	1	00:11:00	\N	0.96	\N	\N	Moores Landing, ICWW, Sewee Bay	SC
67480	Snow Point, 0.4 mi. North of, Cooper River, South Carolina	NOS	8664515	32.9483	-79.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:45:00	\N	1.05	00:59:00	\N	1.02	\N	\N	Snow Point, 0.4 mi. North of	SC
67481	Bacon Bridge, Ashley River, South Carolina	NOS	8664531	32.9583	-80.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	03:41:00	\N	0.16	02:45:00	\N	0.39	\N	\N	Bacon Bridge	SC
67482	Greggs Landing, Matceba Gardens, Ashley River, South Carolina	NOS	8664532	32.9317	-80.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:42:00	\N	1.16	02:06:00	\N	1.15	\N	\N	Greggs Landing, Mateeba Gardens	SC
67483	Yeamans Hall, Goose Creek, Cooper River, South Carolina	NOS	8664541	32.925	-79.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:31:00	\N	1.37	02:06:00	\N	1	\N	\N	Yeamans Hall, Goose Creek	SC
67484	Cainhoy, Wando River, South Carolina (sub)	NOS	8664545	32.9267	-79.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:31:00	\N	1	00:49:00	\N	1.15	\N	\N	Cainhoy	SC
67485	Woodville, Wando River, South Carolina	NOS	8664582	32.92	-79.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:22:00	\N	1.19	02:07:00	\N	1.19	\N	\N	Woodville	SC
67486	Hanahan, Turkey Creek, Goose Creek, Cooper River, South Carolina	NOS	8664589	32.9183	-80.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	02:13:00	\N	0.79	02:51:00	\N	0.9	\N	\N	Hanahan, Turkey Creek, Goose Creek	SC
67487	Big Paradise Island, Wando River, South Carolina	NOS	8664611	32.915	-79.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:52:00	\N	1.11	01:24:00	\N	1.24	\N	\N	Big Paradise Island	SC
67488	Wharf Creek entrance, Bulls Bay, South Carolina	NOS	8664621	32.9133	-79.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:08:00	\N	0.95	00:12:00	\N	0.97	\N	\N	Wharf Creek entrance	SC
67489	Clouter Creek, north entrance, Cooper River, South Carolina	NOS	8664688	32.9067	-79.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:33:00	\N	1	00:45:00	\N	1.04	\N	\N	Clouter Creek, north entrance	SC
67490	Nowell Creek, Wando River, South Carolina	NOS	8664701	32.9	-79.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:23:00	\N	1.05	00:47:00	\N	1.13	\N	\N	Nowell Creek	SC
67491	Parker Island, Horlbeck Creek, Wando River, South Carolina	NOS	8664782	32.885	-79.845	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:27:00	\N	1.11	00:43:00	\N	1.09	\N	\N	Parker Island, Horlbeck Creek	SC
67492	Price Creek, North Capers Island, South Carolina	NOS	8664801	32.8817	-79.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:21:00	\N	0.89	-00:01:00	\N	0.92	\N	\N	Price Creek, North Capers Island	SC
67493	Magnolia Gardens, Ashley River, South Carolina	NOS	8664841	32.8767	-80.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:54:00	\N	1.05	01:02:00	\N	1.1	\N	\N	Magnolia Gardens	SC
67494	Old Capers Landing, Santee Pass, Capers Island, South Carolina	NOS	8664878	32.87	-79.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:09:00	\N	0.84	00:21:00	\N	0.94	\N	\N	Old Capers Landing, Santee Pass, Capers Island	SC
67495	Capers Creek, South Capers Island, South Carolina (sub)	NOS	8664941	32.8567	-79.7067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:15:00	\N	0.95	00:04:00	\N	0.94	\N	\N	Capers Creek, South Capers Island	SC
67496	Clouter Creek, south entrance, Cooper River, South Carolina	NOS	8664945	32.86	-79.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:19:00	\N	1	00:25:00	\N	1.02	\N	\N	Clouter Creek, south entrance	SC
67497	North Dewees Island, Capers Inlet, South Carolina	NOS	8664992	32.85	-79.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:11:00	\N	0.95	-00:02:00	\N	0.91	\N	\N	North Dewees Island, Capers Inlet	SC
67498	Drayton, Bee's Ferry, Ashley River, South Carolina	NOS	8665002	32.8483	-80.0517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:39:00	\N	1.05	00:41:00	\N	1.09	\N	\N	Drayton, Bee's Ferry	SC
67499	I-526 bridge, Ashley River, South Carolina (sub)	NOS	8665099	32.8367	-80.0217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:29:00	\N	1.11	00:30:00	\N	1.08	\N	\N	I-526 bridge	SC
67500	Cosgrove Bridge, Ashley River, South Carolina	NOS	8665101	32.835	-79.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:17:00	\N	1.05	00:25:00	\N	1.07	\N	\N	Cosgrove Bridge	SC
67501	South Dewees Island, Dewees Inlet, South Carolina	NOS	8665111	32.8333	-79.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:17:00	\N	0.89	-00:01:00	\N	0.94	\N	\N	South Dewees Island, Dewees Inlet	SC
67502	Duck Island, Ashley River, South Carolina	NOS	8665145	32.83	-79.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:17:00	\N	1.06	00:23:00	\N	1.06	\N	\N	Duck Island	SC
67503	Hamlin Sound, South Carolina	NOS	8665167	32.8267	-79.7867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:13:00	\N	1	00:13:00	\N	0.99	\N	\N	Hamlin Sound	SC
67504	Hobcaw Point, Wando River, South Carolina	NOS	8665192	32.8217	-79.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:13:00	\N	0.95	00:19:00	\N	1.03	\N	\N	Hobcaw Point	SC
67505	Canaday Landing, south of, Edisto River, South Edisto River, South Carolina	NOS	8665257	32.8133	-80.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	05:34:00	\N	0.32	04:20:00	\N	0.13	\N	\N	Canaday Landing, south of, Edisto River	SC
67506	Hamlin Creek, Isle of Palms, South Carolina	NOS	8665387	32.7867	-79.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:12:00	\N	1	00:06:00	\N	0.97	\N	\N	Hamlin Creek, Isle of Palms	SC
67507	Folly Creek, Hwy. 171 bridge, South Carolina	NOS	8665424	32.675	-79.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:06:00	\N	1	00:25:00	\N	1.04	\N	\N	Folly Creek, Hwy. 171 bridge	SC
67508	Shem Creek, South Carolina	NOS	8665426	32.7933	-79.8817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:03:00	\N	1	-00:02:00	\N	0.99	\N	\N	Shem Creek	SC
67509	Limehouse Bridge, Stono River, South Carolina	NOS	8665475	32.7867	-80.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:34:00	\N	1.08	01:43:00	\N	1.08	\N	\N	Limehouse Bridge	SC
67510	Isle of Palms Pier, South Carolina	NOS	8665494	32.7833	-79.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:28:00	\N	0.89	-00:25:00	\N	0.95	\N	\N	Isle of Palms Pier	SC
67511	South Ashley Bridge, Ashley River, South Carolina	NOS	8665495	32.7833	-79.9567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:07:00	\N	1.05	00:04:00	\N	1.01	\N	\N	South Ashley Bridge	SC
67512	Breach Inlet, Isle of Palms, South Carolina	NOS	8665552	32.7767	-79.8117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:14:00	\N	1.05	-00:05:00	\N	0.95	\N	\N	Breach Inlet, Isle of Palms	SC
67513	Ben Sawyer Bridge, ICWW, South Carolina	NOS	8665567	32.7733	-79.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:12:00	\N	1	00:06:00	\N	0.97	\N	\N	Ben Sawyer Bridge, ICWW	SC
67514	Sandblasters, Pennys Creek, Stono River, South Carolina	NOS	8665589	32.77	-80.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:18:00	\N	1.02	01:30:00	\N	1.02	\N	\N	Sandblasters, Pennys Creek	SC
67515	Pennys Creek, west entrance, Stono River, South Carolina	NOS	8665599	32.7683	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:20:00	\N	1.32	01:23:00	\N	1.03	\N	\N	Pennys Creek, west entrance	SC
67516	Wappoo Creek, highway bridge, Ashley River, South Carolina	NOS	8665613	32.7667	-79.9733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:22:00	\N	0.99	00:22:00	\N	0.99	\N	\N	Wappoo Creek, highway bridge	SC
67517	The Cove, Fort Moultrie, South Carolina	NOS	8665637	32.7633	-79.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:10:00	\N	0.95	-00:01:00	\N	0.97	\N	\N	The Cove, Fort Moultrie	SC
67518	Elliott Cut entrance, Stono River, South Carolina	NOS	8665641	32.7633	-80.0017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:52:00	\N	1.16	00:48:00	\N	0.99	\N	\N	Elliott Cut entrance	SC
67519	Fort Johnson, South Carolina	NOS	8665726	32.7517	-79.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:02:00	\N	1	-00:05:00	\N	0.97	\N	\N	Fort Johnson	SC
67520	Fort Sumter, South Carolina	NOS	8665728	32.7533	-79.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:01:00	\N	0.95	00:02:00	\N	0.97	\N	\N	Fort Sumter	SC
67521	Jacksonboro Camp, South Edisto River, South Carolina	NOS	8665737	32.7533	-80.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	03:34:00	\N	0.86	02:46:00	\N	0.59	\N	\N	Jacksonboro Camp	SC
67522	Church Flats, Stono River, South Carolina	NOS	8665763	32.7467	-80.165	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:14:00	\N	1.16	01:51:00	\N	1.22	\N	\N	Church Flats	SC
67523	James Island Creek, 1 mi. above ent., Ashley River, South Carolina	NOS	8665775	32.745	-79.9483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:07:00	\N	1.05	00:17:00	\N	1.02	\N	\N	James Island Creek, 1 mi. above ent.	SC
67524	Ashepoo, Ashepoo River, South Carolina	NOS	8665814	32.7433	-80.5567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	04:00:00	\N	1.05	04:18:00	\N	0.34	\N	\N	Ashepoo	SC
67525	Penny Creek, south of, Edisto River, South Edisto River, South Carolina	NOS	8666017	32.715	-80.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	02:43:00	\N	1.18	02:10:00	\N	0.73	\N	\N	Penny Creek, south of, Edisto River	SC
67526	Church Creek bridge, Wadmalaw River, South Carolina	NOS	8666029	32.715	-80.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:58:00	\N	1	01:58:00	\N	1.3	\N	\N	Church Creek bridge	SC
67527	Johns Island, Church Creek, Wadmalaw River, South Carolina	NOS	8666101	32.7067	-80.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:00:00	\N	1.16	01:43:00	\N	1.3	\N	\N	Johns Island, Church Creek	SC
67528	Lower Toogoodoo Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8666131	32.7033	-80.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:47:00	\N	1.26	01:26:00	\N	1.29	\N	\N	Lower Toogoodoo Creek, 2 mi. above entrance	SC
67529	Cuckolds Creek, Combahee River, South Carolina	NOS	8666166	32.7133	-80.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	04:12:00	\N	1.73	04:45:00	\N	0.51	\N	\N	Cuckolds Creek	SC
67530	Hope Creek, Edisto River, South Edisto River, South Carolina	NOS	8666167	32.7	-80.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	02:13:00	\N	1.05	01:46:00	\N	0.82	\N	\N	Hope Creek, Edisto River	SC
67531	Yonges Island, Wadmalaw River, South Carolina	NOS	8666217	32.695	-80.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:45:00	\N	1.16	01:22:00	\N	1.24	\N	\N	Yonges Island	SC
67532	Oak Branch, Bohicket Creek, North Edisto River, South Carolina	NOS	8666282	32.6833	-80.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:57:00	\N	1.16	01:39:00	\N	1.26	\N	\N	Oak Branch, Bohicket Creek	SC
67533	Abbapoola Creek entrance, Stono River, South Carolina	NOS	8666283	32.6767	-80.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:02:00	\N	0.95	00:17:00	\N	1.01	\N	\N	Abbapoola Creek entrance	SC
67534	Bluff Plantation, Combahee River, South Carolina	NOS	8666359	32.6833	-80.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	03:51:00	\N	1.59	04:17:00	\N	0.5	\N	\N	Bluff Plantation	SC
67535	Willtown Bluff, Edisto River, South Edisto River, South Carolina	NOS	8666367	32.6817	-80.4167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	02:03:00	\N	1	01:34:00	\N	0.83	\N	\N	Willtown Bluff, Edisto River	SC
67536	Toogoodoo Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8666433	32.6683	-80.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:38:00	\N	1.05	01:06:00	\N	1.21	\N	\N	Toogoodoo Creek, 2 mi. above entrance	SC
67537	Folly River, north, Folly Island, South Carolina	NOS	8666467	32.67	-79.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:05:00	\N	0.95	00:24:00	\N	1.03	\N	\N	Folly River, north, Folly Island	SC
67538	Park Island, Tom Point Creek, North Edisto River, South Carolina	NOS	8666552	32.665	-80.3167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:34:00	\N	1.21	01:19:00	\N	1.21	\N	\N	Park Island, Tom Point Creek	SC
67539	Dawho River, South Edisto River, South Carolina	NOS	8666616	32.6567	-80.3917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:31:00	\N	0.95	01:07:00	\N	0.89	\N	\N	Dawho River	SC
67540	Folly River Bridge, Folly Island, South Carolina	NOS	8666652	32.6617	-79.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:03:00	\N	0.95	00:21:00	\N	1.01	\N	\N	Folly River Bridge, Folly Island	SC
67541	U.S. 17 Bridge, Combahee River, South Carolina	NOS	8666659	32.6517	-80.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	02:29:00	\N	1.14	03:00:00	\N	0.71	\N	\N	U.S. 17 Bridge	SC
67542	Bluff Point, Wadmalaw River, South Carolina	NOS	8666699	32.6467	-80.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:31:00	\N	1.11	00:58:00	\N	1.17	\N	\N	Bluff Point	SC
67543	Airy Hall Plantation, Ashepoo River, South Carolina	NOS	8666749	32.6317	-80.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:59:00	\N	1	01:57:00	\N	0.6	\N	\N	Airy Hall Plantation	SC
67544	Snake Island, Stono River, South Carolina	NOS	8666767	32.64	-80.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:12:00	\N	1	00:01:00	\N	1.01	\N	\N	Snake Island	SC
67545	Leadenwah Creek, 3 mi. above entrance, North Edisto River, South Carolina	NOS	8666775	32.6367	-80.2017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:23:00	\N	1.11	00:54:00	\N	1.15	\N	\N	Leadenwah Creek, 3 mi. above entrance	SC
67546	Dawho Bridge, Dawho River, North Edisto River, South Carolina	NOS	8666799	32.6367	-80.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:47:00	\N	1.11	00:56:00	\N	1.18	\N	\N	Dawho Bridge, Dawho River	SC
67547	Ho-Non-Wah Boy Scout Camp, Bohicket Creek, North Edisto River, South Carolina	NOS	8666918	32.625	-80.1667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:30:00	\N	1.11	00:49:00	\N	1.13	\N	\N	Ho-Non-Wah Boy Scout Camp, Bohicket Creek	SC
67548	Brickyard Ferry, swing bridge, Ashepoo River, South Carolina	NOS	8667017	32.6133	-80.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:34:00	\N	0.86	01:27:00	\N	0.71	\N	\N	Brickyard Ferry, swing bridge	SC
67549	Kiawah River Bridge, South Carolina	NOS	8667062	32.6033	-80.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:06:00	\N	0.89	00:14:00	\N	1.07	\N	\N	Kiawah River Bridge	SC
67550	Pine Landing, South Edisto River, South Carolina	NOS	8667067	32.6033	-80.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:45:00	\N	0.95	00:29:00	\N	0.92	\N	\N	Pine Landing	SC
67551	Wiggins, Chehaw River, Combahee River, South Carolina	NOS	8667074	32.6017	-80.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:20:00	\N	1.18	01:45:00	\N	0.88	\N	\N	Wiggins, Chehaw River	SC
67552	Steamboat Landing, Steamboat Creek, North Edisto River, South Carolina	NOS	8667075	32.6033	-80.2867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:25:00	\N	1.11	00:45:00	\N	1.15	\N	\N	Steamboat Landing, Steamboat Creek	SC
67553	Tulifiny River, I-95 bridge, Broad River, South Carolina	NOS	8667076	32.6017	-80.9033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	03:31:00	\N	0.73	03:24:00	\N	0.73	\N	\N	Tulifiny River, I-95 bridge	SC
67554	Rockville, Bohicket Creek, North Edisto River, South Carolina	NOS	8667089	32.5983	-80.195	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:07:00	\N	1.11	00:19:00	\N	1.09	\N	\N	Rockville, Bohicket Creek	SC
67555	Windsor Plantation, Russel Creek, North Edisto River, South Carolina	NOS	8667101	32.5983	-80.345	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:35:00	\N	1.11	01:16:00	\N	1.21	\N	\N	Windsor Plantation, Russel Creek	SC
67556	North Dawson Landing, Coosawhatchie River, Broad River, South Carolina	NOS	8667146	32.5617	-80.91	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	02:10:00	\N	1.14	02:34:00	\N	1.12	\N	\N	North Dawson Landing, Coosawhatchie River	SC
67557	Sheldon, Huspa Creek, Whale Branch, Coosaw River, South Carolina	NOS	8667172	32.5833	-80.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:52:00	\N	0.77	02:11:00	\N	1.16	\N	\N	Sheldon, Huspa Creek, Whale Branch	SC
67558	Point of Pines, North Edisto River, South Carolina	NOS	8667178	32.585	-80.2283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:11:00	\N	1.05	00:15:00	\N	1.08	\N	\N	Point of Pines	SC
67559	Briars Creek ent., Wimbee Creek, Bull River, Coosaw River, South Carolina	NOS	8667199	32.5783	-80.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:24:00	\N	0.95	02:06:00	\N	0.93	\N	\N	Briars Creek ent., Wimbee Creek, Bull River	SC
67560	Bluff Islands, Ashepoo River, South Carolina	NOS	8667201	32.5783	-80.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:04:00	\N	0.91	00:46:00	\N	0.84	\N	\N	Bluff Islands	SC
67561	Musselboro Island, Mosquito Creek, Ashepoo River, South Carolina	NOS	8667209	32.5783	-80.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:57:00	\N	0.91	01:21:00	\N	0.9	\N	\N	Musselboro Island, Mosquito Creek	SC
67562	Fields Point, Combahee River, South Carolina	NOS	8667259	32.5683	-80.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:52:00	\N	0.91	00:42:00	\N	0.91	\N	\N	Fields Point	SC
67563	Bowles Island, New Chehaw River, Combahee River, South Carolina	NOS	8667272	32.565	-80.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:42:00	\N	1	01:02:00	\N	0.96	\N	\N	Bowles Island, New Chehaw River	SC
67564	Ocella Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8667281	32.5617	-80.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:09:00	\N	1.08	00:32:00	\N	1.08	\N	\N	Ocella Creek, 2 mi. above entrance	SC
67565	Fenwick Island, South Edisto River, South Carolina	NOS	8667309	32.56	-80.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:25:00	\N	1.09	00:15:00	\N	0.9	\N	\N	Fenwick Island	SC
67566	Hutchinson Island, Ashepoo River, South Carolina	NOS	8667351	32.5517	-80.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:44:00	\N	0.91	00:31:00	\N	0.87	\N	\N	Hutchinson Island	SC
68175	Eagle Point, Galveston Bay, Texas (sub)	NOS	8771013	29.48	-94.91830555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	02:38:00	\N	0.8	05:34:00	\N	0.8	\N	\N	Eagle Point	TX
67567	Lobeco, Whale Branch, Coosaw River, South Carolina	NOS	8667411	32.5733	-80.745	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:28:00	\N	0.95	01:40:00	\N	1.11	\N	\N	Lobeco, Whale Branch	SC
67568	Peters Point, St. Pierre Creek, South Edisto River, South Carolina	NOS	8667425	32.54	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:09:00	\N	0.95	00:22:00	\N	0.88	\N	\N	Peters Point, St. Pierre Creek	SC
67569	Ashepoo-Coosaw Cutoff, ICWW, Ashepoo River, South Carolina	NOS	8667482	32.525	-80.4517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:23:00	\N	0.91	00:15:00	\N	0.9	\N	\N	Ashepoo-Coosaw Cutoff, ICWW	SC
67570	Whale Branch entrance, Coosaw River, South Carolina	NOS	8667491	32.525	-80.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:20:00	\N	0.95	01:27:00	\N	1.06	\N	\N	Whale Branch entrance	SC
67571	Summerhouse Point, Bull River, Coosaw River, South Carolina	NOS	8667493	32.5267	-80.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:37:00	\N	0.95	00:55:00	\N	0.96	\N	\N	Summerhouse Point, Bull River	SC
67572	RR. Bridge, Hall Island, Broad River, South Carolina	NOS	8667508	32.5217	-80.8383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:24:00	\N	1.05	01:39:00	\N	1.17	\N	\N	RR. Bridge, Hall Island	SC
67573	Seabrook, Ashepoo River, South Carolina	NOS	8667524	32.5233	-80.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:18:00	\N	0.91	00:11:00	\N	0.9	\N	\N	Seabrook	SC
67574	Pilot Island, West Branch Boyds Creek, Broad River, South Carolina	NOS	8667591	32.505	-80.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:24:00	\N	0.91	01:50:00	\N	1.15	\N	\N	Pilot Island, West Branch Boyds Creek	SC
67575	Brickyard Point, Brickyard Creek, Coosaw River, South Carolina	NOS	8667624	32.4933	-80.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:19:00	\N	0.95	01:27:00	\N	1.08	\N	\N	Brickyard Point, Brickyard Creek	SC
67576	Edisto Beach, Edisto Island, South Carolina	NOS	8667630	32.5017	-80.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:29:00	\N	0.95	-00:21:00	\N	0.84	\N	\N	Edisto Beach, Edisto Island	SC
67577	Clarendon Plantation, South Carolina (sub)	NOS	8667633	32.5025	-80.7841	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:25:00	\N	0.77	01:37:00	\N	1.15	\N	\N	Corning Landing, Whale Branch	SC
67578	Edisto Marina, Big Bay Creek entrance, South Edisto River, South Carolina	NOS	8667676	32.4933	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:13:00	\N	0.91	-00:06:00	\N	0.86	\N	\N	Edisto Marina, Big Bay Creek entrance	SC
67579	Carters Dock, Big Bay Creek, South Edisto River, South Carolina	NOS	8667679	32.4933	-80.3267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:07:00	\N	0.91	00:08:00	\N	0.87	\N	\N	Carters Dock, Big Bay Creek	SC
67580	Sams Point, Lucy Point Creek, Coosaw River, South Carolina	NOS	8667733	32.4833	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:45:00	\N	0.91	00:55:00	\N	0.97	\N	\N	Sams Point, Lucy Point Creek	SC
67581	Otter Island, St. Helena Sound, South Carolina	NOS	8667783	32.4767	-80.42	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:07:00	\N	0.95	00:04:00	\N	0.87	\N	\N	Otter Island	SC
67582	Marine Corps Air Station, Brickyard Creek, Beaufort River, South Carolina	NOS	8667864	32.465	-80.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:11:00	\N	0.95	01:27:00	\N	1.1	\N	\N	Marine Corps Air Station, Brickyard Creek	SC
67583	Lucy Point Creek entrance, Morgan River, South Carolina	NOS	8667901	32.4517	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:33:00	\N	0.88	00:53:00	\N	0.9	\N	\N	Lucy Point Creek entrance	SC
67584	Albergottie Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8667909	32.45	-80.7317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	02:02:00	\N	0.45	01:48:00	\N	0.98	\N	\N	Albergottie Creek, Rt. 21 bridge	SC
67586	Edding Point, Edding Creek, Morgan River, South Carolina	NOS	8667972	32.4467	-80.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:14:00	\N	0.95	00:31:00	\N	0.93	\N	\N	Edding Point, Edding Creek	SC
67587	Jenkins Creek, 1 mi. above entrance, Morgan River, South Carolina	NOS	8667982	32.44	-80.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:17:00	\N	0.95	00:41:00	\N	0.98	\N	\N	Jenkins Creek, 1 mi. above entrance	SC
68332	Westport, California	NOS	9417624	39.6333	-123.783	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66255	00:00:00	\N	0.95	00:14:00	\N	0.98	\N	\N	Westport	CA
67588	Village Creek Cemetery, Morgan River, South Carolina	NOS	8668077	32.4167	-80.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:15:00	\N	0.95	00:36:00	\N	0.94	\N	\N	Village Creek Cemetery	SC
67589	Jenkins Creek, Polawana Island, Morgan River, South Carolina	NOS	8668091	32.42	-80.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:27:00	\N	1.05	00:55:00	\N	1.01	\N	\N	Jenkins Creek, Polawana Island	SC
67590	Battery Creek, 4 mi. above entrance, Beaufort River, South Carolina	NOS	8668092	32.4133	-80.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:37:00	\N	0.91	01:14:00	\N	1.1	\N	\N	Battery Creek, 4 mi. above entrance	SC
67591	Broughton Point, Hazzard Creek, Broad River, South Carolina	NOS	8668109	32.41	-80.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:30:00	\N	0.82	01:34:00	\N	1.1	\N	\N	Broughton Point, Hazzard Creek	SC
67592	Harbor River Bridge, St. Helena Sound, South Carolina	NOS	8668146	32.4033	-80.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:06:00	\N	0.95	00:03:00	\N	0.88	\N	\N	Harbor River Bridge	SC
67593	Distant Island Creek, upper end, Cowen Creek, Beaufort River, South Carolina	NOS	8668155	32.4017	-80.6533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:08:00	\N	0.36	01:00:00	\N	0.98	\N	\N	Distant Island Creek, upper end, Cowen Creek	SC
67594	Cowen Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8668173	32.3983	-80.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:58:00	\N	0.55	00:55:00	\N	1	\N	\N	Cowen Creek, Rt. 21 bridge	SC
67595	Hwy. 170 bridge, Broad River, South Carolina	NOS	8668223	32.3867	-80.7767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:45:00	\N	0.91	00:51:00	\N	1.06	\N	\N	Hwy. 170 bridge	SC
67596	Johnson Creek Bridge, Hunting Island, St. Helena Sound, South Carolina	NOS	8668227	32.3917	-80.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:03:00	\N	0.86	00:03:00	\N	0.85	\N	\N	Johnson Creek Bridge, Hunting Island	SC
67732	Piney Point, Florida	NOS	8720333	30.2283	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	03:36:00	\N	0.4	02:39:00	\N	0.2	\N	\N	Piney Point	FL
67597	Capers Creek, Cowen Creek, St. Helena Island, Beaufort River, South Carolina	NOS	8668255	32.3717	-80.605	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:34:00	\N	0.95	00:58:00	\N	1.08	\N	\N	Capers Creek, Cowen Creek, St. Helena Island	SC
67598	Distant Island, Cowen Creek, Beaufort River, South Carolina	NOS	8668282	32.3783	-80.6333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:27:00	\N	1.05	00:43:00	\N	1.06	\N	\N	Distant Island, Cowen Creek	SC
67599	Chechessee Bluff, Chechessee River, South Carolina	NOS	8668301	32.3733	-80.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:48:00	\N	1	01:06:00	\N	1.1	\N	\N	Chechessee Bluff, Chechessee River	SC
67600	Parris Island, Marine Corps Recruit Depot, Beaufort River, South Carolina	NOS	8668445	32.35	-80.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:26:00	\N	0.91	00:37:00	\N	1.02	\N	\N	Parris Island, Marine Corps Recruit Depot	SC
67601	Baileys Landing, Okatee River, Colleton River, South Carolina	NOS	8668482	32.3467	-80.89	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:57:00	\N	1.05	01:25:00	\N	1.17	\N	\N	Baileys Landing, Okatee River, Colleton River	SC
67602	Fripp Inlet, Hunting Island Bridge, St. Helena Sound, South Carolina (sub)	NOS	8668498	32.34	-80.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:22:00	\N	0.91	-00:10:00	\N	0.88	\N	\N	Fripps Inlet, Hunting Island Bridge	SC
67603	Callawassie Island Bridge, Colleton River, South Carolina	NOS	8668511	32.3417	-80.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:49:00	\N	1.14	01:12:00	\N	1.13	\N	\N	Callawassie Island Bridge, Colleton River	SC
67604	Club Bridge Creek ent., Trenchards Inlet, South Carolina	NOS	8668529	32.335	-80.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:24:00	\N	1	00:15:00	\N	0.99	\N	\N	Club Bridge Creek ent., Trenchards Inlet	SC
67605	Station Creek, County Landing, South Carolina	NOS	8668601	32.325	-80.6017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:16:00	\N	1	00:27:00	\N	0.99	\N	\N	Station Creek, County Landing	SC
67607	Callawassie Creek, Colleton River, South Carolina	NOS	8668636	32.3167	-80.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:53:00	\N	1.14	01:15:00	\N	1.13	\N	\N	Callawassie Creek, Colleton River	SC
67608	Callawassie Island, south, Colleton River, South Carolina	NOS	8668655	32.3133	-80.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:40:00	\N	1.11	01:09:00	\N	1.19	\N	\N	Callawassie Island, south, Colleton River	SC
67609	Fort Fremont, Beaufort River, South Carolina	NOS	8668686	32.3067	-80.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:17:00	\N	0.64	00:19:00	\N	0.95	\N	\N	Fort Fremont	SC
67610	Purrysburg Landing, Savannah River, South Carolina	NOS	8668701	32.3033	-81.1217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	03:38:00	\N	0.41	02:14:00	\N	0.44	\N	\N	Purrysburg Landing, S.C.	SC
67611	Station Creek, west end, South Carolina	NOS	8668836	32.28	-80.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:13:00	\N	0.91	00:16:00	\N	0.96	\N	\N	Station Creek, west end	SC
67612	Capers Island, Trenchards Inlet, South Carolina	NOS	8668837	32.2733	-80.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:18:00	\N	0.95	-00:01:00	\N	0.93	\N	\N	Capers Island, Trenchards Inlet	SC
67613	Skull Creek, Ribaut Island, South Carolina (sub)	NOS	8668918	32.2667	-80.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:16:00	\N	0.91	00:15:00	\N	0.99	\N	\N	Skull Creek, north entrance, Hilton Head Island	SC
67614	Pinckney Island, Mackay Creek, Chechessee River, South Carolina	NOS	8668944	32.26	-80.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:25:00	\N	0.91	00:36:00	\N	1.04	\N	\N	Pinckney Island, Mackay Creek, Chechessee River	SC
67615	Rt. 170 bridge, New River, South Carolina	NOS	8669072	32.2367	-81.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	03:53:00	\N	0.51	04:12:00	\N	0.51	\N	\N	Rt. 170 bridge	SC
67616	Bluffton, May River, South Carolina	NOS	8669103	32.23	-80.8617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:37:00	\N	1.05	01:00:00	\N	1.16	\N	\N	Bluffton	SC
67617	Skull Creek, south entrance, Hilton Head Island, South Carolina	NOS	8669133	32.2233	-80.7717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:23:00	\N	1.05	00:34:00	\N	1.05	\N	\N	Skull Creek, south entrance, Hilton Head Island	SC
67618	Port Royal Plantation, Hilton Head Island, South Carolina	NOS	8669167	32.22	-80.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:11:00	\N	1	00:01:00	\N	0.88	\N	\N	Port Royal Plantation, Hilton Head Island	SC
67619	Bull Island North, May River, South Carolina	NOS	8669262	32.2	-80.815	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:25:00	\N	1.05	00:40:00	\N	1.09	\N	\N	Bull Island North	SC
67620	Cook Landing Cemetery, New River, South Carolina	NOS	8669277	32.195	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	03:00:00	\N	1.41	03:09:00	\N	0.69	\N	\N	Cook Landing Cemetery	SC
67621	Savage I., Savage Creek, Bull Creek, South Carolina	NOS	8669323	32.185	-80.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:19:00	\N	1	00:46:00	\N	1.1	\N	\N	Savage I., Savage Creek, Bull Creek	SC
67622	Broad Creek, Hilton Head Island, South Carolina	NOS	8669338	32.185	-80.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:17:00	\N	1.05	00:33:00	\N	1.08	\N	\N	Broad Creek, Hilton Head Island	SC
67623	Good Hope Landing, south of, New River, South Carolina	NOS	8669346	32.1767	-80.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	02:06:00	\N	1.55	02:19:00	\N	0.85	\N	\N	Good Hope Landing, south of	SC
67624	Moreland Cemetery, May River, South Carolina	NOS	8669369	32.175	-80.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:23:00	\N	0.77	00:49:00	\N	1.11	\N	\N	Moreland Cemetery	SC
67625	Bull Creek, Bull Island South, Cooper River, South Carolina	NOS	8669414	32.165	-80.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:12:00	\N	1.05	00:28:00	\N	1.05	\N	\N	Bull Creek, Bull Island South, Cooper River	SC
67626	Little Back River, Hwy. 17, Back River, Savannah River, South Carolina	NOS	8669415	32.165	-81.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:41:00	\N	1.14	01:28:00	\N	1.1	\N	\N	Little Back River, Hwy. 17, Back River, S.C.	SC
67627	Calibogue Cay, Broad Creek, Hilton Head Island, South Carolina	NOS	8669464	32.1533	-80.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:09:00	\N	1	00:20:00	\N	1.04	\N	\N	Calibogue Cay, Broad Creek, Hilton Head Island	SC
67628	Haig Point, Daufuskie Island, Cooper River, South Carolina	NOS	8669493	32.1467	-80.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:10:00	\N	1	00:20:00	\N	1.02	\N	\N	Haig Point, Daufuskie Island, Cooper River	SC
67629	Doughboy Island, New River, South Carolina	NOS	8669531	32.1383	-80.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:06:00	\N	1.05	01:04:00	\N	1.01	\N	\N	Doughboy Island	SC
67630	Turnbridge Landing, Salt Water Creek, South Carolina	NOS	8669575	32.1283	-81.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:59:00	\N	1.09	01:41:00	\N	1.06	\N	\N	Turnbridge Landing, Salt Water Creek	SC
67631	Pine Island, Ramshorn Creek, Cooper River, South Carolina	NOS	8669601	32.1217	-80.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:28:00	\N	0.91	00:34:00	\N	1.03	\N	\N	Pine Island, Ramshorn Creek, Cooper River	SC
67632	Braddock Point, Hilton Head Island, South Carolina	NOS	8669625	32.1133	-80.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:02:00	\N	1	00:05:00	\N	0.98	\N	\N	Braddock Point, Hilton Head Island	SC
67633	Daufuskie Landing, Daufuskie Island, New River, South Carolina	NOS	8669691	32.1033	-80.895	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:33:00	\N	0.95	00:30:00	\N	1.01	\N	\N	Daufuskie Landing, Daufuskie Island	SC
67634	Hargray Pier, Daufuskie Island, New River, South Carolina	NOS	8669722	32.0983	-80.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:27:00	\N	1.05	00:19:00	\N	1.01	\N	\N	Hargray Pier, Daufuskie Island	SC
67635	Bloody Point, Daufuskie Island, New River, South Carolina	NOS	8669801	32.0817	-80.8783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:19:00	\N	0.91	00:01:00	\N	0.98	\N	\N	Bloody Point, Daufuskie Island	SC
67636	Fields Cut, Wright River, South Carolina	NOS	8669815	32.0867	-80.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:29:00	\N	1.05	00:16:00	\N	1.02	\N	\N	Fields Cut, Wright River	SC
67637	S.C.L. RR. bridge, Savannah River, Georgia	NOS	8670073	32.2317	-81.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	03:08:00	\N	0.91	01:51:00	\N	0.9	\N	\N	S.C.L. RR. bridge	GA
67638	Port Wentworth, Savannah River, Georgia (sub)	NOS	8670424	32.1433	-81.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65866	-00:02:00	\N	0.84	00:11:00	\N	1.03	\N	\N	Port Wentworth	GA
67639	Fort Jackson, Savannah River, Georgia	NOS	8670678	32.0817	-81.0367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:42:00	\N	1.09	00:29:00	\N	1.09	\N	\N	Fort Jackson	GA
67640	Savannah (Bull Street), Georgia (sub)	NOS	8670681	32.0817	-81.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:33:00	\N	1.14	00:44:00	\N	1.14	\N	\N	SAVANNAH	GA
67641	Tybee Light, Savannah River, Georgia	NOS	8670892	32.0283	-80.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:12:00	\N	0.99	-00:10:00	\N	0.99	\N	\N	Tybee Light	GA
67642	Vernon View, Burnside River, Georgia	NOS	8671642	31.9267	-81.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:31:00	\N	1.09	00:40:00	\N	1.09	\N	\N	Vernon View, Burnside River	GA
67643	Florida Passage, Ogeechee River, Georgia	NOS	8672219	31.8533	-81.1467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:46:00	\N	0.91	00:34:00	\N	1.05	\N	\N	Florida Passage, Ogeechee River	GA
67644	Bradley Point, Bradley River, Georgia	NOS	8672455	31.8217	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:13:00	\N	0.95	00:04:00	\N	1.02	\N	\N	Bradley Point, Bradley River	GA
67645	Belfast, Belfast River, Georgia	NOS	8672462	31.8217	-81.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:10:00	\N	1.14	01:23:00	\N	1.13	\N	\N	Belfast, Belfast River	GA
67646	Bear River, (Range 'A' Light), Georgia (sub)	NOS	8672667	31.7933	-81.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:39:00	\N	0.95	00:43:00	\N	1.09	\N	\N	Bear River, (Range 'A' Light)	GA
67647	Kilkenny Club, Kilkenny Creek, Georgia	NOS	8672696	31.7883	-81.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:37:00	\N	0.91	00:48:00	\N	1.09	\N	\N	Kilkenny Club, Kilkenny Creek	GA
67648	Sunbury, Sunbury Channel, Georgia (sub)	NOS	8672875	31.7667	-81.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:52:00	\N	0.73	00:53:00	\N	1.05	\N	\N	Sunbury, Medway River	GA
67649	Halfmoon, Timmons River, Georgia	NOS	8673381	31.695	-81.2717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:09:00	\N	1.05	01:21:00	\N	1.06	\N	\N	Halfmoon, Timmons River	GA
67650	Walburg Creek entrance, Georgia	NOS	8673437	31.69	-81.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:21:00	\N	1	00:16:00	\N	1.03	\N	\N	Walburg Creek entrance	GA
67651	North Newport River (Daymark 119), Georgia	NOS	8673499	31.6817	-81.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:31:00	\N	1	00:35:00	\N	1.05	\N	\N	North Newport River (Daymark 119)	GA
67652	Thomas Landing, S. Newport River, Georgia	NOS	8673812	31.6433	-81.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:46:00	\N	0.95	00:57:00	\N	1.06	\N	\N	Thomas Landing, S. Newport River	GA
68518	Vallenar Point, Alaska	NOS	9450511	55.4267	-131.847	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:06:00	\N	0.96	-00:01:00	\N	0.99	\N	\N	Vallenar Point	AK
67653	Eagle Neck, South Newport River, Georgia	NOS	8673875	31.65	-81.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:06:00	\N	1	01:16:00	\N	1.09	\N	\N	Eagle Neck, South Newport River	GA
67654	Harris Neck, Barbour Island River, Georgia	NOS	8673962	31.6233	-81.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:32:00	\N	1	00:54:00	\N	1.08	\N	\N	Harris Neck, Barbour Island River	GA
67655	Barbour Island, Barbour Island River, Georgia	NOS	8674251	31.5783	-81.24	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:24:00	\N	1	00:36:00	\N	1.06	\N	\N	Barbour Island, Barbour Island River	GA
67656	South Newport River (Daymark 135), Georgia (sub)	NOS	8674301	31.575	-81.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:20:00	\N	1.05	00:27:00	\N	1.03	\N	\N	South Newport River (Daymark 135)	GA
67657	Pine Harbor, Sapelo River, Georgia	NOS	8674512	31.5483	-81.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:04:00	\N	1.05	01:03:00	\N	1.05	\N	\N	Pine Harbor, Sapelo River	GA
67658	Dog Hammock, Sapelo River, Georgia	NOS	8674623	31.5317	-81.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:22:00	\N	0.91	00:33:00	\N	1.04	\N	\N	Dog Hammock, Sapelo River	GA
67659	Bellville Point, Sapelo River, Georgia	NOS	8674638	31.5317	-81.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:02:00	\N	0.86	01:12:00	\N	1.08	\N	\N	Bellville Point, Sapelo River	GA
67660	Eagle Creek, Mud River, Georgia	NOS	8674801	31.51	-81.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:19:00	\N	1.05	00:21:00	\N	1.05	\N	\N	Eagle Creek, Mud River	GA
67661	Creighton Narrows entrance, Crescent River, Georgia	NOS	8674875	31.4983	-81.325	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:37:00	\N	1.09	00:49:00	\N	1.08	\N	\N	Creighton Narrows Entrance, Crescent River	GA
67662	Blackbeard Creek, Blackbeard Island, Georgia	NOS	8674962	31.4883	-81.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:47:00	\N	0.95	00:19:00	\N	0.94	\N	\N	Blackbeard Creek, Blackbeard Island	GA
67663	Hudson Creek entrance, Georgia	NOS	8675245	31.4467	-81.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:31:00	\N	1.05	00:37:00	\N	1.05	\N	\N	Hudson Creek entrance	GA
67664	Old Tea Kettle Creek (Daymark 173), Georgia	NOS	8675365	31.4317	-81.3067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:39:00	\N	0.82	00:39:00	\N	0.96	\N	\N	Old Tea Kettle Creek (Daymark 173)	GA
67665	Old Tower, Sapelo Island, Georgia	NOS	8675622	31.39	-81.2883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:14:00	\N	0.95	00:15:00	\N	0.99	\N	\N	Old Tower, Sapelo Island	GA
67666	Rockdedundy River (Daymark 185), Georgia (sub)	NOS	8675761	31.37386111111111	-81.33394444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:41:00	\N	1.01	00:29:00	\N	1	\N	\N	Rockdedundy River (Daymark 185)	GA
67667	Darien, Darien River, Georgia	NOS	8675779	31.3683	-81.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:15:00	\N	1.05	01:08:00	\N	1.06	\N	\N	Darien, Darien River	GA
67668	Threemile Cut entrance, Darien River, Georgia	NOS	8675843	31.3567	-81.3767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:55:00	\N	1.05	00:44:00	\N	1.03	\N	\N	Threemile Cut entrance, Darien River	GA
67669	Champney Island, South Altamaha River, Georgia	NOS	8676012	31.3317	-81.46	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	02:33:00	\N	0.77	01:10:00	\N	0.76	\N	\N	Champney Island, South Altamaha River	GA
67670	Mackay River (ICWW), Buttermilk Sound, Georgia	NOS	8676329	31.285	-81.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:23:00	\N	1.09	00:58:00	\N	1	\N	\N	Mackay River (ICWW), Buttermilk Sound	GA
67671	Dillard Creek, Turtle River, Georgia	NOS	8676722	31.225	-81.5717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:02:00	\N	1.18	01:32:00	\N	1.16	\N	\N	Dillard Creek	GA
67672	Frederica River, Georgia	NOS	8676743	31.2217	-81.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:56:00	\N	1.05	00:48:00	\N	1.05	\N	\N	Frederica River	GA
67673	Mackay River (Daymark 239), Georgia	NOS	8676766	31.21	-81.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:56:00	\N	1.09	00:58:00	\N	1.03	\N	\N	Mackay River (Daymark 239)	GA
67674	Buffalo River entrance, Turtle River, Georgia	NOS	8676787	31.215	-81.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:58:00	\N	1.18	01:37:00	\N	1.16	\N	\N	Buffalo River entrance	GA
68801	Kuliliak Bay, Unalaska Island, Alaska	NOS	9462557	53.4617	-167.02	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-03:35:00	\N	1.27	-03:10:00	\N	1.46	\N	\N	Kuliliak Bay	AK
67675	Frederick River Bridge, Georgia	NOS	8677045	31.1683	-81.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:45:00	\N	1.09	00:43:00	\N	1	\N	\N	Frederick River Bridge	GA
67676	St. Simons Lighthouse, St. Simons Island, Georgia (sub)	NOS	8677344	31.1317	-81.3967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:16:00	\N	0.91	00:14:00	\N	0.95	\N	\N	St. Simons Light	GA
67677	8 miles above mouth, Little Satilla River, Georgia	NOS	8677566	31.0983	-81.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	01:02:00	\N	1.2	00:24:00	\N	1.2	\N	\N	8 miles above mouth	GA
67678	Jointer Island, Jointer Creek, Georgia	NOS	8677576	31.095	-81.505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:31:00	\N	1.18	00:11:00	\N	1.18	\N	\N	Jointer Island, Jointer Creek	GA
67679	Jekyll Island Marina, Jekyll Creek, Georgia	NOS	8677832	31.0567	-81.4233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:36:00	\N	1.16	00:03:00	\N	1.13	\N	\N	Jekyll Island Marina, Jekyll Creek	GA
67680	2.5 miles above mouth, Little Satilla River, Georgia	NOS	8677833	31.0583	-81.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:31:00	\N	1.12	-00:04:00	\N	1.12	\N	\N	2.5 miles above mouth	GA
67681	Dover Bluff, Dover Creek, Georgia	NOS	8678111	31.0167	-81.5283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:31:00	\N	1.15	00:06:00	\N	1.15	\N	\N	Dover Bluff, Dover Creek	GA
67682	Todd Creek entrance, Satilla River, Georgia	NOS	8678412	30.9717	-81.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:41:00	\N	1.1	-00:08:00	\N	1.1	\N	\N	Todd Creek entrance	GA
67683	Ceylon, Satilla River, Georgia	NOS	8678466	30.9633	-81.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	01:35:00	\N	1.09	00:34:00	\N	1.09	\N	\N	Ceylon	GA
67684	Floyd Creek, 2.8 miles above entrance, Georgia	NOS	8678642	30.9367	-81.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:21:00	\N	1.17	00:08:00	\N	1.17	\N	\N	Floyd Creek, 2.8 miles above entrance	GA
67685	Cumberland Wharf, Cumberland River, Georgia	NOS	8678688	30.93	-81.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:26:00	\N	1.12	00:00:00	\N	1.12	\N	\N	Cumberland Wharf, Cumberland River	GA
67686	Harrietts Bluff, Crooked River, Georgia	NOS	8679083	30.87	-81.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	01:56:00	\N	1.05	01:29:00	\N	1.05	\N	\N	Harrietts Bluff, Crooked River	GA
67687	Crooked River, Cumberland Dividings, Georgia	NOS	8679242	30.8433	-81.4867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:56:00	\N	1.12	00:44:00	\N	1.12	\N	\N	Crooked River, Cumberland Dividings	GA
67688	Kings Bay, Navy Base, Georgia (sub)	NOS	8679511	30.7967	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:10:00	\N	1.05	00:12:00	\N	1.09	\N	\N	Kings Bay, Navy Base	GA
67689	Dungeness, Seacamp Dock, Georgia (sub)	NOS	8679758	30.7633	-81.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:16:00	\N	1.05	00:12:00	\N	1.04	\N	\N	Seacamp Dock, Cumberland Island	GA
67690	Beach Creek ent., Cumberland Island, Georgia	NOS	8679945	30.7267	-81.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	-00:04:00	\N	0.95	00:00:00	\N	0.98	\N	\N	Beach Creek ent., Cumberland Island	GA
67691	St. Marys, St. Marys River, Georgia (sub)	NOS	8679964	30.72	-81.5483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:45:00	\N	1.05	00:38:00	\N	0.98	\N	\N	St. Marys	GA
67693	Kings Ferry, St. Marys River, Florida	NOS	8720001	30.7867	-81.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	04:09:00	\N	1.16	04:05:00	\N	0.49	\N	\N	Kings Ferry	FL
67694	Little St. Marys River, St. Marys River, Florida	NOS	8720006	30.7317	-81.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	02:36:00	\N	0.79	02:49:00	\N	0.71	\N	\N	Little St. Marys River	FL
67695	Roses Bluff, Bells River, Florida	NOS	8720007	30.7033	-81.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:35:00	\N	0.95	00:35:00	\N	1.03	\N	\N	Roses Bluff, Bells River	FL
67696	Chester, Bells River, Florida (sub)	NOS	8720023	30.6833	-81.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:19:00	\N	1.11	00:27:00	\N	1.04	\N	\N	Chester, Bells River	FL
67697	Lofton, Lanceford Creek, Florida (sub)	NOS	8720051	30.6433	-81.5233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	-00:01:00	\N	1.05	00:18:00	\N	1.05	\N	\N	Lofton, Lanceford Creek	FL
67698	Kingsley Creek, RR. bridge, Florida	NOS	8720058	30.6317	-81.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:25:00	\N	1	00:27:00	\N	0.99	\N	\N	Kingsley Creek, RR. bridge	FL
67699	Boggy Creek, 2 mi. above entrance, Nassau River, Florida	NOS	8720084	30.5883	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	03:50:00	\N	0.89	03:29:00	\N	0.49	\N	\N	Boggy Creek, 2 mi. above entrance	FL
67700	Amelia City, South Amelia River, Florida	NOS	8720086	30.5867	-81.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:42:00	\N	0.89	00:21:00	\N	0.89	\N	\N	Amelia City, South Amelia River	FL
67701	Halfmoon Island, highway bridge, Nassau River, Florida	NOS	8720093	30.5767	-81.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	02:39:00	\N	1.05	02:00:00	\N	0.7	\N	\N	Halfmoon Island, highway bridge	FL
67702	Cuno, Lofton Creek, Nassau River, Florida	NOS	8720097	30.5767	-81.5717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	02:48:00	\N	1.05	02:14:00	\N	0.6	\N	\N	Cuno, Lofton Creek	FL
67703	Nassauville, Nassau River East, Florida (sub)	NOS	8720098	30.5683	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	01:09:00	\N	1	00:24:00	\N	0.8	\N	\N	Nassauville	FL
67704	Mink Creek entrance, Nassau River, Florida	NOS	8720119	30.5367	-81.5817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	02:05:00	\N	1.05	01:13:00	\N	0.72	\N	\N	Mink Creek entrance	FL
67705	Nassau River entrance, Florida	NOS	8720135	30.5183	-81.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:41:00	\N	1	-00:18:00	\N	0.86	\N	\N	entrance	FL
67706	Sawpit Creek entrance, bridge, Florida	NOS	8720137	30.5133	-81.4567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:21:00	\N	1	-00:14:00	\N	0.84	\N	\N	Sawpit Creek entrance, bridge	FL
67707	Sawpit Creek, 1 mi. above entrance, Florida	NOS	8720143	30.5033	-81.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:31:00	\N	0.74	00:05:00	\N	0.84	\N	\N	Sawpit Creek, 1 mi. above entrance	FL
67708	Edwards Creek, Nassau River, Florida (sub)	NOS	8720145	30.5017	-81.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	01:51:00	\N	0.85	01:24:00	\N	0.77	\N	\N	Edwards Creek, 1 mi. above entrance	FL
67709	Tiger Point, Pumpkin Hill Creek, Nassau River, Florida	NOS	8720148	30.5017	-81.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	01:46:00	\N	0.95	01:22:00	\N	0.82	\N	\N	Tiger Point, Pumpkin Hill Creek	FL
67710	Simpson Creek, A1A highway bridge, Florida	NOS	8720168	30.465	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:17:00	\N	0.63	00:04:00	\N	0.84	\N	\N	Simpson Creek, A1A highway bridge	FL
67711	Fort George Island, Fort George River, Florida	NOS	8720186	30.44	-81.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:33:00	\N	0.74	00:10:00	\N	0.79	\N	\N	Fort George Island, Fort George River	FL
67712	Little Talbot Island, ocean, Florida	NOS	8720194	30.43	-81.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	-00:13:00	\N	1	-00:36:00	\N	0.91	\N	\N	Little Talbot Island, ocean	FL
67713	Sisters Creek, Florida (sub)	NOS	8720196	30.4167	-81.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	00:50:00	\N	0.93	00:32:00	\N	0.95	\N	\N	Sisters Creek	FL
67714	Blount Island Bridge, Florida	NOS	8720203	30.4133	-81.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	01:05:00	\N	0.73	00:42:00	\N	0.77	\N	\N	Blount Island Bridge	FL
67715	Water Treatment Dock, Mayport Naval Station, St Johns River, Florida (sub)	NOS	8720211	30.4	-81.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	-00:06:00	\N	1	-00:12:00	\N	1.03	\N	\N	Mayport Naval Station, Water Treatment Dock	FL
67716	Sherwood Forest, Trout River, Florida (sub)	NOS	8720213	30.42	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	02:13:00	\N	0.67	01:42:00	\N	0.58	\N	\N	Sherwood Forest	FL
67717	Jacksonville, Navy Fuel Depot, Florida	NOS	8720215	30.4	-81.6267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	01:48:00	\N	0.53	01:14:00	\N	0.56	\N	\N	Jacksonville, Navy Fuel Depot	FL
67718	Lake Forest, Ribault River, Trout River, Florida	NOS	8720216	30.3983	-81.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	02:10:00	\N	0.6	01:13:00	\N	0.58	\N	\N	Lake Forest, Ribault River	FL
67719	Moncrief Creek entrance, Trout River, Florida	NOS	8720217	30.3917	-81.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	01:53:00	\N	0.53	01:11:00	\N	0.55	\N	\N	Moncrief Creek entrance	FL
67720	Dame Point, St. Johns River, Florida (sub)	NOS	8720219	30.3867	-81.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	01:12:00	\N	0.67	00:42:00	\N	0.7	\N	\N	Dame Point	FL
67721	Fulton, Florida	NOS	8720221	30.39	-81.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	00:40:00	\N	0.73	00:24:00	\N	0.8	\N	\N	Fulton	FL
67722	Phoenix Park, Florida (sub)	NOS	8720225	30.3833	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	01:47:00	\N	0.6	01:02:00	\N	0.56	\N	\N	Phoenix Park	FL
67723	Main Street Bridge, St. Johns River, Florida (sub)	NOS	8720226	30.32	-81.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	02:09:00	\N	0.73	01:39:00	\N	0.4	\N	\N	Jacksonville, Main Street Bridge	FL
67724	Pablo Creek entrance, Florida	NOS	8720232	30.3767	-81.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	00:33:00	\N	0.73	00:29:00	\N	0.85	\N	\N	Pablo Creek entrance	FL
67725	Jacksonville, Long Branch, Florida (sub)	NOS	8720242	30.36	-81.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	01:54:00	\N	0.73	01:15:00	\N	0.55	\N	\N	Jacksonville, Long Branch	FL
67726	Atlantic Beach, Florida	NOS	8720259	30.335	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	-00:23:00	\N	0.86	-00:41:00	\N	0.86	\N	\N	Atlantic Beach	FL
67727	Pablo Creek, ICWW bridge, Florida	NOS	8720267	30.3233	-81.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	01:20:00	\N	1	01:14:00	\N	0.84	\N	\N	Pablo Creek, ICWW bridge	FL
67728	Little Pottsburg Creek, Florida	NOS	8720274	30.31	-81.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	02:09:00	\N	0.53	01:31:00	\N	0.44	\N	\N	Little Pottsburg Creek	FL
67729	Jacksonville Beach, Florida (sub)	NOS	8720291	30.2833	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	-00:27:00	\N	0.84	-00:50:00	\N	0.84	\N	\N	Jacksonville Beach	FL
67730	Ortega River entrance, Florida	NOS	8720296	30.2783	-81.705	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	02:47:00	\N	0.47	02:09:00	\N	0.25	\N	\N	Ortega River entrance	FL
67731	Oak Landing, ICWW, Florida	NOS	8720305	30.2533	-81.43	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	02:03:00	\N	0.8	02:15:00	\N	0.68	\N	\N	Oak Landing, ICWW	FL
67733	I-295 Bridge (west end), St. Johns River, Florida (sub)	NOS	8720357	30.1917	-81.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	03:43:00	\N	0.6	02:56:00	\N	0.21	\N	\N	I-295 bridge (west end)	FL
67734	Orange Park Landing, Orange Park, Florida	NOS	8720374	30.16830062866211	-81.69499969482422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	04:44:00	\N	0.2	03:24:00	\N	0.2	\N	\N	Orange Park Landing, Orange Park	FL
67735	Palm Valley, ICWW, Florida	NOS	8720398	30.1333	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	01:49:00	\N	0.75	02:00:00	\N	0.79	\N	\N	Palm Valley, ICWW	FL
67736	Julington Creek, Florida	NOS	8720409	30.135000228881836	-81.62999725341797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	05:13:00	\N	0.2	03:58:00	\N	0.2	\N	\N	Julington Creek	FL
67737	Green Cove Springs, Florida	NOS	8720496	29.99	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	05:55:00	\N	0.27	04:57:00	\N	0.17	\N	\N	Green Cove Springs	FL
67738	Vilano Beach ICWW, Tolomato River, Florida (sub)	NOS	8720554	29.9167	-81.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	-00:05:00	\N	0.9	-00:20:00	\N	0.74	\N	\N	Vilano Beach, Tolomato River	FL
67739	St. Augustine, city dock, Florida	NOS	8720576	29.8917	-81.31	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:01:00	\N	0.89	-00:20:00	\N	0.75	\N	\N	St. Augustine, city dock	FL
67740	St. Augustine Beach, Florida (sub)	NOS	8720587	29.8567	-81.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	-00:32:00	\N	0.84	-00:51:00	\N	0.77	\N	\N	St. Augustine Beach	FL
67741	Tocoi, Florida	NOS	8720596	29.8583	-81.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	07:03:00	\N	0.27	06:02:00	\N	0.21	\N	\N	Tocoi	FL
67742	Palmetto Bluff, Florida	NOS	8720653	29.7633	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	07:36:00	\N	0.47	06:35:00	\N	0.23	\N	\N	Palmetto Bluff	FL
67743	Fort Matanzas, Matanzas River, ICWW, Florida	NOS	8720686	29.715	-81.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	00:49:00	\N	0.95	00:03:00	\N	0.65	\N	\N	Fort Matanzas, Matanzas River, ICWW	FL
67744	Buffalo Bluff, St. Johns River, Florida (sub)	NOS	8720767	29.595	-81.6817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	08:58:00	\N	0.4	07:27:00	\N	0.21	\N	\N	Buffalo Bluff	FL
67745	Palatka, St. Johns River, Florida (sub)	NOS	8720774	29.6433	-81.6317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	08:38:00	\N	0.53	07:11:00	\N	0.25	\N	\N	Palatka	FL
67746	Sutherlands Still, Dunns Creek, Florida	NOS	8720782	29.5717	-81.6067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	09:05:00	\N	0.2	07:35:00	\N	0.18	\N	\N	Sutherlands Still, Dunns Creek	FL
67747	Welaka, St. Johns River, Florida (sub)	NOS	8720832	29.4767	-81.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65901	08:07:00	\N	0.27	07:16:00	\N	0.1	\N	\N	Welaka	FL
67748	Smith Creek, Flagler Beach, Florida	NOS	8720833	29.4783	-81.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	05:00:00	\N	0.3	04:33:00	\N	0.15	\N	\N	Smith Creek, Flagler Beach	FL
67749	Ormond Beach, Halifax River, Florida	NOS	8720954	29.285	-81.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	04:31:00	\N	0.45	03:17:00	\N	0.11	\N	\N	Ormond Beach, Halifax River	FL
67750	Daytona Beach Shores, Sunglow Pier, Florida (sub)	NOS	8721120	29.1467	-80.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	-00:42:00	\N	0.84	-00:56:00	\N	0.65	\N	\N	Daytona Beach Shores, Sunglow Pier	FL
67751	Ponce Inlet, Halifax River, Florida	NOS	8721138	29.0817	-80.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:33:00	\N	1	00:05:00	\N	1.18	\N	\N	Ponce Inlet, Halifax River	FL
67752	Ponce De Leon Inlet South, Florida (sub)	NOS	8721147	29.0633	-80.915	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:19:00	\N	0.92	-00:11:00	\N	1.17	\N	\N	Ponce de Leon Inlet	FL
67753	Patrick Air Force Base, Florida	NOS	8721727	28.245	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:38:00	\N	1.43	-01:04:00	\N	1.5	\N	\N	Patrick Air Force Base	FL
67754	Canova Beach, Florida	NOS	8721804	28.1383	-80.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:26:00	\N	1.5	-00:53:00	\N	1.49	\N	\N	Canova Beach	FL
67755	Micco, Indian River, Florida	NOS	8721994	27.8733	-80.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:19:00	\N	0.57	01:14:00	\N	0.14	\N	\N	Micco	FL
67756	Sebastian Inlet bridge, Florida	NOS	8722004	27.86	-80.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:24:00	\N	1	-00:48:00	\N	0.93	\N	\N	Sebastian Inlet bridge	FL
67757	Sebastian, Indian River, Florida	NOS	8722029	27.8117	-80.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:36:00	\N	0.5	01:32:00	\N	0.15	\N	\N	Sebastian	FL
67758	Wabasso, Indian River, Florida	NOS	8722059	27.755	-80.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:24:00	\N	0.42	02:20:00	\N	0.17	\N	\N	Wabasso	FL
67759	Vero Beach (ocean), Florida	NOS	8722105	27.67	-80.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:35:00	\N	1.36	-00:55:00	\N	1.45	\N	\N	Vero Beach (ocean)	FL
67760	Vero Beach, Indian River, Florida (sub)	NOS	8722125	27.6317	-80.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:41:00	\N	0.79	02:56:00	\N	0.37	\N	\N	Vero Beach	FL
67761	Oslo, Indian River, Florida	NOS	8722146	27.5933	-80.3567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:59:00	\N	0.5	03:00:00	\N	0.34	\N	\N	Oslo	FL
67762	St. Lucie, Indian River, Florida	NOS	8722207	27.48	-80.3333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:46:00	\N	1	00:41:00	\N	0.48	\N	\N	St. Lucie	FL
67763	Fort Pierce Inlet, south jetty, Florida	NOS	8722212	27.47	-80.2883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:18:00	\N	1.5	-00:31:00	\N	1.14	\N	\N	Fort Pierce Inlet, south jetty	FL
67764	Ankona, Indian River, Florida	NOS	8722274	27.355	-80.2733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:03:00	\N	0.85	02:16:00	\N	0.52	\N	\N	Ankona	FL
67765	Eden, Nettles Island, Indian River, Florida	NOS	8722312	27.2867	-80.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:31:00	\N	0.92	02:35:00	\N	0.45	\N	\N	Eden, Nettles Island	FL
67766	North Fork, St. Lucie River, Florida	NOS	8722334	27.2433	-80.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:28:00	\N	0.92	02:28:00	\N	0.46	\N	\N	North Fork	FL
67767	Jensen Beach, Indian River, Florida	NOS	8722338	27.235	-80.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:04:00	\N	0.92	02:17:00	\N	0.48	\N	\N	Jensen Beach	FL
67768	Stuart, St. Lucie River, Florida	NOS	8722357	27.2	-80.2583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:30:00	\N	0.86	02:13:00	\N	0.4	\N	\N	Stuart	FL
67769	Seminole Shores, Florida	NOS	8722366	27.1833	-80.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:35:00	\N	1.28	-00:59:00	\N	1.29	\N	\N	Seminole Shores	FL
67770	Sewall Point, St. Lucie River, Florida	NOS	8722371	27.175	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:10:00	\N	0.93	01:13:00	\N	0.43	\N	\N	Sewall Point	FL
67771	South Fork, St. Lucie River, Florida	NOS	8722376	27.165	-80.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:32:00	\N	0.92	02:35:00	\N	0.43	\N	\N	South Fork	FL
67772	Great Pocket, Florida	NOS	8722381	27.155	-80.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:42:00	\N	1	00:55:00	\N	0.5	\N	\N	Great Pocket	FL
67773	Port Salerno, Manatee Pocket, St. Lucie River, Florida	NOS	8722383	27.1517	-80.195	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:46:00	\N	0.92	00:51:00	\N	0.42	\N	\N	Port Salerno, Manatee Pocket	FL
67774	Peck Lake, ICWW, Florida	NOS	8722404	27.1133	-80.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:10:00	\N	1	01:13:00	\N	0.58	\N	\N	Peck Lake, ICWW	FL
67775	Gomez, South Jupiter Narrows, Florida	NOS	8722414	27.0933	-80.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:37:00	\N	1.07	01:33:00	\N	0.6	\N	\N	Gomez, South Jupiter Narrows	FL
67776	Hobe Sound bridge, Florida	NOS	8722429	27.065	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:25:00	\N	1	01:28:00	\N	0.68	\N	\N	Hobe Sound bridge	FL
67777	Hobe Sound, Jupiter Island, Florida	NOS	8722445	27.0367	-80.1067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:12:00	\N	1	01:16:00	\N	0.75	\N	\N	Hobe Sound, Jupiter Island	FL
67778	Conch Bar, Jupiter Sound, Florida	NOS	8722471	26.9883	-80.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:34:00	\N	1.07	00:56:00	\N	0.74	\N	\N	Conch Bar, Jupiter Sound	FL
67779	Boy Scout Dock, Loxahatchee River, Florida	NOS	8722472	26.9867	-80.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:57:00	\N	1.36	01:01:00	\N	0.92	\N	\N	Boy Scout Dock	FL
67780	North Fork, 2 miles above entrance, Loxahatchee River, Florida	NOS	8722478	26.975	-80.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:55:00	\N	1.14	01:04:00	\N	0.86	\N	\N	North Fork, 2 miles above entrance	FL
67781	3 miles above A1A highway bridge, Loxahatchee River, Florida	NOS	8722481	26.97	-80.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:49:00	\N	1.14	00:56:00	\N	0.86	\N	\N	3 miles above A1A highway bridge	FL
67782	Tequesta, North Fork, Loxahatchee River, Florida	NOS	8722486	26.96	-80.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:13:00	\N	1	01:14:00	\N	0.75	\N	\N	Tequesta, North Fork	FL
67783	Jupiter Sound, south end, Florida	NOS	8722491	26.9517	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:45:00	\N	1.36	00:22:00	\N	0.88	\N	\N	Jupiter Sound, south end	FL
67784	A1A highway bridge, Loxahatchee River, Florida	NOS	8722492	26.9467	-80.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:54:00	\N	1.14	00:34:00	\N	0.87	\N	\N	A1A highway bridge	FL
67785	Southwest Fork, 0.5 mile above entrance, Loxahatchee River, Florida	NOS	8722494	26.9433	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:35:00	\N	1.42	00:41:00	\N	0.89	\N	\N	Southwest Fork, 0.5 mile above entrance	FL
67786	Jupiter Inlet, south jetty, Florida	NOS	8722495	26.9433	-80.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:09:00	\N	1.42	-00:10:00	\N	1.08	\N	\N	Jupiter Inlet, south jetty	FL
67787	Southwest Fork (spillway), Loxahatchee River, Florida	NOS	8722496	26.935	-80.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:45:00	\N	1.28	00:52:00	\N	0.86	\N	\N	Southwest Fork (spillway)	FL
67788	Jupiter, Lake Worth Creek, ICWW, Florida	NOS	8722499	26.935	-80.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:12:00	\N	1.28	00:34:00	\N	0.91	\N	\N	Jupiter, Lake Worth Creek, ICWW	FL
67789	Lake Worth Creek, Day Beacon 19, ICWW, Florida	NOS	8722512	26.9117	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:08:00	\N	1.21	00:29:00	\N	0.92	\N	\N	Lake Worth Creek, Day Beacon 19, ICWW	FL
67790	Donald Ross Bridge, ICWW, Florida	NOS	8722528	26.8817	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:50:00	\N	1.21	00:20:00	\N	1	\N	\N	Donald Ross Bridge, ICWW	FL
67791	PGA Boulevard Bridge, Palm Beach, Florida (sub)	NOS	8722548	26.8433	-80.0667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:31:00	\N	1.36	-00:02:00	\N	1.16	\N	\N	PGA Boulevard Bridge, ICWW	FL
67792	North Palm Beach, Lake Worth, Florida	NOS	8722557	26.8267	-80.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:15:00	\N	1.29	-00:17:00	\N	1.22	\N	\N	North Palm Beach	FL
67793	Port of West Palm Beach, Florida (sub)	NOS	8722588	26.77	-80.0517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:04:00	\N	1.36	-00:21:00	\N	1.18	\N	\N	Port of Palm Beach	FL
67794	Palm Beach, Lake Worth, Florida	NOS	8722607	26.7333	-80.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:16:00	\N	1.29	-00:11:00	\N	1.17	\N	\N	Palm Beach	FL
67795	Palm Beach, Highway 704 bridge, Lake Worth, Florida	NOS	8722621	26.705	-80.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:40:00	\N	1.07	00:18:00	\N	1.1	\N	\N	Palm Beach, Highway 704 bridge	FL
67796	West Palm Beach Canal, Lake Worth, Florida	NOS	8722654	26.645	-80.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:35:00	\N	1.14	00:48:00	\N	1.07	\N	\N	West Palm Beach Canal	FL
67797	Lake Worth Pier, Florida (sub)	NOS	8722670	26.6127778	-80.0341667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:19:00	\N	1	-00:45:00	\N	1.16	\N	\N	Lake Worth Pier (ocean)	FL
67798	Boynton Beach, Lake Worth, Florida (sub)	NOS	8722706	26.54829978942871	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:07:00	\N	1.07	01:05:00	\N	1.06	\N	\N	Boynton Beach, Lake Worth	FL
67799	Delray Beach, ICWW, Florida	NOS	8722746	26.4733	-80.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:07:00	\N	1.14	01:24:00	\N	1.07	\N	\N	Delray Beach, ICWW	FL
67800	Yamato, ICWW, Florida	NOS	8722784	26.4033	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:57:00	\N	1.14	01:22:00	\N	1.02	\N	\N	Yamato, ICWW	FL
67801	Lake Wyman, ICWW, Florida (sub)	NOS	8722802	26.37	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:49:00	\N	1.14	01:17:00	\N	0.96	\N	\N	Lake Wyman, ICWW	FL
67802	Deerfield Beach, Hillsboro River, Florida	NOS	8722832	26.3133	-80.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:03:00	\N	1.07	00:28:00	\N	1.02	\N	\N	Deerfield Beach, Hillsboro River	FL
67803	Hillsboro Beach, ICWW, Florida	NOS	8722854	26.2733	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:34:00	\N	1.07	00:02:00	\N	1.06	\N	\N	Hillsboro Beach, ICWW	FL
67804	Hillsboro Inlet, Coast Guard Light Station, Florida	NOS	8722861	26.2583	-80.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:03:00	\N	1.14	-00:16:00	\N	1.08	\N	\N	Hillsboro Inlet, Coast Guard Light Station	FL
67805	Hillsboro Inlet (ocean), Florida	NOS	8722862	26.2567	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:00:00	\N	1.21	-00:23:00	\N	1.12	\N	\N	Hillsboro Inlet (ocean)	FL
67806	Andrews Avenue bridge, New River, Fort Lauderdale, Florida	NOS	8722937	26.1183	-80.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:51:00	\N	1.07	00:15:00	\N	0.92	\N	\N	Andrews Avenue bridge, New River	FL
67807	Bahia Mar Yacht Club, Fort Lauderdale, Florida	NOS	8722939	26.1133	-80.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:33:00	\N	1.21	-00:05:00	\N	1.05	\N	\N	Bahia Mar Yacht Club	FL
67808	Mayan Lake, Florida	NOS	8722946	26.1	-80.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:02:00	\N	1	00:20:00	\N	0.91	\N	\N	Mayan Lake	FL
67809	Port Everglades, Turning Basin, Florida	NOS	8722951	26.0917	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:09:00	\N	1.14	-00:29:00	\N	1.09	\N	\N	Port Everglades, Turning Basin	FL
67810	Whiskey Creek, north end, Florida	NOS	8722957	26.08	-80.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:06:00	\N	1.28	-00:23:00	\N	1.1	\N	\N	Whiskey Creek, north end	FL
67811	Port Laudania, Dania cut-off Canal, Florida	NOS	8722968	26.06	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:11:00	\N	1.21	00:01:00	\N	1	\N	\N	Port Laudania, Dania cut-off Canal	FL
67812	Whiskey Creek, south entrance, ICWW, Florida	NOS	8722971	26.055	-80.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:31:00	\N	1.14	00:04:00	\N	0.96	\N	\N	Whiskey Creek, south entrance, ICWW	FL
67813	Hollywood Beach, West Lake, north end, Florida	NOS	8722977	26.0433	-80.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:42:00	\N	1.07	01:08:00	\N	0.85	\N	\N	Hollywood Beach, West Lake, north end	FL
67814	Hollywood Beach, Florida	NOS	8722979	26.04	-80.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:41:00	\N	1.14	00:37:00	\N	0.91	\N	\N	Hollywood Beach	FL
67815	Hollywood Beach, West Lake, south end, Florida	NOS	8722982	26.0333	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:45:00	\N	1.14	01:02:00	\N	0.88	\N	\N	Hollywood Beach, West Lake, south end	FL
67816	Golden Beach, ICWW, Florida	NOS	8723026	25.9667	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:57:00	\N	1.07	01:13:00	\N	0.91	\N	\N	Golden Beach, ICWW	FL
67817	Dumfoundling Bay, Florida	NOS	8723044	25.9417	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:07:00	\N	1	01:17:00	\N	0.88	\N	\N	Dumfoundling Bay	FL
67818	North Miami Beach, Newport Fishing Pier, Florida	NOS	8723050	25.93	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:00:00	\N	1.21	-00:22:00	\N	1.08	\N	\N	North Miami Beach, Newport Fishing Pier	FL
67819	Bakers Haulover Inlet (inside), Florida	NOS	8723073	25.9033	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:37:00	\N	0.92	00:57:00	\N	0.87	\N	\N	Bakers Haulover Inlet (inside)	FL
67820	Haulover Pier, N. Miami Beach, Florida (sub)	NOS	8723080	25.9033	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:06:00	\N	1	-00:29:00	\N	1.06	\N	\N	Haulover Pier, N. Miami Beach	FL
67821	Sunny Isles, Biscayne Creek, Florida	NOS	8723087	25.9283	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:24:00	\N	0.71	02:00:00	\N	0.77	\N	\N	Sunny Isles, Biscayne Creek	FL
67822	Biscayne Creek, ICWW, Florida	NOS	8723089	25.88	-80.1633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:39:00	\N	1	00:47:00	\N	0.93	\N	\N	Biscayne Creek, ICWW	FL
67823	Indian Creek Golf Club, ICWW, Florida	NOS	8723094	25.875	-80.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:46:00	\N	0.92	01:13:00	\N	0.92	\N	\N	Indian Creek Golf Club, ICWW	FL
67824	Dodge Island, Fishermans Channel, Biscayne Bay, Florida	NOS	8723155	25.77	-80.1683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:10:00	\N	1	00:34:00	\N	0.91	\N	\N	Dodge Island, Fishermans Channel	FL
67825	San Marino Island, Biscayne Bay, Florida	NOS	8723156	25.7933	-80.1633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:58:00	\N	1	00:37:00	\N	0.92	\N	\N	San Marino Island	FL
67826	Miami, Miamarina, Biscayne Bay, Florida (sub)	NOS	8723165	25.7783	-80.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:49:00	\N	0.92	00:20:00	\N	0.94	\N	\N	Miami Miamarina, Biscayne Bay	FL
67827	Miami Beach (city pier), Florida (sub)	NOS	8723170	25.7683	-80.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:02:00	\N	1.14	-00:22:00	\N	1.07	\N	\N	Miami Harbor Entrance	FL
67828	Dinner Key Marina, Biscayne Bay, Florida	NOS	8723205	25.7267	-80.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:48:00	\N	0.92	00:54:00	\N	0.84	\N	\N	Dinner Key Marina	FL
67829	Virginia Key, Bear Cut, Biscayne Bay, Florida (sub)	NOS	8723214	25.7314	-80.1618	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:51:00	\N	0.86	00:28:00	\N	0.88	\N	\N	Bear Cut, Virginia Key	FL
67830	Key Biscayne Yacht Club, Biscayne Bay, Florida	NOS	8723232	25.6983	-80.17	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:31:00	\N	0.92	00:44:00	\N	0.86	\N	\N	Key Biscayne Yacht Club, Biscayne Bay	FL
67831	Coral Shoal, Biscayne Channel, Florida	NOS	8723251	25.6517	-80.16	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:37:00	\N	0.92	00:11:00	\N	0.88	\N	\N	Coral Shoal, Biscayne Channel	FL
67832	Soldier Key, Florida	NOS	8723303	25.59	-80.1617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:16:00	\N	0.71	00:30:00	\N	0.81	\N	\N	Soldier Key	FL
67833	Ragged Keys, Biscayne Bay, Florida	NOS	8723350	25.5333	-80.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:18:00	\N	1	00:43:00	\N	0.73	\N	\N	Ragged Keys, Biscayne Bay	FL
67834	Sands Key, northwest point, Biscayne Bay, Florida	NOS	8723372	25.5067	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:26:00	\N	0.64	01:25:00	\N	0.63	\N	\N	Sands Key, northwest point, Biscayne Bay	FL
67835	Coon Point, Elliott Key, Biscayne Bay, Florida	NOS	8723391	25.48	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	02:56:00	\N	0.71	01:55:00	\N	0.63	\N	\N	Coon Point, Elliott Key, Biscayne Bay	FL
67836	Sea Grape Point, Elliott Key, Florida	NOS	8723393	25.4767	-80.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:05:00	\N	1.03	-00:25:00	\N	1.03	\N	\N	Sea Grape Point, Elliott Key	FL
67837	Billys Point, south of, Elliott Key, Biscayne Bay, Florida	NOS	8723439	25.415	-80.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:20:00	\N	0.64	02:08:00	\N	0.63	\N	\N	Billys Point, south of, Elliott Key, Biscayne Bay	FL
67838	Adams Key, south end, Biscayne Bay, Florida	NOS	8723453	25.3967	-80.2333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:08:00	\N	1	01:01:00	\N	0.67	\N	\N	Adams Key, south end, Biscayne Bay	FL
67839	Christmas Point, Elliott Key, Florida	NOS	8723457	25.3917	-80.23	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:37:00	\N	1.07	00:13:00	\N	0.8	\N	\N	Christmas Point, Elliott Key	FL
67840	Totten Key, west side, Biscayne Bay, Florida	NOS	8723467	25.3783	-80.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:21:00	\N	0.57	02:19:00	\N	0.54	\N	\N	Totten Key, west side, Biscayne Bay	FL
67841	Card Sound, western side, Florida	NOS	8723491	25.345	-80.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:40:00	\N	0.43	02:51:00	\N	0.3	\N	\N	Card Sound, western side	FL
67842	Wednesday Point, Key Largo, Card Sound, Florida	NOS	8723518	25.31	-80.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:30:00	\N	0.57	02:38:00	\N	0.34	\N	\N	Wednesday Point, Key Largo, Card Sound	FL
67843	Ocean Reef Harbor, Key Largo, Florida	NOS	8723519	25.3083	-80.2767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:17:00	\N	1.5	-00:08:00	\N	1.02	\N	\N	Ocean Reef Harbor, Key Largo	FL
67844	Cormorant Point, Key Largo, Card Sound, Florida	NOS	8723532	25.29	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:01:00	\N	0.5	02:45:00	\N	0.32	\N	\N	Cormorant Point, Key Largo, Card Sound	FL
67845	Main Key, Barnes Sound, Florida	NOS	8723571	25.24	-80.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	06:16:00	\N	0.36	05:04:00	\N	0.19	\N	\N	Main Key, Barnes Sound	FL
67846	Manatee Creek, Manatee Bay, Barnes Sound, Florida	NOS	8723575	25.235	-80.43	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	06:20:00	\N	0.36	05:14:00	\N	0.18	\N	\N	Manatee Creek, Manatee Bay, Barnes Sound	FL
67847	Carysfort Reef, Florida	NOS	8723583	25.2217	-80.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:39:00	\N	1.36	00:19:00	\N	1.03	\N	\N	Carysfort Reef	FL
67848	Garden Cove, Key Largo, Florida	NOS	8723622	25.1717	-80.3667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:25:00	\N	1.14	-00:01:00	\N	0.94	\N	\N	Garden Cove, Key Largo	FL
67849	Flamingo, Florida Bay, Florida	NOS	8723644	25.1417	-80.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	07:20:00	\N	1.08	05:28:00	\N	1.47	\N	\N	Flamingo, Florida Bay	FL
67850	Largo Sound, Key Largo, Florida	NOS	8723651	25.14	-80.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	03:03:00	\N	0.5	02:13:00	\N	0.35	\N	\N	Largo Sound, Key Largo	FL
67851	Key Largo, South Sound, Key Largo, Florida	NOS	8723667	25.113333333332992	-80.41666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:49:00	\N	0.64	00:23:00	\N	0.66	\N	\N	Key Largo, South Sound, Key Largo	FL
67852	Rock Harbor, Key Largo, Florida	NOS	8723689	25.0817	-80.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:36:00	\N	1.21	00:22:00	\N	0.94	\N	\N	Rock Harbor, Key Largo	FL
67853	Point Charles, Key Largo, Florida	NOS	8723691	25.0817	-80.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:53:00	\N	0.64	00:25:00	\N	0.77	\N	\N	Point Charles, Key Largo	FL
67854	Crane Keys, north side, Florida Bay, Florida	NOS	8723746	25.005	-80.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	04:35:00	\N	0.21	02:52:00	\N	0.17	\N	\N	Crane Keys, north side, Florida Bay	FL
67855	Tavernier Harbor, Hawk Channel, Florida	NOS	8723747	25.005	-80.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:26:00	\N	1.36	00:07:00	\N	0.9	\N	\N	Tavernier Harbor, Hawk Channel	FL
67856	Tavernier Creek, Hwy. 1 bridge, Hawk Channel, Florida	NOS	8723748	25.0033	-80.53	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:52:00	\N	1.07	00:25:00	\N	0.6	\N	\N	Tavernier Creek, Hwy. 1 bridge, Hawk Channel	FL
67857	East Key, southern end, Florida Bay, Florida	NOS	8723752	24.9967	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	04:06:00	\N	0.14	02:43:00	\N	0.22	\N	\N	East Key, southern end, Florida Bay	FL
67858	Plantation Key, Hawk Channel, Florida	NOS	8723769	24.9733	-80.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:12:00	\N	1.21	00:05:00	\N	0.96	\N	\N	Plantation Key, Hawk Channel	FL
68802	Raven Bay, Unalaska Island, Alaska	NOS	9462573	53.475	-166.873	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-03:48:00	\N	1.27	-03:16:00	\N	1.49	\N	\N	Raven Bay	AK
67859	Yacht Harbor, Cowpens Anchorage, Plantation Key, Florida	NOS	8723776	24.965	-80.5683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	04:00:00	\N	0.29	02:45:00	\N	0.23	\N	\N	Yacht Harbor, Cowpens Anchorage, Plantation Key	FL
67860	Snake Creek, USCG Station, Plantation Key, Florida	NOS	8723786	24.9533	-80.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:56:00	\N	0.5	01:08:00	\N	0.36	\N	\N	Snake Creek, USCG Station, Plantation Key	FL
67861	Snake Creek, Hwy. 1 bridge, Windley Key, Florida	NOS	8723787	24.9517	-80.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:56:00	\N	0.5	00:49:00	\N	0.46	\N	\N	Snake Creek, Hwy. 1 bridge, Windley Key	FL
67862	Whale Harbor, Windley Key, Hawk Channel, Florida	NOS	8723795	24.94	-80.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:51:00	\N	0.36	00:07:00	\N	0.65	\N	\N	Whale Harbor, Windley Key, Hawk Channel	FL
67863	Whale Harbor Channel, Hwy. 1 bridge, Windley Key, Florida	NOS	8723797	24.9383	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:00:00	\N	0.71	00:16:00	\N	0.59	\N	\N	Whale Harbor Channel, Hwy. 1 bridge, Windley Key	FL
67864	Shell Key, northwest side, Lignumvitae Basin, Florida	NOS	8723807	24.9233	-80.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:57:00	\N	0.46	00:31:00	\N	0.46	\N	\N	Shell Key, northwest side, Lignumvitae Basin	FL
67865	Islamorada, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723808	24.925	-80.6317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:07:00	\N	0.37	00:39:00	\N	0.37	\N	\N	Islamorada, Upper Matecumbe Key, Florida Bay	FL
67866	Shell Key Channel, Florida Bay, Florida	NOS	8723812	24.9133	-80.66	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:45:00	\N	0.78	-00:20:00	\N	0.78	\N	\N	Shell Key Channel, Florida Bay	FL
67867	Little Basin, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723813	24.915	-80.64	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:15:00	\N	0.61	00:08:00	\N	0.61	\N	\N	Little Basin, Upper Matecumbe Key, Florida Bay	FL
67868	Upper Matecumbe Key, Hawk Channel, Florida	NOS	8723814	24.915	-80.6317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:49:00	\N	1.21	00:34:00	\N	0.87	\N	\N	Upper Matecumbe Key, Hawk Channel	FL
67869	Lignumvitae Key, NE side, Florida Bay, Florida	NOS	8723824	24.9033	-80.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:31:00	\N	0.52	00:09:00	\N	0.52	\N	\N	Lignumvitae Key, NE side, Florida Bay	FL
67870	Lignumvitae Key, west side, Florida Bay, Florida	NOS	8723825	24.9	-80.705	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:54:00	\N	0.47	00:32:00	\N	0.47	\N	\N	Lignumvitae Key, west side, Florida Bay	FL
67871	Upper Matecumbe Key, west end, Hawk Channel, Florida	NOS	8723828	24.8967	-80.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:14:00	\N	0.33	-01:00:00	\N	0.98	\N	\N	Upper Matecumbe Key, west end, Hawk Channel	FL
67872	Indian Key, Hawk Channel, Florida	NOS	8723843	24.8767	-80.6767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:35:00	\N	0.71	-00:58:00	\N	1.3	\N	\N	Indian Key, Hawk Channel	FL
67873	Indian Key Anchorage, Lower Matecumbe Key, Florida	NOS	8723851	24.8683	-80.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:54:00	\N	0.88	-01:25:00	\N	1.38	\N	\N	Indian Key Anchorage, Lower Matecumbe Key	FL
67874	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723852	24.865	-80.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:33:00	\N	0.38	-00:18:00	\N	0.55	\N	\N	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay	FL
67875	Alligator Reef, Hawk Channel, Florida	NOS	8723861	24.85	-80.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	00:24:00	\N	1.36	00:08:00	\N	0.86	\N	\N	Alligator Reef, Hawk Channel	FL
67876	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723862	24.8517	-80.74	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:23:00	\N	0.33	-00:25:00	\N	0.59	\N	\N	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay	FL
67877	Channel Two, east, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723868	24.845	-80.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:42:00	\N	0.54	-00:49:00	\N	0.85	\N	\N	Channel Two, east, Lower Matecumbe Key, Fla. Bay	FL
67878	Channel Two, west side, Hawk Channel, Florida	NOS	8723869	24.8417	-80.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:54:00	\N	0.75	-01:06:00	\N	1.12	\N	\N	Channel Two, west side, Hawk Channel	FL
67879	Channel Five, west side, Hawk Channel, Florida	NOS	8723872	24.84	-80.78	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:41:00	\N	0.67	-00:58:00	\N	1	\N	\N	Channel Five, west side, Hawk Channel	FL
67880	Jewfish Hole, Long Key, Florida Bay, Florida	NOS	8723873	24.8383	-80.7983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:32:00	\N	0.38	-00:11:00	\N	0.42	\N	\N	Jewfish Hole, Long Key, Florida Bay	FL
67881	Channel Five, east side, Hawk Channel, Florida	NOS	8723874	24.8367	-80.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:42:00	\N	0.58	-00:54:00	\N	0.9	\N	\N	Channel Five, east side, Hawk Channel	FL
67882	Long Key Bight, Long Key, Florida	NOS	8723879	24.8283	-80.8083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:43:00	\N	0.62	-00:59:00	\N	1.03	\N	\N	Long Key Bight, Long Key	FL
67883	Long Key Lake, Long Key, Florida	NOS	8723887	24.82	-80.8167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:57:00	\N	0.46	00:33:00	\N	0.62	\N	\N	Long Key Lake, Long Key	FL
67884	Long Key, western end, Florida	NOS	8723899	24.8033	-80.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:54:00	\N	0.33	-01:01:00	\N	0.82	\N	\N	Long Key, western end	FL
67885	Conch Key, eastern end, Florida	NOS	8723906	24.7917	-80.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:45:00	\N	0.54	-01:09:00	\N	0.85	\N	\N	Conch Key, eastern end	FL
67886	Toms Harbor Cut, Florida	NOS	8723912	24.7833	-80.9067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:30:00	\N	0.38	-01:19:00	\N	0.37	\N	\N	Toms Harbor Cut	FL
67887	Toms Harbor Channel, Hwy. 1 bridge, Florida	NOS	8723918	24.7767	-80.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:49:00	\N	0.38	05:07:00	\N	0.38	\N	\N	Toms Harbor Channel, Hwy. 1 bridge	FL
67888	Grassy Key, north side, Florida Bay, Florida	NOS	8723921	24.7717	-80.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	06:48:00	\N	1.04	05:40:00	\N	0.73	\N	\N	Grassy Key, north side, Florida Bay	FL
67889	Duck Key, Hawk Channel, Florida	NOS	8723927	24.765	-80.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:40:00	\N	0.55	-01:11:00	\N	0.97	\N	\N	Duck Key, Hawk Channel	FL
67890	Grassy Key, south side, Hawk Channel, Florida	NOS	8723933	24.755	-80.9583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:26:00	\N	0.71	-00:52:00	\N	1.22	\N	\N	Grassy Key, south side, Hawk Channel	FL
67891	Fat Deer Key, Florida Bay, Florida	NOS	8723949	24.7333	-81.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	06:26:00	\N	0.87	05:09:00	\N	0.87	\N	\N	Fat Deer Key, Florida Bay	FL
67892	Vaca Key-Fat Deer Key bridge, Florida	NOS	8723950	24.73	-81.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:36:00	\N	0.71	-01:11:00	\N	0.95	\N	\N	Vaca Key-Fat Deer Key bridge	FL
67893	Key Colony Beach, Florida (sub)	NOS	8723962	24.7183	-81.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:53:00	\N	0.83	-01:17:00	\N	1.22	\N	\N	Key Colony Beach	FL
67894	Boot Key Harbor bridge, Boot Key, Florida	NOS	8723971	24.7033	-81.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:37:00	\N	0.75	-01:03:00	\N	1.13	\N	\N	Boot Key Harbor bridge, Boot Key	FL
67895	Sombrero Key, Hawk Channel, Florida	NOS	8723999	24.6267	-81.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:39:00	\N	0.79	-01:03:00	\N	1.18	\N	\N	Sombrero Key, Hawk Channel	FL
67896	Knight Key Channel, Knight Key, Florida Bay, Florida	NOS	8724008	24.7067	-81.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:18:00	\N	0.5	-00:02:00	\N	0.54	\N	\N	Knight Key Channel, Knight Key, Florida Bay	FL
67897	Pigeon Key, south side, Hawk Channel, Florida	NOS	8724032	24.7033	-81.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:26:00	\N	0.5	-00:55:00	\N	0.81	\N	\N	Pigeon Key, south side, Hawk Channel	FL
67898	Pigeon Key, north side, Florida Bay, Florida	NOS	8724033	24.705	-81.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:45:00	\N	0.46	-00:10:00	\N	0.46	\N	\N	Pigeon Key, north side, Florida Bay	FL
67899	Molasses Key Channel, Molasses Keys, Florida	NOS	8724062	24.6833	-81.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:16:00	\N	0.5	-00:56:00	\N	0.79	\N	\N	Molasses Key Channel, Molasses Keys	FL
67900	Money Key, Florida	NOS	8724082	24.6833	-81.2167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:17:00	\N	0.58	00:03:00	\N	0.58	\N	\N	Money Key	FL
67901	Little Duck Key, east end, Hawk Channel, Florida	NOS	8724093	24.6817	-81.2283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:05:00	\N	0.67	-00:49:00	\N	0.67	\N	\N	Little Duck Key, east end, Hawk Channel	FL
67902	East Bahia Honda Key, south end, Florida Bay, Florida	NOS	8724094	24.775	-81.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:49:00	\N	0.69	04:04:00	\N	0.69	\N	\N	East Bahia Honda Key, south end, Florida Bay	FL
67903	Cocoanut Key, Florida Bay, Florida	NOS	8724098	24.745	-81.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:50:00	\N	0.55	03:52:00	\N	0.55	\N	\N	Cocoanut Key, Florida Bay	FL
67904	Missouri Key-Little Duck Key Channel, Florida	NOS	8724099	24.68	-81.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:36:00	\N	0.46	-00:52:00	\N	0.7	\N	\N	Missouri Key-Little Duck Key Channel	FL
67905	Missouri Key-Ohio Key Channel, west side, Florida	NOS	8724107	24.6733	-81.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:22:00	\N	0.5	-00:47:00	\N	0.77	\N	\N	Missouri Key-Ohio Key Channel, west side	FL
67906	Ohio Key-Bahia Honda Key Channel, west side, Florida	NOS	8724112	24.67	-81.2517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:14:00	\N	0.62	-00:57:00	\N	0.81	\N	\N	Ohio Key-Bahia Honda Key Channel, west side	FL
67907	West Bahia Honda Key, Florida	NOS	8724129	24.78	-81.2717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:01:00	\N	1	03:59:00	\N	0.97	\N	\N	West Bahia Honda Key	FL
67908	Bahia Honda Key, Bahia Honda Channel, Florida	NOS	8724138	24.655	-81.2817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:28:00	\N	0.63	-00:46:00	\N	0.86	\N	\N	Bahia Honda Key, Bahia Honda Channel	FL
67909	Horseshoe Keys, south end, Florida	NOS	8724139	24.7667	-81.2833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	03:09:00	\N	1	03:54:00	\N	0.86	\N	\N	Horseshoe Keys, south end	FL
67910	Johnson Keys, south end, Florida	NOS	8724153	24.7433	-81.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:33:00	\N	0.96	03:36:00	\N	0.72	\N	\N	Johnson Keys, south end	FL
67911	Little Pine Key, south end, Florida	NOS	8724154	24.7133	-81.3033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:07:00	\N	0.79	01:07:00	\N	0.56	\N	\N	Little Pine Key, south end	FL
67912	No Name Key, east side, Bahia Honda Channel, Florida	NOS	8724168	24.6983	-81.3183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:33:00	\N	0.83	01:35:00	\N	0.58	\N	\N	No Name Key, east side, Bahia Honda Channel	FL
67913	Johnson Keys, north end, Florida	NOS	8724172	24.7667	-81.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:22:00	\N	1.38	03:35:00	\N	1.31	\N	\N	Johnson Keys, north end	FL
67914	Little Pine Key, north end, Florida	NOS	8724177	24.75	-81.3283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	03:28:00	\N	1.21	03:38:00	\N	1.05	\N	\N	Little Pine Key, north end	FL
67915	Big Pine Key, Spanish Harbor, Florida	NOS	8724178	24.6483	-81.33	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:03:00	\N	0.42	-00:44:00	\N	0.75	\N	\N	Big Pine Key, Spanish Harbor	FL
67916	Water Key, west end, Big Spanish Channel, Florida	NOS	8724189	24.74	-81.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:37:00	\N	1.04	03:23:00	\N	0.81	\N	\N	Water Key, west end, Big Spanish Channel	FL
67917	Big Pine Key, Coupon Bight, Florida	NOS	8724192	24.6517	-81.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:49:00	\N	0.5	-00:20:00	\N	0.87	\N	\N	Big Pine Key, Coupon Bight	FL
67918	Big Pine Key, Bogie Channel Bridge, Florida	NOS	8724193	24.6967	-81.3483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:11:00	\N	0.83	02:10:00	\N	0.65	\N	\N	Big Pine Key, Bogie Channel Bridge	FL
67919	Porpoise Key, Big Spanish Channel, Florida	NOS	8724196	24.7183	-81.3517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:29:00	\N	1	03:23:00	\N	0.72	\N	\N	Porpoise Key, Big Spanish Channel	FL
67920	Crawl Key, Big Spanish Channel, Florida	NOS	8724199	24.7567	-81.3583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:13:00	\N	1.33	03:34:00	\N	1.33	\N	\N	Crawl Key, Big Spanish Channel	FL
67921	Big Pine Key, Doctors Arm, Bogie Channel, Florida	NOS	8724201	24.69	-81.3567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:47:00	\N	0.71	00:41:00	\N	0.63	\N	\N	Big Pine Key, Doctors Arm, Bogie Channel	FL
67922	Mayo Key, Big Spanish Channel, Florida	NOS	8724205	24.7333	-81.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	03:01:00	\N	1.08	03:35:00	\N	0.92	\N	\N	Mayo Key, Big Spanish Channel	FL
67923	Little Spanish Key, Spanish Banks, Florida	NOS	8724209	24.7733	-81.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:30:00	\N	1.62	03:25:00	\N	1.74	\N	\N	Little Spanish Key, Spanish Banks	FL
67924	Big Pine Key, Pine Channel Bridge, north side, Florida	NOS	8724211	24.67	-81.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:43:00	\N	0.33	00:03:00	\N	0.57	\N	\N	Big Pine Key, Pine Channel Bridge, north side	FL
67925	Big Pine Key, Pine Channel Bridge, south side, Florida	NOS	8724213	24.6683	-81.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:03:00	\N	0.33	-00:13:00	\N	0.67	\N	\N	Big Pine Key, Pine Channel Bridge, south side	FL
67926	Big Pine Key, Newfound Harbor Channel, Florida	NOS	8724215	24.6517	-81.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:44:00	\N	0.46	-00:09:00	\N	0.82	\N	\N	Big Pine Key, Newfound Harbor Channel	FL
67927	Little Torch Key, Pine Channel Bridge, south side, Florida	NOS	8724223	24.665	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:57:00	\N	0.33	-00:15:00	\N	0.68	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
67928	Little Torch Key, Pine Channel Bridge, south side, Florida (2)	NOS	8724224	24.665	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:54:00	\N	0.38	-00:13:00	\N	0.69	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
67929	Big Pine Key, northeast shore, Florida	NOS	8724226	24.7283	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:30:00	\N	1.08	03:19:00	\N	0.86	\N	\N	Big Pine Key, northeast shore	FL
67930	Big Pine Key, west side, Pine Channel, Florida	NOS	8724227	24.69	-81.3833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:52:00	\N	0.42	00:21:00	\N	0.52	\N	\N	Big Pine Key, west side, Pine Channel	FL
67931	Annette Key, north end, Big Spanish Channel, Florida	NOS	8724229	24.7583	-81.39	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:33:00	\N	1.29	03:30:00	\N	1.44	\N	\N	Annette Key, north end, Big Spanish Channel	FL
67932	Big Pine Key, north end, Florida	NOS	8724231	24.745	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:56:00	\N	0.83	04:24:00	\N	0.96	\N	\N	Big Pine Key, north end	FL
67933	Little Torch Key, Torch Channel, Florida	NOS	8724232	24.665	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:45:00	\N	0.33	00:11:00	\N	0.57	\N	\N	Little Torch Key, Torch Channel	FL
67934	Middle Torch Key, Torch Ramrod Channel, Florida	NOS	8724237	24.6617	-81.4017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:29:00	\N	0.38	-00:16:00	\N	0.69	\N	\N	Middle Torch Key, Torch Ramrod Channel	FL
67935	Munson Island, Newfound Harbor Channel, Florida	NOS	8724238	24.6233	-81.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:12:00	\N	0.67	-00:40:00	\N	0.98	\N	\N	Munson Island, Newfound Harbor Channel	FL
67936	Ramrod Key, Newfound Harbor, Florida	NOS	8724239	24.65	-81.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:05:00	\N	0.5	-00:41:00	\N	0.9	\N	\N	Ramrod Key, Newfound Harbor	FL
67937	Howe Key, south end, Harbor Channel, Florida	NOS	8724243	24.725	-81.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:49:00	\N	0.62	04:43:00	\N	0.72	\N	\N	Howe Key, south end, Harbor Channel	FL
67938	Big Spanish Key, Florida	NOS	8724246	24.7883	-81.4117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:29:00	\N	1.5	03:19:00	\N	1.97	\N	\N	Big Spanish Key	FL
67939	Ramrod Key, Niles Channel Bridge, Florida	NOS	8724255	24.66	-81.4233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:12:00	\N	0.46	-00:13:00	\N	0.67	\N	\N	Ramrod Key, Niles Channel Bridge	FL
67940	Howe Key, northwest end, Florida	NOS	8724257	24.7583	-81.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:22:00	\N	1.33	03:29:00	\N	1.68	\N	\N	Howe Key, northwest end	FL
67941	Big Torch Key, Niles Channel, Florida	NOS	8724264	24.705	-81.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:05:00	\N	0.71	03:15:00	\N	0.61	\N	\N	Big Torch Key, Niles Channel	FL
67942	Summerland Key, Niles Channel South, Florida	NOS	8724266	24.6517	-81.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:11:00	\N	0.71	-00:36:00	\N	0.85	\N	\N	Summerland Key, Niles Channel South	FL
67943	Summerland Key, Niles Channel Bridge, Florida	NOS	8724267	24.66	-81.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:56:00	\N	0.58	-00:10:00	\N	0.67	\N	\N	Summerland Key, Niles Channel Bridge	FL
67944	Water Keys, south end, Harbor Channel, Florida	NOS	8724273	24.7467	-81.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:41:00	\N	1	03:42:00	\N	1.52	\N	\N	Water Keys, south end, Harbor Channel	FL
67945	Big Torch Key, Harbor Channel, Florida	NOS	8724274	24.7367	-81.4433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:51:00	\N	1.29	03:47:00	\N	1.58	\N	\N	Big Torch Key, Harbor Channel	FL
67946	Summerland Key, southwest side, Kemp Channel, Florida	NOS	8724276	24.65	-81.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:50:00	\N	0.54	-00:26:00	\N	0.81	\N	\N	Summerland Key, southwest side, Kemp Channel	FL
67947	Kemp Channel Viaduct, Florida Keys, Florida	NOS	8724292	24.6617	-81.4683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:04:00	\N	0.46	00:47:00	\N	0.58	\N	\N	Kemp Channel Viaduct	FL
67948	Key Lois, southeast end, Florida	NOS	8724293	24.6067	-81.47	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:45:00	\N	0.75	-01:15:00	\N	1.06	\N	\N	Key Lois, southeast end	FL
67949	Knockemdown Key, north end, Florida	NOS	8724302	24.715	-81.4783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:54:00	\N	1.21	03:30:00	\N	1.35	\N	\N	Knockemdown Key, north end	FL
67950	Gopher Key, Cudjoe Bay, Florida	NOS	8724306	24.6417	-81.485	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:17:00	\N	0.71	-00:46:00	\N	0.9	\N	\N	Gopher Key, Cudjoe Bay	FL
67951	Content Keys, Content Passage, Florida	NOS	8724307	24.79	-81.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	03:49:00	\N	1.83	02:46:00	\N	2.13	\N	\N	Content Keys, Content Passage	FL
67952	Raccoon Key, east side, Florida	NOS	8724311	24.7417	-81.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:09:00	\N	1.21	03:20:00	\N	1.5	\N	\N	Raccoon Key, east side	FL
67953	Cudjoe Key, Cudjoe Bay, Florida	NOS	8724313	24.66	-81.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:41:00	\N	0.71	-00:38:00	\N	0.87	\N	\N	Cudjoe Key, Cudjoe Bay	FL
67954	Sugarloaf Key, Pirates Cove, Florida	NOS	8724326	24.6533	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:41:00	\N	0.75	-00:48:00	\N	0.59	\N	\N	Sugarloaf Key, Pirates Cove	FL
67955	Sugarloaf Key, east side, Tarpon Creek, Florida	NOS	8724327	24.6283	-81.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:15:00	\N	0.58	-00:41:00	\N	0.89	\N	\N	Sugarloaf Key, east side, Tarpon Creek	FL
67956	Cudjoe Key, north end, Kemp Channel, Florida	NOS	8724328	24.7	-81.505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:40:00	\N	1.46	03:33:00	\N	1.61	\N	\N	Cudjoe Key, north end, Kemp Channel	FL
67957	Cudjoe Key, Pirates Cove, Florida	NOS	8724332	24.6617	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:54:00	\N	0.79	03:50:00	\N	0.77	\N	\N	Cudjoe Key, Pirates Cove	FL
67958	Tarpon Creek, Upper Sugarloaf Sound, Florida	NOS	8724334	24.63	-81.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:17:00	\N	0.38	-00:29:00	\N	0.35	\N	\N	Tarpon Creek	FL
67959	Sugarloaf Key, northeast side, Bow Channel, Florida	NOS	8724347	24.6717	-81.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	03:24:00	\N	0.71	03:47:00	\N	1.01	\N	\N	Sugarloaf Key, northeast side, Bow Channel	FL
67960	Park Channel Bridge, Upper Sugarloaf Sound, Florida	NOS	8724353	24.655	-81.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	08:33:00	\N	0.29	05:47:00	\N	0.26	\N	\N	Park Channel Bridge	FL
67961	North Harris Channel, Upper Sugarloaf Sound, Florida	NOS	8724367	24.6533	-81.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	08:04:00	\N	0.25	05:32:00	\N	0.25	\N	\N	North Harris Channel	FL
67962	Sugarloaf Key, north end, Bow Channel, Florida	NOS	8724368	24.6933	-81.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:20:00	\N	0.75	03:37:00	\N	1.29	\N	\N	Sugarloaf Key, north end, Bow Channel	FL
67963	Sawyer Key, inside, Cudjoe Channel, Florida	NOS	8724369	24.7583	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:19:00	\N	0.5	02:37:00	\N	1.43	\N	\N	Sawyer Key, inside, Cudjoe Channel	FL
67964	Sawyer Key, outside, Cudjoe Channel, Florida	NOS	8724370	24.7583	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:24:00	\N	0.5	02:45:00	\N	1.57	\N	\N	Sawyer Key, outside, Cudjoe Channel	FL
67965	Pumpkin Key, Bow Channel, Florida	NOS	8724373	24.7167	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:39:00	\N	1.17	03:17:00	\N	1.56	\N	\N	Pumpkin Key, Bow Channel	FL
67966	Perky, Upper Sugarloaf Sound, Florida	NOS	8724378	24.6483	-81.57	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	08:25:00	\N	0.08	05:37:00	\N	0.28	\N	\N	Perky	FL
67967	Johnston Key, southwest end, Turkey Basin, Florida	NOS	8724397	24.71	-81.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:38:00	\N	0.5	03:26:00	\N	1.1	\N	\N	Johnston Key, southwest end, Turkey Basin	FL
67968	Saddlebunch Keys, Channel No. 3, Florida	NOS	8724405	24.6233	-81.6033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:10:00	\N	0.21	01:44:00	\N	0.43	\N	\N	Saddlebunch Keys, Channel No. 3	FL
68060	Aripeka, Hammock Creek, Florida	NOS	8727097	28.4333	-82.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	00:23:00	\N	0.63	-00:37:00	\N	0.81	\N	\N	Aripeka, Hammock Creek	FL
67969	Snipe Keys, southeast end, Inner Narrows, Florida	NOS	8724409	24.6583	-81.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:39:00	\N	0.83	03:25:00	\N	1.28	\N	\N	Snipe Keys, southeast end, Inner Narrows	FL
67970	Saddlebunch Keys, Channel No. 4, Florida	NOS	8724417	24.615	-81.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:36:00	\N	0.29	04:35:00	\N	0.54	\N	\N	Saddlebunch Keys, Channel No. 4	FL
67971	Saddlebunch Keys, Similar Sound, Florida	NOS	8724422	24.6	-81.6217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:41:00	\N	0.21	00:39:00	\N	0.37	\N	\N	Saddlebunch Keys, Similar Sound	FL
67972	Saddlebunch Keys, Channel No. 5, Florida	NOS	8724423	24.6117	-81.6233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	06:58:00	\N	1.12	04:32:00	\N	0.66	\N	\N	Saddlebunch Keys, Channel No. 5	FL
67973	Snipe Keys, Middle Narrows, Florida	NOS	8724427	24.6667	-81.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:54:00	\N	0.67	03:44:00	\N	1.02	\N	\N	Snipe Keys, Middle Narrows	FL
67974	Bird Key, Similar Sound, Florida	NOS	8724436	24.5883	-81.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:03:00	\N	0.42	-00:21:00	\N	0.59	\N	\N	Bird Key, Similar Sound	FL
67975	Shark Key, southeast end, Similar Sound, Florida	NOS	8724438	24.6033	-81.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:51:00	\N	0.46	00:18:00	\N	0.52	\N	\N	Shark Key, southeast end, Similar Sound	FL
67976	O'Hara Key, north end, Waltz Key Basin, Florida	NOS	8724441	24.6167	-81.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:39:00	\N	0.83	03:53:00	\N	1.03	\N	\N	O'Hara Key, north end, Waltz Key Basin	FL
67977	Waltz Key, Waltz Key Basin, Florida	NOS	8724448	24.6467	-81.6533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:33:00	\N	0.96	03:53:00	\N	1.03	\N	\N	Waltz Key, Waltz Key Basin	FL
67978	Rockland Key, Rockland Channel Bridge, Florida	NOS	8724459	24.5917	-81.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	06:06:00	\N	0.88	05:02:00	\N	0.76	\N	\N	Rockland Key, Rockland Channel Bridge	FL
67979	Snipe Keys, Snipe Point, Florida	NOS	8724463	24.6917	-81.6733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	03:33:00	\N	1.29	02:15:00	\N	1.69	\N	\N	Snipe Keys, Snipe Point	FL
67980	Duck Key Point, Duck Key, Waltz Key Basin, Florida	NOS	8724474	24.6233	-81.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	04:57:00	\N	0.96	03:27:00	\N	1.19	\N	\N	Duck Key Point, Duck Key, Waltz Key Basin	FL
67981	Boca Chica Key, Long Point, Florida	NOS	8724485	24.6033	-81.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	05:22:00	\N	0.71	03:54:00	\N	0.94	\N	\N	Boca Chica Key, Long Point	FL
67982	Big Coppitt Key, northeast side, Waltz Key Basin, Florida	NOS	8724489	24.6017	-81.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	06:54:00	\N	0.33	04:21:00	\N	0.84	\N	\N	Big Coppitt Key, northeast side, Waltz Key Basin	FL
67983	Boca Chica Key, Southwest end, Florida	NOS	8724499	24.5633	-81.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:16:00	\N	0.63	-00:14:00	\N	0.66	\N	\N	Boca Chica Key, Southwest end	FL
67984	Boca Chica Channel Bridge, Florida	NOS	8724503	24.5767	-81.7217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:29:00	\N	0.67	01:23:00	\N	0.57	\N	\N	Boca Chica Channel Bridge	FL
67985	Channel Key, west side, Florida	NOS	8724507	24.6033	-81.725	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	03:07:00	\N	0.71	03:09:00	\N	0.7	\N	\N	Channel Key, west side	FL
67986	Key Haven - Stock Island Channel, Florida	NOS	8724517	24.58	-81.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:57:00	\N	0.79	02:25:00	\N	0.73	\N	\N	Key Haven - Stock Island Channel	FL
67987	Cow Key Channel, Florida	NOS	8724527	24.57	-81.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:05:00	\N	0.71	01:55:00	\N	0.65	\N	\N	Cow Key Channel	FL
67988	Riviera Canal, Key West, Florida	NOS	8724529	24.565	-81.7517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	01:00:00	\N	0.63	-00:12:00	\N	0.65	\N	\N	Riveria Canal, Key West	FL
67989	Sigsbee Park, Garrison Bight Channel, Florida	NOS	8724542	24.585	-81.775	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	02:06:00	\N	0.88	01:59:00	\N	0.81	\N	\N	Sigsbee Park, Garrison Bight Channel	FL
67990	Key West, south side, White Street Pier, Florida	NOS	8724557	24.545	-81.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:31:00	\N	0.92	-00:53:00	\N	1.07	\N	\N	Key West, south side, White Street Pier	FL
67991	Sand Key Lighthouse, Sand Key Channel, Florida (sub)	NOS	8724635	24.4533	-81.8783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	-00:32:00	\N	0.88	-00:43:00	\N	0.95	\N	\N	Sand Key Lighthouse, Sand Key Channel	FL
67992	Garden Key, Dry Tortugas, Florida	NOS	8724697	24.6267	-82.8717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65964	00:33:00	\N	1.33	00:29:00	\N	0.94	\N	\N	Garden Key, Dry Tortugas	FL
67993	Shark River entrance, Florida	NOS	8724769	25.345	-81.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	01:45:00	\N	0.98	00:57:00	\N	1.43	\N	\N	Shark River entrance	FL
67994	Lostmans River entrance, Florida	NOS	8724842	25.5533	-81.2133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	01:59:00	\N	0.98	01:09:00	\N	1.33	\N	\N	Lostmans River entrance	FL
67995	Onion Key, Lostmans River, Florida	NOS	8724863	25.6117	-81.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	04:53:00	\N	0.16	03:09:00	\N	0.26	\N	\N	Onion Key, Lostmans River	FL
67996	Chatham River entrance, Florida	NOS	8724891	25.69	-81.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	01:53:00	\N	0.66	00:59:00	\N	1.43	\N	\N	Chatham River entrance	FL
67997	Chokoloskee, Florida	NOS	8724919	25.8133	-81.3633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	03:14:00	\N	0.62	02:15:00	\N	1.11	\N	\N	Chokoloskee	FL
67998	Cape Romano, Florida	NOS	8724947	25.8533	-81.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	01:04:00	\N	0.98	00:43:00	\N	1.19	\N	\N	Cape Romano	FL
67999	Everglades City, Barron River, Florida	NOS	8724948	25.8583	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	03:26:00	\N	0.57	02:25:00	\N	0.99	\N	\N	Everglades City, Barron River	FL
68000	Dismal Key, Pumpkin Bay, Florida (sub)	NOS	8724963	25.895	-81.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	03:07:00	\N	0.49	02:39:00	\N	0.89	\N	\N	Pumpkin Bay	FL
68001	Coon Key Pass, Gullivan Bay, Florida (sub)	NOS	8724964	25.8967	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	01:31:00	\N	0.98	01:15:00	\N	1.19	\N	\N	Coon Key	FL
68002	Naples, Naples Bay, north end, Florida	NOS	8725114	26.1367	-81.7883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	00:56:00	\N	0.9	00:43:00	\N	0.97	\N	\N	Naples, Naples Bay, north end	FL
68003	Cocohatchee River, U.S. 41 bridge, Florida	NOS	8725228	26.2817	-81.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	01:28:00	\N	0.65	01:10:00	\N	0.74	\N	\N	Cocohatchee River, U.S. 41 bridge	FL
68004	Wiggins Pass, Cocohatchee River, Florida	NOS	8725235	26.29	-81.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	00:59:00	\N	0.73	00:44:00	\N	0.77	\N	\N	Wiggins Pass, Cocohatchee River	FL
68005	Little Hickory Island, Estero Bay, Florida	NOS	8725283	26.3533	-81.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-01:05:00	\N	1.09	-00:58:00	\N	1.09	\N	\N	Little Hickory Island	FL
68006	Carlos Point, Estero Bay, Florida	NOS	8725325	26.405	-81.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-01:28:00	\N	1.17	-01:08:00	\N	1.17	\N	\N	Carlos Point	FL
68007	Estero River, Estero Bay, Florida	NOS	8725346	26.43	-81.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-00:10:00	\N	1.11	-00:45:00	\N	1.09	\N	\N	Estero River	FL
68008	Matanzas Pass (fixed bridge) Estero Island, Florida	NOS	8725366	26.4567	-81.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-01:34:00	\N	1.22	-01:10:00	\N	1.22	\N	\N	Matanzas Pass (fixed bridge) Estero Island	FL
68009	Captiva Island (outside), Florida	NOS	8725383	26.4783	-82.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-02:28:00	\N	1.13	-02:20:00	\N	1.13	\N	\N	Captiva Island (outside)	FL
68010	St. James City, Pine Island, Florida	NOS	8725393	26.4917	-82.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-00:44:00	\N	1.04	-00:30:00	\N	1.04	\N	\N	St. James City, Pine Island	FL
68011	Galt Island, Pine Island Sound, Florida	NOS	8725411	26.5133	-82.1067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:16:00	\N	0.91	-00:25:00	\N	0.91	\N	\N	Galt Island, Pine Island Sound	FL
68012	Captiva Island, Pine Island Sound, Florida	NOS	8725417	26.5217	-82.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-00:20:00	\N	0.91	-00:46:00	\N	0.91	\N	\N	Captiva Island, Pine Island Sound	FL
68013	Iona Shores, Caloosahatchee River, Florida	NOS	8725418	26.5217	-81.965	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	01:40:00	\N	0.43	01:08:00	\N	0.43	\N	\N	Iona Shores	FL
68014	Tropical Homesites Landing, Pine Island, Florida	NOS	8725439	26.5483	-82.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:22:00	\N	0.87	-00:08:00	\N	0.87	\N	\N	Tropical Homesites Landing, Pine Island	FL
68015	Redfish Pass, Captiva Island (north end), Florida	NOS	8725441	26.55	-82.1967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-01:14:00	\N	0.91	-00:55:00	\N	0.91	\N	\N	Redfish Pass, Captiva Island (north end)	FL
68016	Cape Coral Bridge, Caloosahatchee River, Florida	NOS	8725451	26.56447222222222	-81.93580555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	02:02:00	\N	0.43	01:15:00	\N	0.43	\N	\N	Cape Coral Bridge	FL
68017	Matlacha Pass (bascule bridge), Florida	NOS	8725506	26.6317	-82.0683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	01:28:00	\N	0.83	00:43:00	\N	0.83	\N	\N	Matlacha Pass (bascule bridge)	FL
68018	Fort Myers, Caloosahatchee River, Florida (sub)	NOS	8725520	26.6477	-81.8712	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	02:23:00	\N	0.39	01:56:00	\N	0.56	\N	\N	Fort Myers	FL
68019	Pineland, Pine Island, Florida	NOS	8725528	26.66	-82.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:26:00	\N	0.83	-00:19:00	\N	0.83	\N	\N	Pineland, Pine Island	FL
68020	Placida, Gasparilla Sound, Florida	NOS	8725667	26.8333	-82.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-00:56:00	\N	0.94	-00:43:00	\N	0.59	\N	\N	Placida, Gasparilla Sound	FL
68021	Punta Gorda, Charlotte Harbor, Florida	NOS	8725744	26.9283	-82.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	01:27:00	\N	0.83	01:06:00	\N	0.83	\N	\N	Punta Gorda, Charlotte Harbor	FL
68022	Englewood, Lemon Bay, Florida	NOS	8725747	26.9333	-82.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-00:17:00	\N	0.82	-00:17:00	\N	0.66	\N	\N	Englewood, Lemon Bay	FL
68023	El Jobean, Myakka River, Florida	NOS	8725769	26.9617	-82.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	01:56:00	\N	0.83	01:38:00	\N	0.83	\N	\N	El Jobean, Myakka River	FL
68024	Venice Inlet (inside), Florida	NOS	8725889	27.1117	-82.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-01:38:00	\N	0.91	-02:02:00	\N	0.91	\N	\N	Venice Inlet (inside)	FL
68025	Sarasota, Sarasota Bay, Florida	NOS	8726083	27.3317	-82.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-00:58:00	\N	0.91	-01:38:00	\N	0.91	\N	\N	Sarasota, Sarasota Bay	FL
68026	Cortez, Sarasota Bay, Florida	NOS	8726217	27.4667	-82.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-01:25:00	\N	0.96	-02:00:00	\N	0.96	\N	\N	Cortez, Sarasota Bay	FL
68027	Anna Maria Key, Bradenton Beach, Florida	NOS	8726243	27.4967	-82.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-03:32:00	\N	1	-02:27:00	\N	0.99	\N	\N	Anna Maria Key, Bradenton Beach	FL
68028	Bradenton, Manatee River, Florida	NOS	8726247	27.5	-82.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-00:55:00	\N	0.95	-01:24:00	\N	0.97	\N	\N	Bradenton, Manatee River	FL
68029	Redfish Point, Manatee River, Florida	NOS	8726278	27.5267	-82.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:14:00	\N	1	-00:30:00	\N	0.92	\N	\N	Redfish Point, Manatee River	FL
68030	Anna Maria Key, city pier, Florida	NOS	8726282	27.5333	-82.73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-02:19:00	\N	0.99	-02:10:00	\N	0.99	\N	\N	Anna Maria Key, city pier	FL
68031	Egmont Key, Egmont Channel, Tampa Bay, Florida (sub)	NOS	8726347	27.6017	-82.76	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-03:20:00	\N	1	-02:15:00	\N	0.96	\N	\N	Egmont Key, Egmont Channel	FL
68032	Mullet Key Channel (Skyway), Tampa Bay, Florida (sub)	NOS	8726364	27.615	-82.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-02:01:00	\N	0.92	-02:03:00	\N	0.92	\N	\N	Mullet Key Channel (Skyway)	FL
68033	Port Manatee, Tampa Bay, Florida (sub)	NOS	8726384	27.6383333	-82.5625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-00:48:00	\N	0.95	-01:00:00	\N	0.97	\N	\N	Port Manatee	FL
68034	Point Pinellas, Florida	NOS	8726454	27.7017	-82.64	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-00:29:00	\N	0.86	-00:22:00	\N	0.86	\N	\N	Point Pinellas	FL
68035	Shell Point, Florida	NOS	8726468	27.7183	-82.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:17:00	\N	0.91	00:08:00	\N	0.91	\N	\N	Shell Point	FL
68036	Gulfport, Boca Ciega Bay, Florida	NOS	8726486	27.7367	-82.7067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-01:05:00	\N	0.96	-01:32:00	\N	0.96	\N	\N	Gulfport	FL
68037	Long Key, 0.5mi N. of Corey Causeway, Boca Ciega Bay, Florida	NOS	8726494	27.7517	-82.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-00:44:00	\N	1	-01:18:00	\N	0.92	\N	\N	Long Key, 0.5mi N. of Corey Causeway	FL
68038	Johns Pass, Boca Ciega Bay, Florida	NOS	8726533	27.785	-82.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-02:04:00	\N	1.02	-02:14:00	\N	0.97	\N	\N	Johns Pass	FL
68039	Apollo Beach, Hillsborough Bay, Tampa Bay, Florida	NOS	8726537	27.786699295043945	-82.42669677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:32:00	\N	1.2	00:53:00	\N	1.1	\N	\N	APOLLO BEACH, HILLSBOROUGH BAY	FL
68040	Madeira Beach Causeway, Boca Ciega Bay, Florida	NOS	8726574	27.8083	-82.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-01:45:00	\N	1.18	-01:32:00	\N	1.08	\N	\N	Madeira Beach Causeway	FL
68041	Port Tampa, Old Tampa Bay, Florida (sub)	NOS	8726607	27.8577778	-82.5527778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:39:00	\N	1.18	00:25:00	\N	1.1	\N	\N	Old Port Tampa	FL
68042	Indian Rocks Beach (inside), Florida	NOS	8726625	27.8767	-82.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-00:53:00	\N	0.63	-00:57:00	\N	0.65	\N	\N	Indian Rocks Beach (inside)	FL
68043	Gandy Bridge, Old Tampa Bay, Florida	NOS	8726641	27.8933	-82.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:57:00	\N	1.24	00:59:00	\N	1.12	\N	\N	Gandy Bridge, Old Tampa Bay	FL
68044	Pendola Point, Hillsborough Bay, Florida	NOS	8726651	27.8983	-82.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:05:00	\N	1.18	00:21:00	\N	1.14	\N	\N	Pendola Point, Hillsborough Bay	FL
68045	Davis Island, Hillsborough Bay, Florida	NOS	8726657	27.9083	-82.4517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:32:00	\N	1.24	00:03:00	\N	1.16	\N	\N	Davis Island, Hillsborough Bay	FL
68047	Bay Aristocrat Village, Old Tampa Bay, Florida	NOS	8726689	27.9417	-82.72	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	01:32:00	\N	1.37	01:01:00	\N	1.24	\N	\N	Bay Aristocrat Village, Old Tampa Bay	FL
68048	Clearwater, Florida	NOS	8726706	27.955	-82.8067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-01:35:00	\N	0.63	-01:48:00	\N	0.65	\N	\N	Clearwater	FL
68049	Clearwater Beach, Gulf Of Mexico, Florida (sub)	NOS	8726724	27.9783	-82.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-02:19:00	\N	0.84	-02:07:00	\N	0.69	\N	\N	Clearwater Beach	FL
68050	Safety Harbor, Old Tampa Bay, Florida (sub)	NOS	8726738	27.9883	-82.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	01:34:00	\N	1.39	01:32:00	\N	1.23	\N	\N	Safety Harbor, Old Tampa Bay	FL
68051	Dunedin, St. Joseph Sound, Florida	NOS	8726761	28.0133	-82.7933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-01:45:00	\N	0.79	-01:50:00	\N	0.7	\N	\N	Dunedin, St. Joseph Sound	FL
68052	Mobbly Bayou, Florida	NOS	8726769	28.0217	-82.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	02:54:00	\N	0.45	02:38:00	\N	0.71	\N	\N	Mobbly Bayou	FL
68053	Tarpon Springs, Anclote River, Florida	NOS	8726905	28.16	-82.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-01:03:00	\N	0.83	-01:16:00	\N	0.77	\N	\N	Tarpon Springs, Anclote River	FL
68054	Anclote, Anclote River, Florida	NOS	8726924	28.1717	-82.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-01:24:00	\N	0.87	-01:28:00	\N	0.78	\N	\N	Anclote, Anclote River	FL
68055	North Anclote Key, Florida	NOS	8726942	28.21	-82.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-01:38:00	\N	0.86	-01:55:00	\N	0.8	\N	\N	North Anclote Key	FL
68056	Gulf Harbors, Florida	NOS	8726995	28.2433	-82.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-00:52:00	\N	0.9	-01:15:00	\N	0.84	\N	\N	Gulf Harbors	FL
68057	New Port Richey, Pithlachascotee River, Florida	NOS	8727001	28.2483	-82.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-00:11:00	\N	0.87	-00:58:00	\N	0.88	\N	\N	New Port Richey, Pithlachascotee River	FL
68058	Hwy. 19 bridge, Pithlachascotee River, Florida	NOS	8727012	28.2683	-82.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-00:40:00	\N	0.84	-01:16:00	\N	0.85	\N	\N	Hwy. 19 bridge, Pithlachascotee River	FL
68059	Hudson, Hudson Creek, Florida	NOS	8727061	28.3617	-82.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	-01:02:00	\N	0.89	-01:12:00	\N	0.91	\N	\N	Hudson, Hudson Creek	FL
68061	Hernando Beach, Rocky Creek, Little Pine I. Bay, Florida	NOS	8727122	28.4867	-82.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	00:58:00	\N	0.83	-00:20:00	\N	0.83	\N	\N	Hernando Beach, Rocky Creek, Little Pine I. Bay	FL
68062	Johns Island, Chassahowitzka Bay, Florida (sub)	NOS	8727235	28.6917	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	02:14:00	\N	0.49	01:09:00	\N	0.62	\N	\N	Johns Island, Chassahowitzka Bay	FL
68063	Chassahowitzka, Chassahowitzka River, Florida (sub)	NOS	8727246	28.715	-82.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	05:45:00	\N	0.16	03:59:00	\N	0.14	\N	\N	Chassahowitzka, Chassahowitzka River	FL
68064	Mason Creek, Homosassa Bay, Florida (sub)	NOS	8727274	28.7617	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	04:44:00	\N	0.25	03:09:00	\N	0.32	\N	\N	Mason Creek, Homosassa Bay	FL
68065	Tuckers Island, Homosassa River, Florida (sub)	NOS	8727277	28.7717	-82.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	02:23:00	\N	0.33	01:26:00	\N	0.47	\N	\N	Tuckers Island, Homosassa River	FL
68066	Halls River bridge, Homosassa River, Florida (sub)	NOS	8727293	28.8	-82.6033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	05:41:00	\N	0.13	04:30:00	\N	0.16	\N	\N	Halls River bridge, Homosassa River	FL
68067	Ozello, St. Martin's River, Florida (sub)	NOS	8727306	28.825	-82.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	05:21:00	\N	0.14	04:25:00	\N	0.17	\N	\N	Ozello, St. Martins River	FL
68068	Ozello North, Crystal Bay, Florida (sub)	NOS	8727328	28.8633	-82.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	03:17:00	\N	0.25	01:25:00	\N	0.5	\N	\N	Ozello north, Crystal Bay	FL
68069	Mangrove Pt., Crystal Bay, Florida (sub)	NOS	8727333	28.87	-82.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	00:41:00	\N	0.76	00:22:00	\N	0.95	\N	\N	Mangrove Pt., Crystal Bay	FL
68070	Dixie Bay, Salt River, Crystal Bay, Florida (sub)	NOS	8727336	28.8817	-82.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	03:06:00	\N	0.33	02:00:00	\N	0.55	\N	\N	Dixie Bay, Salt River, Crystal Bay	FL
68071	Crystal River, Kings Bay, Florida (sub)	NOS	8727343	28.8983	-82.5983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	03:07:00	\N	0.41	02:20:00	\N	0.59	\N	\N	Kings Bay	FL
68072	Twin Rivers Marina, Crystal River, Florida (sub)	NOS	8727348	28.905	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	02:30:00	\N	0.49	01:46:00	\N	0.64	\N	\N	Twin Rivers Marina	FL
68073	Shell Island, north end, Crystal River, Florida (sub)	NOS	8727359	28.9233	-82.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	01:30:00	\N	0.59	00:36:00	\N	0.79	\N	\N	Shell Island, north end	FL
68074	Florida Power, Crystal River, Florida	NOS	8727386	28.96	-82.725	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	00:30:00	\N	0.89	-00:03:00	\N	1.04	\N	\N	Florida Power	FL
68075	Withlacoochee River entrance, Florida	NOS	8727395	29.0017	-82.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	00:55:00	\N	0.95	00:07:00	\N	0.91	\N	\N	Withlacoochee River entrance	FL
68076	Suwannee, Salt Creek, Florida	NOS	8727577	29.3283	-83.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	00:24:00	\N	0.83	-00:07:00	\N	0.91	\N	\N	Suwannee, Salt Creek	FL
68077	Steinhatchee River ent., Deadman Bay, Florida	NOS	8727695	29.6717	-83.39	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	00:00:00	\N	1.08	00:02:00	\N	1.03	\N	\N	Steinhatchee River ent., Deadman Bay	FL
68078	Mandalay, Aucilla River, Apalachee Bay, Florida	NOS	8727989	30.1267	-83.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66019	00:57:00	\N	0.55	00:25:00	\N	0.69	\N	\N	Mandalay, Aucilla River	FL
68079	St. Marks, St. Marks River, Apalachee Bay, Florida	NOS	8728142	30.1533	-84.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66019	01:04:00	\N	0.91	00:36:00	\N	0.93	\N	\N	St. Marks, St. Marks River	FL
68080	Shell Point, Walker Creek, Apalachee Bay, Florida (sub)	NOS	8728229	30.06	-84.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66019	-00:03:00	\N	1.08	-00:03:00	\N	1.02	\N	\N	Shell Point, Walker Creek	FL
68081	Bald Point, Ochlockonee Bay, Apalachee Bay, Florida	NOS	8728237	29.9483	-84.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66019	00:19:00	\N	0.7	00:33:00	\N	0.85	\N	\N	Bald Point, Ochlockonee Bay	FL
68082	Panacea, Dickerson Bay, Apalachee Bay, Florida	NOS	8728269	30.0283	-84.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66019	00:20:00	\N	0.82	00:16:00	\N	1.01	\N	\N	Panacea, Dickerson Bay	FL
68083	Alligator Point, St. James Island, Apalachee Bay, Florida	NOS	8728288	29.9033	-84.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66019	00:11:00	\N	0.73	-00:08:00	\N	0.75	\N	\N	Alligator Point, St. James Island	FL
68084	Turkey Point, Apalachee Bay, St. James Island, Florida (sub)	NOS	8728360	29.915	-84.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66019	-00:21:00	\N	0.98	-00:16:00	\N	0.78	\N	\N	Turkey Point, St. James Island	FL
68085	Carrabelle, Carrabelle River, St. George Sound, Florida (sub)	NOS	8728464	29.85	-84.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66030	-02:13:00	\N	1.6	-01:25:00	\N	1.6	\N	\N	Carrabelle, Carrabelle River	FL
68086	Dog Island, west end, St. George Sound, Florida	NOS	8728465	29.785	-84.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66030	-02:38:00	\N	1.4	-01:53:00	\N	1.73	\N	\N	Dog Island, west end	FL
68087	St. George Island, East End, St. George Sound, Florida	NOS	8728548	29.6867	-84.7867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66030	-02:48:00	\N	1	-02:02:00	\N	1.13	\N	\N	St. George Island, East End	FL
68088	St. George Island, Rattlesnake Cove, St. George Sound, Florida	NOS	8728552	29.6917	-84.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66030	-01:35:00	\N	1.2	-01:00:00	\N	1.33	\N	\N	St. George Island, Rattlesnake Cove	FL
68089	Cat Point, Apalachicola Bay, Florida (sub)	NOS	8728619	29.7233	-84.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66030	-01:17:00	\N	0.6	-00:40:00	\N	1.07	\N	\N	Cat Point	FL
68090	St. George Island, 12th St. W (bayside), St. George Sound, Florida (sub)	NOS	8728626	29.6533	-84.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66030	-01:08:00	\N	1.26	-00:55:00	\N	1.26	\N	\N	St. George Island, 12th St. W (Bayside)	FL
68091	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida (sub)	NOS	8728711	29.7633	-85.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66030	00:35:00	\N	0.83	00:28:00	\N	0.85	\N	\N	Apalachicola River (A&N RR bridge)	FL
68092	West Pass, Apalachicola Bay, Florida	NOS	8728766	29.6333	-85.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66030	-00:27:00	\N	1	-00:27:00	\N	0.87	\N	\N	West Pass	FL
68093	Port Saint Joe, St. Joseph Bay, Florida (sub)	NOS	8728912	29.815	-85.3133	:America/New_York	USA	feet	\N	\N	\N	Reference is in time zone :America/Chicago; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-02:45:00	\N	1.11	-02:06:00	\N	1.11	\N	\N	Port Saint Joe, St. Joseph Bay	FL
68094	Wetappo Creek, East Bay, St. Andrew Bay, Florida	NOS	8728973	30.0383	-85.3933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	01:40:00	\N	1.1	01:01:00	\N	1.1	\N	\N	Wetappo Creek, East Bay	FL
68095	Allanton, East Bay, St. Andrew Bay, Florida	NOS	8729015	30.03	-85.465	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-01:01:00	\N	1.15	-00:16:00	\N	1.15	\N	\N	Allanton, East Bay	FL
68096	Farmdale, East Bay, St. Andrew Bay, Florida	NOS	8729017	30.0167	-85.47	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-00:59:00	\N	1.17	-00:16:00	\N	1.17	\N	\N	Farmdale, East Bay	FL
68097	Laird Bayou, East Bay, St. Andrew Bay, Florida	NOS	8729045	30.1217	-85.5283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-01:05:00	\N	1.13	-00:28:00	\N	1.13	\N	\N	Laird Bayou, East Bay	FL
68098	Parker, St. Andrew Bay, Florida	NOS	8729084	30.1267	-85.6117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	00:22:00	\N	1.2	-00:05:00	\N	1.2	\N	\N	Parker	FL
68099	Lynn Haven, North Bay, St. Andrew Bay, Florida	NOS	8729102	30.255	-85.6483	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-01:01:00	\N	1.1	-00:31:00	\N	1.1	\N	\N	Lynn Haven, North Bay	FL
68100	Panama City, St. Andrew Bay, Florida (sub)	NOS	8729108	30.15227777777778	-85.66694444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-01:11:00	\N	1.66	-00:57:00	\N	1.05	\N	\N	Panama City	FL
68101	Channel entrance, St. Andrew Bay, Florida	NOS	8729136	30.125	-85.73	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-01:50:00	\N	1.02	-01:39:00	\N	1.02	\N	\N	Channel entrance	FL
68102	Alligator Bayou, St. Andrew Bay, Florida	NOS	8729152	30.17	-85.755	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-01:10:00	\N	1.07	-00:47:00	\N	1.07	\N	\N	Alligator Bayou	FL
68103	West Bay Creek, West Bay, St. Andrew Bay, Florida	NOS	8729197	30.2933	-85.8583	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-00:47:00	\N	1.13	-00:10:00	\N	1.13	\N	\N	West Bay Creek, West Bay	FL
68104	East Pass (Destin), Choctawhatchee Bay, Florida	NOS	8729511	30.395	-86.5133	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-00:34:00	\N	0.33	-00:33:00	\N	0.49	\N	\N	East Pass (Destin)	FL
68105	Shalimar, Garnier Bayou, Choctawhatchee Bay, Florida	NOS	8729538	30.435	-86.5867	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	03:03:00	\N	0.32	03:33:00	\N	0.32	\N	\N	Shalimar, Garnier Bayou	FL
68106	Harris, The Narrows, Florida	NOS	8729613	30.4083	-86.7317	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	02:51:00	\N	1.1	01:37:00	\N	1.1	\N	\N	Harris, The Narrows	FL
68107	Navarre Beach, Florida (sub)	NOS	8729678	30.3767	-86.865	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-02:26:00	\N	1.67	-02:07:00	\N	1.07	\N	\N	Navarre Beach	FL
68108	Bay Point, Blackwater River, Pensacola Bay, Florida	NOS	8729742	30.5717	-87.005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	01:27:00	\N	1.2	01:23:00	\N	1.2	\N	\N	Bay Point, Blackwater River	FL
68109	Warrington, 2 miles south of, Pensacola Bay, Florida	NOS	8729868	30.345	-87.2733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-00:30:00	\N	1	-00:27:00	\N	1	\N	\N	Warrington, 2 miles south of	FL
68110	Fort McRee Breakwater, Pensacola Bay, Florida	NOS	8729887	30.3267	-87.3117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	-00:34:00	\N	0.8	-01:23:00	\N	0.8	\N	\N	Fort McRee Breakwater	FL
68111	Nix Point, Perdido Bay, Florida	NOS	8729962	30.3933	-87.425	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	03:37:00	\N	0.33	02:29:00	\N	0.57	\N	\N	Nix Point, Perdido Bay	FL
68112	Bon Secour, Bon Secour River, Alabama	NOS	8731952	30.3033	-87.735	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66067	-01:17:00	\N	1.07	-01:13:00	\N	1.07	\N	\N	Bon Secour, Bon Secour River	AL
68113	Mobile Point (Fort Morgan), Alabama	NOS	8734635	30.2333	-88.02	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66067	-01:32:00	\N	0.8	-01:46:00	\N	0.8	\N	\N	Mobile Point (Fort Morgan)	AL
68114	Lower Hall Landing, Tensaw River, Alabama	NOS	8737182	30.8183	-87.915	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66067	03:05:00	\N	0.87	02:16:00	\N	0.87	\N	\N	Lower Hall Landing, Tensaw River	AL
68115	Bayou La Batre, Mississippi Sound, Alabama	NOS	8739051	30.3717	-88.275	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	01:14:00	\N	1.23	01:52:00	\N	1.23	\N	\N	Bayou La Batre, Mississippi Sound	AL
68116	Point of Pines, Bayou Cumbest, Mississippi	NOS	8740448	30.3867	-88.44	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	01:09:00	\N	1.25	01:49:00	\N	1.25	\N	\N	Point of Pines, Bayou Cumbest	MS
68117	Pascagoula Point, Mississippi Sound, Mississippi (sub)	NOS	8741196	30.34	-88.5333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	00:48:00	\N	1.21	01:20:00	\N	1.21	\N	\N	Pascagoula, Mississippi Sound	MS
68118	Horn Island, Mississippi Sound, Mississippi (sub)	NOS	8742221	30.2383	-88.6667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	00:59:00	\N	1.25	01:34:00	\N	1.25	\N	\N	Horn Island, Mississippi Sound	MS
68119	Hollingsworth Point, Davis Bayou, Mississippi (sub)	NOS	8743081	30.3867	-88.7733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	01:52:00	\N	1.42	02:24:00	\N	1.42	\N	\N	Hollingsworth Point, Davis Bayou	MS
68120	Biloxi (Cadet Point), Biloxi Bay, Mississippi (sub)	NOS	8743735	30.39	-88.8567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	01:30:00	\N	1.38	02:04:00	\N	1.38	\N	\N	Biloxi (Cadet Point), Biloxi Bay	MS
68121	Ship Island, Mississippi Sound, Mississippi (sub)	NOS	8744756	30.2133	-88.9717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	01:22:00	\N	1.3	01:52:00	\N	1.3	\N	\N	Ship Island, Mississippi Sound	MS
68122	Turkey Creek, Bernard Bayou, Mississippi	NOS	8745375	30.4267	-89.0533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	02:27:00	\N	1.54	03:23:00	\N	1.54	\N	\N	Turkey Creek, Bernard Bayou	MS
68123	Gulfport, Gulfport Harbor, Mississippi (sub)	NOS	8745557	30.36	-89.0817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	01:09:00	\N	1.29	02:09:00	\N	1.29	\N	\N	Gulfport Harbor, Mississippi Sound	MS
68124	Cat Island, Mississippi	NOS	8745799	30.2317	-89.1167	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	02:00:00	\N	1.23	02:13:00	\N	1.23	\N	\N	Cat Island	MS
68125	Pass Christian Yacht Club, Mississippi Sound, Mississippi (sub)	NOS	8746819	30.31	-89.245	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	02:04:00	\N	1.37	02:36:00	\N	1.37	\N	\N	Pass Christian Yacht Club, Mississippi Sound	MS
68126	Bay Waveland Yacht Club, Bay St. Louis, Mississippi (sub)	NOS	8747437	30.325	-89.325	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	02:57:00	\N	1.36	03:17:00	\N	1.36	\N	\N	St. Louis Bay entrance	MS
68127	Waveland, Mississipi Sound, Mississippi (sub)	NOS	8747766	30.2817	-89.3667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	02:49:00	\N	1.28	03:09:00	\N	1.28	\N	\N	Waveland	MS
68128	Wolf River, Henderson Avenue bridge, Mississippi	NOS	8748038	30.358333333332993	-89.27333333333299	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	02:51:00	\N	1.36	03:18:00	\N	1.36	\N	\N	Wolf River, Henderson Avenue bridge	MS
68129	Pearlington, Pearl River, Mississippi	NOS	8749704	30.24	-89.615	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	05:31:00	\N	0.99	05:51:00	\N	0.99	\N	\N	Pearlington, Pearl River	MS
68130	Chandeleur Light, Louisiana	NOS	8760172	30.0483	-88.8717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	01:54:00	\N	0.98	01:50:00	\N	0.98	\N	\N	Chandeleur Light	LA
68131	North Pass, Mississippi River, Louisiana	NOS	8760412	29.205	-89.0367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	00:43:00	\N	0.91	00:42:00	\N	0.91	\N	\N	North Pass, Pass a Loutre	LA
68132	Southeast Pass, Mississippi River, Louisiana	NOS	8760416	29.1167	-89.045	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	-00:28:00	\N	0.98	00:37:00	\N	0.98	\N	\N	Southeast Pass	LA
68133	Lonesome Bayou (Thomasin), Louisiana	NOS	8760424	29.2283	-89.05	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	-00:29:00	\N	0.9	00:34:00	\N	0.9	\N	\N	Lonesome Bayou (Thomasin)	LA
68134	Port Eads, South Pass, Mississippi River, Louisiana	NOS	8760579	29.015	-89.16	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	-00:17:00	\N	0.9	00:56:00	\N	0.9	\N	\N	Port Eads, South Pass	LA
68135	Breton Islands, Louisiana	NOS	8760595	29.4933	-89.1733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	02:08:00	\N	1.14	02:07:00	\N	1.14	\N	\N	Breton Islands	LA
68136	Joseph Bayou, Mississippi River, Louisiana	NOS	8760736	29.0583	-89.2717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	-00:17:00	\N	1.15	00:37:00	\N	1.15	\N	\N	Joseph Bayou	LA
68137	Comfort Island, Louisiana	NOS	8760742	29.8233	-89.27	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	02:14:00	\N	1.28	02:47:00	\N	1.28	\N	\N	Comfort Island	LA
68138	Jack Bay, Louisiana	NOS	8760841	29.3667	-89.345	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	02:48:00	\N	1	03:12:00	\N	1	\N	\N	Jack Bay	LA
68139	Olga Compressor Station, Grand Bay, Louisiana (sub)	NOS	8760889	29.38655555555556	-89.3801388888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	02:56:00	\N	1.08	02:54:00	\N	1.08	\N	\N	Grand Bay	LA
68140	Southwest Pass, Mississippi River, Louisiana	NOS	8760959	28.9317	-89.4283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	-00:13:00	\N	1.07	00:35:00	\N	1.07	\N	\N	Southwest Pass	LA
68144	Shell Beach, Lake Borgne, Louisiana (sub)	NOS	8761305	29.86811111111111	-89.67325	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	05:45:00	\N	1.13	05:45:00	\N	1.13	\N	\N	Shell Beach, Lake Borgne	LA
68145	Bayou BonFouca, Route 433, Louisiana	NOS	8761473	30.2717	-89.7933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	11:31:00	\N	0.43	11:12:00	\N	0.43	\N	\N	Bayou BonFouca, Route 433	LA
68146	Chef Menteur, Chef Menteur Pass, Louisiana	NOS	8761487	30.065	-89.8	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	06:27:00	\N	0.88	06:25:00	\N	0.88	\N	\N	Chef Menteur, Chef Menteur Pass	LA
68147	Quatre Bayous Pass, Louisiana	NOS	8761557	29.31	-89.8533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	00:17:00	\N	1.23	02:18:00	\N	1.23	\N	\N	Quatre Bayous Pass	LA
68148	Independence Island, Barataria Bay, Louisiana	NOS	8761677	29.31	-89.9383	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	01:59:00	\N	0.85	02:29:00	\N	0.85	\N	\N	Independence Island	LA
68149	Michoud Substation, ICWW, Louisiana	NOS	8761678	30.0067	-89.9367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	06:22:00	\N	1.09	06:37:00	\N	1.09	\N	\N	Michoud Substation, ICWW	LA
68150	Barataria Pass, Louisiana	NOS	8761687	29.275	-89.945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	-00:10:00	\N	1.13	01:00:00	\N	1.13	\N	\N	Barataria Pass	LA
68151	Manilla, Barataria Bay, Louisiana	NOS	8761732	29.4267	-89.9767	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	03:13:00	\N	0.94	02:32:00	\N	0.94	\N	\N	Manilla	LA
68152	New Canal USCG station, Lake Pontchartrain, Louisiana (sub)	NOS	8761927	30.02722222222222	-90.11333333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	12:09:00	\N	0.43	11:47:00	\N	0.43	\N	\N	New Canal USCG station, Lake Pontchartrain	LA
68153	Tchefuncta River, Lake Pontchartrain, Louisiana	NOS	8761993	30.3783	-90.16	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66103	12:21:00	\N	0.48	11:36:00	\N	0.48	\N	\N	Tchefuncta River, Lake Pontchartrain	LA
68154	Pelican Islands, Timbalier Bay, Louisiana	NOS	8762481	29.1283	-90.4233	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	02:26:00	\N	1.13	02:26:00	\N	1.13	\N	\N	Pelican Islands, Timbalier Bay	LA
68155	Timbalier Island, Timbalier Bay, Louisiana	NOS	8762675	29.0867	-90.5267	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	00:23:00	\N	1.13	00:19:00	\N	1.13	\N	\N	Timbalier Island, Timbalier Bay	LA
68156	Wine Island, Terrebonne Bay, Louisiana	NOS	8762850	29.0783	-90.5867	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	01:02:00	\N	1.23	01:08:00	\N	1.23	\N	\N	Wine Island, Terrebonne Bay	LA
68157	Caillou Boca, Louisiana	NOS	8763206	29.0633	-90.8067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	00:48:00	\N	1.32	00:40:00	\N	1.32	\N	\N	Caillou Boca	LA
68158	Raccoon Point, Caillou Bay, Louisiana	NOS	8763506	29.0633	-90.9617	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	-00:20:00	\N	1.6	-00:03:00	\N	1.6	\N	\N	Raccoon Point, Caillou Bay	LA
68159	Ship Shoal Light, Louisiana	NOS	8763719	28.915	-91.0717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	-01:50:00	\N	1.51	-01:54:00	\N	1.51	\N	\N	Ship Shoal Light	LA
68160	Shell Island, Atchafalaya Bay, Louisiana	NOS	8764165	29.4733	-91.305	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-00:39:00	\N	1.07	00:54:00	\N	1.07	\N	\N	Shell Island	LA
68161	Point Au Fer, Atchafalaya Bay, Louisiana	NOS	8764256	29.3333	-91.3533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-02:26:00	\N	1.4	-00:21:00	\N	1.4	\N	\N	Point Au Fer	LA
68162	Point Chevreuil, Atchafalaya Bay, Louisiana	NOS	8764634	29.5183	-91.555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-00:54:00	\N	1.07	01:02:00	\N	1.07	\N	\N	Point Chevreuil	LA
68163	Rabbit Island, 5 miles south of, Atchafalaya Bay, Louisiana	NOS	8764706	29.42	-91.5933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-02:00:00	\N	1.4	-00:13:00	\N	1.4	\N	\N	Rabbit Island, 5 miles south of	LA
68164	Cote Blanche Island, West Cote Blanche Bay, Louisiana	NOS	8764931	29.735	-91.7133	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	02:16:00	\N	1	02:19:00	\N	1	\N	\N	Cote Blanche Island, West Cote Blanche Bay	LA
68165	South Point, Marsh Island, Atchafalaya Bay, Louisiana	NOS	8765026	29.485	-91.7633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-01:57:00	\N	1.3	-00:19:00	\N	1.3	\N	\N	South Point, Marsh Island	LA
68166	Southwest Pass, Vermilion Bay, Louisiana	NOS	8765551	29.58	-92.035	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-00:33:00	\N	1.14	-00:32:00	\N	1.14	\N	\N	Southwest Pass, Vermilion Bay	LA
68167	Lighthouse Point, Atchafalaya Bay, Louisiana	NOS	8765568	29.5233	-92.0433	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-02:17:00	\N	1.4	-01:16:00	\N	1.4	\N	\N	Lighthouse Point	LA
68168	Point Barrow, Trinity Bay, Galveston Bay, Texas	NOS	8770557	29.74	-94.8317	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	04:43:00	\N	0.79	05:48:00	\N	0.79	\N	\N	Point Barrow, Trinity Bay	TX
68169	Round Point, Trinity Bay, Galveston Bay, Texas (sub)	NOS	8770559	29.7133	-94.69	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	05:15:00	\N	0.71	10:39:00	\N	0.71	\N	\N	Round Point, Trinity Bay	TX
68170	Sabine Pass (north), Texas (sub)	NOS	8770570	29.7284	-93.8701	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-00:38:00	\N	1.14	-01:18:00	\N	1.14	\N	\N	Sabine Pass	TX
68171	Barbours Cut, Morgans Point, Galveston Bay, Texas (sub)	NOS	8770613	29.68169444444445	-94.985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	04:17:00	\N	0.4	05:11:00	\N	0.95	\N	\N	Morgans Point, Barbours Cut	TX
68172	Lynchburg Landing, San Jacinto River, Galveston Bay, Texas (sub)	NOS	8770733	29.76486111111111	-95.07886111111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	04:51:00	\N	0.57	04:55:00	\N	1.05	\N	\N	Lynchburg Landing, San Jacinto River	TX
68173	Houston Ship Channel, Galveston Bay, Manchester, Texas (sub)	NOS	8770777	29.72622222222222	-95.26577777777777	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	05:05:00	\N	0.83	04:55:00	\N	1.15	\N	\N	Manchester, Houston Ship Channel	TX
68174	Clear Lake, Galveston Bay, Texas (sub)	NOS	8770933	29.5633	-95.0667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	05:19:00	\N	0.83	06:57:00	\N	0.83	\N	\N	Clear Lake	TX
68176	Port Bolivar, Galveston Bay, Texas (sub)	NOS	8771328	29.365	-94.78	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	00:09:00	\N	0.63	00:57:00	\N	1	\N	\N	Port Bolivar	TX
68177	Galveston Pleasure Pier, Gulf Of Mexico, Texas (sub)	NOS	8771510	29.2853	-94.7894	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-01:03:00	\N	1.3	-01:33:00	\N	1.4	\N	\N	Galveston Pleasure Pier	TX
68178	Jamaica Beach, West Bay, Galveston Bay, Texas	NOS	8771721	29.2	-94.985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	03:31:00	\N	0.71	02:38:00	\N	0.71	\N	\N	Jamaica Beach, West Bay	TX
68179	Alligator Point, West Bay, Texas	NOS	8771801	29.1667	-95.125	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	02:33:00	\N	0.64	02:39:00	\N	0.64	\N	\N	Alligator Point, West Bay	TX
68180	Christmas Bay, Texas	NOS	8772132	29.0417	-95.175	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	02:37:00	\N	0.23	04:47:00	\N	0.58	\N	\N	Christmas Bay	TX
68181	Freeport, DOW Barge Canal, Texas (sub)	NOS	8772440	28.9483	-95.3083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-01:08:00	\N	0.9	-01:17:00	\N	1.23	\N	\N	Freeport Harbor	TX
68182	Queen Isabella Causeway (east end), Texas	NOS	8779724	26.0783	-97.17	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66190	00:21:00	\N	0.75	00:24:00	\N	0.87	\N	\N	Queen Isabella Causeway (east end)	TX
68183	Queen Isabella Causeway (west end), Texas	NOS	8779739	26.0717	-97.1917	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66190	00:30:00	\N	0.63	00:52:00	\N	0.81	\N	\N	Queen Isabella Causeway (west end)	TX
68184	South Bay entrance, Texas	NOS	8779768	26.0517	-97.1817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66190	00:21:00	\N	0.94	00:14:00	\N	0.91	\N	\N	South Bay entrance	TX
68185	Port Isabel, Laguna Madre, Texas (sub)	NOS	8779770	26.06116666666667	-97.21552777777778	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66190	00:26:00	\N	1	00:10:00	\N	0.92	\N	\N	Port Isabel	TX
68186	San Nicolas Island, California	NOS	9410068	33.2667	-119.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:21:00	\N	0.88	00:10:00	\N	0.88	\N	\N	San Nicolas Island	CA
68187	Catalina Harbor, Santa Catalina Island, California	NOS	9410092	33.4317	-118.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:17:00	\N	0.94	00:11:00	\N	0.94	\N	\N	Catalina Harbor, Santa Catalina Island	CA
68188	Imperial Beach, California	NOS	9410120	32.5783	-117.135	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66196	-00:03:00	\N	0.96	00:00:00	\N	0.93	\N	\N	Imperial Beach	CA
68189	National City, San Diego Bay, California	NOS	9410152	32.665	-117.118	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66196	00:10:00	0	\N	00:04:00	0.2	\N	\N	\N	National City, San Diego Bay	CA
68190	San Diego, Quarantine Station, California	NOS	9410166	32.7033	-117.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66196	00:02:00	\N	0.96	-00:04:00	\N	0.96	\N	\N	San Diego, Quarantine Station	CA
68191	La Jolla (Scripps Institution Wharf), California (sub)	NOS	9410230	32.86688888888889	-117.2571388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66196	-00:04:00	\N	0.97	00:00:00	\N	0.92	\N	\N	La Jolla (Scripps Institution Wharf)	CA
68193	Balboa Pier, Newport Beach, California	NOS	9410583	33.6	-117.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:00:00	\N	0.96	-00:09:00	\N	0.96	\N	\N	Balboa Pier, Newport Beach	CA
68194	Santa Ana River entrance (inside), California	NOS	9410599	33.63	-117.958	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	01:47:00	\N	0.2	00:23:00	\N	0.54	\N	\N	Santa Ana River entrance (inside)	CA
68195	Cabrillo Beach, California	NOS	9410650	33.7067	-118.273	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:00:00	\N	1	00:00:00	\N	1	\N	\N	Cabrillo Beach	CA
68196	Long Beach, Terminal Island, California (sub)	NOS	9410680	33.7517	-118.227	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:00:00	\N	1.01	-00:01:00	\N	1.01	\N	\N	Long Beach, Terminal Island	CA
68197	Long Beach, Inner Harbor, California	NOS	9410686	33.7717	-118.21	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:05:00	\N	0.96	00:04:00	\N	0.96	\N	\N	Long Beach, Inner Harbor	CA
68198	King Harbor, Santa Monica Bay, California	NOS	9410738	33.8467	-118.398	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:07:00	\N	1	00:08:00	\N	0.96	\N	\N	King Harbor, Santa Monica Bay	CA
68199	El Segundo, Santa Monica Bay, California	NOS	9410777	33.9083	-118.433	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:13:00	\N	0.96	00:13:00	\N	0.96	\N	\N	El Segundo, Santa Monica Bay	CA
68200	Santa Monica, Municipal Pier, San Pedro Channel, California (sub)	NOS	9410840	34.0083	-118.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:03:00	\N	0.99	00:03:00	\N	0.99	\N	\N	Santa Monica, Municipal Pier	CA
68201	Bechers Bay, Santa Rosa Island, California	NOS	9410962	34.0083	-120.047	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:27:00	\N	1.03	00:27:00	\N	0.93	\N	\N	Bechers Bay, Santa Rosa Island	CA
68202	Prisoners Harbor, Santa Cruz Island, California	NOS	9410971	34.02	-119.683	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:18:00	\N	1.01	00:19:00	\N	0.94	\N	\N	Prisoners Harbor, Santa Cruz Island	CA
68203	Cuyler Harbor, San Miguel Island, California	NOS	9410988	34.0567	-120.355	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:34:00	\N	0.94	00:33:00	\N	0.94	\N	\N	Cuyler Harbor, San Miguel Island	CA
68204	Port Hueneme, California	NOS	9411065	34.1483	-119.203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:13:00	0	\N	00:10:00	-0.1	\N	\N	\N	Port Hueneme	CA
68205	Ventura, California	NOS	9411189	34.2667	-119.283	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:16:00	0	\N	00:09:00	-0.1	\N	\N	\N	Ventura	CA
68206	Rincon Island, Mussel Shoals, Santa Barbara Channel, California (sub)	NOS	9411270	34.3483	-119.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:18:00	\N	1.05	00:20:00	\N	0.99	\N	\N	Rincon Island, Mussel Shoals	CA
68207	Santa Barbara, California (sub)	NOS	9411340	34.40311111111111	-119.6928055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:21:00	\N	1.04	00:23:00	\N	0.98	\N	\N	Santa Barbara	CA
68208	San Simeon, California	NOS	9412553	35.6417	-121.188	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66207	00:07:00	\N	1	00:08:00	\N	0.99	\N	\N	San Simeon	CA
68209	Carmel Cove, Carmel Bay, California	NOS	9413375	36.52	-121.94	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66209	-00:04:00	\N	0.99	-00:03:00	\N	0.97	\N	\N	Carmel Cove, Carmel Bay	CA
68210	Ocean Pier, Moss Landing, Monterey Bay, California	NOS	9413616	36.8017	-121.79	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66209	-00:01:00	\N	0.9	-00:01:00	\N	0.95	\N	\N	Moss Landing, Ocean Pier	CA
68211	General Fish Company Pier, Moss Landing, Monterey Bay, California	NOS	9413617	36.8017	-121.787	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66209	00:01:00	\N	0.95	00:01:00	\N	0.98	\N	\N	General Fish Company Pier	CA
68212	Elkhorn Slough, Highway 1 Bridge, Monterey Bay, California	NOS	9413623	36.81	-121.785	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66209	-00:02:00	\N	0.9	00:03:00	\N	0.95	\N	\N	Elkhorn Slough, Highway 1 Bridge	CA
68213	Pacific Mariculture Dock, Monterey Bay, California	NOS	9413624	36.8133	-121.758	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66209	00:07:00	\N	0.98	00:15:00	\N	1	\N	\N	Pacific Mariculture Dock	CA
68214	Elkhorn Yacht Club, Monterey Bay, California	NOS	9413626	36.8133	-121.787	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66209	00:02:00	\N	0.95	00:00:00	\N	0.97	\N	\N	Elkhorn Yacht Club	CA
68215	Santa Cruz, Monterey Bay, California	NOS	9413745	36.9583	-122.017	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66209	-00:11:00	\N	0.99	-00:06:00	\N	0.97	\N	\N	Santa Cruz, Monterey Bay	CA
68216	Ano Nuevo Island, California	NOS	9413878	37.1083	-122.338	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	-01:04:00	-0.1	\N	-01:24:00	-0.7	\N	\N	\N	Ano Nuevo Island	CA
68217	Southeast Farallon Island, California	NOS	9414262	37.7	-123	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	-00:19:00	0	\N	-00:39:00	-0.3	\N	\N	\N	Southeast Farallon Island	CA
68218	Ocean Beach, outer coast, California	NOS	9414275	37.775	-122.513	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	-00:35:00	0	\N	-00:49:00	0.1	\N	\N	\N	Ocean Beach, outer coast	CA
68219	North Point, Pier 41, San Francisco, San Francisco Bay, California (sub)	NOS	9414305	37.81	-122.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:11:00	0	\N	00:13:00	0.2	\N	\N	\N	San Francisco, North Point, Pier 41	CA
68220	Rincon Point, Pier 22, San Francisco Bay, California (sub)	NOS	9414317	37.79	-122.387	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:25:00	0	\N	00:23:00	0.4	\N	\N	\N	Rincon Point, Pier 22 1/2	CA
68803	Anderson Bay, Unalaska Island, Alaska	NOS	9462578	53.6783	-166.832	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	00:28:00	\N	1.1	-00:01:00	\N	1.08	\N	\N	Anderson Bay	AK
68221	Potrero Point, San Francisco Bay, California	NOS	9414334	37.7583	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:46:00	0	\N	00:33:00	0.5	\N	\N	\N	Potrero Point	CA
68222	Hunters Point, San Francisco Bay, California (sub)	NOS	9414358	37.73	-122.357	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:39:00	0	\N	00:25:00	0.9	\N	\N	\N	Hunters Point	CA
68223	Borden Highway Bridge, San Joaquin River, San Joaquin River, California	NOS	9414367	37.93666666666701	-121.33333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	04:48:00	\N	0.64	04:28:00	\N	0.78	\N	\N	Borden Highway Bridge, San Joaquin River	CA
68224	South San Francisco, San Francisco Bay, California	NOS	9414391	37.6667	-122.39	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:56:00	0	\N	00:38:00	1.2	\N	\N	\N	South San Francisco	CA
68225	Oyster Point Marina, San Francisco Bay, California (sub)	NOS	9414392	37.665	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:00:00	\N	1	00:41:00	\N	1.23	\N	\N	Oyster Point Marina	CA
68226	Point San Bruno, San Francisco Bay, California	NOS	9414402	37.65	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:10:00	0.1	\N	00:38:00	1.1	\N	\N	\N	Point San Bruno	CA
68227	Seaplane Harbor, San Francisco Bay, California	NOS	9414413	37.6367	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:03:00	0	\N	00:42:00	1.4	\N	\N	\N	Seaplane Harbor	CA
68228	Coyote Point Marina, San Francisco Bay, California	NOS	9414449	37.5917	-122.313	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:08:00	\N	1.01	00:42:00	\N	1.29	\N	\N	Coyote Point Marina	CA
68229	San Mateo Bridge (west end), San Francisco Bay, California (sub)	NOS	9414458	37.58	-122.253	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:11:00	\N	1.04	00:44:00	\N	1.36	\N	\N	San Mateo Bridge (west end)	CA
68230	Bay Slough, west end, San Francisco Bay, California	NOS	9414483	37.5517	-122.243	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:28:00	\N	1	00:48:00	\N	1.35	\N	\N	Bay Slough, west end	CA
68231	Bay Slough, east end, San Francisco Bay, California	NOS	9414486	37.545	-122.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:52:00	\N	0.77	00:49:00	\N	1.27	\N	\N	Bay Slough, east end	CA
68232	Redwood Creek Marker 8, San Francisco Bay, California (sub)	NOS	9414501	37.5333	-122.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:28:00	\N	1.05	00:53:00	\N	1.41	\N	\N	Redwood Creek Marker 8	CA
68233	Corkscrew Slough, San Francisco Bay, California	NOS	9414505	37.5083	-122.21	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:42:00	0.1	\N	01:03:00	2.2	\N	\N	\N	Corkscrew Slough	CA
68234	Newark Slough, San Francisco Bay, California	NOS	9414506	37.5133	-122.08	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:58:00	0.1	\N	01:11:00	2.6	\N	\N	\N	Newark Slough	CA
68235	West Point Slough, San Francisco Bay, California	NOS	9414507	37.505	-122.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:30:00	\N	1.04	00:56:00	\N	1.44	\N	\N	West Point Slough	CA
68236	Dumbarton Highway Bridge, San Francisco Bay, California (sub)	NOS	9414509	37.5067	-122.115	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:15:00	\N	1.05	00:50:00	\N	1.51	\N	\N	Dumbarton Highway Bridge	CA
68237	Smith Slough, San Francisco Bay, California	NOS	9414511	37.5017	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:58:00	0	\N	01:15:00	2.1	\N	\N	\N	Smith Slough	CA
68238	Granite Rock, Redwood Creek, San Francisco Bay, California	NOS	9414513	37.495	-122.213	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:31:00	\N	1.04	00:55:00	\N	1.43	\N	\N	Granite Rock, Redwood Creek	CA
68239	Mowry Slough, San Francisco Bay, California	NOS	9414519	37.4933	-122.042	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:07:00	0	\N	01:12:00	2.6	\N	\N	\N	Mowry Slough	CA
68240	Palo Alto Yacht Harbor, San Francisco Bay, California	NOS	9414525	37.4583	-122.105	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:14:00	\N	0.68	00:59:00	\N	1.34	\N	\N	Palo Alto Yacht Harbor	CA
68241	Calaveras Point, west of, San Francisco Bay, California	NOS	9414539	37.4667	-122.067	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:49:00	0.1	\N	01:05:00	2.8	\N	\N	\N	Calaveras Point, west of	CA
68242	Upper Guadalupe Slough, San Francisco Bay, California	NOS	9414549	37.435	-122.007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:13:00	\N	1.13	01:14:00	\N	1.66	\N	\N	Upper Guadalupe Slough	CA
68243	Gold Street Bridge, Alviso Slough, San Francisco Bay, California	NOS	9414551	37.4233	-121.975	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:21:00	\N	0.96	01:03:00	\N	1.67	\N	\N	Gold Street Bridge, Alviso Slough	CA
68244	Coyote Creek, Tributary no.1, San Francisco Bay, California	NOS	9414561	37.4467	-121.963	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:45:00	-0.3	\N	01:21:00	2.6	\N	\N	\N	Coyote Creek, Tributary no.1	CA
68245	Coyote Creek, Alviso Slough, San Francisco Bay, California (sub)	NOS	9414575	37.465	-122.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:49:00	\N	1.09	00:59:00	\N	1.61	\N	\N	Coyote Creek, Alviso Slough	CA
68246	South Bay Wreck, San Francisco Bay, California	NOS	9414609	37.5517	-122.162	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:37:00	0.1	\N	01:02:00	2.2	\N	\N	\N	South Bay Wreck	CA
68247	Coyote Hills Slough entrance, San Francisco Bay, California	NOS	9414621	37.5633	-122.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:21:00	\N	0.45	00:52:00	\N	1.17	\N	\N	Coyote Hills Slough entrance	CA
68248	Alameda Creek, San Francisco Bay, California	NOS	9414632	37.595	-122.145	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:25:00	\N	0.27	00:57:00	\N	1.05	\N	\N	Alameda Creek	CA
68249	San Mateo Bridge (east end), San Francisco Bay, California	NOS	9414637	37.6083	-122.182	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:19:00	0	\N	00:48:00	1.8	\N	\N	\N	San Mateo Bridge (east end)	CA
68250	San Leandro Marina, San Francisco Bay, California (sub)	NOS	9414688	37.695	-122.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:23:00	\N	1.01	00:54:00	\N	1.28	\N	\N	San Leandro Marina	CA
68251	Oakland Airport, San Francisco Bay, California	NOS	9414711	37.7317	-122.208	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:45:00	\N	0.96	00:40:00	\N	1.15	\N	\N	Oakland Airport	CA
68252	San Leandro Channel, San Leandro Bay, San Francisco Bay, California	NOS	9414724	37.7483	-122.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:52:00	\N	0.98	00:42:00	\N	1.16	\N	\N	San Leandro Channel, San Leandro Bay	CA
68253	Alameda, San Francisco Bay, California (sub)	NOS	9414750	37.7717	-122.3	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:39:00	\N	0.99	00:29:00	\N	1.11	\N	\N	Alameda	CA
68254	Oakland Berth 67, San Francisco Bay, California	NOS	9414763	37.795	-122.283	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:42:00	0	\N	00:33:00	0.4	\N	\N	\N	Oakland Harbor, Grove Street	CA
68255	Oakland Pier, San Francisco Bay, California	NOS	9414765	37.795	-122.33	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:48:00	0	\N	00:33:00	0.2	\N	\N	\N	Oakland Pier	CA
68256	Alameda Naval Air Station fuel pier, San Francisco Bay, California (sub)	NOS	9414767	37.7933	-122.315	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:33:00	\N	1	00:24:00	\N	1.11	\N	\N	Alameda Naval Air Station	CA
68257	Oakland Middle Harbor, San Francisco Bay, California	NOS	9414777	37.805	-122.338	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:31:00	\N	0.96	00:21:00	\N	1.07	\N	\N	Oakland Middle Harbor	CA
68258	Oakland, Matson Wharf, San Francisco Bay, California	NOS	9414779	37.81	-122.327	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:36:00	0	\N	00:28:00	0.3	\N	\N	\N	Oakland, Matson Wharf	CA
68259	Yerba Buena Island, San Francisco Bay, California	NOS	9414782	37.81	-122.36	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:33:00	\N	0.99	00:25:00	\N	1.06	\N	\N	Yerba Buena Island	CA
68260	Grant Line Canal (drawbridge), San Joaquin River, California	NOS	9414785	37.82	-121.447	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	06:20:00	\N	0.68	06:14:00	\N	0.76	\N	\N	Grant Line Canal (drawbridge)	CA
68261	Alcatraz Island, San Francisco Bay, California	NOS	9414792	37.8267	-122.417	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:18:00	0	\N	00:14:00	0	\N	\N	\N	Alcatraz Island	CA
68262	Sausalito, San Francisco Bay, California (sub)	NOS	9414806	37.8467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:14:00	\N	1	00:10:00	\N	0.97	\N	\N	Sausalito	CA
68263	Nurse Slough, Bradmoor Island, Suisun Bay, California (sub)	NOS	9414811	38.1833	-121.923	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	01:06:00	\N	0.99	00:59:00	\N	1.07	\N	\N	Bradmoor Island, Nurse Slough	CA
68264	Angel Island (west side), San Francisco Bay, California	NOS	9414817	37.86	-122.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:21:00	0	\N	00:13:00	-0.2	\N	\N	\N	Angel Island (west side)	CA
68265	Angel Island, East Garrison, San Francisco Bay, California	NOS	9414818	37.8633	-122.42	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:20:00	\N	1.04	00:16:00	\N	1.02	\N	\N	Angel Island, East Garrison	CA
68266	Sausalito, Corps of Engineers Dock, San Francisco Bay, California (sub)	NOS	9414819	37.865	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:21:00	\N	1	00:10:00	\N	0.98	\N	\N	Sausalito, Corps of Engineers Dock	CA
68267	Borden Highway Bridge, Middle River, San Joaquin River, California	NOS	9414835	37.8917	-121.488	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	04:54:00	\N	0.62	04:50:00	\N	0.67	\N	\N	Borden Highway Bridge, Middle River	CA
68268	Borden Highway Bridge, Old River, San Joaquin River, California	NOS	9414836	37.8833	-121.577	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	04:35:00	\N	0.61	04:40:00	\N	0.64	\N	\N	Borden Highway Bridge, Old River	CA
68269	Point Chauncey, San Francisco Bay, California	NOS	9414837	37.8917	-122.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:32:00	\N	0.96	00:28:00	\N	0.98	\N	\N	Point Chauncey	CA
68270	Point Isabel, San Francisco Bay, California	NOS	9414843	37.8983	-122.32	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:33:00	0	\N	00:23:00	0.1	\N	\N	\N	Point Isabel	CA
68271	Richmond Inner Harbor, San Francisco Bay, California	NOS	9414849	37.91	-122.358	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:30:00	\N	0.98	00:16:00	\N	1.04	\N	\N	Richmond Inner Harbor	CA
68272	Chevron Oil Company Pier, Richmond, San Francisco Bay, California (sub)	NOS	9414863	37.923	-122.4095833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:38:00	\N	0.98	00:24:00	\N	1.04	\N	\N	Chevron Oil Company Pier, Richmond	CA
68273	Holt, Whiskey Slough, San Joaquin River, California	NOS	9414866	37.935	-121.435	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	04:39:00	\N	0.68	04:18:00	\N	0.8	\N	\N	Holt, Whiskey Slough	CA
68274	Orwood, Old River, San Joaquin River, California	NOS	9414868	37.9383	-121.56	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	04:33:00	\N	0.68	04:32:00	\N	0.76	\N	\N	Orwood, Old River	CA
68275	Point San Quentin, San Francisco Bay, California	NOS	9414873	37.945	-122.475	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:50:00	\N	0.93	00:42:00	\N	0.99	\N	\N	Point San Quentin	CA
68276	Corte Madera Creek, San Francisco Bay, California	NOS	9414874	37.9433	-122.513	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:51:00	\N	0.95	00:36:00	\N	0.99	\N	\N	Corte Madera Creek	CA
68277	Point Orient, San Francisco Bay, California	NOS	9414881	37.9583	-122.425	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:52:00	\N	0.96	00:50:00	\N	1.03	\N	\N	Point Orient	CA
68278	Stockton, San Joaquin River, California	NOS	9414883	37.9583	-121.29	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	04:33:00	\N	0.66	04:06:00	\N	0.81	\N	\N	Stockton	CA
68279	Point Bonita, Bonita Cove, San Francisco Bay, California	NOS	9414906	37.8183	-122.528	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	-00:10:00	0	\N	-00:17:00	0.3	\N	\N	\N	Point Bonita, Bonita Cove	CA
68280	Bolinas, Bolinas Lagoon, California (sub)	NOS	9414958	37.907779693603516	-122.6786117553711	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:38:00	\N	0.61	-00:10:00	\N	0.7	\N	\N	Bolinas Lagoon	CA
68281	Point San Pedro, San Pablo Bay, California	NOS	9415009	37.9933	-122.447	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:07:00	\N	0.92	01:02:00	\N	1.01	\N	\N	Point San Pedro	CA
68282	Blackslough Landing, San Joaquin River, California (sub)	NOS	9415021	37.99469444444444	-121.4190444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	04:15:00	\N	0.62	04:00:00	\N	0.75	\N	\N	Blackslough Landing	CA
68283	Gallinas, Gallinas Creek, San Pablo Bay, California	NOS	9415052	38.015	-122.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:25:00	\N	0.89	01:18:00	\N	1.02	\N	\N	Gallinas, Gallinas Creek	CA
68284	Davis Slough, San Joaquin River, California	NOS	9415053	38.0117	-121.638	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	02:46:00	\N	0.72	02:33:00	\N	0.68	\N	\N	Dutch Slough	CA
68285	Antioch, San Joaquin River, California (sub)	NOS	9415064	38.02	-121.815	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	01:26:00	\N	0.78	01:12:00	\N	0.77	\N	\N	Antioch	CA
68286	Hercules, Refugio Landing, San Pablo Bay, California	NOS	9415074	38.0233	-122.292	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:39:00	\N	0.85	01:15:00	\N	1.05	\N	\N	Hercules, Refugio Landing	CA
68287	Irish Landing, Sand Mound Slough, San Joaquin River, California	NOS	9415095	38.0333	-121.583	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	03:34:00	\N	0.68	03:29:00	\N	0.73	\N	\N	Irish Landing, Sand Mound Slough	CA
68288	Pittsburg, New York Slough, Suisun Bay, California	NOS	9415096	38.0367	-121.88	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	01:05:00	\N	0.84	00:59:00	\N	0.83	\N	\N	Pittsburg, New York Slough	CA
68289	Wards Island, Little Connection Slough, San Joaquin River, California (sub)	NOS	9415105	38.05002527777778	-121.4968555555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	03:51:00	\N	0.61	03:45:00	\N	0.68	\N	\N	Wards Island, Little Connection Slough	CA
68290	Benicia, California	NOS	9415111	38.0433	-122.13	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	-00:33:00	\N	1.18	-00:24:00	\N	1.09	\N	\N	Benicia	CA
68291	Mallard Island Ferry Wharf, Suisun Bay, California (sub)	NOS	9415112	38.0433	-121.918	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	00:57:00	\N	0.81	00:54:00	\N	0.83	\N	\N	Mallard Island Ferry Wharf	CA
68292	Bishop Cut, Disappointment Slough, San Joaquin River, California	NOS	9415117	38.045	-121.42	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	04:12:00	\N	0.66	04:12:00	\N	0.79	\N	\N	Bishop Cut, Disappointment Slough	CA
68293	Selby, California	NOS	9415142	38.0583	-122.243	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:04:00	0	\N	01:29:00	0.6	\N	\N	\N	Selby	CA
68294	Crockett, Carquinez Strait, California (sub)	NOS	9415143	38.0583	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	-01:05:00	\N	1.31	-00:58:00	\N	1.22	\N	\N	Crockett	CA
68295	False River, San Joaquin River, California	NOS	9415145	38.055	-121.657	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	02:45:00	\N	0.64	02:45:00	\N	0.66	\N	\N	False River	CA
68296	Prisoners Point, San Joaquin River, California	NOS	9415149	38.0617	-121.555	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	03:29:00	\N	0.69	03:25:00	\N	0.73	\N	\N	Prisoners Point	CA
68297	Vallejo, Mare Island Strait, California	NOS	9415165	38.1117	-122.273	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:12:00	\N	0.84	01:47:00	\N	1.02	\N	\N	Vallejo, Mare Island Strait	CA
68298	Collinsville, Sacramento River, California	NOS	9415176	38.0733	-121.848	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	01:20:00	\N	0.8	01:11:00	\N	0.8	\N	\N	Collinsville	CA
68299	Threemile Slough entrance, San Joaquin River, California (sub)	NOS	9415193	38.0867	-121.685	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	02:52:00	\N	0.68	02:27:00	\N	0.71	\N	\N	Threemile Slough entrance	CA
68300	Montezuma Slough, Suisun Bay, California	NOS	9415205	38.0767	-121.885	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	01:27:00	\N	0.82	01:16:00	\N	0.84	\N	\N	Montezuma Slough	CA
68301	Mare Island Naval Shipyard, Carquinez Strait, California (sub)	NOS	9415218	38.07	-122.25	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:58:00	\N	0.84	01:32:00	\N	1.01	\N	\N	Mare Island	CA
68302	Point Buckler, Suisun Bay, California	NOS	9415227	38.1	-122.033	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	00:22:00	\N	1.08	00:13:00	\N	1.12	\N	\N	Point Buckler	CA
68303	Inverness, Tomales Bay, California	NOS	9415228	38.1133	-122.868	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:08:00	\N	0.91	00:29:00	\N	0.94	\N	\N	Inverness, Tomales Bay	CA
68304	Threemile Slough, Sacramento River, California	NOS	9415236	38.1067	-121.7	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	01:58:00	\N	0.78	01:49:00	\N	0.82	\N	\N	Threemile Slough	CA
68305	Petaluma River entrance, San Pablo Bay, California (sub)	NOS	9415252	38.11530555555556	-122.5056666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:08:00	\N	0.86	01:23:00	\N	1.06	\N	\N	Petaluma River entrance	CA
68306	Terminous, South Fork, Mokelumne River, California	NOS	9415257	38.11	-121.498	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	04:11:00	\N	0.59	03:53:00	\N	0.7	\N	\N	Terminous, South Fork	CA
68307	Suisun Slough entrance, Suisun Bay, California (sub)	NOS	9415265	38.1283	-122.073	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	00:26:00	\N	0.93	00:13:00	\N	0.97	\N	\N	Suisun Slough entrance	CA
68308	Pierce Harbor, Goodyear Slough, Suisun Bay, California	NOS	9415266	38.1267	-122.1	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	00:41:00	\N	0.96	00:27:00	\N	1	\N	\N	Pierce Harbor, Goodyear Slough	CA
68804	Usof Bay, Unalaska Island, Alaska	NOS	9462582	53.515	-166.79	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-03:45:00	\N	1.19	-03:30:00	\N	1.55	\N	\N	Usof Bay	AK
68309	Georgiana Slough entrance, Mokelumne River, California	NOS	9415287	38.125	-121.578	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	03:41:00	\N	0.59	03:29:00	\N	0.67	\N	\N	Georgiana Slough entrance	CA
68310	Meins Landing, Montezuma Slough, Suisun Bay, California	NOS	9415307	38.1367	-121.907	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	01:11:00	\N	0.93	00:57:00	\N	1.01	\N	\N	Meins Landing, Montezuma Slough	CA
68311	Rio Vista, Sacramento River, California (sub)	NOS	9415316	38.145	-121.692	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	02:02:00	\N	0.78	01:51:00	\N	0.88	\N	\N	Rio Vista	CA
68312	Reynolds, Tomales Bay, California	NOS	9415320	38.1467	-122.883	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:59:00	\N	0.83	00:26:00	\N	0.89	\N	\N	Reynolds, Tomales Bay	CA
68313	Marshall, Tomales Bay, California	NOS	9415339	38.1617	-122.893	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:16:00	-0.1	\N	00:38:00	-0.6	\N	\N	\N	Marshall, Tomales Bay	CA
68314	Hog Island, San Antonio Creek, San Pablo Bay, California	NOS	9415344	38.1617	-122.55	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:36:00	\N	0.79	01:47:00	\N	1.07	\N	\N	Hog Island, San Antonio Creek	CA
68315	Joice Island, Suisun Slough, Suisun Bay, California	NOS	9415379	38.18	-122.045	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	00:41:00	\N	1	00:21:00	\N	1.07	\N	\N	Joice Island, Suisun Slough	CA
68316	Blakes Landing, Tomales Bay, California	NOS	9415396	38.19	-122.917	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:15:00	\N	0.79	00:32:00	\N	0.86	\N	\N	Blakes Landing, Tomales Bay	CA
68317	Montezuma Slough Bridge, Suisun Bay, California	NOS	9415402	38.1867	-121.98	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	00:46:00	\N	0.95	00:37:00	\N	1.01	\N	\N	Montezuma Slough Bridge	CA
68318	Steamboat Slough, Snug Harbor Marina, Sacramento River, California	NOS	9415414	38.1833	-121.655	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	02:48:00	\N	0.65	02:24:00	\N	0.8	\N	\N	Steamboat Slough, Snug Harbor Marina	CA
68319	Edgerley Island, Napa River, California	NOS	9415415	38.1917	-122.312	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:29:00	\N	0.76	02:02:00	\N	1.06	\N	\N	Edgerley Island, Napa River	CA
68320	Brazos Drawbridge, Napa River, California	NOS	9415446	38.21	-122.307	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:29:00	\N	0.86	02:02:00	\N	1.14	\N	\N	Brazos Drawbridge, Napa River	CA
68321	Wingo, Sonoma Creek, San Pablo Bay, California	NOS	9415447	38.21	-122.427	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	03:11:00	-0.3	\N	02:12:00	0.1	\N	\N	\N	Wingo, Sonoma Creek	CA
68322	Tomales Bay entrance, California	NOS	9415469	38.2283	-122.977	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	00:20:00	\N	0.91	-00:12:00	\N	0.87	\N	\N	Tomales Bay entrance	CA
68323	New Hope Bridge, Mokelumne River, California	NOS	9415478	38.2267	-121.49	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	04:56:00	\N	0.68	04:22:00	\N	0.73	\N	\N	New Hope Bridge	CA
68324	Suisun City, Suisun Slough, Suisun Bay, California	NOS	9415498	38.2367	-122.03	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	01:01:00	\N	1	00:36:00	\N	1.11	\N	\N	Suisun City, Suisun Slough	CA
68325	Snodgrass Slough, Sacramento River, California	NOS	9415565	38.2767	-121.495	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	05:36:00	\N	0.39	05:00:00	\N	0.49	\N	\N	Snodgrass Slough	CA
68326	Upper drawbridge, Petaluma River, San Pablo Bay, California (sub)	NOS	9415584	38.2283	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:59:00	\N	0.82	02:11:00	\N	1.15	\N	\N	Upper drawbridge, Petaluma River	CA
68327	Napa, Napa River, California	NOS	9415623	38.2983	-122.28	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:37:00	\N	0.9	02:05:00	\N	1.22	\N	\N	Napa, Napa River	CA
68328	Bodega Harbor entrance, California	NOS	9415625	38.3083	-123.055	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	-00:16:00	0.1	\N	-00:38:00	-0.2	\N	\N	\N	Bodega Harbor entrance	CA
68329	Clarksburg, Sacramento River, California	NOS	9415846	38.4167	-121.523	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	05:02:00	\N	0.41	03:58:00	\N	0.6	\N	\N	Clarksburg	CA
68330	Fort Ross, California	NOS	9416024	38.5133	-123.245	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	-00:30:00	\N	0.96	-00:51:00	\N	0.96	\N	\N	Fort Ross	CA
68331	Sacramento, Sacramento River, California	NOS	9416174	38.58	-121.507	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66244	06:32:00	\N	0.41	05:07:00	\N	0.6	\N	\N	Sacramento	CA
68333	Hookton Slough, Humboldt Bay, California	NOS	9418686	40.6867	-124.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66260	00:15:00	\N	0.98	00:06:00	\N	1.01	\N	\N	Hookton Slough	CA
68334	Elk River Railroad Bridge, Humboldt Bay, California	NOS	9418757	40.7567	-124.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66260	01:32:00	\N	0.31	00:19:00	\N	0.71	\N	\N	Elk River Railroad Bridge	CA
68335	Bucksport, Humboldt Bay, California	NOS	9418778	40.7783	-124.197	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66260	00:16:00	\N	1	00:17:00	\N	1.01	\N	\N	Bucksport	CA
68336	Eureka, Humboldt Bay, California	NOS	9418801	40.8067	-124.167	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66260	00:13:00	\N	1.03	00:26:00	\N	1.06	\N	\N	Eureka	CA
68337	Eureka Slough Bridge, Humboldt Bay, California	NOS	9418802	40.8067	-124.142	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66260	00:19:00	\N	1.02	00:33:00	\N	1.08	\N	\N	Eureka Slough Bridge	CA
68338	Arcata Wharf, Humboldt Bay, California	NOS	9418851	40.85	-124.117	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66260	00:54:00	0.1	\N	00:48:00	0.1	\N	\N	\N	Arcata Wharf	CA
68339	Mad River Slough, Arcata Bay, Humboldt Bay, California	NOS	9418865	40.865	-124.148	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66260	00:35:00	\N	1.07	00:43:00	\N	1.12	\N	\N	Mad River Slough, Arcata Bay	CA
68340	Trinidad Harbor, California	NOS	9419059	41.0567	-124.147	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	-00:03:00	\N	0.98	-00:02:00	\N	0.97	\N	\N	Trinidad Harbor	CA
68341	Brookings, Chetco Cove, Oregon	NOS	9430104	42.0433	-124.285	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	00:04:00	\N	1	00:01:00	\N	1	\N	\N	Brookings, Chetco Cove	OR
68342	Bandon, Coquille River, Oregon	NOS	9432373	43.12	-124.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66268	00:02:00	\N	0.94	-00:05:00	\N	0.92	\N	\N	Bandon, Coquille River	OR
68343	Coos Bay, Oregon	NOS	9432845	43.38	-124.215	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66268	01:28:00	\N	0.88	01:26:00	\N	0.96	\N	\N	Coos Bay	OR
68344	Empire, Coos Bay, Oregon	NOS	9432864	43.3917	-124.28	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66268	00:50:00	\N	0.88	00:37:00	\N	0.86	\N	\N	Empire	OR
68345	Sitka Dock, Coos Bay, Oregon	NOS	9432879	43.3767	-124.297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66268	00:08:00	\N	1.01	00:07:00	\N	1.01	\N	\N	Sitka Dock, Coos Bay	OR
68346	Florence, Siuslaw River, Oregon	NOS	9434032	43.9667	-124.103	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66268	00:58:00	\N	0.8	00:44:00	\N	0.86	\N	\N	Florence	OR
68347	Siuslaw River entrance, Oregon	NOS	9434132	44.0167	-124.13	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66268	00:03:00	\N	0.96	-00:06:00	\N	0.96	\N	\N	Suislaw River Entrance	OR
68486	Elbow Bay, Alaska	NOS	9450158	54.9	-132.653	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:04:00	0.1	\N	-00:04:00	2.6	\N	\N	\N	Elbow Bay	AK
68348	Drift Creek, Alsea River, Oregon	NOS	9434938	44.4133	-123.99	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66268	01:51:00	\N	0.53	00:44:00	\N	0.83	\N	\N	Drift Creek, Alsea River	OR
68349	Toledo, Yaquina River, Oregon	NOS	9435362	44.6167	-123.937	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	01:17:00	\N	1.02	01:02:00	\N	1.31	\N	\N	TOLEDO	OR
68350	South Beach, Yaquina Bay and River, Oregon (sub)	NOS	9435380	44.625	-124.043	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	00:34:00	\N	1.1	00:41:00	\N	1.23	\N	\N	Southbeach	OR
68351	Yaquina USCG station, Newport, Yaquina Bay, Oregon	NOS	9435385	44.6267	-124.055	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	00:35:00	\N	1.11	00:39:00	\N	1.22	\N	\N	YAQUINA USCG STA, NEWPORT	OR
68352	Depoe Bay, Oregon (sub)	NOS	9435827	44.81	-124.058	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	00:27:00	\N	1.1	00:27:00	\N	1.21	\N	\N	Depoe Bay	OR
68353	Kernville, Siletz River, Oregon	NOS	9436031	44.8967	-124	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	01:53:00	\N	0.67	01:24:00	\N	0.86	\N	\N	Kernville, Siletz River	OR
68354	Taft, Siletz Bay, Oregon	NOS	9436101	44.9267	-124.013	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	01:13:00	\N	0.75	00:48:00	\N	0.94	\N	\N	Taft, Siletz Bay	OR
68355	Netarts, Netarts Bay, Oregon	NOS	9437262	45.43	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	01:38:00	\N	0.85	01:17:00	\N	0.98	\N	\N	Netarts, Netarts Bay	OR
68356	Tillamook, Hoquarten Slough, Tillamook Bay, Oregon	NOS	9437331	45.46	-123.845	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	03:15:00	\N	0.58	01:52:00	\N	0.94	\N	\N	Tillamook, Hoquarten Slough	OR
68357	Garibaldi, Tillamook Bay, Oregon (sub)	NOS	9437540	45.55453	-123.91894444439146	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	01:11:00	\N	1.06	01:19:00	\N	1.19	\N	\N	Garibaldi	OR
68358	Barview, Tillamook Bay, Oregon	NOS	9437581	45.5683	-123.943	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	00:56:00	\N	0.92	00:42:00	\N	1.08	\N	\N	Barview	OR
68359	Brighton, Nehalem River, Oregon	NOS	9437815	45.67	-123.925	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	00:54:00	\N	1	00:51:00	\N	1.13	\N	\N	Brighton	OR
68360	Nehalem, Nehalem River, Oregon	NOS	9437908	45.71	-123.89	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	01:56:00	\N	0.75	01:17:00	\N	1.03	\N	\N	Nehalem	OR
68361	Astoria (Port Docks), Oregon	NOS	9439023	46.1867	-123.86	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	-00:03:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Astoria (Port Docks), Oreg.	OR
68362	Astoria (Youngs Bay), Oregon	NOS	9439026	46.1717	-123.842	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	-00:14:00	0.1	\N	-00:13:00	0.1	\N	\N	\N	Astoria (Youngs Bay), Oreg.	OR
68363	Settlers Point, Oregon	NOS	9439054	46.175	-123.678	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	00:53:00	-0.1	\N	00:22:00	-0.5	\N	\N	\N	Settlers Point, Oreg.	OR
68364	Knappa, Knappa Slough, Oregon	NOS	9439069	46.1867	-123.588	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	00:58:00	\N	0.86	00:29:00	\N	0.97	\N	\N	Knappa, Knappa Slough	OR
68365	Hungry Harbor, Washington	NOS	9440563	46.2583	-123.848	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	-00:09:00	0.1	\N	00:04:00	-0.2	\N	\N	\N	Hungry Harbor, Wash.	WA
68366	Fort Canby, Jetty 'A', Washington	NOS	9440572	46.2683	-124.037	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	-01:05:00	\N	1.22	-00:41:00	\N	0.97	\N	\N	Fort Canby, Jetty 'A', Wash.	WA
68367	Chinook, Baker Bay, Washington	NOS	9440573	46.2717	-123.948	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	-00:52:00	\N	1.12	-00:30:00	\N	0.95	\N	\N	Chinook, Baker Bay, Wash.	WA
68369	Ilwaco, Baker Bay, Washington	NOS	9440597	46.3033	-124.04	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	00:01:00	-0.1	\N	-00:13:00	-0.8	\N	\N	\N	Ilwaco, Baker Bay, Wash.	WA
68370	Naselle River, 4 miles above swing bridge, Willapa Bay, Washington	NOS	9440662	46.3883	-123.84	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	01:02:00	\N	0.93	01:02:00	\N	1.22	\N	\N	Naselle River, 4 miles above swing bridge	WA
68371	Naselle River, swing bridge, Willapa Bay, Washington	NOS	9440691	46.43	-123.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	00:37:00	\N	1.08	00:42:00	\N	1.22	\N	\N	Naselle River, swing bridge	WA
68584	Kasnyku Bay, Alaska	NOS	9451717	57.2167	-134.868	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:06:00	-0.1	\N	-00:10:00	-2.4	\N	\N	\N	Kasnyku Bay	AK
68372	Paradise Point, Long Island, Willapa Bay, Washington	NOS	9440723	46.4683	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	00:41:00	\N	1.04	00:43:00	\N	1.15	\N	\N	Paradise Point, Long Island	WA
68373	Nahcotta, Willapa Bay, Washington (sub)	NOS	9440747	46.5017	-124.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	00:28:00	\N	1.01	00:29:00	\N	1.13	\N	\N	Nahcotta	WA
68374	Palix River, south fork, Willapa Bay, Washington	NOS	9440813	46.5867	-123.91	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	00:31:00	\N	0.96	00:25:00	\N	1.04	\N	\N	Palix River, south fork	WA
68375	Bay Center, Palix River, Willapa Bay, Washington	NOS	9440846	46.6233	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	00:22:00	\N	1.03	00:09:00	\N	1.04	\N	\N	Bay Center, Palix River	WA
68376	South Bend, Willapa River, Willapa Bay, Washington (sub)	NOS	9440875	46.6633	-123.798	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	00:15:00	\N	1.05	00:14:00	\N	1.11	\N	\N	South Bend, Willapa River	WA
68377	Raymond, Willapa River, Willapa Bay, Washington	NOS	9440886	46.6833	-123.755	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	00:17:00	\N	1.04	00:27:00	\N	1.13	\N	\N	Raymond, Willapa River	WA
68378	Bay City, South Bay, Grays Harbor, Washington	NOS	9441038	46.8617	-124.06	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	-00:26:00	\N	1.13	-00:01:00	\N	1.1	\N	\N	Bay City, South Bay	WA
68379	Markham, Grays Harbor, Washington	NOS	9441098	46.9067	-123.998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	-00:15:00	\N	1.02	00:05:00	\N	1.06	\N	\N	Markham	WA
68380	Westport, Point Chehalis, Grays Harbor, Washington (sub)	NOS	9441102	46.90431	-124.1050833331214	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	-00:29:00	\N	1.01	-00:11:00	\N	1.03	\N	\N	Westport, Point Chehalis	WA
68381	Point Brown, Grays Harbor, Washington	NOS	9441156	46.95	-124.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	-00:24:00	\N	1.04	-00:09:00	\N	1.06	\N	\N	Point Brown	WA
68382	Cosmopolis, Chehalis River, Grays Harbor, Washington	NOS	9441158	46.9667	-123.778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	00:15:00	\N	1.12	00:26:00	\N	1.23	\N	\N	Cosmopolis, Chehalis River	WA
68383	Point Grenville, Washington	NOS	9441627	47.3033	-124.27	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	-00:44:00	\N	0.9	-00:37:00	\N	0.92	\N	\N	Point Grenville	WA
68384	James Island, Washington	NOS	9442388	47.9067	-124.647	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	-00:32:00	\N	0.96	-00:39:00	\N	0.92	\N	\N	James Island	WA
68385	La Push, Quillayute River, Washington (sub)	NOS	9442396	47.91333333333333	-124.6369444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	-00:34:00	\N	0.94	-00:39:00	\N	0.91	\N	\N	La Push, Quillayute River	WA
68386	Makah Bay, Washington	NOS	9442861	48.2967	-124.672	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	-00:28:00	\N	1.1	-00:25:00	\N	0.99	\N	\N	Makah Bay	WA
68387	Tatoosh Island, Cape Flattery, Strait of Juan de Fuca, Washington	NOS	9442971	48.391700744628906	-124.73699951171875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66309	-00:10:00	\N	1	-00:08:00	\N	1.01	\N	\N	Tatoosh Island, Cape Flattery	WA
68388	Twin Rivers, Strait of Juan de Fuca, Washington	NOS	9443644	48.17499923706055	-123.94999694824219	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66309	00:59:00	\N	1.2	00:47:00	\N	0.89	\N	\N	Twin Rivers	WA
68389	Crescent Bay, Strait of Juan de Fuca, Washington	NOS	9443826	48.1617	-123.725	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	-02:02:00	\N	0.8	-02:41:00	\N	0.8	\N	\N	Crescent Bay	WA
68390	Port Angeles, Strait Of Juan De Fuca, Washington (sub)	NOS	9444090	48.12472222222223	-123.4411388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	-01:14:00	\N	0.77	-01:45:00	\N	0.83	\N	\N	Port Angeles	WA
68391	Ediz Hook, Port Angeles, Strait of Juan de Fuca, Washington	NOS	9444122	48.14	-123.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	-01:13:00	\N	0.9	-01:37:00	\N	0.81	\N	\N	Ediz Hook, Port Angeles	WA
68392	Dungeness, Strait of Juan de Fuca, Washington	NOS	9444471	48.1667	-123.117	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	-00:38:00	\N	0.9	-00:54:00	\N	0.9	\N	\N	Dungeness	WA
68393	Sequim Bay entrance, Strait of Juan de Fuca, Washington	NOS	9444555	48.0817	-123.043	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	-00:07:00	\N	0.94	-00:39:00	\N	0.94	\N	\N	Sequim Bay entrance	WA
68394	Gardiner, Discovery Bay, Strait of Juan de Fuca, Washington	NOS	9444705	48.0583	-122.917	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	-00:17:00	\N	0.94	-00:47:00	\N	0.94	\N	\N	Gardiner, Discovery Bay	WA
68395	Mystery Bay, Marrowstone Island, Admiralty Inlet, Washington	NOS	9444971	48.0583	-122.692	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:52:00	\N	0.99	00:15:00	\N	0.95	\N	\N	Mystery Bay, Marrowstone Island	WA
68396	Marrowstone Point, Admiralty Inlet, Washington	NOS	9444972	48.0917	-122.69	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:05:00	-0.1	\N	00:02:00	0.4	\N	\N	\N	Marrowstone Point	WA
68397	Foulweather Bluff, Washington (sub)	NOS	9445016	47.9267	-122.617	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:07:00	\N	0.98	-00:11:00	\N	0.89	\N	\N	Foulweather Bluff	WA
68398	Port Ludlow, Washington	NOS	9445017	47.925	-122.68	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:14:00	\N	0.95	-00:14:00	\N	0.87	\N	\N	Port Ludlow	WA
68399	Port Gamble, Washington	NOS	9445059	47.8583	-122.58	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:05:00	\N	0.95	-00:09:00	\N	0.9	\N	\N	Port Gamble	WA
68400	Lofall, Washington	NOS	9445088	47.815	-122.657	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:06:00	\N	1.01	-00:08:00	\N	0.94	\N	\N	Lofall	WA
68401	Bangor Wharf, Washington (sub)	NOS	9445133	47.7483	-122.727	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:01:00	\N	1.03	-00:06:00	\N	0.97	\N	\N	Bangor Wharf	WA
68402	Whitney Point, Dabob Bay, Washington	NOS	9445246	47.7617	-122.85	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:02:00	\N	1.06	-00:05:00	\N	1.01	\N	\N	Whitney Point, Dabob Bay	WA
68403	Zelatched Point, Dabob Bay, Washington	NOS	9445269	47.7117	-122.822	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:05:00	\N	1.02	-00:09:00	\N	1	\N	\N	Zelatched Point, Dabob Bay	WA
68404	Quilcene, Quilcene Bay, Dabob Bay, Washington	NOS	9445272	47.8	-122.858	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:02:00	\N	1.04	-00:08:00	\N	1	\N	\N	Quilcene, Quilcene Bay, Dabob Bay	WA
68405	Pleasant Harbor, Washington	NOS	9445293	47.665	-122.912	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:01:00	\N	1.02	-00:14:00	\N	1.01	\N	\N	Pleasant Harbor	WA
68406	Seabeck, Seabeck Bay, Washington	NOS	9445303	47.6417	-122.828	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:01:00	\N	1.06	-00:04:00	\N	1.01	\N	\N	Seabeck, Seabeck Bay	WA
68407	Triton Head, Washington	NOS	9445326	47.6033	-122.982	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:06:00	\N	1.02	-00:06:00	\N	1	\N	\N	Triton Head	WA
68408	Ayock Point, Washington	NOS	9445388	47.5083	-123.052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:05:00	\N	1.07	-00:03:00	\N	0.99	\N	\N	Ayock Point	WA
68409	Lynch Cove Dock, Washington	NOS	9445441	47.4183	-122.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:06:00	\N	1.08	00:00:00	\N	1.07	\N	\N	Lynch Cove Dock	WA
68410	Hansville, Puget Sound, Washington	NOS	9445526	47.9183	-122.545	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:08:00	\N	0.98	-00:07:00	\N	0.92	\N	\N	Hansville	WA
68411	Kingston, Appletree Cove, Puget Sound, Washington	NOS	9445639	47.7967	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:05:00	\N	1	-00:05:00	\N	0.97	\N	\N	Kingston, Appletree Cove	WA
68412	Port Jefferson, Puget Sound, Washington	NOS	9445683	47.7467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:04:00	\N	0.98	-00:03:00	\N	0.95	\N	\N	Port Jefferson	WA
68413	Poulsbo, Liberty Bay, Puget Sound, Washington	NOS	9445719	47.725	-122.638	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:12:00	\N	1.01	00:05:00	\N	1.03	\N	\N	Poulsbo, Liberty Bay	WA
68414	Port Madison, Puget Sound, Washington	NOS	9445753	47.705	-122.525	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:03:00	\N	0.99	00:09:00	\N	1	\N	\N	Port Madison	WA
68415	Brownsville, Port Orchard, Puget Sound, Washington	NOS	9445832	47.6517	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:09:00	\N	1.03	00:07:00	\N	1.04	\N	\N	Brownsville, Port Orchard	WA
68416	Eagle Harbor, Bainbridge Island, Puget Sound, Washington	NOS	9445882	47.62	-122.515	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:05:00	\N	1.02	00:04:00	\N	1	\N	\N	Eagle Harbor, Bainbridge Island	WA
68417	Tracyton, Dyes Inlet, Puget Sound, Washington	NOS	9445901	47.61	-122.66	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:53:00	\N	0.95	00:28:00	\N	1.06	\N	\N	Tracyton, Dyes Inlet	WA
68705	Port Graham, Cook Inlet, Alaska	NOS	9455437	59.35	-151.8266666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:14:00	0	\N	-00:08:00	-1	\N	\N	\N	Port Graham	AK
68418	Port Blakely, Puget Sound, Washington	NOS	9445913	47.5967	-122.51	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:04:00	\N	0.99	00:04:00	\N	1.01	\N	\N	Port Blakely	WA
68419	Clam Bay, Rich Passage, Puget Sound, Washington	NOS	9445938	47.5733	-122.543	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:04:00	\N	1	00:03:00	\N	1.01	\N	\N	Clam Bay, Rich Passage	WA
68420	Harper, Yukon Harbor, Puget Sound, Washington	NOS	9445993	47.5233	-122.517	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:01:00	\N	0.99	-00:06:00	\N	1.02	\N	\N	Harper, Yukon Harbor	WA
68421	Point Vashon, Vashon Island, Puget Sound, Washington	NOS	9446025	47.5117	-122.463	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:02:00	\N	1.01	00:02:00	\N	1.02	\N	\N	Point Vashon, Vashon Island	WA
68422	Des Moines, East Passage, Puget Sound, Washington	NOS	9446248	47.4	-122.328	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:08:00	\N	1.01	00:05:00	\N	1.03	\N	\N	Des Moines, East Passage	WA
68423	Burton, Quartermaster Hbr. (inside), Vashon I., Puget Sound, Washington	NOS	9446254	47.395	-122.463	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:03:00	\N	1.02	00:01:00	\N	1.06	\N	\N	Burton, Quartermaster Hbr. (inside), Vashon I.	WA
68424	Allyn, Case Inlet, Puget Sound, Washington	NOS	9446281	47.3833	-122.823	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:59:00	\N	1.07	00:48:00	\N	1.26	\N	\N	Allyn, Case Inlet	WA
68425	Vaughn, Case Inlet, Puget Sound, Washington	NOS	9446366	47.3417	-122.775	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:57:00	\N	1.06	00:51:00	\N	1.26	\N	\N	Vaughn, Case Inlet	WA
68426	Gig Harbor, Puget Sound, Washington	NOS	9446369	47.34	-122.588	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:22:00	\N	0.99	00:18:00	\N	1.05	\N	\N	Gig Harbor	WA
68427	Tahlequah, Neil Pt., Dalco Passage, Vashon I., Puget Sound, Washington	NOS	9446375	47.3333	-122.507	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:05:00	\N	1.01	00:04:00	\N	1.05	\N	\N	Tahlequah, Neil Pt., Dalco Passage, Vashon I.	WA
68428	Horsehead Bay, Carr Inlet, Puget Sound, Washington	NOS	9446451	47.3017	-122.682	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:46:00	\N	1.05	00:38:00	\N	1.2	\N	\N	Horsehead Bay, Carr Inlet	WA
68429	Tacoma, Commencement Bay, Sitcum Waterway, Puget Sound, Washington (sub)	NOS	9446484	47.26667	-122.41333333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:04:00	\N	1	00:04:00	\N	1.04	\N	\N	Tacoma, Commencement Bay, Sitcum Waterway	WA
68430	Tacoma Narrows Bridge, Puget Sound, Washington	NOS	9446486	47.2717	-122.552	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:23:00	\N	1.02	00:28:00	\N	1.11	\N	\N	Tacoma Narrows Bridge	WA
68431	Walkers Landing, Pickering Passage, Puget Sound, Washington	NOS	9446489	47.2817	-122.923	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:55:00	\N	1.07	00:44:00	\N	1.26	\N	\N	Walkers Landing, Pickering Passage	WA
68432	Arletta, Hale Passage, Puget Sound, Washington	NOS	9446491	47.28	-122.652	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:40:00	\N	1.04	00:31:00	\N	1.18	\N	\N	Arletta, Hale Passage	WA
68433	Home, Von Geldern Cove, Carr Inlet, Puget Sound, Washington	NOS	9446500	47.275	-122.758	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:45:00	\N	1.04	00:37:00	\N	1.19	\N	\N	Home, Von Geldern Cove, Carr Inlet	WA
68434	McMicken Island, Case Inlet, Puget Sound, Washington	NOS	9446583	47.2467	-122.862	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:52:00	\N	1.06	00:40:00	\N	1.24	\N	\N	McMicken Island, Case Inlet	WA
68435	Shelton, Oakland Bay, Puget Sound, Washington	NOS	9446628	47.215	-123.083	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	02:05:00	\N	0.92	01:26:00	\N	1.26	\N	\N	Shelton, Oakland Bay	WA
68436	Longbranch, Filucy Bay, Puget Sound, Washington	NOS	9446638	47.21	-122.753	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:47:00	\N	1.02	00:38:00	\N	1.2	\N	\N	Longbranch, Filucy Bay	WA
68437	Arcadia, Totten Inlet, Puget Sound, Washington	NOS	9446666	47.1967	-122.938	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	01:05:00	\N	1.06	00:49:00	\N	1.28	\N	\N	Arcadia, Totten Inlet	WA
68438	Devils Head, Drayton Passage, Puget Sound, Washington	NOS	9446671	47.1667	-122.763	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:50:00	\N	1.1	00:40:00	\N	1.25	\N	\N	Devils Head, Drayton Passage	WA
68439	Steilacoom, Cormorant Passage, Puget Sound, Washington	NOS	9446714	47.1733	-122.603	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:45:00	\N	1.05	00:37:00	\N	1.2	\N	\N	Steilacoom, Cormorant Passage	WA
68441	Henderson Inlet, Puget Sound, Washington	NOS	9446752	47.155	-122.838	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:58:00	\N	1.06	00:47:00	\N	1.24	\N	\N	Henderson Inlet	WA
68442	Dofflemeyer Point, Boston Hbr., Budd Inlet, Puget Sound, Washington	NOS	9446800	47.1417	-122.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:57:00	\N	1.09	00:44:00	\N	1.28	\N	\N	Dofflemeyer Point, Boston Hbr., Budd Inlet	WA
68443	Dupont Wharf, Nisqually Reach, Puget Sound, Washington	NOS	9446828	47.1183	-122.665	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:49:00	\N	1.04	00:41:00	\N	1.2	\N	\N	Dupont Wharf, Nisqually Reach	WA
68444	Olympia, Budd Inlet, Puget Sound, Washington	NOS	9446969	47.06	-122.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:57:00	\N	1.08	00:45:00	\N	1.29	\N	\N	Olympia, Budd Inlet	WA
68445	Duwamish Waterway, Eighth Ave. South, Puget Sound, Washington	NOS	9447029	47.535	-122.322	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:11:00	\N	0.95	00:10:00	\N	0.97	\N	\N	Duwamish Waterway, Eighth Ave. South	WA
68446	Lockheed Shipyard, Harbor Island, Puget Sound, Washington	NOS	9447110	47.585	-122.362	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Lockheed Shipyard, Harbor Island	WA
68447	Meadow Point, Shilshole Bay, Puget Sound, Washington	NOS	9447265	47.6883	-122.403	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:01:00	\N	0.99	00:00:00	\N	0.98	\N	\N	Meadow Point, Shilshole Bay	WA
68448	Edmonds, Puget Sound, Washington	NOS	9447427	47.8133	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:04:00	\N	0.99	00:00:00	\N	0.96	\N	\N	Edmonds	WA
68449	Glendale, Whidbey Island, Washington	NOS	9447814	47.94	-122.357	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:03:00	\N	0.99	00:01:00	\N	0.97	\N	\N	Glendale, Whidbey Island	WA
68450	Bush Point, Whidbey Island, Admiralty Inlet, Washington	NOS	9447854	48.0333	-122.607	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:45:00	\N	1.08	00:10:00	\N	1.09	\N	\N	Bush Point, Whidbey Island	WA
68451	Holly Farms Harbor, Holmes Harbor, Whidbey I., Washington	NOS	9447855	48.0267	-122.535	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:04:00	\N	0.99	00:01:00	\N	1.01	\N	\N	Holly Farms Harbor, Holmes Harbor, Whidbey I.	WA
68452	Sandy Point, Whidbey Island, Washington	NOS	9447856	48.035	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:01:00	\N	1	00:03:00	\N	0.99	\N	\N	Sandy Point, Whidbey Island	WA
68453	Admiralty Head, Admiralty Inlet, Washington	NOS	9447905	48.1583	-122.668	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:20:00	-0.1	\N	-00:11:00	0	\N	\N	\N	Admiralty Head	WA
68454	Coupeville, Penn Cove, Whidbey Island, Washington	NOS	9447929	48.2233	-122.69	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:09:00	\N	0.99	00:15:00	\N	1.01	\N	\N	Coupeville, Penn Cove, Whidbey Island	WA
68455	Point Partridge, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447934	48.2317	-122.765	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	-00:15:00	\N	0.92	-00:11:00	\N	0.92	\N	\N	Point Partridge, Whidbey Island	WA
68456	Sunset Beach, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447951	48.2833	-122.728	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	-00:16:00	\N	0.95	-00:27:00	\N	0.87	\N	\N	Sunset Beach, Whidbey Island	WA
68457	Crescent Harbor, N. Whidbey Island, Washington	NOS	9447952	48.2867	-122.617	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:04:00	\N	0.99	00:04:00	\N	1.03	\N	\N	Crescent Harbor, N. Whidbey Island	WA
68458	Smith Island, Strait of Juan de Fuca, Washington	NOS	9447985	48.3167	-122.837	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	-00:25:00	\N	0.83	-00:13:00	\N	0.83	\N	\N	Smith Island	WA
68459	Ala Spit, Whidbey Island, Washington	NOS	9447993	48.3967	-122.587	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:26:00	\N	0.95	00:12:00	\N	0.92	\N	\N	Ala Spit, Whidbey Island	WA
68460	Cornet Bay, Deception Pass, Washington	NOS	9447995	48.4017	-122.623	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:26:00	\N	0.95	00:15:00	\N	0.89	\N	\N	Cornet Bay, Deception Pass	WA
68461	Kayak Point, Washington	NOS	9448094	48.1367	-122.367	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	-00:02:00	\N	0.99	00:00:00	\N	0.99	\N	\N	Kayak Point	WA
68462	La Conner, Swinomish Channel, Washington	NOS	9448558	48.3917	-122.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:39:00	\N	0.95	00:21:00	\N	0.9	\N	\N	La Conner, Swinomish Channel	WA
68463	Yokeko Point, Deception Pass, Washington (sub)	NOS	9448601	48.4133	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:38:00	-0.2	\N	00:26:00	-1	\N	\N	\N	Yokeko Point, Deception Pass	WA
68464	Burrows Bay (Allan Island), Washington	NOS	9448683	48.46	-122.695	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:03:00	\N	0.88	00:09:00	\N	0.95	\N	\N	Burrows Bay (Allan Island)	WA
68465	Ship Harbor, Fidalgo Island, Washington	NOS	9448772	48.5067	-122.677	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:29:00	\N	1.02	00:18:00	\N	0.93	\N	\N	Ship Harbor, Fidalgo Island	WA
68466	Anacortes, Guemes Channel, Washington	NOS	9448794	48.5183	-122.62	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:33:00	\N	1	00:22:00	\N	0.96	\N	\N	Anacortes, Guemes Channel	WA
68467	Strawberry Bay, Cypress Island, Washington	NOS	9448876	48.565	-122.722	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:52:00	\N	0.95	00:34:00	\N	0.95	\N	\N	Strawberry Bay, Cypress Island	WA
68468	Tide Point, Cypress Island, Washington	NOS	9448918	48.5867	-122.748	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:41:00	\N	0.95	00:31:00	\N	0.94	\N	\N	Tide Point, Cypress Island	WA
68469	Gooseberry Point, Hale Passage, Washington	NOS	9449184	48.73	-122.67	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	01:10:00	\N	0.97	00:41:00	\N	1.04	\N	\N	Gooseberry Point	WA
68470	Bellingham, Bellingham Bay, Washington	NOS	9449211	48.745	-122.495	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	01:11:00	\N	0.94	00:43:00	\N	0.99	\N	\N	Bellingham	WA
68471	Sandy Point, Lummi Bay, Washington	NOS	9449292	48.79	-122.708	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	01:24:00	\N	1.03	00:52:00	\N	1.05	\N	\N	Sandy Point, Lummi Bay	WA
68472	Drayton Harbor, Blaine, Strait of Georgia, Washington (sub)	NOS	9449679	48.9917	-122.765	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	01:27:00	\N	1.06	00:54:00	\N	1.11	\N	\N	Blaine, Semiahmoo Bay	WA
68473	Patos Island Wharf, Boundary Pass, Washington	NOS	9449704	48.7867	-122.97	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	01:30:00	0	\N	01:03:00	0.2	\N	\N	\N	Patos Island Wharf	WA
68474	Echo Bay, Sucia Islands, Strait of Georgia, Washington	NOS	9449712	48.7567	-122.897	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	01:34:00	0	\N	01:01:00	0.1	\N	\N	\N	Echo Bay, Sucia Islands	WA
68475	Orcas, Orcas Island, Washington	NOS	9449798	48.6	-122.95	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:56:00	\N	0.9	00:33:00	\N	0.9	\N	\N	Orcas, Orcas Island	WA
68476	Roche Harbor, San Juan Island, Haro Strait, Washington	NOS	9449834	48.61	-123.155	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:47:00	\N	0.99	00:33:00	\N	0.9	\N	\N	Roche Harbor, San Juan Island	WA
68477	Friday Harbor, San Juan Island, San Juan Channel, Washington (sub)	NOS	9449880	48.54530555555556	-123.0128888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:51:00	\N	0.92	00:33:00	\N	0.91	\N	\N	Friday Harbor, San Juan Island	WA
68478	Shaw Island, Ferry Terminal, Harney Channel, San Juan Channel, Washington	NOS	9449904	48.585	-122.928	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:56:00	\N	0.99	00:31:00	\N	0.9	\N	\N	Shaw Island, Ferry Terminal, Harney Channel	WA
68479	Aleck Bay, Lopez Island, Washington	NOS	9449994	48.425	-122.853	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	-00:08:00	\N	0.88	-00:18:00	\N	0.88	\N	\N	Aleck Bay, Lopez Island	WA
68480	Minnie Bay, Alaska	NOS	9450041	54.7267	-132.302	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:00:00	0.1	\N	-00:05:00	2.7	\N	\N	\N	Minnie Bay	AK
68481	Security Cove, Dall Island, Alaska	NOS	9450055	54.7483	-132.855	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:24:00	0	\N	-00:20:00	1	\N	\N	\N	Security Cove	AK
68482	Nakat Harbor, Dixon Entrance, Alaska	NOS	9450104	54.82	-130.7	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:09:00	\N	0.89	00:01:00	\N	0.95	\N	\N	Nakat Harbor, Alaska	AK
68483	American Bay, Kaigani Strait, Alaska	NOS	9450125	54.85	-132.83	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:01:00	0	\N	00:01:00	2.5	\N	\N	\N	American Bay, Kaigani Strait	AK
68484	Hunter Bay, Alaska	NOS	9450139	54.8717	-132.322	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:03:00	0.1	\N	-00:02:00	2.7	\N	\N	\N	Hunter Bay	AK
68485	Kelp Island Passage, Duke Island, Dixon Entrance, Alaska	NOS	9450142	54.8767	-131.3	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:03:00	\N	0.96	-00:04:00	\N	0.94	\N	\N	Kelp Island Passage, Duke Island	AK
68487	Morse Cove, Duke Island, Revillagigedo Channel, Alaska	NOS	9450172	54.92	-131.255	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:15:00	\N	0.96	00:03:00	\N	0.96	\N	\N	Morse Cove, Duke Island	AK
68488	Kassa Inlet entrance, Alaska	NOS	9450176	54.9267	-132.522	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:01:00	0.1	\N	-00:03:00	2.6	\N	\N	\N	Kassa Inlet entrance	AK
68489	Ingraham Bay, Prince of Wales Island, Alaska	NOS	9450212	54.98	-132.007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:04:00	\N	0.96	00:03:00	\N	0.93	\N	\N	Ingraham Bay, Prince of Wales Island	AK
68490	Mabel Island, Alaska	NOS	9450226	55	-132.592	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:01:00	0.1	\N	-00:10:00	2.8	\N	\N	\N	Mabel Island	AK
68491	Menefee Anch., Prince of Wales Island, Alaska	NOS	9450244	55.0267	-132.013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:01:00	\N	0.89	-00:02:00	\N	0.94	\N	\N	Menefee Anch., Prince of Wales Island	AK
68492	Kah Shakes Cove, Revillagigedo Channel, Alaska	NOS	9450254	55.0417	-130.98	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:06:00	\N	0.96	00:00:00	\N	0.97	\N	\N	Kah Shakes Cove	AK
68493	Keete Island, Nutkwa Inlets, Alaska	NOS	9450258	55.0467	-132.577	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:05:00	0.1	\N	-00:13:00	2.8	\N	\N	\N	Keete Island, Nutkwa Inlets	AK
68494	Niblack Anchorage, Moira Sound, Alaska	NOS	9450271	55.0667	-132.12	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:09:00	\N	0.96	00:03:00	\N	0.94	\N	\N	Niblack Anchorage, Moira Sound	AK
68495	Sakie Bay, Dall Island, Alaska	NOS	9450272	55.0667	-133.2	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:05:00	0	\N	00:01:00	0.3	\N	\N	\N	Sakie Bay	AK
68496	Tamgas Harbor, Annette Island, Alaska	NOS	9450273	55.0667	-131.542	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:08:00	\N	0.89	-00:09:00	\N	0.98	\N	\N	Tamgas Harbor, Annette Island	AK
68497	Keete Inlet, Alaska	NOS	9450281	55.08	-132.49	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:01:00	0.1	\N	-00:11:00	2.9	\N	\N	\N	Keete Inlet	AK
68498	Mud Bay, Hetta Inlet, Alaska	NOS	9450282	55.0817	-132.632	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:01:00	0.1	\N	-00:05:00	2.8	\N	\N	\N	Mud Bay	AK
68499	View Cove, Tlevak Strait, Alaska	NOS	9450283	55.0833	-133.017	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:02:00	0	\N	-00:02:00	2.8	\N	\N	\N	View Cove	AK
68500	Boca de Quadra, Revillagigedo Channel, Alaska	NOS	9450305	55.1167	-130.798	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:02:00	\N	0.98	00:00:00	\N	0.98	\N	\N	Boca de Quadra	AK
68501	Sea Otter Harbor, Dall Island, Alaska	NOS	9450312	55.1267	-133.167	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:04:00	-0.1	\N	-00:04:00	-0.2	\N	\N	\N	Sea Otter Harbor	AK
68502	Metlakatla, Port Chester, Alaska (sub)	NOS	9450314	55.1283	-131.567	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:07:00	\N	0.96	-00:10:00	\N	0.95	\N	\N	Metlakatla, Port Chester	AK
68503	Nehenta Bay, Gravina Island, Alaska	NOS	9450339	55.1667	-131.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:01:00	\N	0.96	-00:01:00	\N	0.95	\N	\N	Nehenta Bay, Gravina Island	AK
68504	South Pass, Sukkwan Strait, Tlevak Strait, Alaska	NOS	9450341	55.1667	-132.87	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:02:00	0.1	\N	-00:02:00	2.9	\N	\N	\N	South Pass, Sukkwan Strait	AK
68505	Saltery Point, Tlevak Strait, Alaska	NOS	9450351	55.1817	-132.795	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:05:00	0.1	\N	-00:08:00	2.9	\N	\N	\N	Saltery Point	AK
68506	North Pass, West End, Tlevak Strait, Alaska	NOS	9450366	55.205	-132.94	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:06:00	0.1	\N	-00:12:00	3	\N	\N	\N	North Pass, West End	AK
68507	Copper Harbor, Hetta Inlet, Alaska	NOS	9450369	55.21	-132.625	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:08:00	0.1	\N	-00:10:00	2.8	\N	\N	\N	Copper Harbor	AK
68508	Lancaster Cove, Cholmondeley Sound, Alaska	NOS	9450373	55.2133	-132.095	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:03:00	\N	0.96	00:05:00	\N	0.98	\N	\N	Lancaster Cove, Cholmondeley Sound	AK
68509	Alva Bay, Revillagigedo Island, Alaska	NOS	9450382	55.2283	-131.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:03:00	\N	0.96	-00:05:00	\N	0.98	\N	\N	Alva Bay, Revillagigedo Island	AK
68510	Natalia Point, Tlevak Strait, Alaska	NOS	9450387	55.2333	-133.043	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:01:00	0.1	\N	-00:05:00	2.9	\N	\N	\N	Natalia Point	AK
68511	Divide Head, Cholmondeley Sound, Alaska	NOS	9450399	55.2517	-132.3	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:08:00	\N	0.96	-00:05:00	\N	0.98	\N	\N	Divide Head, Cholmondeley Sound	AK
68512	Block Island, Tlevak Strait, Alaska	NOS	9450406	55.263301849365234	-133.11500549316406	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:02:00	\N	1	00:07:00	\N	1.2	\N	\N	Block Island, Tlevak Narrows	AK
68513	Soda Bay, Tlevak Strait, Alaska	NOS	9450413	55.275	-132.967	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:07:00	0.1	\N	00:03:00	3	\N	\N	\N	Soda Bay	AK
68514	Sulzer, Hetta Inlet, Alaska	NOS	9450421	55.285	-132.622	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:08:00	0.1	\N	-00:02:00	2.9	\N	\N	\N	Sulzer	AK
68515	Mop Point, Thorne Arm, Revillagigedo Channel, Alaska	NOS	9450483	55.3833	-131.235	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:03:00	\N	0.98	-00:05:00	\N	0.98	\N	\N	Mop Point, Thorne Arm	AK
68516	Ward Cove, Revillagigedo Channel, Alaska	NOS	9450492	55.3983	-131.727	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:03:00	\N	0.96	-00:05:00	\N	1.02	\N	\N	Ward Cove	AK
68517	Saltery Cove, Skowl Arm, Kasaan Bay, Alaska	NOS	9450495	55.4017	-132.328	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:02:00	\N	1.01	00:04:00	\N	1.01	\N	\N	Saltery Cove, Skowl Arm	AK
68519	Coon Island, George Inlet, Revillagigedo Channel, Alaska	NOS	9450533	55.4617	-131.505	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:07:00	\N	0.96	-00:03:00	\N	0.99	\N	\N	Coon Island, George Inlet	AK
68520	Hollis Anchorage, Kasaan Bay, Alaska	NOS	9450544	55.48	-132.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:02:00	\N	1.01	00:06:00	\N	1.03	\N	\N	Hollis Anchorage	AK
68521	Craig, Klawock Inlet, Bucareli Bay, Alaska (sub)	NOS	9450551	55.4883	-133.142	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:08:00	\N	0.94	-00:08:00	\N	1.02	\N	\N	Craig, Klawock Inlet	AK
68522	Steamboat Bay, Noyes Island, Gulf of Esquibel, Alaska	NOS	9450578	55.5333	-133.637	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:13:00	\N	0.93	-00:12:00	\N	1.04	\N	\N	Steamboat Bay, Noyes Island	AK
68523	Kasaan, Kasaan Bay, Alaska	NOS	9450581	55.535	-132.397	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:03:00	\N	1.01	00:05:00	\N	1.02	\N	\N	Kasaan	AK
68524	Cruz Pass, San Fernando Island, Bucareli Bay, Alaska	NOS	9450584	55.5417	-133.315	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:12:00	-0.1	\N	-00:15:00	0.1	\N	\N	\N	Cruz Pass, San Fernando Island	AK
68525	Loring, Naha Bay, Alaska	NOS	9450624	55.6017	-131.632	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:06:00	\N	0.96	-00:02:00	\N	1.02	\N	\N	Loring, Naha Bay	AK
68526	Lindeman Cove, Kasaan Bay, Alaska (sub)	NOS	9450625	55.6017	-132.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:03:00	\N	1.01	00:06:00	\N	1.02	\N	\N	Lindeman Cove	AK
68527	Rudyerd Bay, Alaska	NOS	9450651	55.6417	-130.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:02:00	\N	0.96	00:01:00	\N	1.02	\N	\N	Rudyerd Bay	AK
68528	Anguilla Island, Gulf of Esquibel, Alaska	NOS	9450679	55.6833	-133.587	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:14:00	-0.1	\N	-00:18:00	0.4	\N	\N	\N	Anguilla Island	AK
68529	Nossuk Bay, Tonowek Bay, Gulf of Esquibel, Alaska (sub)	NOS	9450711	55.72166666666666	-133.35	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:14:00	\N	0.94	-00:14:00	\N	1.05	\N	\N	Nossuk Bay, Tonowek Bay	AK
68530	Davis River entrance, Alaska	NOS	9450729	55.76	-130.177	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:00:00	\N	0.96	-00:02:00	\N	1.08	\N	\N	Davis River entrance, Alaska	AK
68531	Port Alice, Heceta Island, Davidson Inlet, Alaska	NOS	9450768	55.8117	-133.605	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:14:00	0	\N	-00:20:00	0.9	\N	\N	\N	Port Alice, Heceta Island	AK
68532	Ratz Harbor, Prince of Wales Island, Alaska	NOS	9450815	55.88	-132.595	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:00:00	\N	0.99	00:09:00	\N	1.03	\N	\N	Ratz Harbor, Prince of Wales Island	AK
68533	Tuxekan, 0.5 mile south of, Davidson Inlet, Alaska	NOS	9450817	55.8833	-133.243	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:07:00	-0.1	\N	-00:17:00	0.9	\N	\N	\N	Tuxekan, 0.5 mile south of	AK
68534	Coronation Island, Alaska	NOS	9450829	55.9033	-134.118	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:17:00	0	\N	-00:16:00	0.8	\N	\N	\N	Coronation Island	AK
68535	Yes Cannery, Yes Bay, Alaska	NOS	9450836	55.9133	-131.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:01:00	\N	0.96	00:00:00	\N	1.02	\N	\N	Yes Cannery, Yes Bay	AK
68536	El Capitan Island, Davidson Inlet, Alaska	NOS	9450851	55.9367	-133.325	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:10:00	-0.1	\N	-00:11:00	0.9	\N	\N	\N	El Capitan Island	AK
68537	Edna Bay, Davidson Inlet, Alaska	NOS	9450859	55.95	-133.662	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:08:00	0	\N	-00:20:00	0.9	\N	\N	\N	Edna Bay	AK
68538	Pole Anchorage, Kosciusko Island, Alaska	NOS	9450862	55.955	-133.81	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:22:00	-0.1	\N	-00:22:00	1.4	\N	\N	\N	Pole Anchorage, Kosciusko Island	AK
68539	Fitzgibbon Cove, Alaska	NOS	9450879	55.9833	-131.175	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	-00:01:00	\N	0.96	-00:05:00	\N	1.02	\N	\N	Fitzgibbon Cove	AK
68540	Lake Bay, Alaska	NOS	9450904	56.0233	-132.92	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:01:00	\N	0.89	00:10:00	\N	1.03	\N	\N	Lake Bay	AK
68541	Beck Island, Clarence Strait, Alaska	NOS	9450906	56.0467	-132.862	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:05:00	\N	1.01	00:10:00	\N	1.05	\N	\N	Beck Island, Clarence Strait	AK
68542	Kuiu Island, Affleck Canal, Alaska	NOS	9450913	56.0369	-134.115	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:06:00	\N	0.95	-00:09:00	\N	1.09	\N	\N	Affleck Canal entrance, Kuiu Island	AK
68543	El Capitan Passage, Alaska (sub)	NOS	9450937	56.0733	-133.313	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:02:00	-0.1	\N	-00:05:00	0.9	\N	\N	\N	El Capitan Passage, S. of Devilfish Bay	AK
68544	Thorne Island, Whale Passage, Alaska	NOS	9450938	56.0583	-132.968	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:01:00	\N	0.98	00:12:00	\N	1.04	\N	\N	Thorne Island, Whale Passage	AK
68545	Point St. Albans, Alaska	NOS	9450943	56.0817	-133.97	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:13:00	0	\N	-00:17:00	1.4	\N	\N	\N	Point St. Albans	AK
68546	Thoms Point, Zimovia Strait, Alaska (sub)	NOS	9450970	56.1183	-132.078	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:01:00	\N	0.99	00:07:00	\N	1.06	\N	\N	Thoms Point, Zimovia Strait	AK
68547	Blashke Island, Clarence Strait, Alaska	NOS	9450973	56.1267	-132.895	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:24:00	\N	0.93	00:13:00	\N	1.03	\N	\N	Blashke Island	AK
68549	Shakan Strait, Kosciusko Island, Alaska	NOS	9450987	56.1483	-133.46	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:10:00	\N	0.95	-00:07:00	\N	1.16	\N	\N	Shakan Strait, Kosciusko Island	AK
68550	Kell Bay, Affleck Canal, Kuiu Island, Alaska	NOS	9450988	56.15	-134.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:01:00	0	\N	00:01:00	1.3	\N	\N	\N	Kell Bay, Affleck Canal, Kuiu Island	AK
68551	Table Bay, Kuiu Island, Alaska	NOS	9451001	56.1667	-134.245	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:13:00	0	\N	-00:15:00	1.1	\N	\N	\N	Table Bay, Kuiu Island	AK
68552	Point Harrington, Clarence Strait, Alaska (sub)	NOS	9451005	56.1783	-132.697	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:01:00	\N	0.97	00:09:00	\N	1.04	\N	\N	Point Harrington	AK
68553	Bradfield Canal, Alaska (sub)	NOS	9451012	56.1833	-131.572	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:05:00	\N	0.99	00:11:00	\N	1.08	\N	\N	Bradfield Canal, Ernest Sound	AK
68554	Village Rock, Zimovia Strait, Alaska (sub)	NOS	9451037	56.22	-132.297	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:01:00	\N	0.97	00:09:00	\N	1.05	\N	\N	Village Rock, Zimovia Strait	AK
68555	Port Alexander, Baranof Island, Alaska (sub)	NOS	9451054	56.2467	-134.647	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:10:00	\N	1.01	00:07:00	\N	1.14	\N	\N	Port Alexander, Baranof Island	AK
68556	Bushy Island, Snow Passage, Alaska (sub)	NOS	9451074	56.2767	-132.985	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:01:00	\N	0.93	00:03:00	\N	0.95	\N	\N	Bushy Island, Snow Passage	AK
68557	Port Beauclerc, Kuiu Island, Alaska	NOS	9451082	56.2883	-133.962	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:12:00	-0.1	\N	-00:14:00	1.9	\N	\N	\N	Port Beauclerc, Kuiu Island	AK
68558	Port Malmesbury, Kuiu Island, Alaska	NOS	9451093	56.305	-134.238	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:13:00	0.1	\N	00:04:00	1.2	\N	\N	\N	Port Malmesbury, Kuiu Island	AK
68559	Port Protection, Prince of Wales Island., Alaska	NOS	9451095	56.3083	-133.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:11:00	0	\N	-00:13:00	2.4	\N	\N	\N	Port Protection, Prince of Wales Island.	AK
68560	Reef Point, Stikine Strait, Alaska (sub)	NOS	9451124	56.3533	-132.553	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:02:00	\N	0.96	00:09:00	\N	1.04	\N	\N	Reef Point, Stikine Strait	AK
68561	Reid Bay, Alaska	NOS	9451148	56.3883	-133.883	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:19:00	0	\N	-00:11:00	2.5	\N	\N	\N	Reid Bay	AK
68562	Port Walter, Baranof Island, Alaska	NOS	9451151	56.3917	-134.66	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:13:00	0.1	\N	00:04:00	1.5	\N	\N	\N	Port Walter, Baranof Island	AK
68563	Madan Bay, Clarence Strait, Alaska (sub)	NOS	9451152	56.3922	-132.169	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:04:00	\N	0.98	00:12:00	\N	1.05	\N	\N	Madan Bay	AK
68564	Sumner Island, Alaska	NOS	9451163	56.41	-133.793	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:12:00	0	\N	-00:19:00	2.6	\N	\N	\N	Sumner Island	AK
68565	Wrangell, Wrangell Island, Alaska (sub)	NOS	9451204	56.47	-132.387	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:01:00	\N	0.96	00:10:00	\N	1.04	\N	\N	Wrangell, Wrangell Island	AK
68566	Greys Island, Alaska	NOS	9451238	56.5217	-132.542	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:05:00	\N	0.94	00:11:00	\N	1.01	\N	\N	Greys Island	AK
68567	Monte Carlo Island, Keku Strait, Alaska (sub)	NOS	9451247	56.535	-133.767	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:03:00	\N	0.89	00:03:00	\N	0.8	\N	\N	Monte Carlo Island	AK
68568	Point Lockwood, Woewodski Island, Wrangell Narrows, Alaska (sub)	NOS	9451263	56.5583	-132.963	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:08:00	\N	0.98	00:15:00	\N	0.98	\N	\N	Point Lockwood, Woewodski Island	AK
68569	Beecher Pass, Wrangell Narrows, Alaska (sub)	NOS	9451287	56.595	-132.987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:14:00	\N	0.98	00:22:00	\N	1	\N	\N	Beecher Pass	AK
68570	Dry Strait, Frederick Sound, Alaska	NOS	9451301	56.615	-132.575	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:03:00	0	\N	-00:18:00	-0.2	\N	\N	\N	Dry Strait	AK
68571	Anchor Point, Wrangell Narrows, Alaska (sub)	NOS	9451317	56.6383	-132.927	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:40:00	\N	0.99	00:31:00	\N	1.04	\N	\N	Anchor Point	AK
68572	Cosmos Point, Frederick Sound, Alaska	NOS	9451335	56.6633	-132.617	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:05:00	\N	0.99	-00:05:00	\N	0.98	\N	\N	Cosmos Point	AK
68573	Papke's Landing, Wrangell Narrows, Alaska (sub)	NOS	9451346	56.6767	-132.933	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:50:00	\N	1.01	00:33:00	\N	1	\N	\N	Papke's Landing	AK
68574	The Summit, Keku Strait, Alaska (sub)	NOS	9451349	56.68242222222222	-133.7369083333333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:23:00	\N	0.99	00:19:00	\N	0.98	\N	\N	The Summit	AK
68575	Dorothy Cove, Necker Bay, Baranof Island, Alaska	NOS	9451376	56.7217	-135.075	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:02:00	\N	0.95	-00:02:00	\N	0.97	\N	\N	Dorothy Cove, Necker Bay	AK
68576	Turn Point, Alaska (sub)	NOS	9451434	56.8	-132.98	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:38:00	\N	0.96	00:25:00	\N	1.04	\N	\N	Turn Point	AK
68577	Entrance Island, Keku Strait, Alaska (sub)	NOS	9451438	56.8117	-133.787	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:20:00	\N	0.98	00:18:00	\N	0.94	\N	\N	Entrance Island	AK
68578	Petersburg, Wrangell Narrows, Alaska	NOS	9451439	56.815	-132.957	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66354	00:37:00	\N	0.97	00:28:00	\N	1.04	\N	\N	Petersburg	AK
68579	Symonds Bay, Biorka Island, Sitka Sound, Alaska	NOS	9451468	56.8567	-135.52	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:16:00	0	\N	-00:15:00	-0.1	\N	\N	\N	Symonds Bay, Biorka Island	AK
68580	Thomas Bay, Frederick Sound, Alaska	NOS	9451561	56.9967	-132.785	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:07:00	-0.1	\N	00:07:00	-0.8	\N	\N	\N	Thomas Bay	AK
68581	Baranof, Warm Spring Bay, Alaska (sub)	NOS	9451625	57.08833333333333	-134.825	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:04:00	-0.1	\N	-00:07:00	-2.8	\N	\N	\N	Baranof, Warm Spring Bay	AK
68582	Herring Bay, Frederick Sound, Alaska	NOS	9451634	57.1133	-134.38	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:07:00	\N	0.91	-00:08:00	\N	0.84	\N	\N	Herring Bay	AK
68583	Eliza Harbor, Admiralty Island, Frederick Sound, Alaska	NOS	9451706	57.1883	-134.287	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:04:00	\N	0.92	-00:06:00	\N	0.87	\N	\N	Eliza Harbor, Admiralty Island	AK
68585	Cleveland Passage, Whitney Island, Frederick Sound, Alaska	NOS	9451718	57.2183	-133.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:03:00	-0.1	\N	-00:01:00	-1.2	\N	\N	\N	Cleveland Passage, Whitney Island	AK
68586	Olga Point, Olga Strait, Sitka Sound, Alaska	NOS	9451725	57.2283	-135.537	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:14:00	0	\N	00:00:00	0	\N	\N	\N	Olga Point, Olga Strait	AK
68587	Cannery Cove, Pybus Bay, Frederick Sound, Alaska	NOS	9451781	57.3067	-134.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:06:00	\N	0.94	-00:08:00	\N	0.9	\N	\N	Cannery Cove, Pybus Bay	AK
68588	The Brothers, Stephens Passage, Alaska (sub)	NOS	9451785	57.295	-133.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:04:00	\N	0.98	-00:07:00	\N	0.91	\N	\N	The Brothers	AK
68589	Scraggy Point, Alaska	NOS	9451802	57.3367	-135.723	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:00:00	0.1	\N	-00:09:00	-0.1	\N	\N	\N	Scraggy Point	AK
68590	Scraggy Island, Alaska (sub)	NOS	9451805	57.34	-135.707	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:01:00	\N	1.03	00:00:00	\N	1	\N	\N	Scraggy Island	AK
68591	Haley Anchorage, Fish Bay, Alaska	NOS	9451826	57.3717	-135.618	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:12:00	0.1	\N	00:03:00	0.2	\N	\N	\N	Haley Anchorage, Fish Bay	AK
68592	Hobart Bay, Alaska	NOS	9451851	57.4067	-133.42	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:03:00	-0.1	\N	-00:06:00	-1.1	\N	\N	\N	Hobart Bay	AK
68593	Sergius Narrows, Alaska (sub)	NOS	9451853	57.41	-135.627	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:24:00	\N	1.05	00:19:00	\N	1.33	\N	\N	Serguis Narrows	AK
68594	Klokachef Island, Alaska	NOS	9451858	57.4167	-135.89	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:06:00	0.1	\N	-00:10:00	-0.1	\N	\N	\N	Klokachef Island	AK
68595	Bear Bay, Alaska	NOS	9451859	57.4183	-135.583	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:29:00	0.2	\N	00:18:00	3.7	\N	\N	\N	Bear Bay	AK
68596	Killisnoo, Alaska	NOS	9451895	57.47	-134.565	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:04:00	0	\N	-00:06:00	-2.1	\N	\N	\N	Killisnoo	AK
68597	Gambier Bay (cannery wharf), Alaska	NOS	9451906	57.4833	-133.96	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:01:00	\N	0.96	-00:01:00	\N	0.92	\N	\N	Gambier Bay (cannery wharf)	AK
68598	Good Island, Gambier Bay, Alaska	NOS	9451909	57.4867	-133.898	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:04:00	\N	0.96	-00:05:00	\N	0.93	\N	\N	Good Island, Gambier Bay	AK
68599	Provorotni Island, Alaska (sub)	NOS	9451936	57.515	-135.555	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:02:00	-0.1	\N	-00:09:00	-1.3	\N	\N	\N	Povorotni Island, Pogibshi Point	AK
68600	Windham Bay, Alaska	NOS	9451962	57.5433	-133.498	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:00:00	-0.1	\N	00:00:00	-1.1	\N	\N	\N	Windham Bay	AK
68601	Nismeni Cove, Alaska	NOS	9451979	57.5617	-135.412	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:03:00	-0.1	\N	-00:15:00	-1.3	\N	\N	\N	Nismeni Cove	AK
68602	Upper Endicott Arm, North Shore, Stephens Passage, Alaska	NOS	9452005	57.5217	-133.055	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:06:00	\N	0.99	00:01:00	\N	0.98	\N	\N	Upper Endicott Arm, North Shore	AK
68603	Sawyer Island, Tracy Arm, Alaska	NOS	9452022	57.8783	-133.19	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:06:00	\N	1.01	00:02:00	\N	0.97	\N	\N	Sawyer Island, Tracy Arm	AK
68604	Holkham Bay, Wood Spit, Alaska	NOS	9452064	57.7183	-133.578	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:06:00	-0.1	\N	00:03:00	-0.8	\N	\N	\N	Holkham Bay, Wood Spit	AK
68606	Port Snettisham, Crib Point, Alaska	NOS	9452082	58.0967	-133.742	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:03:00	\N	0.97	-00:03:00	\N	0.98	\N	\N	Port Snettisham, Crib Point	AK
68607	Taku Harbor, Alaska	NOS	9452123	58.0683	-134.012	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:04:00	\N	1	-00:03:00	\N	0.97	\N	\N	Taku Harbor	AK
68608	Taku Point, Taku Inlet, Alaska	NOS	9452124	58.4	-134.015	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:13:00	0	\N	00:14:00	0.4	\N	\N	\N	Taku Point, Taku Inlet	AK
68609	Rasp Ledge, Seymour Canal, Alaska	NOS	9452128	57.6783	-134.038	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:05:00	0.1	\N	00:06:00	-0.7	\N	\N	\N	Rasp Ledge, Seymour Canal	AK
68610	Greely Point, Taku Inlet, Alaska	NOS	9452133	58.2233	-134.06	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:04:00	-0.1	\N	-00:01:00	-0.6	\N	\N	\N	Greely Point, Taku Inlet	AK
68611	Young Bay, Alaska	NOS	9452249	58.1833	-134.587	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:02:00	\N	1	00:00:00	\N	1	\N	\N	Young Bay	AK
68612	Auke Bay, Alaska	NOS	9452263	58.3817	-134.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:03:00	0	\N	-00:06:00	-0.4	\N	\N	\N	Auke Bay	AK
68614	Barlow Cove, Mansfield Peninsula, Lynn Canal, Alaska	NOS	9452318	58.3217	-134.878	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:01:00	\N	0.99	-00:04:00	\N	0.96	\N	\N	Barlow Cove, Mansfield Peninsula	AK
68615	Funter, Funter Bay, Lynn Canal, Alaska	NOS	9452321	58.255	-134.895	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:01:00	0	\N	00:00:00	-1.1	\N	\N	\N	Funter, Funter Bay	AK
68616	Lincoln Island, Lynn Canal, Alaska	NOS	9452336	58.4983	-134.965	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:01:00	\N	1	-00:03:00	\N	0.98	\N	\N	Lincoln Island	AK
68617	Cove Point, Berner's Bay, Lynn Canal, Alaska	NOS	9452346	58.7517	-135.028	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:00:00	\N	1.02	-00:02:00	\N	1	\N	\N	Cove Point, Berner's Bay	AK
68618	Swanson Harbor, Icy Strait, Alaska	NOS	9452368	58.215	-135.127	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:11:00	\N	1.08	00:14:00	\N	1.41	\N	\N	Swanson Harbor	AK
68619	Tenakee Springs, Tenakee Inlet, Alaska	NOS	9452386	57.78	-135.212	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:05:00	-0.1	\N	-00:04:00	-1.5	\N	\N	\N	Tenakee Springs, Tenakee Inlet	AK
68620	William Henry Bay, Lynn Canal, Alaska	NOS	9452391	58.7133	-135.232	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:09:00	0	\N	00:02:00	-0.5	\N	\N	\N	William Henry Bay	AK
68621	Skagway, Taiya Inlet, Lynn Canal, Alaska (sub)	NOS	9452400	59.45	-135.327	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:01:00	\N	1.01	-00:03:00	\N	1.03	\N	\N	Skagway, Taiya Inlet	AK
68622	Chilkat Inlet, Lynn Canal, Alaska (sub)	NOS	9452421	59.17	-135.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:01:00	\N	1	-00:04:00	\N	1.01	\N	\N	Chilkat Inlet	AK
68623	Taiyasanka Harbor, Taiya Inlet, Lynn Canal, Alaska	NOS	9452434	59.3017	-135.428	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:02:00	\N	1.01	-00:04:00	\N	1.03	\N	\N	Taiyasanka Harbor, Taiya Inlet	AK
68624	Haines Inlet, Lynn Canal, Alaska	NOS	9452435	59.23	-135.433	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:06:00	0	\N	-00:09:00	0.5	\N	\N	\N	Haines Inlet	AK
68626	Excursion Inlet, Icy Strait, Alaska	NOS	9452447	58.4967	-135.488	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:24:00	\N	1.07	00:26:00	\N	1.36	\N	\N	Excursion Inlet, North End	AK
68627	Point Adolphus, Icy Strait, Alaska	NOS	9452516	58.2867	-135.803	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:35:00	\N	1.11	00:29:00	\N	1.31	\N	\N	Point Adolphus	AK
68628	Bartlett Cove, Glacier Bay, Alaska	NOS	9452534	58.4567	-135.883	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:22:00	\N	1.11	00:19:00	\N	1.36	\N	\N	Bartlett Cove	AK
68629	Mud Bay, Goose Island, Icy Strait, Alaska	NOS	9452567	58.2117	-136.035	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:06:00	\N	0.96	00:06:00	\N	1.2	\N	\N	Mud Bay, Goose Island	AK
68630	Elbow Passage, Klag Bay, Chichagof Island, Alaska	NOS	9452579	57.6133	-136.087	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:13:00	\N	1.03	00:08:00	\N	0.98	\N	\N	Elbow Passage, Klag Bay	AK
68631	Kimshan Cove, Ogden Passage, Chichagof Island, Alaska	NOS	9452583	57.6867	-136.107	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:06:00	\N	1.03	00:05:00	\N	0.92	\N	\N	Kimshan Cove, Ogden Passage	AK
68632	Muir Inlet, Glacier Bay, Alaska (sub)	NOS	9452584	58.9133	-136.108	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:49:00	\N	1.19	00:39:00	\N	1.55	\N	\N	Muir Inlet	AK
68633	Willoughby Island, Glacier Bay, Alaska	NOS	9452586	58.6083	-136.117	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:50:00	\N	1.16	00:41:00	\N	1.5	\N	\N	Willoughby Island	AK
68634	Inian Cove, North Inian Pass, Cross Sound, Alaska	NOS	9452629	58.2633	-136.325	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:03:00	\N	1.01	00:12:00	\N	1.05	\N	\N	Inian Cove, North Inian Pass	AK
68635	Wachusett Inlet, Glacier Bay, Alaska	NOS	9452632	58.9467	-136.333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:50:00	\N	1.2	00:39:00	\N	1.57	\N	\N	Wachusett Inlet, Glacier Bay	AK
68636	Miner Island, Lisianski Strait and Inlet, Alaska	NOS	9452633	58.01	-136.342	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	-00:06:00	\N	0.96	-00:08:00	\N	0.94	\N	\N	Miner Island	AK
68637	Elfin Cove, Port Althorp, Cross Sound, Alaska (sub)	NOS	9452634	58.19472	-136.34694444444443	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:05:00	\N	1.01	00:04:00	\N	1.1	\N	\N	Elfin Cove, Port Althorp	AK
68969	Point Loma, California	NOS	TWC0405	32.666666666667005	-117.23333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66196	-00:02:00	\N	0.92	-00:09:00	\N	0.92	\N	\N	Point Loma	CA
68638	Canoe Cove, North Pass, Lisianski Strait and Inlet, Alaska	NOS	9452649	57.8467	-136.422	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	-00:01:00	\N	0.89	00:02:00	\N	0.91	\N	\N	Canoe Cove, North Pass	AK
68639	Takanis Bay, Yakobi Island, outer coast, Alaska	NOS	9452671	57.9283	-136.52	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	-00:01:00	\N	1.03	-00:04:00	\N	0.9	\N	\N	Takanis Bay	AK
68640	Surge Bay, Yakobi Island, outer coast, Alaska	NOS	9452672	58.0183	-136.528	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:02:00	\N	0.96	00:00:00	\N	0.88	\N	\N	Surge Bay	AK
68641	Composite Island, Glacier Bay, Alaska	NOS	9452682	58.8883	-136.573	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:51:00	\N	1.2	00:45:00	\N	1.54	\N	\N	Composite Island	AK
68642	Graves Harbor, Alaska	NOS	9452704	58.2767	-136.678	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:07:00	\N	1.03	00:04:00	\N	0.91	\N	\N	Graves Harbor	AK
68643	Dixon Harbor, Alaska	NOS	9452747	58.3833	-136.867	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:07:00	\N	0.96	00:07:00	\N	0.89	\N	\N	Dixon Harbor	AK
68644	Lituya Bay, 2 miles inside entrance, Alaska	NOS	9452928	58.6167	-137.65	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:36:00	\N	0.89	00:06:00	\N	0.87	\N	\N	Lituya Bay, 2 miles inside entrance	AK
68645	Redfield Cove, Yakutat Bay, Alaska	NOS	9453208	59.6117	-139.58	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66405	00:00:00	\N	0.92	00:01:00	\N	1	\N	\N	Redfield Cove, Yakutat Bay	AK
68646	Point Latouche, Yakutat Bay, Alaska	NOS	9453210	59.9033	-139.627	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66405	00:03:00	\N	0.93	00:06:00	\N	1	\N	\N	Point Latouche, Yakutat Bay	AK
68647	Johnstone Passage, Yakutat Bay, Alaska	NOS	9453215	59.5817	-139.702	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66405	00:03:00	\N	1	00:01:00	\N	1	\N	\N	Johnstone Passage, Yakutat Bay	AK
68648	Yakutat, Yakutat Bay, Alaska (sub)	NOS	9453220	59.5485	-139.7334	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:16:00	\N	0.95	00:17:00	\N	1.01	\N	\N	Yakutat, Yakutat Bay	AK
68649	Tyndall Glacier, Icy Bay, Alaska	NOS	9453431	60.0783	-141.275	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66405	00:17:00	\N	0.97	00:20:00	\N	0.96	\N	\N	Tyndall Glacier, Icy Bay	AK
68650	Riou Bay, Alaska	NOS	9453456	59.885	-141.457	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66405	00:03:00	\N	1.01	00:02:00	\N	0.98	\N	\N	Icy Bay	AK
68651	Shag Rock, Orca Inlet, Alaska	NOS	9454125	60.465	-145.988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:16:00	-0.1	\N	-00:11:00	-1.1	\N	\N	\N	Shag Rock	AK
68652	Comfort Cove, Port Gravina, Prince William Sound, Alaska	NOS	9454157	60.71	-146.085	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:06:00	-0.1	\N	-00:16:00	-0.7	\N	\N	\N	Comfort Cove, Port Gravina	AK
68653	Middleton Island (north end), Alaska	NOS	9454224	59.4617	-146.31	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:14:00	-0.1	\N	-00:21:00	-2.2	\N	\N	\N	Middleton Island (north end)	AK
68654	Landlocked Bay, Port Fidalgo, Prince William Sound, Alaska	NOS	9454296	60.8533	-146.535	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:08:00	-0.1	\N	-00:12:00	-0.7	\N	\N	\N	Landlocked Bay, Port Fidalgo	AK
68655	Jack Bay, Valdez Arm, Alaska	NOS	9454309	61.04	-146.615	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66407	-00:02:00	\N	0.99	-00:01:00	\N	0.99	\N	\N	Jack Bay	AK
68656	Johnstone Point, Hinchinbrook Island, Alaska	NOS	9454319	60.4817	-146.61	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:02:00	-0.1	\N	-00:07:00	-0.8	\N	\N	\N	Johnstone Point	AK
68657	Cape Hinchinbrook, Hinchinbrook Island, Alaska	NOS	9454329	60.2383	-146.648	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:03:00	\N	0.98	-00:10:00	\N	0.88	\N	\N	Cape Hinchinbrook	AK
68658	Rocky Point, Valdez Arm, Alaska	NOS	9454363	60.9467	-146.755	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66407	-00:03:00	\N	0.99	00:00:00	\N	0.99	\N	\N	Rocky Point	AK
68659	Busby Island, Valdez Arm, Alaska	NOS	9454374	60.8983	-146.782	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66407	-00:02:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	Busby Island	AK
68660	Jackson Cove, Glacier Island, Prince William Sound, Alaska	NOS	9454507	60.88	-147.223	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:02:00	0	\N	-00:10:00	-0.6	\N	\N	\N	Jackson Cove, Glacier Island	AK
68661	Port Chalmers, Montague Island, Alaska	NOS	9454511	60.2418	-147.249	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:01:00	\N	0.97	-00:02:00	\N	0.94	\N	\N	Port Chalmers	AK
68662	Perch Point, Montague Island, Alaska (sub)	NOS	9454561	60.1267	-147.395	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:03:00	\N	0.94	-00:08:00	\N	0.92	\N	\N	Perch Point	AK
68663	Wooded Islands, Montague Island, Alaska (sub)	NOS	9454562	59.875	-147.403	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:00:00	\N	0.95	-00:02:00	\N	0.8	\N	\N	Wooded Islands	AK
68664	Naked Island, McPherson Passage, Prince William Sound, Alaska	NOS	9454563	60.6833	-147.388	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:08:00	-0.1	\N	-00:18:00	-0.7	\N	\N	\N	Naked Island, McPherson Passage	AK
68665	Gibbon Anchorage, Green Island, Prince William Sound, Alaska	NOS	9454573	60.27	-147.438	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:06:00	-0.2	\N	-00:21:00	-0.8	\N	\N	\N	Gibbon Anchorage, Green Island	AK
68666	Patton Bay, Montague Island, Alaska	NOS	9454574	59.9067	-147.45	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:05:00	-0.1	\N	-00:12:00	-2.3	\N	\N	\N	Patton Bay	AK
68667	Montague Island, Alaska (sub)	NOS	9454616	60.025	-147.592	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:00:00	\N	0.96	-00:02:00	\N	0.91	\N	\N	5 miles NE of Point Brazil, Montague Island	AK
68668	Louis Bay, Knight Island, Prince William Sound, Alaska	NOS	9454642	60.4617	-147.672	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:03:00	\N	1.04	00:00:00	\N	0.96	\N	\N	Louis Bay	AK
68669	Snug Harbor, Knight Island, Alaska (sub)	NOS	9454662	60.25	-147.717	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:00:00	\N	0.97	-00:03:00	\N	0.91	\N	\N	Snug Harbor, Knight Island	AK
68670	Point Helen, Knight Island, Alaska	NOS	9454671	60.1533	-147.767	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:01:00	\N	1	-00:03:00	\N	0.92	\N	\N	Point Helen	AK
68671	Port Audrey, Knight Island, Alaska	NOS	9454673	60.3433	-147.768	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:03:00	\N	0.95	00:00:00	\N	0.92	\N	\N	Port Audrey	AK
68672	Macleod Harbor, Montague Island, Prince William Sound, Alaska	NOS	9454674	59.89	-147.795	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:04:00	\N	0.96	00:10:00	\N	0.89	\N	\N	Macleod Harbor	AK
68673	Herring Point, Knight Island, Prince William Sound, Alaska (sub)	NOS	9454691	60.475	-147.792	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:01:00	\N	1.01	-00:04:00	\N	0.95	\N	\N	Herring Point	AK
68674	Latouche, Latouche Island, Prince William Sound, Alaska	NOS	9454713	60.0533	-147.907	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:02:00	0	\N	-00:05:00	-1	\N	\N	\N	Latouche, Latouche Island	AK
68675	Eshamy Bay, Knight Island Passage, Prince William Sound, Alaska	NOS	9454735	60.4483	-147.978	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:04:00	0	\N	00:01:00	-0.4	\N	\N	\N	Eshamy Bay, Knight Island Passage	AK
68676	Guguak, Alaska (sub)	NOS	9454751	60.1	-148.038	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:03:00	\N	0.95	-00:07:00	\N	0.91	\N	\N	Guguak	AK
68677	Bainbridge Point, Bainbridge Island, Prince William Sound, Alaska	NOS	9454755	60.1967	-148.042	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:01:00	\N	0.98	-00:06:00	\N	0.93	\N	\N	Bainbridge Point, Bainbridge Island	AK
68678	Eshamy Lagoon, Prince William Sound, Alaska	NOS	9454757	60.4617	-148.045	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:00:00	\N	1.03	-00:11:00	\N	0.92	\N	\N	Eshamy Lagoon	AK
68679	Sawmill Bay, Evans Island, Prince William Sound, Alaska	NOS	9454764	60.0517	-148.065	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:03:00	0	\N	-00:03:00	-1.2	\N	\N	\N	Sawmill Bay, Evans Island	AK
68680	Chenega Island, southwest end, Prince William Sound, Alaska	NOS	9454777	60.2833	-148.113	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:00:00	\N	1	-00:03:00	\N	0.94	\N	\N	Chenega Island, southwest end	AK
68800	Skan Bay, Unalaska Island, Alaska	NOS	9462554	53.61	-167.045	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:19:00	\N	1.1	-00:07:00	\N	1.05	\N	\N	Skan Bay	AK
68681	Chenega Island, Dangerous Passage, Prince William Sound, Alaska	NOS	9454787	60.33	-148.143	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:06:00	0	\N	-00:01:00	-0.9	\N	\N	\N	Chenega Island, Dangerous Passage	AK
68682	Applegate Island, Prince William Sound, Alaska	NOS	9454794	60.6233	-148.165	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:06:00	0	\N	-00:01:00	-0.6	\N	\N	\N	Applegate Island	AK
68683	Culross Bay, Wells Passage, Prince William Sound, Alaska	NOS	9454798	60.7417	-148.172	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:01:00	0	\N	-00:15:00	-0.4	\N	\N	\N	Culross Bay, Wells Passage	AK
68684	Hogg Bay, Port Bainbridge, Prince William Sound, Alaska	NOS	9454805	60.0767	-148.195	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:03:00	-0.1	\N	-00:12:00	-1.9	\N	\N	\N	Hogg Bay, Port Bainbridge	AK
68685	Point Elrington, Elrington Island, Prince William Sound, Alaska (sub)	NOS	9454814	59.9383	-148.227	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:02:00	\N	0.94	-00:13:00	\N	0.84	\N	\N	Point Elrington, Elrington Island	AK
68687	Kings Bay, Port Nellie Juan, Prince William Sound, Alaska	NOS	9454887	60.5417	-148.46	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:09:00	0	\N	-00:01:00	-0.6	\N	\N	\N	Kings Bay, Port Nellie Juan	AK
68688	Whittier, Prince William Sound, Alaska (sub)	NOS	9454949	60.7783	-148.665	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:01:00	0	\N	-00:05:00	-0.3	\N	\N	\N	Whittier, Passage Canal	AK
68689	Day Harbor, Alaska	NOS	9455036	60.01	-149.062	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66420	00:00:00	\N	1.01	-00:02:00	\N	0.99	\N	\N	Day Harbor	AK
68690	Seward, Resurrection Bay, Alaska (sub)	NOS	9455090	60.12	-149.4266667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:13:00	\N	0.91	-00:06:00	\N	0.83	\N	\N	Seward, Resurrection Bay	AK
68691	Agnes Cove, Aialik Peninsula, Alaska (sub)	NOS	9455120	59.7733	-149.588	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:00:00	\N	0.91	-00:06:00	\N	0.84	\N	\N	Agnes Cove, Aialik Peninsula	AK
68692	Bear Cove, Aialik Peninsula, Alaska	NOS	9455128	59.8017	-149.615	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66420	00:01:00	\N	0.97	00:01:00	\N	1	\N	\N	Bear Cove, Aialik Peninsula	AK
68693	Aialik Bay, north end, Alaska (sub)	NOS	9455145	59.9533	-149.715	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:01:00	\N	0.89	-00:06:00	\N	0.83	\N	\N	Aialik Bay, North end	AK
68694	Aialik Sill, Aialik Bay, Alaska (sub)	NOS	9455146	59.885	-149.718	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:00:00	\N	0.9	-00:05:00	\N	0.83	\N	\N	Aialik Sill, Aialik Bay	AK
68695	Camp Cove, Harris Peninsula, Alaska (sub)	NOS	9455151	59.6933	-149.748	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:00:00	\N	0.9	-00:06:00	\N	0.84	\N	\N	Camp Cove, Aialik Bay	AK
68696	Crater Bay, Harris Bay, Alaska (sub)	NOS	9455159	59.7133	-149.787	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:01:00	\N	0.87	-00:03:00	\N	0.84	\N	\N	Crater Bay, Harris Bay	AK
68697	Upper Northwestern Fiord, Harris Bay, Alaska (sub)	NOS	9455204	59.79	-150.032	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:11:00	\N	0.9	00:01:00	\N	0.85	\N	\N	Upper Northwestern Fiord, Harris Bay	AK
68698	Two Arm Bay, Harris Bay, Alaska	NOS	9455217	59.6617	-150.108	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66420	-00:05:00	\N	0.94	-00:10:00	\N	1.03	\N	\N	Two Arm Bay, Harris Bay	AK
68699	Chance Cove (Lagoon), Alaska	NOS	9455249	59.4883	-150.312	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66420	00:01:00	\N	1.01	00:00:00	\N	1.04	\N	\N	Chance Cove (Lagoon)	AK
68700	Beauty Bay, Nuka Bay, Alaska	NOS	9455304	59.5267	-150.628	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66420	00:14:00	\N	1.01	00:12:00	\N	1.08	\N	\N	Beauty Bay, Nuka Bay	AK
68701	Nuka Passage, Alaska	NOS	9455308	59.4083	-150.667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66420	00:12:00	\N	1.01	00:11:00	\N	1.09	\N	\N	Nuka Passage	AK
68702	Takoma Cove, Port Dick, Alaska	NOS	9455347	59.2617	-150.982	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66420	00:18:00	\N	1.01	00:23:00	\N	1.15	\N	\N	Takoma Cove, Port Dick	AK
68703	Picnic Harbor, Rocky Bay, Alaska	NOS	9455399	59.255	-151.42	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66420	00:21:00	\N	1.01	00:26:00	\N	1.23	\N	\N	Picnic Harbor, Rocky Bay	AK
68704	Port Chatham, Cook Inlet, Alaska	NOS	9455428	59.2133	-151.728	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:34:00	\N	0.92	-00:28:00	\N	0.78	\N	\N	Port Chatham	AK
68706	Ushagat Island, Barren Islands, Cook Inlet, Alaska	NOS	9455478	58.9467	-152.268	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:04:00	\N	0.76	-00:08:00	\N	0.76	\N	\N	Ushagat Island, Barren Islands	AK
68707	Tutka Bay,Kachemak Bay, Cook Inlet, Alaska	NOS	9455506	59.4317	-151.357	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:01:00	0	\N	-00:01:00	0.2	\N	\N	\N	Tutka Bay,Kachemak Bay	AK
68708	Sadie Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455514	59.49	-151.365	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:04:00	-0.1	\N	-00:04:00	0.1	\N	\N	\N	Sadie Cove, Kachemak Bay	AK
68709	Halibut Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455556	59.5967	-151.22	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:05:00	0	\N	-00:03:00	0.7	\N	\N	\N	Halibut Cove, Kachemak Bay	AK
68710	Bear Cove, Kachemak Bay, Cook Inlet, Alaska (sub)	NOS	9455595	59.725	-151.023	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:05:00	-0.1	\N	-00:04:00	0.4	\N	\N	\N	Bear Cove, Kachemak Bay	AK
68711	Anchor Point, Cook Inlet, Alaska (sub)	NOS	9455606	59.77197222222223	-151.8670277777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:21:00	0	\N	00:29:00	0.4	\N	\N	\N	Anchor Point	AK
68712	Drift River Terminal, Cook Inlet, Alaska	NOS	9455741	60.555	-152.133	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	02:04:00	\N	1.18	01:39:00	\N	1.01	\N	\N	Drift River Terminal	AK
68713	Kenai City Pier, Cook Inlet, Alaska	NOS	9455742	60.545	-151.218	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	02:55:00	-0.1	\N	01:54:00	1.9	\N	\N	\N	Kenai City Pier	AK
68714	Snug Harbor, Cook Inlet, Alaska	NOS	9456173	60.10747222222222	-152.5816666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	01:15:00	0	\N	01:04:00	-2.3	\N	\N	\N	Snug Harbor, Cook Inlet	AK
68715	Tuxedni Channel, Cook Inlet, Alaska	NOS	9456204	60.1533	-152.635	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:53:00	0.2	\N	00:39:00	-1.3	\N	\N	\N	Tuxedni Channel	AK
68716	Oil Bay, Kamishak Bay, Cook Inlet, Alaska	NOS	9456463	59.64	-153.262	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	01:16:00	\N	0.83	01:15:00	\N	0.77	\N	\N	Oil Bay, Kamishak Bay	AK
68717	Nukshak Island, Shelikof Strait, Alaska (sub)	NOS	9456717	58.3917	-153.958	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:07:00	\N	0.95	-00:01:00	\N	0.76	\N	\N	Nukshak Island, Shelikof Strait	AK
68718	Nordyke Island, Kamishak Bay, Cook Inlet, Alaska	NOS	9456822	59.1783	-154.087	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:22:00	-0.2	\N	00:10:00	-2.8	\N	\N	\N	Nordyke Island, Kamishak Bay	AK
68719	Kukak, Kukak Bay, Alaska	NOS	9456835	58.3417	-154.117	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:05:00	\N	0.74	-00:08:00	\N	0.74	\N	\N	Kukak, Kukak Bay	AK
68720	Aguchik Island, Kukak Bay, Alaska (sub)	NOS	9456901	58.29	-154.27	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:06:00	\N	0.94	-00:04:00	\N	0.75	\N	\N	Aguchik Island, Kukak Bay	AK
68721	Takli Island, Shelikof Strait, Alaska	NOS	9456992	58.0633	-154.477	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:03:00	\N	1	-00:09:00	\N	0.73	\N	\N	Takli Island, Shelikof Strait	AK
68722	Tonki Bay, Alaska	NOS	9457152	58.3167	-152.067	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:21:00	0.2	\N	00:12:00	2.3	\N	\N	\N	Tonki Bay	AK
68723	Seal Bay, Alaska	NOS	9457201	58.3717	-152.238	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:36:00	0.3	\N	00:29:00	2.4	\N	\N	\N	Seal Bay	AK
68724	Andreon Bay, Shuyak Island, Alaska	NOS	9457259	58.5183	-152.415	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:44:00	0.3	\N	00:35:00	2.5	\N	\N	\N	Andreon Bay, Shuyak Island	AK
68725	Kodiak, Port of Kodiak, Alaska	NOS	9457261	57.7833	-152.428	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	-00:02:00	0	\N	-00:03:00	0	\N	\N	\N	Kodiak, Port of Kodiak	AK
68726	Spruce Island (north side), Alaska	NOS	9457262	57.9383	-152.417	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:08:00	0.1	\N	00:02:00	0.4	\N	\N	\N	Spruce Island (north side)	AK
68727	Perenosa Bay, Afognak Island, Alaska	NOS	9457271	58.3567	-152.448	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:39:00	0.3	\N	00:28:00	2.5	\N	\N	\N	Perenosa Bay	AK
68728	Kodiak, St. Paul Harbor, Alaska	NOS	9457283	57.745	-152.483	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	-00:02:00	0	\N	-00:05:00	-0.1	\N	\N	\N	Kodiak, St. Paul Harbor	AK
68729	Ouzinkie, Spruce Island, Alaska (sub)	NOS	9457287	57.9217	-152.498	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	-00:04:00	0	\N	-00:05:00	0.2	\N	\N	\N	Ouzinkie, Spruce Island	AK
68730	Carry Inlet, Shuyak Island, Alaska	NOS	9457293	58.5867	-152.513	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:07:00	\N	0.73	00:06:00	\N	0.73	\N	\N	Carry Inlet	AK
68731	Redfox Bay, Shuyak Strait, Alaska	NOS	9457316	58.4533	-152.595	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:02:00	-0.2	\N	-00:14:00	-4.4	\N	\N	\N	Redfox Bay, Shuyak Strait	AK
68732	Big Bay, Shuyak Island, Alaska	NOS	9457321	58.555	-152.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:15:00	\N	0.77	00:10:00	\N	0.77	\N	\N	Big Bay	AK
68733	Ugak Bay (Saltery Cove), Alaska	NOS	9457351	57.4817	-152.718	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	-00:20:00	-0.1	\N	-00:29:00	-0.3	\N	\N	\N	Ugak Bay (Saltery Cove)	AK
68734	Fox Bay, Whale Island, Alaska	NOS	9457361	57.9783	-152.755	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:37:00	0.2	\N	00:22:00	1.2	\N	\N	\N	Fox Bay, Whale Island	AK
68735	Kizhuyak Bay, Alaska	NOS	9457401	57.82	-152.9	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:11:00	0	\N	00:06:00	0.8	\N	\N	\N	Kizhuyak Bay	AK
68736	Port Hobron, Sitkalidak Island, Alaska	NOS	9457479	57.1633	-153.152	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	-00:06:00	0.1	\N	-00:18:00	-0.3	\N	\N	\N	Port Hobron, Sitkalidak Island	AK
68737	Dolphin Point, Raspberry Strait, Alaska	NOS	9457481	58.11	-153.155	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:05:00	-0.1	\N	-00:25:00	-4.1	\N	\N	\N	Dolphin Point, Raspberry Strait	AK
68738	Zachar Bay, Uyak Bay, Alaska	NOS	9457648	57.5483	-153.735	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:00:00	\N	0.77	-00:09:00	\N	0.77	\N	\N	Zachar Bay	AK
68739	Mining Camp, Uyak Bay, Alaska	NOS	9457671	57.46	-153.817	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:10:00	-0.1	\N	-00:37:00	-4.1	\N	\N	\N	Mining Camp	AK
68740	Moser Bay (Trap Point), Alaska	NOS	9457773	57.0017	-154.148	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66459	00:10:00	\N	1.01	00:11:00	\N	0.99	\N	\N	Moser Bay (Trap Point)	AK
68741	Olga Bay (A. P. A. Cannery), Alaska	NOS	9457798	57.1617	-154.228	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66459	03:54:00	\N	0.06	03:46:00	\N	0.1	\N	\N	Olga Bay (A. P. A. Cannery)	AK
68742	Alitak, Lazy Bay, Alaska (sub)	NOS	9457804	56.8974	-154.248	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:19:00	\N	1.42	00:02:00	\N	1.38	\N	\N	Alitak, Lazy Bay	AK
68743	Puale Bay, Alaska (sub)	NOS	9458209	57.7067	-155.393	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:03:00	\N	0.67	-00:22:00	\N	0.67	\N	\N	Puale Bay	AK
68744	Kanatak Lagoon, Portage Bay, Alaska	NOS	9458365	57.52	-156.052	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:51:00	0.3	\N	00:21:00	3	\N	\N	\N	Kanatak Lagoon, Portage Bay	AK
68745	Chowiet Island, Semidi Island, Alaska (sub)	NOS	9458519	56.0517	-156.698	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:25:00	\N	1.29	00:15:00	\N	1.04	\N	\N	Chowiet Island, Semidi Island	AK
68746	Unavikshak Island, Alaska	NOS	9458762	56.4917	-157.74	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:44:00	\N	1.24	00:31:00	\N	1.05	\N	\N	Unavikshak Island	AK
68747	Nakchamik Island, Alaska	NOS	9458779	56.3517	-157.812	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:41:00	\N	1.33	00:29:00	\N	1.04	\N	\N	Nakchamik Island	AK
68748	Kujulik Bay (North Shore), Alaska	NOS	9458819	56.6133	-157.983	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:46:00	\N	1.35	00:31:00	\N	1.1	\N	\N	Kujulik Bay (North Shore)	AK
68749	Chankliut Island, Alaska	NOS	9458849	56.1467	-158.107	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:43:00	\N	1.27	00:32:00	\N	0.98	\N	\N	Chankliut Island	AK
68750	Chignik, Anchorage Bay, Alaska	NOS	9458917	56.2967	-158.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:44:00	\N	1.28	00:34:00	\N	1.04	\N	\N	Chignik, Anchorage Bay	AK
68751	Hump Island, Kuiukta Bay, Alaska (sub)	NOS	9458964	56.1133	-158.598	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:42:00	\N	1.23	00:35:00	\N	0.91	\N	\N	Hump Island, Kuiukta Bay	AK
68752	Mitrofania Island, Alaska (sub)	NOS	9459016	55.89	-158.82	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:39:00	\N	1.23	00:32:00	\N	0.88	\N	\N	Mitrofania Island	AK
68753	Chiachi Island (east side), Alaska	NOS	9459085	55.8433	-159.105	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:37:00	\N	1.28	00:22:00	\N	0.89	\N	\N	Chiachi Island (east side)	AK
68754	Kupreanof Harbor, Paul Island, Alaska	NOS	9459145	55.79	-159.35	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:35:00	\N	1.28	00:19:00	\N	0.89	\N	\N	Kupreanof Harbor, Paul Island	AK
68755	Dent Point, Stepovak Bay, Alaska	NOS	9459281	55.7833	-159.88	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:33:00	\N	1.19	00:17:00	\N	0.86	\N	\N	Dent Point, Stepovak Bay	AK
68756	Sanborn Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	9459311	55.155	-159.995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	-00:03:00	\N	0.98	00:03:00	\N	1	\N	\N	Sanborn Harbor, Nagai Island	AK
68757	Pirate Cove, Popof Island, Shumagin Islands, Alaska	NOS	9459398	55.3617	-160.36	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	00:03:00	\N	0.98	00:08:00	\N	1.03	\N	\N	Pirate Cove, Popof Island	AK
68758	Albatross Anchorage, Balboa Bay, Alaska	NOS	9459464	55.59	-160.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	00:03:00	\N	1.05	-00:02:00	\N	1.06	\N	\N	Albatross Anchorage, Balboa Bay	AK
68759	Beaver Bay, Alaska	NOS	9459522	55.4733	-160.84	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:02:00	\N	1.05	00:03:00	\N	1.01	\N	\N	Beaver Bay	AK
68760	Seal Cape, Coal Bay, Alaska	NOS	9459643	55.365	-161.325	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	00:05:00	\N	1.05	00:00:00	\N	0.98	\N	\N	Seal Cape, Coal Bay	AK
68761	Ukolnoi Island, Alaska	NOS	9459696	55.2583	-161.537	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	00:00:00	\N	0.98	00:07:00	\N	0.97	\N	\N	Ukolnoi Island	AK
68762	Lenard Harbor, Cold Bay, Alaska	NOS	9459895	55.1183	-162.378	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	00:17:00	\N	0.98	00:12:00	\N	0.98	\N	\N	Lenard Harbor, Cold Bay	AK
68763	Peterson Bay, Sanak Islands, Alaska	NOS	9459939	54.3933	-162.637	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	-00:08:00	\N	1.05	-00:05:00	\N	0.83	\N	\N	Peterson Bay	AK
68764	Sanak Harbor, Sanak Islands, Alaska	NOS	9459968	54.4817	-162.812	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	00:03:00	\N	1.05	00:14:00	\N	0.89	\N	\N	Sanak Harbor	AK
68765	Ogliuga Island (east coast), Delarof Islands, Alaska	NOS	9461081	51.6033	-178.617	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-00:43:00	\N	0.95	00:01:00	\N	0.95	\N	\N	Ogliuga Island (east coast)	AK
68766	Lash Bay, Tanaga Island, Alaska	NOS	9461132	51.6717	-178.045	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-01:39:00	\N	1.14	-00:56:00	\N	1.14	\N	\N	Lash Bay	AK
68767	Tanaga Bay, Tanaga Island, Alaska	NOS	9461138	51.7183	-177.997	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-00:32:00	\N	1.08	-00:06:00	\N	1.08	\N	\N	Tanaga Bay	AK
68768	Hot Springs Bay, Tanaga Island, Alaska	NOS	9461162	51.7783	-177.8	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-00:12:00	\N	0.84	-00:40:00	\N	0.84	\N	\N	Hot Springs Bay	AK
68769	Cape Chunu, Kanaga Island, Alaska	NOS	9461183	51.665	-177.637	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-01:54:00	\N	1.11	-01:44:00	\N	1.11	\N	\N	Cape Chunu	AK
68770	Kanaga Bay, Kanaga Island, Alaska	NOS	9461264	51.7183	-177.2	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-01:44:00	\N	1.05	-01:39:00	\N	1.05	\N	\N	Kanaga Bay	AK
68771	Cape Chlanak, Kanaga Island, Alaska	NOS	9461276	51.71	-177.145	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-01:34:00	\N	0.92	-01:22:00	\N	0.92	\N	\N	Cape Chlanak	AK
68772	Shoal Point, Kanaga Island, Alaska	NOS	9461292	51.87	-177.068	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-00:16:00	\N	0.86	00:01:00	\N	0.86	\N	\N	Shoal Point	AK
68773	Bay of Waterfalls, Adak Island, Alaska	NOS	9461337	51.6417	-176.825	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-02:04:00	\N	0.95	-01:20:00	\N	0.95	\N	\N	Bay of Waterfalls	AK
68774	Unalga Bight, Adak Island, Alaska	NOS	9461341	51.78	-176.807	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-00:21:00	\N	0.97	-00:07:00	\N	0.97	\N	\N	Unalga Bight	AK
68775	Boot Bay, Adak Island, Alaska	NOS	9461391	51.7133	-176.53	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-02:09:00	\N	0.97	-01:38:00	\N	0.97	\N	\N	Boot Bay	AK
68776	Adak Bight, Adak Island, Alaska	NOS	9461406	51.77	-176.435	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-02:02:00	\N	1	-01:24:00	\N	1	\N	\N	Adak Bight	AK
68777	Laska Cove, Kagalaska Island, Aleutian Islands, Alaska	NOS	9461411	51.825	-176.402	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	00:07:00	\N	0.97	-00:04:00	\N	0.97	\N	\N	Laska Cove, Kagalaska Island	AK
68778	Sand Bay, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461453	51.9733	-176.085	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-00:20:00	\N	0.97	-00:05:00	\N	0.97	\N	\N	Sand Bay, Great Sitkin Island	AK
68779	Bugle Point, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461467	52.0383	-175.98	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-00:05:00	\N	0.89	00:01:00	\N	0.89	\N	\N	Bugle Point, Great Sitkin Island	AK
68780	Fenimore Pass, Aleutian Islands, Alaska	NOS	9461519	51.96	-175.588	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-00:13:00	\N	0.89	-00:04:00	\N	0.89	\N	\N	Fenimore Pass	AK
68781	Atka Pass, east end, Atka Island, Alaska	NOS	9461555	52.0067	-175.32	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-02:10:00	\N	1.24	-01:07:00	\N	1.24	\N	\N	Atka Pass, east end	AK
68782	Bechevin Bay, Atka Island, Alaska	NOS	9461582	52.0367	-175.115	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	00:04:00	\N	0.95	00:11:00	\N	0.95	\N	\N	Bechevin Bay	AK
68783	Explorer Bay, Atka Island, Alaska	NOS	9461656	52.0733	-174.568	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-02:24:00	\N	1.24	-02:43:00	\N	1.24	\N	\N	Explorer Bay	AK
68784	Sagchudak Island, Atka Island, Alaska	NOS	9461667	52.0267	-174.48	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-02:25:00	\N	1.24	-01:26:00	\N	1.24	\N	\N	Sagchudak Island	AK
68785	Martin Harbor, Korovin Bay, Atka Island, Alaska	NOS	9461693	52.2267	-174.292	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	00:21:00	\N	0.87	00:19:00	\N	0.87	\N	\N	Martin Harbor, Korovin Bay	AK
68786	Cape Utalug (4 miles west of), Atka Island, Alaska	NOS	9461704	52.1183	-174.207	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-02:32:00	\N	1.19	-01:38:00	\N	1.19	\N	\N	Cape Utalug (4 miles west of)	AK
68787	Finch Cove, Seguam Island, Aleutian Islands, Alaska	NOS	9461945	52.3917	-172.405	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	00:07:00	\N	0.87	-01:00:00	\N	0.87	\N	\N	Finch Cove, Seguam Island	AK
68788	North side, Yunaska Island, Alaska	NOS	9462144	52.6817	-170.707	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-01:29:00	\N	1.19	-01:05:00	\N	1.02	\N	\N	North side	AK
68789	East Cove, Yunaska Island, Alaska	NOS	9462161	52.6533	-170.563	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-02:35:00	\N	0.85	-01:36:00	\N	0.88	\N	\N	East Cove	AK
68790	Applegate Cove, Chuginadak Island, Aleutian Islands, Alaska	NOS	9462239	52.8617	-169.862	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:58:00	\N	1.27	-00:21:00	\N	1.08	\N	\N	Applegate Cove, Chuginadak Island	AK
68791	Adugak Island, Aleutian Islands, Alaska	NOS	9462317	52.9117	-169.165	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:56:00	\N	1.1	-00:33:00	\N	1.02	\N	\N	Adugak Island	AK
68792	Cape Sagak, Umnak Island, Alaska	NOS	9462331	52.8417	-169.043	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-03:16:00	\N	1.02	-03:03:00	\N	1.2	\N	\N	Cape Sagak	AK
68793	Okee Bay, Umnak Island, Alaska	NOS	9462354	53.0167	-168.835	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:43:00	\N	1.1	-00:07:00	\N	0.99	\N	\N	Okee Bay	AK
68794	Driftwood Bay, Umnak Island, Alaska	NOS	9462367	52.9583	-168.72	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-03:22:00	\N	1.1	-02:56:00	\N	1.35	\N	\N	Driftwood Bay	AK
68795	Kigul Island, Umnak Island, Alaska	NOS	9462398	53.045	-168.442	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-03:42:00	\N	1.27	-03:04:00	\N	1.37	\N	\N	Kigul Island	AK
68796	Inanudak Bay, Umnak Island, Alaska	NOS	9462408	53.2967	-168.352	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:30:00	\N	0.93	-00:06:00	\N	0.96	\N	\N	Inanudak Bay	AK
68797	Bogoslof Island, Aleutian Islands, Alaska	NOS	9462444	53.93	-168.033	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:55:00	\N	1.1	-00:30:00	\N	1.08	\N	\N	Bogoslof Island	AK
68798	Otter Point, Umnak Island, Alaska	NOS	9462465	53.3967	-167.843	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:40:00	\N	0.93	-00:27:00	\N	0.88	\N	\N	Otter Point	AK
68799	Chernofski Harbor, Unalaska Island, Alaska	NOS	9462501	53.395	-167.533	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:29:00	\N	1.1	-00:10:00	\N	1.02	\N	\N	Chernofski Harbor	AK
68805	Kisselen Bay, Beaver Inlet, Unalaska Island, Alaska	NOS	9462606	53.7133	-166.572	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-03:14:00	\N	1.1	-02:59:00	\N	1.4	\N	\N	Kisselen Bay, Beaver Inlet	AK
68806	Dutch Harbor, Amaknak Island, Unalaska Island, Alaska	NOS	9462611	53.8917	-166.537	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:07:00	\N	1	00:00:00	\N	1	\N	\N	Dutch Harbor, Amaknak Island	AK
68807	Udagak Strait, Unalaska Island, Alaska	NOS	9462637	53.7367	-166.295	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-03:59:00	\N	1.02	-03:32:00	\N	1.37	\N	\N	Udagak Strait	AK
68808	English Bay, Unalaska Island, Alaska	NOS	9462641	53.925	-166.257	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:01:00	\N	0.76	00:16:00	\N	0.79	\N	\N	English Bay	AK
68809	Biorka Village, Biverly Inlet, Alaska (sub)	NOS	9462645	53.82891666666667	-166.21625	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-03:25:00	\N	1.35	-03:13:00	\N	1.35	\N	\N	Udamat Bay, Sedanka Island	AK
68810	Akutan Harbor, Akutan Island, Aleutian Islands, Alaska	NOS	9462691	54.1283	-165.808	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:07:00	\N	1.1	-00:17:00	\N	1.08	\N	\N	Akutan Harbor, Akutan Island	AK
68811	Trident Bay, Akun Island, Aleutian Islands, Alaska (sub)	NOS	9462721	54.14	-165.527	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-04:11:00	\N	0.76	-03:59:00	\N	0.99	\N	\N	Trident Bay, Akun Island	AK
68812	Cape Sarichef, Unimak Island, Alaska (sub)	NOS	9462787	54.6	-164.928	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:56:00	\N	1.27	-00:24:00	\N	1.37	\N	\N	Cape Sarichef	AK
68813	Scotch Cap, Unimak Island, Alaska (sub)	NOS	9462808	54.39363888888889	-164.7457222222222	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-02:49:00	\N	1.27	-02:27:00	\N	1.4	\N	\N	Scotch Cap	AK
68814	Cape Mordvinof, Unimak Island, Alaska	NOS	9462838	54.9283	-164.467	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	00:19:00	\N	1.36	00:26:00	\N	1.73	\N	\N	Cape Mordvinof	AK
68815	St. Catherine Cove, Unimak Island, Alaska	NOS	9462944	55.01	-163.507	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:18:00	\N	1.36	00:04:00	\N	1.23	\N	\N	St. Catherine Cove	AK
68816	Dora Harbor, Unimak Island, Alaska	NOS	9462971	54.71	-163.267	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	00:15:00	\N	1.05	00:15:00	\N	0.87	\N	\N	Dora Harbor	AK
68817	Amak Island, Bristol Bay, Alaska	NOS	9462987	55.4133	-163.115	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	01:48:00	\N	1.78	01:47:00	\N	2.13	\N	\N	Amak Island	AK
68818	Grant Point, Izembek Lagoon, Bristol Bay, Alaska	NOS	9463058	55.27	-162.9	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	04:05:00	\N	0.85	03:03:00	\N	1.23	\N	\N	Grant Point, Izembek Lagoon	AK
68819	Settlement Point, Pavlof Bay, Alaska	NOS	9463195	55.5	-161.46666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	00:08:00	\N	0.9	00:09:00	\N	0.98	\N	\N	Settlement Point, Pavlof Bay	AK
68820	Egegik, Egegik River, Alaska	NOS	9464874	58.2167	-157.375	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66496	05:36:00	\N	0.36	03:42:00	\N	1.2	\N	\N	Egegik	AK
68821	Egegik River entrance, Alaska	NOS	9464881	58.2383	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66496	03:47:00	\N	1.14	03:16:00	\N	1.69	\N	\N	Egegik River Ent, Bristol Bay	AK
68822	Middle Bluff, Kvichak Bay, Bristol Bay, Alaska	NOS	9465022	58.4533	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66496	04:10:00	\N	1.14	03:56:00	\N	1.84	\N	\N	Middle Bluff, Kvichak Bay	AK
68823	King Salmon Airport, Naknek River, Alaska	NOS	9465149	58.6717	-156.657	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66496	09:46:00	\N	0.09	05:43:00	\N	0.24	\N	\N	King Salmon Airport	AK
68824	Omakstalia Point, Naknek River, Alaska	NOS	9465174	58.7067	-156.757	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66496	08:35:00	\N	0.14	04:58:00	\N	0.69	\N	\N	Omakstalia Point	AK
68825	Black Rock, Walrus Islands, Nushagak Bay, Alaska	NOS	9465182	58.70830154418945	-160.18800354003906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66496	04:53:00	\N	0.82	04:53:00	\N	0.8	\N	\N	Black Rock, Walrus Islands	AK
68826	Naknek River entrance, Alaska	NOS	9465183	58.7217	-157.057	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66496	05:26:00	\N	1	04:27:00	\N	2.15	\N	\N	Naknek River Entrance, Kvichak B	AK
68827	Kvichak, Kvichak River, Alaska	NOS	9465342	58.97	-156.947	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66496	07:49:00	\N	0.41	05:21:00	\N	1.54	\N	\N	Kvichak	AK
68828	Goodnews Bay entrance, Alaska	NOS	9465368	59.045	-161.808	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66510	00:11:00	\N	0.95	00:04:00	\N	1.01	\N	\N	Goodnews Bay entrance	AK
68829	Snag Point, Dillingham, Alaska (sub)	NOS	9465374	59.04	-158.447	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66506	00:54:00	\N	0.97	00:28:00	\N	1.03	\N	\N	Snag Point	AK
68830	Platinum, Alaska (sub)	NOS	9465396	59.0467	-161.818	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66506	05:41:00	\N	0.25	06:17:00	\N	0.38	\N	\N	Platinum	AK
68831	Levelock, Kvichak River, Alaska	NOS	9465419	59.1133	-156.832	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66496	09:34:00	\N	0.23	06:13:00	\N	0.9	\N	\N	Levelock	AK
68832	Apokak Creek entrance, Alaska	NOS	9466079	60.1367	-162.158	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66510	04:30:00	\N	0.79	03:18:00	\N	1.47	\N	\N	Apokak Creek entrance	AK
68833	St. Matthew Island, Bering Sea, Alaska	NOS	9466203	60.358299255371094	-172.71499633789062	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66499	00:29:00	\N	0.61	00:06:00	\N	0.61	\N	\N	St. Matthew Island	AK
68834	Bethel, Kuskokwim River, Alaska (sub)	NOS	9466477	60.8	-161.75	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66506	03:47:00	\N	0.16	01:48:00	\N	0.15	\N	\N	Bethel	AK
68835	Pikmiktalik River entrance, Norton Sound, Alaska	NOS	9468011	63.28	-162.602	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66529	-01:13:00	\N	1.08	-01:13:00	\N	1.08	\N	\N	Pikmiktalik River entrance	AK
68836	Fossil River entrance, St. Lawrence Island, Alaska	NOS	9468123	63.4667	-170.017	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66531	-03:08:00	\N	0.67	-03:00:00	\N	1.13	\N	\N	Fossil River entrance	AK
68837	St. Michael, Norton Sound, Alaska (sub)	NOS	9468132	63.475	-162.027	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66529	-02:16:00	\N	1	-00:11:00	\N	1	\N	\N	St. Michael	AK
68838	Niyrakpak Lagoon entrance, St. Lawrence Island, Alaska	NOS	9468216	63.62	-171.383	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66531	-03:31:00	\N	0.67	-03:27:00	\N	0.83	\N	\N	Niyrakpak Lagoon entrance	AK
68839	North Bay, Stuart Island, Norton Sound, Alaska	NOS	9468226	63.6283	-162.517	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66529	-00:28:00	\N	0.72	-00:28:00	\N	0.72	\N	\N	North Bay, Stuart Island	AK
68840	Point Spencer, Port Clarence, Norton Sound, Alaska (sub)	NOS	9469237	65.2567	-166.847	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66531	05:26:00	\N	0.35	05:15:00	\N	0.81	\N	\N	Point Spencer, Port Clarence	AK
68841	Teller, Port Clarence, Alaska (sub)	NOS	9469239	65.2667	-166.353	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66531	04:13:00	\N	0.87	04:01:00	\N	0.8	\N	\N	Teller, Port Clarance	AK
68842	Lost River, Seward Peninsula, Alaska (sub)	NOS	9469338	65.39	-167.145	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66531	05:30:00	\N	0.29	06:43:00	\N	0.71	\N	\N	Lost River, Seward Peninsula	AK
68843	Tin City, Bering Sea, Alaska (sub)	NOS	9469439	65.55833333333334	-167.975	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66531	06:14:00	\N	0.32	07:30:00	\N	0.61	\N	\N	Tin City	AK
68844	Point Barrow, Alaska	NOS	9495048	71.36	-156.353	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	-00:26:00	\N	0.04	-00:37:00	\N	0.04	\N	\N	Point Barrow	AK
68845	Redhook Bay, St. Thomas, Virgin Islands	NOS	9751540	18.3267	-64.8517	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66562	00:44:00	\N	1.28	-00:46:00	\N	1.28	\N	\N	Redhook Bay, St. Thomas Island	VI
68846	Mayagez, Puerto Rico (sub)	NOS	9759394	18.21888888888889	-67.1625	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66572	-00:11:00	\N	0.76	-00:09:00	\N	0.93	\N	\N	Mayaguez	PR
68847	Troy, Hudson River, New York	NOS	TEC1603	42.71666666666667	-73.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65692	00:10:00	\N	1	00:08:00	\N	1	\N	\N	Troy	NY
68848	Chelsea, Arthur Kill, New Jersey	NOS	TEC1645	40.6	-74.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	00:37:00	\N	1.05	00:23:00	\N	1.07	\N	\N	Chelsea	NJ
68849	Oregon Inlet, North Carolina	NOS	TEC2771	35.76666666666701	-75.516666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65821	-00:27:00	\N	0.71	-00:03:00	\N	1.98	\N	\N	Oregon Inlet	NC
68850	Cape Hatteras, North Carolina	NOS	TEC2789	35.23333333333299	-75.516666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:01:00	\N	1.08	00:01:00	\N	1	\N	\N	Cape Hatteras	NC
68851	Hatteras Inlet, North Carolina	NOS	TEC2791	35.2	-75.733333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:13:00	\N	0.83	00:08:00	\N	0.66	\N	\N	Hatteras Inlet	NC
68852	Ocracoke Inlet, North Carolina	NOS	TEC2793	35.06666666666701	-76.016666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:11:00	\N	0.83	00:09:00	\N	0.63	\N	\N	Ocracoke Inlet	NC
68853	Shell Point, Harkers Island, North Carolina	NOS	TEC2801	34.68333333333299	-76.53333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	02:34:00	\N	0.83	01:52:00	\N	0.54	\N	\N	Shell Point, Harkers Island	NC
68854	N.C. State Fisheries, North Carolina	NOS	TEC2831	34.71666666666701	-76.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	01:32:00	\N	0.83	01:05:00	\N	0.66	\N	\N	N.C. State Fisheries	NC
68855	Bogue Inlet, North Carolina	NOS	TEC2837	34.65	-77.1	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:15:00	\N	0.83	00:13:00	\N	0.73	\N	\N	Bogue Inlet	NC
68856	Cape Fear, North Carolina	NOS	TEC2847	33.85	-77.96666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65824	00:07:00	\N	1.33	00:04:00	\N	1.47	\N	\N	Cape Fear	NC
68857	Castle Hayne, Northeast River, Cape Fear River, North Carolina	NOS	TEC2863	34.35	-77.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65834	02:54:00	\N	0.42	02:44:00	\N	0.42	\N	\N	Castle Hayne, Northeast River	NC
68858	Bannermans Branch, Northeast River, Cape Fear River, North Carolina	NOS	TEC2865	34.583333333332995	-77.766666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65834	06:08:00	\N	0.31	05:58:00	\N	0.32	\N	\N	Bannermans Branch, Northeast River	NC
68859	Lockwoods Folly Inlet, North Carolina	NOS	TEC2869	33.916666666667005	-78.233333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65841	00:15:00	\N	1	00:04:00	\N	0.84	\N	\N	Lockwoods Folly Inlet	NC
68861	Frazier Point, South Carolina	NOS	TEC2937	33.31666666666701	-79.28333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	02:07:00	\N	0.68	01:26:00	\N	0.66	\N	\N	Frazier Point	SC
68862	North Santee River Inlet, South Carolina	NOS	TEC2991	33.13333333333299	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:04:00	\N	0.84	-00:09:00	\N	0.85	\N	\N	North Santee River Inlet	SC
68863	Brown Island, South Santee River, South Carolina	NOS	TEC3001	33.15	-79.33333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	01:31:00	\N	0.79	00:27:00	\N	0.78	\N	\N	Brown Island, South Santee River	SC
68864	Cape Romain, 46 miles east of, South Carolina	NOS	TEC3011	33.1	-78.433333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-01:13:00	\N	0.79	-01:05:00	\N	0.78	\N	\N	Cape Romain, 46 miles east of	SC
68865	Jack Creek entrance, Bulls Bay, South Carolina	NOS	TEC3023	32.93333333333299	-79.58333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:15:00	\N	0.95	-00:14:00	\N	0.95	\N	\N	Jack Creek entrance	SC
68866	Sullivans Island (outer coast), South Carolina	NOS	TEC3047	32.76666666666701	-79.83333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:12:00	\N	1	-00:08:00	\N	0.99	\N	\N	Sullivans Island (outer coast)	SC
68867	Shipyard Creek, 0.8 mile above entrance., South Carolina	NOS	TEC3061	32.833333333332995	-79.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	00:20:00	\N	1	00:34:00	\N	1.01	\N	\N	Shipyard Creek, 0.8 mile above entrance.	SC
68868	Folly Island (outer coast), South Carolina	NOS	TEC3127	32.65	-79.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:14:00	\N	1	-00:08:00	\N	0.98	\N	\N	Folly Island (outer coast)	SC
68869	Euhaw Creek, 2.5 mi. above entrance, Broad River, South Carolina	NOS	TEC3327	32.435	-80.85166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:09:00	\N	0.91	01:33:00	\N	1.14	\N	\N	Euhaw Creek, 2.5 mi. above entrance	SC
68870	Tybee Creek entrance, Georgia	NOS	TEC3399	31.983333333332993	-80.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:05:00	\N	1	-00:09:00	\N	0.99	\N	\N	Tybee Creek entrance	GA
68871	Beach Hammock, Georgia	NOS	TEC3401	31.95	-80.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:07:00	\N	1	-00:01:00	\N	1	\N	\N	Beach Hammock	GA
68872	Romerly Marsh Creek, Georgia	NOS	TEC3403	31.933333333332993	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:03:00	\N	1.03	00:08:00	\N	1.03	\N	\N	Romerly Marsh Creek	GA
68873	Savannah Sheraton Resort Hotel, Wilmington River, Georgia	NOS	TEC3405	32	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:06:00	\N	1.14	00:14:00	\N	1.13	\N	\N	Savannah Sheraton Resort Hotel	GA
68874	Thunderbolt, Wilmington River, Georgia	NOS	TEC3407	32.03333333333299	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:12:00	\N	1.14	00:32:00	\N	1.15	\N	\N	Thunderbolt	GA
68875	North entrance, Wilmington River, Georgia	NOS	TEC3409	32.06666666666701	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:44:00	\N	1.09	00:40:00	\N	1.1	\N	\N	North entrance	GA
68876	Isle of Hope, Skidaway River, Georgia	NOS	TEC3411	31.983333333332993	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:28:00	\N	1.13	00:50:00	\N	1.13	\N	\N	Isle of Hope, Skidaway River	GA
68877	Egg Islands, Georgia	NOS	TEC3413	31.83333333333299	-81.08333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:10:00	\N	1.04	00:04:00	\N	1.04	\N	\N	Egg Islands	GA
68878	Coffee Bluff, Forest River, Georgia	NOS	TEC3417	31.933333333332993	-81.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:42:00	\N	1.09	01:05:00	\N	1.09	\N	\N	Coffee Bluff, Forest River	GA
68879	Fort McAllister, Ogeechee River, Georgia	NOS	TEC3419	31.883333333332992	-81.21666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:16:00	\N	1	00:48:00	\N	1	\N	\N	Fort McAllister, Ogeechee River	GA
68880	Highway bridge, Ogeechee River, Georgia	NOS	TEC3421	31.983333333332993	-81.28333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	04:25:00	\N	0.14	03:19:00	\N	0.15	\N	\N	Highway bridge, Ogeechee River	GA
68881	Florida Passage, Bear River, Georgia	NOS	TEC3425	31.816666666667007	-81.16666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:49:00	\N	0.95	00:46:00	\N	1.09	\N	\N	Florida Passage, Bear River	GA
68882	Cane Patch Creek entrance, Georgia	NOS	TEC3427	31.816666666667007	-81.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:43:00	\N	1.05	00:55:00	\N	1.05	\N	\N	Cane Patch Creek entrance	GA
68883	North Newport River, Georgia	NOS	TEC3445	31.66666666666701	-81.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:36:00	\N	1.09	00:56:00	\N	1.1	\N	\N	North Newport River	GA
68884	South Newport Cut, N. Newport River, Georgia	NOS	TEC3447	31.66666666666701	-81.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:54:00	\N	1.04	01:01:00	\N	1.08	\N	\N	South Newport Cut, N. Newport River	GA
68885	Dallas Bluff, Julienton River, Georgia	NOS	TEC3457	31.58333333333299	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	01:04:00	\N	1.09	00:48:00	\N	1.1	\N	\N	Dallas Bluff, Julienton River	GA
68886	Blackbeard Island, Georgia	NOS	TEC3463	31.53333333333299	-81.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:22:00	\N	1	00:18:00	\N	1	\N	\N	Blackbeard Island	GA
68887	Wolf Island, south end, Georgia	NOS	TEC3491	31.33333333333299	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:45:00	\N	1.09	00:25:00	\N	0.97	\N	\N	Wolf Island, south end	GA
68888	Hampton River entrance, Georgia	NOS	TEC3495	31.21666666666701	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:04:00	\N	0.95	00:16:00	\N	0.96	\N	\N	Hampton River entrance	GA
68889	Jones Creek entrance, Hampton River, Georgia	NOS	TEC3497	31.3	-81.33333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:13:00	\N	1.05	01:03:00	\N	1.05	\N	\N	Jones Creek entrance, Hampton River	GA
68890	St. Simons Sound Bar, Georgia	NOS	TEC3499	31.1	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	-00:02:00	\N	0.95	-00:01:00	\N	0.95	\N	\N	St. Simons Sound Bar	GA
68891	Allied Chemical Corp. docks, Turtle River, Georgia	NOS	TEC3515	31.183333333332993	-81.516666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:42:00	\N	1.09	01:03:00	\N	1.1	\N	\N	Allied Chemical Corp. docks	GA
68892	Highway bridge, South Brunswick River, Georgia	NOS	TEC3521	31.15	-81.566666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:49:00	\N	1.09	01:07:00	\N	1.1	\N	\N	Highway bridge, South Brunswick River	GA
68893	Below Spring Bluff, Little Satilla River, Georgia	NOS	TEC3531	31.16666666666701	-81.616666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	01:31:00	\N	1.23	01:09:00	\N	1.23	\N	\N	Below Spring Bluff	GA
68894	Burnt Fort, Satilla River, Georgia	NOS	TEC3541	30.95	-81.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	05:05:00	\N	0.53	03:55:00	\N	0.53	\N	\N	Burnt Fort	GA
68895	Cape Canaveral, Florida	NOS	TEC3693	28.433333333332993	-80.566666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	-00:44:00	\N	1.42	-01:06:00	\N	1.5	\N	\N	Cape Canaveral	FL
68896	Jupiter Inlet, U.S. Highway 1 Bridge, Florida	NOS	TEC3783	26.948333333332993	-80.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:05:00	\N	1.14	00:28:00	\N	0.86	\N	\N	Jupiter Inlet, U.S. Highway 1 Bridge	FL
68897	Tequesta, Loxahatchee River, Florida	NOS	TEC3787	26.95	-80.10166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:58:00	\N	1.14	00:59:00	\N	0.8	\N	\N	Tequesta	FL
68898	Tequesta, North Fork entrance, Loxahatchee River, Florida	NOS	TEC3789	26.95166666666701	-80.10166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65951	01:42:00	\N	0.92	00:51:00	\N	0.78	\N	\N	Tequesta, North Fork entrance	FL
68899	Cape Sable, East Cape, Florida	NOS	TEC4165	25.116666666667008	-81.08333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	01:50:00	\N	0.98	01:33:00	\N	1.3	\N	\N	Cape Sable, East Cape	FL
68900	Whitewater Bay, Florida	NOS	TEC4169	25.316666666667007	-81.03333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	04:38:00	\N	0.33	03:53:00	\N	0.26	\N	\N	Whitewater Bay	FL
68901	Indian Key, Florida	NOS	TEC4183	25.8	-81.46666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	01:19:00	\N	0.98	00:55:00	\N	1.48	\N	\N	Indian Key	FL
68902	Round Key, Florida	NOS	TEC4185	25.83333333333299	-81.53333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65974	01:12:00	\N	0.98	00:54:00	\N	1.48	\N	\N	Round Key	FL
68903	Point Ybel, San Carlos Bay entrance, Florida	NOS	TEC4207	26.45	-82.016666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-01:12:00	\N	1.21	-01:50:00	\N	1.21	\N	\N	Point Ybel, San Carlos Bay entrance	FL
68904	Pass-a-Grille Beach, Boca Ciega Bay, Florida	NOS	TEC4271	27.683333333332993	-82.733333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	-01:30:00	\N	0.87	-01:34:00	\N	0.87	\N	\N	Pass-a-Grille Beach	FL
68905	Suwannee River entrance, Florida	NOS	TEC4299	29.28333333333299	-83.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	00:18:00	\N	0.95	00:06:00	\N	0.88	\N	\N	Suwannee River entrance	FL
68906	Pepperfish Keys, Florida	NOS	TEC4301	29.5	-83.366666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66016	00:24:00	\N	0.95	00:12:00	\N	0.88	\N	\N	Pepperfish Keys	FL
68907	Fishermans Rest, Florida	NOS	TEC4305	29.733333333332993	-83.53333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66019	-00:02:00	\N	0.86	-00:14:00	\N	0.93	\N	\N	Fishermans Rest	FL
68908	Rock Islands, Florida	NOS	TEC4309	29.96666666666701	-83.83333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66019	00:04:00	\N	0.91	-00:03:00	\N	0.93	\N	\N	Rock Islands	FL
68909	Lower Anchorage, Apalachicola Bay, Florida	NOS	TEC4343	29.6	-85.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66030	-00:35:00	\N	1	-00:17:00	\N	0.93	\N	\N	Lower Anchorage	FL
68910	Milton, Blackwater River, Pensacola Bay, Florida	NOS	TEC4383	30.616666666667008	-87.03333333333299	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66053	01:47:00	\N	1.2	01:40:00	\N	1.2	\N	\N	Milton, Blackwater River	FL
68911	Paris Road Bridge (ICWW), Louisiana	NOS	TEC4445	30	-89.933333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	05:58:00	\N	1.04	05:53:00	\N	1.04	\N	\N	Paris Road Bridge (ICWW)	LA
68912	Bayou Rigaud, Grand Isle, Barataria Bay, Louisiana	NOS	TEC4455	29.266666666667007	-89.96666666666701	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66115	00:46:00	\N	0.94	01:32:00	\N	0.94	\N	\N	Bayou Rigaud, Grand Isle	LA
68913	Mermentau River entrance, Louisiana	NOS	TEC4495	29.75	-93.1	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	-00:59:00	\N	1.79	-01:54:00	\N	1.79	\N	\N	Mermentau River entrance	LA
68914	Texas City, Turning Basin, Galveston Bay, Texas	NOS	TEC4513	29.383333333332992	-94.883333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	00:41:00	\N	1	00:33:00	\N	1	\N	\N	Texas City, Turning Basin	TX
68915	Gilchrist, East Bay, Galveston Bay, Texas	NOS	TEC4525	29.516666666667007	-94.483333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66161	04:18:00	\N	0.86	03:16:00	\N	0.86	\N	\N	Gilchrist, East Bay	TX
68916	Guanica, Puerto Rico	NOS	TEC4731	17.96666666666701	-66.91666666666701	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66577	00:18:00	\N	1	-01:22:00	\N	1	\N	\N	Guanica	PR
68917	Playa de Ponce, Puerto Rico	NOS	TEC4733	17.96666666666701	-66.616666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66577	-00:13:00	\N	1.14	-00:39:00	\N	1.14	\N	\N	Playa de Ponce	PR
68918	Playa Cortada, Puerto Rico	NOS	TEC4735	17.983333333332993	-66.45	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66577	-00:37:00	\N	1.14	00:16:00	\N	1.14	\N	\N	Playa Cortada	PR
68919	Arroyo, Puerto Rico	NOS	TEC4737	17.96666666666701	-66.066666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66577	00:13:00	\N	1.14	00:52:00	\N	1.14	\N	\N	Arroyo	PR
68920	Puerto Maunabo, Puerto Rico	NOS	TEC4739	18	-65.883333333333	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66577	01:13:00	\N	1	-00:56:00	\N	1	\N	\N	Puerto Maunabo	PR
68921	Culebrita, Isla, Puerto Rico	NOS	TEC4741	18.316666666667007	-65.233333333333	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66577	02:40:00	\N	1.57	-02:34:00	\N	1.57	\N	\N	Culebrita, Isla	PR
68922	Puerto Ferro, Isla de Vieques, Puerto Rico	NOS	TEC4743	18.1	-65.433333333333	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66577	03:01:00	\N	1.14	-02:26:00	\N	1.14	\N	\N	Puerto Ferro, Isla de Vieques	PR
68923	Punta Mulas, Isla de Vieques, Puerto Rico	NOS	TEC4745	18.15	-65.433333333333	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66572	-00:17:00	\N	0.72	-00:14:00	\N	0.72	\N	\N	Punta Mulas, Isla de Vieques	PR
68924	Roosevelt Roads, Puerto Rico	NOS	TEC4747	18.233333333332993	-65.616666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66572	00:20:00	\N	0.63	00:02:00	\N	0.63	\N	\N	Roosevelt Roads	PR
68925	Ensenada Honda, Culebra Island, Puerto Rico	NOS	TEC4749	18.3	-65.28333333333299	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66572	-00:15:00	\N	0.63	-00:34:00	\N	0.63	\N	\N	Ensenada Honda, Culebra Island	PR
68926	Playa de Fajardo, Puerto Rico	NOS	TEC4751	18.33333333333299	-65.633333333333	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66572	-00:13:00	\N	0.99	-00:10:00	\N	0.99	\N	\N	Playa de Fajardo	PR
68927	Magens Bay, St. Thomas, Virgin Islands	NOS	TEC4759	18.366666666667008	-64.91666666666701	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66562	-00:17:00	\N	1.59	-00:06:00	\N	1.59	\N	\N	Magens Bay, St. Thomas Island	VI
68928	Pagan Island, Marianas	NOS	TPT2621	18.1333	145.76666	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65516	00:01:00	\N	0.94	00:05:00	\N	0.94	\N	\N	Pagan Island	MP
68929	Saipan Harbor, Saipan Island, Marianas	NOS	TPT2623	15.2	145.71666666667008	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65516	00:07:00	\N	0.8	00:02:00	\N	0.8	\N	\N	Saipan Harbor, Saipan Island	MP
68930	Tinian Island, Marianas	NOS	TPT2625	14.966666666667008	145.61666666667008	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65516	-00:23:00	\N	0.33	-00:02:00	\N	0.74	\N	\N	Tinian Island	MP
68931	Rota Island, Marianas	NOS	TPT2627	14.1333	145.1333	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65516	-00:06:00	\N	0.94	-00:03:00	\N	0.94	\N	\N	Rota Island	MP
68932	Ifalik Atoll, Caroline Islands, FSM	NOS	TPT2647	7.25	144.45	:Pacific/Yap	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65516	-00:13:00	\N	1.33	-00:54:00	\N	1	\N	\N	Ifalik Atoll	FM
68933	Pulap Atoll, Chuuk, FSM	NOS	TPT2651	7.633333333333304	149.41666666667007	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65521	00:43:00	\N	0.74	-00:53:00	\N	0.74	\N	\N	Pulap Atoll	FM
68934	Namonuito Atoll, Caroline Islands, FSM	NOS	TPT2653	8.583333333333297	149.65	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65521	00:21:00	\N	0.69	-01:23:00	\N	0.69	\N	\N	Namonuito Atoll	FM
68935	Nomwin Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2655	8.45	151.78333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65521	00:20:00	\N	0.8	-00:08:00	\N	0.8	\N	\N	Nomwin Atoll, Hall Islands	FM
68936	Murilo Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2657	8.6	152.25	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65521	00:00:00	\N	0.85	-00:28:00	\N	0.85	\N	\N	Murilo Atoll, Hall Islands	FM
68937	Chuuk, Moen Island, E. Caroline Islands, FSM (sub)	NOS	TPT2659	7.45	151.85	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65521	00:11:00	\N	0.85	00:10:00	\N	0.85	\N	\N	Moen Island, Truk Islands	FM
68938	Dublon Island, Chuuk, FSM	NOS	TPT2661	7.366666666666704	151.88333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65521	00:30:00	\N	1.07	00:02:00	\N	1.07	\N	\N	Dublon Island, Truk Islands	FM
68939	Losap Atoll, Chuuk, FSM	NOS	TPT2663	6.9	152.7333333333299	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65521	00:25:00	\N	0.8	-00:03:00	\N	0.8	\N	\N	Losap Atoll	FM
68940	Namoluk Atoll, Chuuk, FSM	NOS	TPT2665	5.9	153.13333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65521	00:27:00	\N	0.8	-00:01:00	\N	0.8	\N	\N	Namoluk Atoll	FM
68941	Satawan Anchorage, Nomoi Islands, Chuuk, FSM	NOS	TPT2667	5.333333333333304	153.7333333333299	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65521	00:25:00	\N	0.96	-00:03:00	\N	0.96	\N	\N	Satawan Anchorage, Nomoi Islands	FM
68942	Bikini Atoll, Marshall Islands	NOS	TPT2687	11.6	165.55	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:19:00	0	\N	-00:19:00	0	\N	\N	\N	Bikini Atoll	MH
68943	Eniirikku Island, Bikini Atoll, Marshall Islands	NOS	TPT2689	11.5	165.33333333332993	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:16:00	\N	0.85	-00:15:00	\N	0.85	\N	\N	Eniirikku Island, Bikini Atoll	MH
68944	Rongelap Island, Rongelap Atoll, Marshall Islands	NOS	TPT2691	11.15	166.9	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:07:00	\N	0.96	-00:07:00	\N	0.96	\N	\N	Rongelap Island, Rongelap Atoll	MH
68945	Rongerik Atoll, Marshall Islands	NOS	TPT2693	11.383333333333008	167.5166666666701	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:15:00	0	\N	-00:14:00	0.1	\N	\N	\N	Rongerik Atoll	MH
68946	Ujae Atoll, Marshall Islands	NOS	TPT2695	9.033333333333296	165.6	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ujae Atoll	MH
68947	Kwajalein Atoll (Namur Island), Marshall Islands	NOS	TPT2697	9.4	167.4833333333299	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:05:00	0	\N	-00:02:00	0	\N	\N	\N	Kwajalein Atoll (Namur Island)	MH
68948	Ailinglapalap Atoll, Marshall Islands	NOS	TPT2701	7.283333333333304	168.75	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	00:07:00	0.3	\N	00:08:00	0.4	\N	\N	\N	Ailinglapalap Atoll	MH
68949	Jaluit Atoll (SE Pass), Marshall Islands	NOS	TPT2703	5.916666666666696	169.65	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:08:00	-0.1	\N	-00:12:00	-0.1	\N	\N	\N	Jaluit Atoll (SE Pass)	MH
68950	Ebon (Boston) Atoll, Marshall Islands	NOS	TPT2705	4.6	168.68333333332993	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:10:00	0.1	\N	-00:10:00	0.1	\N	\N	\N	Ebon (Boston) Atoll	MH
68951	Taongi Atoll, Marshall Islands	NOS	TPT2707	14.566666666667007	168.95	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:20:00	0	\N	-00:20:00	0	\N	\N	\N	Taongi Atoll	MH
68952	Bikar (Dawson) Atoll, Marshall Islands	NOS	TPT2709	12.25	170.13333333332992	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Bikar (Dawson) Atoll	MH
68953	Ailuk Atoll, Marshall Islands	NOS	TPT2711	10.216666666667008	169.9833333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ailuk Atoll	MH
68954	Likiep Atoll, Marshall Islands	NOS	TPT2713	9.816666666666704	169.31666666667007	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:01:00	0	\N	00:00:00	0.1	\N	\N	\N	Likiep Atoll	MH
68955	Wotje Atoll, Marshall Islands	NOS	TPT2715	9.466666666666704	170.2333333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:11:00	-0.2	\N	-00:11:00	-0.2	\N	\N	\N	Wotje Atoll	MH
68956	Erikub Atoll, Marshall Islands	NOS	TPT2717	9.2	169.91666666667007	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Erikub Atoll	MH
68957	Maloelap Atoll, Marshall Islands	NOS	TPT2719	8.716666666666704	171.2333333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:05:00	-0.1	\N	-00:04:00	0.1	\N	\N	\N	Maloelap Atoll	MH
68958	Majuro Atoll, Marshall Islands	NOS	TPT2721	7.116666666666704	171.36666666667008	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:06:00	0.1	\N	-00:05:00	0.3	\N	\N	\N	Majuro Atoll	MH
68959	Arno Atoll, Marshall Islands	NOS	TPT2723	7.133333333333304	171.7	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	-00:05:00	-0.1	\N	-00:04:00	0.6	\N	\N	\N	Arno Atoll	MH
68960	Port Rhin, Mili Atoll, Marshall Islands	NOS	TPT2725	6.233333333333296	171.8	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65520	00:04:00	0	\N	00:04:00	0.7	\N	\N	\N	Port Rhin, Mili Atoll	MH
68961	Howland Island	NOS	TPT2737	0.8	-176.63333333332992	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	03:46:00	0.4	\N	03:48:00	4.2	\N	\N	\N	Howland Island	\N
68962	Palmyra Island	NOS	TPT2739	5.883333333333304	-162.08333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	01:13:00	-0.2	\N	01:19:00	0.6	\N	\N	\N	Palmyra Island	\N
68963	Waikane, Kaneohe Bay, Oahu Island, Hawaii	NOS	TPT2777	21.5	-157.85	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65509	-00:04:00	\N	1	-00:22:00	\N	1.13	\N	\N	Waikane, Kaneohe Bay	HI
68964	Laie Bay, Oahu Island, Hawaii	NOS	TPT2779	21.65	-157.93333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65509	-00:32:00	\N	0.75	-00:21:00	\N	1	\N	\N	Laie Bay	HI
68965	Kihei, Maalaea Bay, Maui Island, Hawaii	NOS	TPT2797	20.78333333333299	-156.46666666667008	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65511	01:19:00	\N	0.54	01:52:00	\N	0.94	\N	\N	Kihei, Maalaea Bay	HI
68966	Lahaina, Maui Island, Hawaii	NOS	TPT2799	20.883333333332992	-156.68333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65511	01:01:00	\N	0.81	01:18:00	\N	0.89	\N	\N	Lahaina	HI
68967	Smuggler Cove, Kahoolawe Island, Hawaii	NOS	TPT2803	20.516666666667007	-156.68333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65506	00:03:00	0	\N	-00:15:00	0.2	\N	\N	\N	Smuggler Cove	HI
68968	Tau Island, Manua Islands, American Samoa	NOS	TPT2865	-14.21666666666667	-169.5333333333333	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65519	-00:24:00	\N	1	-00:25:00	\N	1.43	\N	\N	Tau Island, Manua Islands	AS
68970	Quivira Basin, Mission Bay, California	NOS	TWC0413	32.76666666666701	-117.23333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66196	00:04:00	\N	0.95	00:05:00	\N	0.95	\N	\N	Quivira Basin, Mission Bay	CA
68971	San Clemente, California	NOS	TWC0419	33.416666666667005	-117.61666666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66196	-00:11:00	\N	0.92	-00:15:00	\N	0.92	\N	\N	San Clemente	CA
68972	Los Patos (highway bridge), California	NOS	TWC0427	33.71666666666701	-118.05	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	01:12:00	\N	0.6	01:00:00	\N	0.83	\N	\N	Los Patos (highway bridge)	CA
68973	Los Angeles Harbor, Mormon Island, California	NOS	TWC0439	33.75	-118.26666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:02:00	0	\N	00:04:00	-0.1	\N	\N	\N	Los Angeles Harbor, Mormon Island	CA
68974	Mugu Lagoon (ocean pier), California	NOS	TWC0445	34.1	-119.1	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:11:00	\N	0.96	00:03:00	\N	0.96	\N	\N	Mugu Lagoon (ocean pier)	CA
68975	Santa Barbara Island, California	NOS	TWC0463	33.48333333333299	-119.03333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	00:04:00	\N	0.92	-00:02:00	\N	0.92	\N	\N	Santa Barbara Island	CA
68976	Point Arguello, California	NOS	TWC0473	34.583333333332995	-120.65	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66207	-00:08:00	\N	0.96	-00:03:00	\N	0.96	\N	\N	Point Arguello	CA
68977	San Francisco Bar, California	NOS	TWC0509	37.76666666666701	-122.63333333333004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	-00:31:00	0	\N	-00:35:00	-0.2	\N	\N	\N	San Francisco Bar	CA
68978	Roberts Landing, 1.3 miles west of, San Francisco Bay, California	NOS	TWC0547	37.666666666667005	-122.2	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	01:28:00	0.1	\N	00:52:00	1.4	\N	\N	\N	Roberts Landing, 1.3 miles west of	CA
68979	Lakeville, Petaluma River, San Pablo Bay, California	NOS	TWC0649	38.2	-122.56666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66215	02:50:00	\N	0.81	01:59:00	\N	1.11	\N	\N	Lakeville, Petaluma River	CA
68980	Point Arena, California	NOS	TWC0771	38.95	-123.73333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66255	00:01:00	\N	0.95	00:03:00	\N	0.98	\N	\N	Point Arena	CA
68981	Mendocino, Mendocino Bay, California	NOS	TWC0777	39.3	-123.8	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66255	00:01:00	\N	0.95	00:07:00	\N	0.98	\N	\N	Mendocino, Mendocino Bay	CA
68982	Wedderburn, Rogue River, Oregon	NOS	TWC0817	42.43333333333299	-124.41666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	00:16:00	\N	0.92	00:09:00	\N	0.95	\N	\N	Wedderburn, Rogue River	OR
68983	Gardiner, Umpqua River, Oregon	NOS	TWC0831	43.73333333333299	-124.11666666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66268	01:09:00	\N	0.8	00:56:00	\N	0.88	\N	\N	Gardiner	OR
68984	Nestucca Bay entrance, Oregon	NOS	TWC0857	45.166666666667005	-123.96666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	01:12:00	\N	0.92	00:55:00	\N	1.1	\N	\N	Nestucca Bay entrance	OR
68985	Miami Cove, Tillamook Bay, Oregon	NOS	TWC0863	45.55	-123.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	01:26:00	\N	0.92	01:15:00	\N	1.06	\N	\N	Miami Cove	OR
68986	Bay City, Tillamook Bay, Oregon	NOS	TWC0865	45.51666666666701	-123.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66263	02:00:00	\N	0.83	01:33:00	\N	1.02	\N	\N	Bay City	OR
68987	Point Adams, Oregon	NOS	TWC0881	46.2	-123.95	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	-00:38:00	0.1	\N	-00:25:00	-0.2	\N	\N	\N	Point Adams, Oreg.	OR
68988	Warrenton, Skipanon River, Oregon	NOS	TWC0883	46.166666666667005	-123.91666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	-00:19:00	0.1	\N	-00:13:00	-0.1	\N	\N	\N	Warrenton, Skipanon River, Oreg.	OR
68989	Harrington Point, Washington	NOS	TWC0895	46.26666666666701	-123.65	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	00:52:00	-0.2	\N	00:21:00	-0.8	\N	\N	\N	Harrington Point, Wash.	WA
68990	Tarlatt Slough, Willapa Bay, Washington	NOS	TWC0933	46.37	-124.005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	01:14:00	\N	1.05	00:45:00	\N	1.05	\N	\N	Tarlatt Slough	WA
68991	Mailboat Slough, Willapa River, Willapa Bay, Washington	NOS	TWC0940	46.68833333333299	-123.81666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	00:11:00	\N	1.02	00:18:00	\N	1.07	\N	\N	Mailboat Slough, Willapa River	WA
68992	Montesano, Chehalis River, Grays Harbor, Washington	NOS	TWC0959	46.96833333333299	-123.6	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	01:45:00	\N	0.94	01:34:00	\N	0.94	\N	\N	Montesano, Chehalis River	WA
68993	Destruction Island, Washington	NOS	TWC0965	47.666666666667005	-124.48333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66303	-00:43:00	\N	1.02	-00:37:00	\N	0.98	\N	\N	Destruction Island	WA
68994	Burns Point, Totten Inlet, Puget Sound, Washington	NOS	TWC1113	47.12166666666701	-123.05666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	01:07:00	\N	1.06	00:54:00	\N	1.33	\N	\N	Burns Point, Totten Inlet	WA
68995	Rocky Point, Eld Inlet, Puget Sound, Washington	NOS	TWC1115	47.081666666667005	-123.005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:56:00	\N	1.1	00:39:00	\N	1.31	\N	\N	Rocky Point, Eld Inlet	WA
68996	Marysville, Quilceda Creek, Washington	NOS	TWC1125	48.045	-122.21166666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:29:00	\N	0.89	00:09:00	\N	0.95	\N	\N	Marysville, Quilceda Creek	WA
68997	Stanwood, Stillaguamish River, Washington	NOS	TWC1131	48.21666666666667	-122.3666666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	02:14:00	\N	0.29	00:23:00	\N	0.62	\N	\N	Stanwood, Stillaguamish River	WA
68998	Peavine Pass, Washington	NOS	TWC1165	48.6	-122.8	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:18:00	\N	0.92	00:34:00	\N	0.98	\N	\N	Peavine Pass	WA
68999	Chuckanut Bay, Bellingham Bay, Washington	NOS	TWC1169	48.666666666667005	-122.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:53:00	-0.1	\N	00:33:00	0	\N	\N	\N	Chuckanut Bay	WA
69000	Point Migley, Hale Passage, Washington	NOS	TWC1173	48.75	-122.71666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	00:51:00	0	\N	00:56:00	0.1	\N	\N	\N	Point Migley	WA
69001	Ferndale, Strait of Georgia, Washington	NOS	TWC1189	48.833333333332995	-122.71666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66313	01:20:00	0	\N	00:49:00	0.5	\N	\N	\N	Ferndale	WA
69002	Tah Bay, Alaska	NOS	TWC1487	54.833333333332995	-132.33333333332993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:03:00	0.1	\N	-00:04:00	2.6	\N	\N	\N	Tah Bay	AK
69003	Kasook Inlet, Sukkwan Island, Tlevak Strait, Alaska	NOS	TWC1513	55.01666666666701	-132.78333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:05:00	0	\N	-00:13:00	2.8	\N	\N	\N	Kasook Inlet, Sukkwan Island	AK
69004	Cyrus Cove, Sea Otter Sound, Davidson Inlet, Alaska	NOS	TWC1579	55.916666666667005	-133.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:12:00	0	\N	-00:16:00	1.1	\N	\N	\N	Cyrus Cove, Sea Otter Sound	AK
69005	Marble Island, Davidson Inlet, Alaska	NOS	TWC1583	56	-133.46666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:15:00	-0.1	\N	-00:19:00	0.8	\N	\N	\N	Marble Island	AK
69006	Port McArthur, Kuiu Island, Alaska	NOS	TWC1593	56.06666666666701	-134.11666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:07:00	-0.1	\N	-00:11:00	0.6	\N	\N	\N	Port McArthur, Kuiu Island	AK
69007	Ideal Cove, Mitkof Island, Frederick Sound, Alaska	NOS	TWC1657	56.666666666667005	-132.63333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:05:00	0	\N	-00:09:00	-0.2	\N	\N	\N	Ideal Cove, Mitkof Island	AK
69008	Brown Cove, Frederick Sound, Alaska	NOS	TWC1659	56.88333333333299	-132.8	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:10:00	-0.1	\N	-00:14:00	-0.3	\N	\N	\N	Brown Cove	AK
69009	Portage Bay, Kupreanof Island, Frederick Sound, Alaska	NOS	TWC1663	57	-133.31666666667007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:15:00	0	\N	-00:19:00	-0.7	\N	\N	\N	Portage Bay, Kupreanof Island	AK
69010	Eliza Harbor, Liesnoi Island, Frederick Sound, Alaska	NOS	TWC1669	57.166666666667005	-134.28333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:19:00	-0.1	\N	-00:19:00	-1.9	\N	\N	\N	Eliza Harbor, Liesnoi Island	AK
69011	Port Houghton, Robert Islands, Alaska	NOS	TWC1673	57.3	-133.46666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:17:00	-0.1	\N	-00:21:00	-0.8	\N	\N	\N	Port Houghton, Robert Islands	AK
69012	Windfall Harbor, Seymour Canal, Alaska	NOS	TWC1683	57.86666666666701	-134.2666666666701	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:18:00	0	\N	00:14:00	-0.2	\N	\N	\N	Windfall Harbor, Seymour Canal	AK
69013	Port Snettisham, Point Styleman, Alaska	NOS	TWC1687	57.96666666666701	-133.88333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:06:00	-0.1	\N	-00:12:00	-0.4	\N	\N	\N	Port Snettisham, Point Styleman	AK
69014	Fritz Cove, Douglas Island, Alaska	NOS	TWC1697	58.31666666666701	-134.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:05:00	-0.1	\N	-00:01:00	-0.3	\N	\N	\N	Fritz Cove, Douglas Island	AK
69015	Tebenkof Bay, Kuiu Island, Alaska	NOS	TWC1723	56.416666666667005	-134.13333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	00:11:00	0.1	\N	00:04:00	1.8	\N	\N	\N	Tebenkof Bay, Kuiu Island	AK
69016	Whitewater Bay, Admiralty Island, Alaska	NOS	TWC1731	57.23333333333299	-134.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:15:00	0.3	\N	-00:19:00	-2	\N	\N	\N	Whitewater Bay, Admiralty Island	AK
69017	Point Thatcher, Alaska	NOS	TWC1735	57.416666666667005	-134.85	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:11:00	0.2	\N	-00:15:00	-1.9	\N	\N	\N	Point Thatcher	AK
69018	Favorite Bay, Kootznahoo Inlet, Alaska	NOS	TWC1739	57.48333333333299	-134.55	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:15:00	0.3	\N	00:11:00	-2.8	\N	\N	\N	Favorite Bay	AK
69019	Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	TWC1741	57.53333333333299	-134.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	01:31:00	\N	0.62	01:22:00	\N	0.67	\N	\N	Mitchell Bay	AK
69020	Freshwater Bay, Chichagof Island, Alaska	NOS	TWC1743	57.85	-135.0166666666701	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:00:00	0.3	\N	-00:08:00	-1.5	\N	\N	\N	Freshwater Bay, Chichagof Island	AK
69021	Point Elizabeth, Alaska	NOS	TWC1783	57.51666666666701	-135.28333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:05:00	0	\N	-00:15:00	-1.6	\N	\N	\N	Point Elizabeth	AK
69022	Lindenburg Head, Alaska	NOS	TWC1785	57.45	-135.03333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:05:00	0	\N	-00:15:00	-1.8	\N	\N	\N	Lindenburg Head	AK
69023	Fairway Island, Alaska	NOS	TWC1787	57.45	-134.88333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:05:00	0	\N	-00:15:00	-2.1	\N	\N	\N	Fairway Island	AK
69024	Falcon Arm, Slocum Arm, Chichagof Island, Alaska	NOS	TWC1789	57.55	-135.93333333332993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	-00:07:00	\N	1.1	-00:05:00	\N	0.96	\N	\N	Falcon Arm, Slocum Arm	AK
69025	Wingham Island, Controller Bay, Alaska	NOS	TWC1863	60.05	-144.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66405	00:08:00	\N	1.01	00:05:00	\N	0.99	\N	\N	Wingham Island, Controller Bay	AK
69026	Pete Dahl Slough, Copper River Delta, Alaska	NOS	TWC1867	60.38333333333299	-145.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:38:00	0	\N	00:06:00	-2.4	\N	\N	\N	Pete Dahl Slough	AK
69027	Eyak River entrance, Alaska	NOS	TWC1869	60.46666666666701	-145.66666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:58:00	-0.1	\N	00:14:00	-1.6	\N	\N	\N	Eyak River entrance	AK
69028	Gravel Point, Orca Inlet, Alaska	NOS	TWC1875	60.46666666666701	-145.96666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:31:00	0	\N	00:01:00	-0.1	\N	\N	\N	Gravel Point	AK
69029	Orca, Orca Inlet, Alaska	NOS	TWC1879	60.583333333332995	-145.71666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:01:00	0	\N	00:01:00	-0.2	\N	\N	\N	Orca	AK
69030	Windy Bay, Hawkins Island, Prince William Sound, Alaska	NOS	TWC1881	60.56666666666701	-145.96666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:01:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Windy Bay, Hawkins Island	AK
69031	Port Etches, Hinchinbrook Island, Alaska	NOS	TWC1887	60.333333333332995	-146.55	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:01:00	-0.2	\N	-00:09:00	-1.3	\N	\N	\N	Port Etches	AK
69032	Hanning Bay, Montague Island, Alaska	NOS	TWC1893	59.95	-147.68333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:05:00	-0.1	\N	-00:08:00	-1	\N	\N	\N	Hanning Bay	AK
69033	Smith Island, Prince William Sound, Alaska	NOS	TWC1907	60.53333333333299	-147.31666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:04:00	-0.1	\N	-00:05:00	-0.8	\N	\N	\N	Smith Island	AK
69034	Snug Corner Cove, Port Fidalgo, Prince William Sound, Alaska	NOS	TWC1909	60.73333333333299	-146.65	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	-00:06:00	0	\N	-00:07:00	-0.6	\N	\N	\N	Snug Corner Cove, Port Fidalgo	AK
69035	Cape Ninilchik, Cook Inlet, Alaska	NOS	TWC1979	60.01666666666701	-151.71666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:54:00	0.2	\N	00:41:00	1.2	\N	\N	\N	Cape Ninilchik	AK
69036	Kenai River entrance, Cook Inlet, Alaska	NOS	TWC1983	60.55	-151.28333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	02:18:00	0.5	\N	01:52:00	2.7	\N	\N	\N	Kenai River entrance	AK
69037	East Foreland, Cook Inlet, Alaska	NOS	TWC1989	60.71666666666701	-151.41666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	02:58:00	0.5	\N	02:37:00	3	\N	\N	\N	East Foreland	AK
69038	Iliamna Bay, Cook Inlet, Alaska	NOS	TWC2009	59.61666666666701	-153.58333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:16:00	\N	0.82	00:12:00	\N	0.8	\N	\N	Iliamna Bay	AK
69039	Marmot Island, Marmot Strait, Alaska	NOS	TWC2021	58.23333333333299	-151.86666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:07:00	0	\N	00:18:00	0.9	\N	\N	\N	Marmot Island, Marmot Strait	AK
69040	Izhut Bay, Alaska	NOS	TWC2023	58.21666666666701	-152.31666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:21:00	0	\N	00:12:00	0.1	\N	\N	\N	Izhut Bay	AK
69041	Kazakof Bay, Marmot Bay, Alaska	NOS	TWC2025	58.13333333333299	-152.56666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:06:00	0.2	\N	00:04:00	0.6	\N	\N	\N	Kazakof Bay, Marmot Bay	AK
69042	Kizhuyak Point, Alaska	NOS	TWC2031	57.9	-152.65	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:09:00	0.1	\N	00:05:00	0.6	\N	\N	\N	Kizhuyak Point	AK
69043	Three Saints Bay, Alaska	NOS	TWC2047	57.11666666666701	-153.5166666666701	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	-00:13:00	0.1	\N	-00:22:00	-0.2	\N	\N	\N	Three Saints Bay	AK
69044	Sitkinak Lagoon, Alaska	NOS	TWC2051	56.5	-154.13333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:07:00	0.2	\N	-00:20:00	-1	\N	\N	\N	Sitkinak Lagoon	AK
69045	Village Islands, Uganik Bay, Alaska	NOS	TWC2067	57.78333333333299	-153.55	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:02:00	\N	0.8	-00:15:00	\N	0.8	\N	\N	Village Islands	AK
69046	Northeast Arm, Uganik Bay, Alaska	NOS	TWC2069	57.73333333333299	-153.33333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:01:00	\N	0.77	-00:12:00	\N	0.77	\N	\N	Northeast Arm	AK
69047	Uganik Passage, Uganik Bay, Alaska	NOS	TWC2071	57.8	-153.3	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:02:00	\N	0.81	-00:07:00	\N	0.81	\N	\N	Uganik Passage	AK
69048	Viekoda Bay, Alaska	NOS	TWC2073	57.9	-153.16666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:03:00	\N	0.8	-00:11:00	\N	0.8	\N	\N	Viekoda Bay	AK
69049	Onion Bay, Kupreanof Strait, Alaska	NOS	TWC2075	58.05	-153.2333333333299	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	-00:01:00	\N	0.8	00:00:00	\N	0.8	\N	\N	Onion Bay	AK
69050	Dry Spruce Island, Kupreanof Strait, Alaska	NOS	TWC2077	57.95	-153.03333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:13:00	\N	0.77	00:02:00	\N	0.77	\N	\N	Dry Spruce Island	AK
69051	Malina Bay, Shelikof Strait, Alaska	NOS	TWC2085	58.18333333333299	-152.95	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:00:00	\N	0.81	-00:14:00	\N	0.81	\N	\N	Malina Bay, Shelikof Strait	AK
69052	Katmai Bay, Shelikof Strait, Alaska	NOS	TWC2095	58	-154.9833333333299	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66427	00:01:00	\N	0.71	-00:14:00	\N	0.71	\N	\N	Katmai Bay, Shelikof Strait	AK
69053	Lees Cabins, Wide Bay, Alaska	NOS	TWC2101	57.43333333333299	-156.3	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:32:00	0.2	\N	00:21:00	3.2	\N	\N	\N	Lees Cabins, Wide Bay	AK
69054	Three Star Point, Alaska	NOS	TWC2105	55.9	-159.16666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:37:00	\N	1.28	00:28:00	\N	0.9	\N	\N	Three Star Point	AK
69055	Fox Bay, Kupreanof Peninsula, Alaska	NOS	TWC2111	55.63333333333299	-159.61666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	00:33:00	\N	1.19	00:18:00	\N	0.86	\N	\N	Fox Bay, Kupreanof Peninsula	AK
69056	Mist Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	TWC2119	55.13333333333299	-159.85	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66469	-00:01:00	\N	0.9	00:01:00	\N	0.97	\N	\N	Mist Harbor, Nagai Island	AK
69057	Malga Bay, Unalga Island, Aleutian Islands, Alaska	NOS	TWC2175	53.98333333333299	-166.16666666667007	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-01:05:00	\N	0.93	-00:18:00	\N	0.85	\N	\N	Malga Bay, Unalga Island	AK
69058	Kashega Bay, Unalaska Island, Alaska	NOS	TWC2187	53.46666666666701	-167.08333333332993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-00:24:00	\N	1.19	-00:08:00	\N	1.08	\N	\N	Kashega Bay	AK
69059	Eagle Bay, Unalaska Island, Alaska	NOS	TWC2193	53.48333333333299	-166.93333333332993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-03:16:00	\N	1.02	-02:56:00	\N	1.46	\N	\N	Eagle Bay	AK
69060	Herbert Island, west side, Aleutian Islands, Alaska	NOS	TWC2223	52.71666666666701	-170.15	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-01:51:00	\N	0.93	-01:40:00	\N	1.14	\N	\N	Herbert Island, west side	AK
69061	Amukta Island, north side, Aleutian Islands, Alaska	NOS	TWC2229	52.51666666666701	-171.2333333333299	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66478	-02:03:00	\N	1.1	-01:32:00	\N	0.94	\N	\N	Amukta Island, north side	AK
69062	Gareloi Island, Delarof Islands, Alaska	NOS	TWC2297	51.75	-178.8	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-00:30:00	\N	1	-00:08:00	\N	1	\N	\N	Gareloi Island	AK
69063	Constantine Harbor, Amchitka Island, Rat Islands, Alaska	NOS	TWC2303	51.41669845581055	179.28329467773438	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-01:06:00	\N	0.76	00:19:00	\N	0.76	\N	\N	Constantine Harbor, Amchitka Island	AK
69064	Gertrude Cove, Kiska Island, Rat Islands, Alaska	NOS	TWC2305	51.93330001831055	177.4499969482422	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-01:19:00	\N	0.86	00:02:00	\N	0.86	\N	\N	Gertrude Cove, Kiska Island	AK
69065	Kiska Harbor, Kiska Island, Rat Islands, Alaska	NOS	TWC2307	51.983299255371094	177.5500030517578	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66475	-01:13:00	\N	0.97	00:24:00	\N	0.97	\N	\N	Kiska Harbor, Kiska Island	AK
69066	Alcan Harbor, Shemya Island, Aleutian Islands, Alaska	NOS	TWC2309	52.71670150756836	174.0666961669922	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66474	-01:03:00	\N	1.03	00:00:00	\N	1.03	\N	\N	Alcan Harbor, Shemya Island	AK
69067	Otkriti Bay, Agattu Island, Aleutian Islands, Alaska	NOS	TWC2311	52.36669921875	173.61669921875	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66474	-01:13:00	\N	1.03	-01:14:00	\N	1.03	\N	\N	Otkriti Bay, Agattu Island	AK
69068	Chichagof Harbor, Attu Island, Alaska	NOS	TWC2315	52.91669845581055	173.21670532226562	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66474	00:16:00	\N	1.09	00:13:00	\N	1.09	\N	\N	Chichagof Harbor	AK
69069	Holtz Bay, Attu Island, Alaska	NOS	TWC2317	52.91669845581055	173.1667022705078	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66474	00:18:00	\N	1.12	-01:04:00	\N	1.12	\N	\N	Holtz Bay	AK
69070	Steller Cove, Attu Island, Alaska	NOS	TWC2319	52.96670150756836	172.89999389648438	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66474	00:11:00	\N	1.12	-01:13:00	\N	1.12	\N	\N	Steller Cove	AK
69071	Etienne Bay, Attu Island, Alaska	NOS	TWC2321	52.91669845581055	172.61669921875	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66474	00:03:00	\N	1.12	-01:17:00	\N	1.12	\N	\N	Etienne Bay	AK
69072	Apoon Mouth, Yukon River, Norton Sound, Alaska	NOS	TWC2405	63.05	-163.38333333332992	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66529	-01:30:00	\N	1.03	-01:30:00	\N	1.03	\N	\N	Apoon Mouth, Yukon River	AK
69073	Flaxman Island, Alaska	NOS	TWC2423	70.183333333333	-145.83333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66446	-00:28:00	\N	0.09	-00:57:00	\N	0.08	\N	\N	Flaxman Island	AK
64580	Agate Passage, south end (Depth 25.1ft), Puget Sound, Washington Current	NOS	PUG1501_1	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	21	200	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64581	Agate Passage, south end (Depth 21.9ft), Puget Sound, Washington Current	NOS	PUG1501_2	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64582	Agate Passage, south end (Depth 18.6ft), Puget Sound, Washington Current	NOS	PUG1501_3	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64583	Agate Passage, south end (Depth 15.3ft), Puget Sound, Washington Current	NOS	PUG1501_4	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64585	Agate Passage, south end (Depth 8.7ft), Puget Sound, Washington Current	NOS	PUG1501_6	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	16	203	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64586	Agate Passage, south end (Depth 5.4ft), Puget Sound, Washington Current	NOS	PUG1501_7	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64587	Agate Passage, south end (Depth 2.2ft), Puget Sound, Washington Current	NOS	PUG1501_8	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64588	Alki Point, 1 mile west of (Depth 640.5ft), Puget Sound, Washington Current	NOS	PUG1502_1	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64589	Alki Point, 1 mile west of (Depth 627.4ft), Puget Sound, Washington Current	NOS	PUG1502_2	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64591	Alki Point, 1 mile west of (Depth 601.1ft), Puget Sound, Washington Current	NOS	PUG1502_4	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64592	Alki Point, 1 mile west of (Depth 588ft), Puget Sound, Washington Current	NOS	PUG1502_5	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64593	Alki Point, 1 mile west of (Depth 574.9ft), Puget Sound, Washington Current	NOS	PUG1502_6	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64594	Alki Point, 1 mile west of (Depth 561.7ft), Puget Sound, Washington Current	NOS	PUG1502_7	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64595	Alki Point, 1 mile west of (Depth 548.6ft), Puget Sound, Washington Current	NOS	PUG1502_8	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64596	Alki Point, 1 mile west of (Depth 535.5ft), Puget Sound, Washington Current	NOS	PUG1502_9	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64597	Alki Point, 1 mile west of (Depth 522.4ft), Puget Sound, Washington Current	NOS	PUG1502_10	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64598	Alki Point, 1 mile west of (Depth 509.3ft), Puget Sound, Washington Current	NOS	PUG1502_11	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64599	Alki Point, 1 mile west of (Depth 496.1ft), Puget Sound, Washington Current	NOS	PUG1502_12	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64600	Alki Point, 1 mile west of (Depth 483ft), Puget Sound, Washington Current	NOS	PUG1502_13	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	8	189	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64601	Alki Point, 1 mile west of (Depth 469.9ft), Puget Sound, Washington Current	NOS	PUG1502_14	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64602	Alki Point, 1 mile west of (Depth 456.8ft), Puget Sound, Washington Current	NOS	PUG1502_15	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64603	Alki Point, 1 mile west of (Depth 443.6ft), Puget Sound, Washington Current	NOS	PUG1502_16	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64604	Alki Point, 1 mile west of (Depth 430.5ft), Puget Sound, Washington Current	NOS	PUG1502_17	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64605	Alki Point, 1 mile west of (Depth 417.4ft), Puget Sound, Washington Current	NOS	PUG1502_18	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64606	Alki Point, 1 mile west of (Depth 404.3ft), Puget Sound, Washington Current	NOS	PUG1502_19	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64607	Alki Point, 1 mile west of (Depth 391.1ft), Puget Sound, Washington Current	NOS	PUG1502_20	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64608	Alki Point, 1 mile west of (Depth 378ft), Puget Sound, Washington Current	NOS	PUG1502_21	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64611	Alki Point, 1 mile west of (Depth 338.6ft), Puget Sound, Washington Current	NOS	PUG1502_24	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64612	Alki Point, 1 mile west of (Depth 325.5ft), Puget Sound, Washington Current	NOS	PUG1502_25	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64613	Alki Point, 1 mile west of (Depth 312.4ft), Puget Sound, Washington Current	NOS	PUG1502_26	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64614	Alki Point, 1 mile west of (Depth 299.3ft), Puget Sound, Washington Current	NOS	PUG1502_27	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64615	Alki Point, 1 mile west of (Depth 286.2ft), Puget Sound, Washington Current	NOS	PUG1502_28	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64616	Alki Point, 1 mile west of (Depth 273ft), Puget Sound, Washington Current	NOS	PUG1502_29	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64617	Alki Point, 1 mile west of (Depth 259.9ft), Puget Sound, Washington Current	NOS	PUG1502_30	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64618	Alki Point, 1 mile west of (Depth 246.8ft), Puget Sound, Washington Current	NOS	PUG1502_31	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64619	Alki Point, 1 mile west of (Depth 233.7ft), Puget Sound, Washington Current	NOS	PUG1502_32	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64620	Alki Point, 1 mile west of (Depth 220.5ft), Puget Sound, Washington Current	NOS	PUG1502_33	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64621	Alki Point, 1 mile west of (Depth 207.4ft), Puget Sound, Washington Current	NOS	PUG1502_34	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64622	Alki Point, 1 mile west of (Depth 194.3ft), Puget Sound, Washington Current	NOS	PUG1502_35	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	359	187	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64623	Alki Point, 1 mile west of (Depth 181.2ft), Puget Sound, Washington Current	NOS	PUG1502_36	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64624	Alki Point, 1 mile west of (Depth 168ft), Puget Sound, Washington Current	NOS	PUG1502_37	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64625	Alki Point, 1 mile west of (Depth 154.9ft), Puget Sound, Washington Current	NOS	PUG1502_38	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64626	Alki Point, 1 mile west of (Depth 141.8ft), Puget Sound, Washington Current	NOS	PUG1502_39	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64627	Alki Point, 1 mile west of (Depth 128.7ft), Puget Sound, Washington Current	NOS	PUG1502_40	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64628	Alki Point, 1 mile west of (Depth 115.6ft), Puget Sound, Washington Current	NOS	PUG1502_41	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.247	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64631	Alki Point, 1 mile west of (Depth 76.2ft), Puget Sound, Washington Current	NOS	PUG1502_44	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	31	201	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.325	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64632	Alki Point, 1 mile west of (Depth 63.1ft), Puget Sound, Washington Current	NOS	PUG1502_45	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.337	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64633	Alki Point, 1 mile west of (Depth 49.9ft), Puget Sound, Washington Current	NOS	PUG1502_46	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.335	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64634	Edmonds, 2.5 miles west of (Depth 500.4ft), Puget Sound, Washington Current	NOS	PUG1503_1	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64635	Edmonds, 2.5 miles west of (Depth 487.2ft), Puget Sound, Washington Current	NOS	PUG1503_2	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64636	Edmonds, 2.5 miles west of (Depth 474.1ft), Puget Sound, Washington Current	NOS	PUG1503_3	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64637	Edmonds, 2.5 miles west of (Depth 461ft), Puget Sound, Washington Current	NOS	PUG1503_4	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64638	Edmonds, 2.5 miles west of (Depth 447.9ft), Puget Sound, Washington Current	NOS	PUG1503_5	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64639	Edmonds, 2.5 miles west of (Depth 434.7ft), Puget Sound, Washington Current	NOS	PUG1503_6	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64640	Edmonds, 2.5 miles west of (Depth 421.6ft), Puget Sound, Washington Current	NOS	PUG1503_7	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64641	Edmonds, 2.5 miles west of (Depth 408.5ft), Puget Sound, Washington Current	NOS	PUG1503_8	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64642	Edmonds, 2.5 miles west of (Depth 395.4ft), Puget Sound, Washington Current	NOS	PUG1503_9	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64643	Edmonds, 2.5 miles west of (Depth 382.3ft), Puget Sound, Washington Current	NOS	PUG1503_10	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64644	Edmonds, 2.5 miles west of (Depth 369.1ft), Puget Sound, Washington Current	NOS	PUG1503_11	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64645	Edmonds, 2.5 miles west of (Depth 356ft), Puget Sound, Washington Current	NOS	PUG1503_12	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64646	Edmonds, 2.5 miles west of (Depth 342.9ft), Puget Sound, Washington Current	NOS	PUG1503_13	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64648	Edmonds, 2.5 miles west of (Depth 316.6ft), Puget Sound, Washington Current	NOS	PUG1503_15	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	346	167	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64649	Edmonds, 2.5 miles west of (Depth 303.5ft), Puget Sound, Washington Current	NOS	PUG1503_16	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64651	Edmonds, 2.5 miles west of (Depth 277.3ft), Puget Sound, Washington Current	NOS	PUG1503_18	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64652	Edmonds, 2.5 miles west of (Depth 264.1ft), Puget Sound, Washington Current	NOS	PUG1503_19	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64654	Edmonds, 2.5 miles west of (Depth 237.9ft), Puget Sound, Washington Current	NOS	PUG1503_21	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64655	Edmonds, 2.5 miles west of (Depth 224.8ft), Puget Sound, Washington Current	NOS	PUG1503_22	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64656	Edmonds, 2.5 miles west of (Depth 211.6ft), Puget Sound, Washington Current	NOS	PUG1503_23	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64657	Edmonds, 2.5 miles west of (Depth 198.5ft), Puget Sound, Washington Current	NOS	PUG1503_24	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64658	Edmonds, 2.5 miles west of (Depth 185.4ft), Puget Sound, Washington Current	NOS	PUG1503_25	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64659	Edmonds, 2.5 miles west of (Depth 172.3ft), Puget Sound, Washington Current	NOS	PUG1503_26	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64660	Edmonds, 2.5 miles west of (Depth 159.2ft), Puget Sound, Washington Current	NOS	PUG1503_27	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64661	Edmonds, 2.5 miles west of (Depth 146ft), Puget Sound, Washington Current	NOS	PUG1503_28	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64662	Edmonds, 2.5 miles west of (Depth 132.9ft), Puget Sound, Washington Current	NOS	PUG1503_29	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	355	161	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64663	Edmonds, 2.5 miles west of (Depth 119.8ft), Puget Sound, Washington Current	NOS	PUG1503_30	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64664	Edmonds, 2.5 miles west of (Depth 106.7ft), Puget Sound, Washington Current	NOS	PUG1503_31	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64665	Edmonds, 2.5 miles west of (Depth 93.5ft), Puget Sound, Washington Current	NOS	PUG1503_32	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64666	Edmonds, 2.5 miles west of (Depth 80.4ft), Puget Sound, Washington Current	NOS	PUG1503_33	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64667	Edmonds, 2.5 miles west of (Depth 67.3ft), Puget Sound, Washington Current	NOS	PUG1503_34	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	358	161	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64668	Edmonds, 2.5 miles west of (Depth 54.2ft), Puget Sound, Washington Current	NOS	PUG1503_35	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.248	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64669	Ballard Locks entrance (Depth 28.9ft), Puget Sound, Washington Current	NOS	PUG1504_1	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64672	Ballard Locks entrance (Depth 19.1ft), Puget Sound, Washington Current	NOS	PUG1504_4	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64673	Ballard Locks entrance (Depth 15.8ft), Puget Sound, Washington Current	NOS	PUG1504_5	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64674	Ballard Locks entrance (Depth 12.5ft), Puget Sound, Washington Current	NOS	PUG1504_6	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64675	Ballard Locks entrance (Depth 9.3ft), Puget Sound, Washington Current	NOS	PUG1504_7	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	90	144	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64676	Ballard Locks entrance (Depth 6ft), Puget Sound, Washington Current	NOS	PUG1504_8	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64678	Eagle Harbor entrance (Depth 8.6ft), Puget Sound, Washington Current	NOS	PUG1505_8	47.619571685791	-122.495300292968	:America/Los_Angeles	USA	knots	137	337	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Harbor entrance	WA
64679	Harbor Island East (Depth 42.3ft), Puget Sound, Washington Current	NOS	PUG1506_1	47.588451385498	-122.343971252441	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island East	WA
64680	Harbor Island East (Depth 22.6ft), Puget Sound, Washington Current	NOS	PUG1506_7	47.588451385498	-122.343971252441	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island East	WA
64681	Harbor Island East (Depth 6.2ft), Puget Sound, Washington Current	NOS	PUG1506_12	47.588451385498	-122.343971252441	:America/Los_Angeles	USA	knots	356	0	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island East	WA
64682	Harbor Island West (Depth 47.7ft), Puget Sound, Washington Current	NOS	PUG1507_1	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64683	Harbor Island West (Depth 44.5ft), Puget Sound, Washington Current	NOS	PUG1507_2	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64684	Harbor Island West (Depth 41.2ft), Puget Sound, Washington Current	NOS	PUG1507_3	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64685	Harbor Island West (Depth 37.9ft), Puget Sound, Washington Current	NOS	PUG1507_4	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64686	Harbor Island West (Depth 34.6ft), Puget Sound, Washington Current	NOS	PUG1507_5	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64687	Harbor Island West (Depth 31.3ft), Puget Sound, Washington Current	NOS	PUG1507_6	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64688	Harbor Island West (Depth 28.1ft), Puget Sound, Washington Current	NOS	PUG1507_7	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64689	Harbor Island West (Depth 24.8ft), Puget Sound, Washington Current	NOS	PUG1507_8	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64690	Harbor Island West (Depth 21.5ft), Puget Sound, Washington Current	NOS	PUG1507_9	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	356	177	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64691	Harbor Island West (Depth 18.2ft), Puget Sound, Washington Current	NOS	PUG1507_10	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64693	Harbor Island West (Depth 11.6ft), Puget Sound, Washington Current	NOS	PUG1507_12	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64694	Harbor Island West (Depth 8.4ft), Puget Sound, Washington Current	NOS	PUG1507_13	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	1	178	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64696	Liberty Bay (entrance), Port Orchard (Depth 33.4ft), Puget Sound, Washington Current	NOS	PUG1508_2	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64697	Liberty Bay (entrance), Port Orchard (Depth 30.1ft), Puget Sound, Washington Current	NOS	PUG1508_3	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64698	Liberty Bay (entrance), Port Orchard (Depth 26.8ft), Puget Sound, Washington Current	NOS	PUG1508_4	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64699	Liberty Bay (entrance), Port Orchard (Depth 23.6ft), Puget Sound, Washington Current	NOS	PUG1508_5	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	124	288	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64700	Liberty Bay (entrance), Port Orchard (Depth 20.3ft), Puget Sound, Washington Current	NOS	PUG1508_6	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64701	Liberty Bay (entrance), Port Orchard (Depth 17ft), Puget Sound, Washington Current	NOS	PUG1508_7	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64702	Liberty Bay (entrance), Port Orchard (Depth 13.7ft), Puget Sound, Washington Current	NOS	PUG1508_8	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64703	Liberty Bay (entrance), Port Orchard (Depth 10.4ft), Puget Sound, Washington Current	NOS	PUG1508_9	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64704	Liberty Bay (entrance), Port Orchard (Depth 7.2ft), Puget Sound, Washington Current	NOS	PUG1508_10	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	313	287	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64705	Point Jefferson, east of (Depth 71ft), Puget Sound, Washington Current	NOS	PUG1509_1	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	14	212	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64706	Point Jefferson, east of (Depth 64.5ft), Puget Sound, Washington Current	NOS	PUG1509_2	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64707	Point Jefferson, east of (Depth 57.9ft), Puget Sound, Washington Current	NOS	PUG1509_3	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64708	Point Jefferson, east of (Depth 51.3ft), Puget Sound, Washington Current	NOS	PUG1509_4	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64709	Point Jefferson, east of (Depth 44.8ft), Puget Sound, Washington Current	NOS	PUG1509_5	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	21	214	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64710	Point Jefferson, east of (Depth 38.2ft), Puget Sound, Washington Current	NOS	PUG1509_6	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64711	Point Jefferson, east of (Depth 31.7ft), Puget Sound, Washington Current	NOS	PUG1509_7	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64714	Port Washington Narrows, Warren Ave. Bridge (Depth 20.5ft), Washington Current	NOS	PUG1510_1	47.5795707702636	-122.630653381347	:America/Los_Angeles	USA	knots	102	279	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Washington Narrows, Warren Ave. Bridge	WA
64715	Port Washington Narrows, Warren Ave. Bridge (Depth 4.1ft), Washington Current	NOS	PUG1510_6	47.5795707702636	-122.630653381347	:America/Los_Angeles	USA	knots	99	286	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Washington Narrows, Warren Ave. Bridge	WA
64713	Point Jefferson, east of (Depth 18.5ft), Puget Sound, Washington Current	NOS	PUG1509_9	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	31	217	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64734	Rich Passage, west end (Depth 44.3ft), Puget Sound, Washington Current	NOS	PUG1514_3	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64717	President Point, 1.5 miles east of (Depth 176.4ft), Puget Sound, Washington Current	NOS	PUG1511_30	47.76712	-122.4319	:America/Los_Angeles	USA	knots	341	158	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
64718	President Point, 1.5 miles east of (Depth 71.4ft), Puget Sound, Washington Current	NOS	PUG1511_38	47.76712	-122.4319	:America/Los_Angeles	USA	knots	3	177	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
64719	Restoration Point (Depth 140ft), Puget Sound, Washington Current	NOS	PUG1512_1	47.5788497924804	-122.468719482421	:America/Los_Angeles	USA	knots	45	151	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
64720	Restoration Point (Depth 81ft), Puget Sound, Washington Current	NOS	PUG1512_10	47.5788497924804	-122.468719482421	:America/Los_Angeles	USA	knots	42	142	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
64721	Restoration Point (Depth 21.9ft), Puget Sound, Washington Current	NOS	PUG1512_19	47.5788497924804	-122.468719482421	:America/Los_Angeles	USA	knots	52	0	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.429	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
64722	Rich Passage, east end (Depth 70.3ft), Puget Sound, Washington Current	NOS	PUG1513_1	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	108	314	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64723	Rich Passage, east end (Depth 63.7ft), Puget Sound, Washington Current	NOS	PUG1513_2	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64724	Rich Passage, east end (Depth 57.2ft), Puget Sound, Washington Current	NOS	PUG1513_3	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64725	Rich Passage, east end (Depth 50.6ft), Puget Sound, Washington Current	NOS	PUG1513_4	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64726	Rich Passage, east end (Depth 44ft), Puget Sound, Washington Current	NOS	PUG1513_5	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64727	Rich Passage, east end (Depth 37.5ft), Puget Sound, Washington Current	NOS	PUG1513_6	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	127	323	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64728	Rich Passage, east end (Depth 30.9ft), Puget Sound, Washington Current	NOS	PUG1513_7	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64729	Rich Passage, east end (Depth 24.3ft), Puget Sound, Washington Current	NOS	PUG1513_8	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64730	Rich Passage, east end (Depth 17.8ft), Puget Sound, Washington Current	NOS	PUG1513_9	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64732	Rich Passage, west end (Depth 57.4ft), Puget Sound, Washington Current	NOS	PUG1514_1	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	53	235	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64733	Rich Passage, west end (Depth 50.8ft), Puget Sound, Washington Current	NOS	PUG1514_2	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64735	Rich Passage, west end (Depth 37.7ft), Puget Sound, Washington Current	NOS	PUG1514_4	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64736	Rich Passage, west end (Depth 31.1ft), Puget Sound, Washington Current	NOS	PUG1514_5	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	55	238	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64737	Rich Passage, west end (Depth 24.6ft), Puget Sound, Washington Current	NOS	PUG1514_6	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64738	Rich Passage, west end (Depth 18ft), Puget Sound, Washington Current	NOS	PUG1514_7	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64739	Rich Passage, west end (Depth 11.5ft), Puget Sound, Washington Current	NOS	PUG1514_8	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	55	239	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64740	West Point, west of (Depth 107.6ft), Puget Sound, Washington Current	NOS	PUG1515_1	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	21	228	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64741	West Point, west of (Depth 101ft), Puget Sound, Washington Current	NOS	PUG1515_2	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64742	West Point, west of (Depth 94.5ft), Puget Sound, Washington Current	NOS	PUG1515_3	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64743	West Point, west of (Depth 87.9ft), Puget Sound, Washington Current	NOS	PUG1515_4	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64744	West Point, west of (Depth 81.4ft), Puget Sound, Washington Current	NOS	PUG1515_5	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64745	West Point, west of (Depth 74.8ft), Puget Sound, Washington Current	NOS	PUG1515_6	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.193	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64746	West Point, west of (Depth 68.2ft), Puget Sound, Washington Current	NOS	PUG1515_7	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64747	West Point, west of (Depth 61.7ft), Puget Sound, Washington Current	NOS	PUG1515_8	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.193	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64748	West Point, west of (Depth 55.1ft), Puget Sound, Washington Current	NOS	PUG1515_9	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64749	West Point, west of (Depth 48.6ft), Puget Sound, Washington Current	NOS	PUG1515_10	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	357	230	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64750	West Point, west of (Depth 42ft), Puget Sound, Washington Current	NOS	PUG1515_11	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64751	West Point, west of (Depth 35.4ft), Puget Sound, Washington Current	NOS	PUG1515_12	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64753	West Point, west of (Depth 22.3ft), Puget Sound, Washington Current	NOS	PUG1515_14	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64754	West Point, west of (Depth 15.7ft), Puget Sound, Washington Current	NOS	PUG1515_15	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	341	234	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64755	Alki Point, west of (Depth 247.6ft), Puget Sound, Washington Current	NOS	PUG1516_1	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64756	Alki Point, west of (Depth 234.5ft), Puget Sound, Washington Current	NOS	PUG1516_2	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64757	Alki Point, west of (Depth 221.4ft), Puget Sound, Washington Current	NOS	PUG1516_3	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64758	Alki Point, west of (Depth 208.2ft), Puget Sound, Washington Current	NOS	PUG1516_4	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64759	Alki Point, west of (Depth 195.1ft), Puget Sound, Washington Current	NOS	PUG1516_5	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	4	200	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64760	Alki Point, west of (Depth 182ft), Puget Sound, Washington Current	NOS	PUG1516_6	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64762	Alki Point, west of (Depth 155.7ft), Puget Sound, Washington Current	NOS	PUG1516_8	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64763	Alki Point, west of (Depth 142.6ft), Puget Sound, Washington Current	NOS	PUG1516_9	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64764	Alki Point, west of (Depth 129.5ft), Puget Sound, Washington Current	NOS	PUG1516_10	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64765	Alki Point, west of (Depth 116.4ft), Puget Sound, Washington Current	NOS	PUG1516_11	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64766	Alki Point, west of (Depth 103.2ft), Puget Sound, Washington Current	NOS	PUG1516_12	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	6	213	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64767	Alki Point, west of (Depth 90.1ft), Puget Sound, Washington Current	NOS	PUG1516_13	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64768	Alki Point, west of (Depth 77ft), Puget Sound, Washington Current	NOS	PUG1516_14	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64769	Alki Point, west of (Depth 63.9ft), Puget Sound, Washington Current	NOS	PUG1516_15	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64770	Alki Point, west of (Depth 50.8ft), Puget Sound, Washington Current	NOS	PUG1516_16	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64771	Alki Point, west of (Depth 37.6ft), Puget Sound, Washington Current	NOS	PUG1516_17	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	4	215	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64772	Alki Point, west of (Depth 24.5ft), Puget Sound, Washington Current	NOS	PUG1516_18	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64774	Blake Island, S of (Depth 230.7ft), Puget Sound, Washington Current	NOS	PUG1517_2	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.392	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64775	Blake Island, S of (Depth 220.9ft), Puget Sound, Washington Current	NOS	PUG1517_3	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64776	Blake Island, S of (Depth 211ft), Puget Sound, Washington Current	NOS	PUG1517_4	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64777	Blake Island, S of (Depth 201.2ft), Puget Sound, Washington Current	NOS	PUG1517_5	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64778	Blake Island, S of (Depth 191.3ft), Puget Sound, Washington Current	NOS	PUG1517_6	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.444	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64779	Blake Island, S of (Depth 181.5ft), Puget Sound, Washington Current	NOS	PUG1517_7	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.454	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64780	Blake Island, S of (Depth 171.7ft), Puget Sound, Washington Current	NOS	PUG1517_8	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	350	218	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.465	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64781	Blake Island, S of (Depth 161.8ft), Puget Sound, Washington Current	NOS	PUG1517_9	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.476	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64782	Blake Island, S of (Depth 152ft), Puget Sound, Washington Current	NOS	PUG1517_10	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.488	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64784	Blake Island, S of (Depth 132.3ft), Puget Sound, Washington Current	NOS	PUG1517_12	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.512	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64785	Blake Island, S of (Depth 122.4ft), Puget Sound, Washington Current	NOS	PUG1517_13	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.524	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64786	Blake Island, S of (Depth 112.6ft), Puget Sound, Washington Current	NOS	PUG1517_14	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.538	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64787	Blake Island, S of (Depth 102.8ft), Puget Sound, Washington Current	NOS	PUG1517_15	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.551	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64788	Blake Island, S of (Depth 92.9ft), Puget Sound, Washington Current	NOS	PUG1517_16	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	349	237	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.564	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64789	Blake Island, S of (Depth 83.1ft), Puget Sound, Washington Current	NOS	PUG1517_17	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64790	Blake Island, S of (Depth 73.2ft), Puget Sound, Washington Current	NOS	PUG1517_18	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.588	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64791	Blake Island, S of (Depth 63.4ft), Puget Sound, Washington Current	NOS	PUG1517_19	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.599	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64792	Blake Island, S of (Depth 53.5ft), Puget Sound, Washington Current	NOS	PUG1517_20	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.607	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64793	Blake Island, S of (Depth 43.7ft), Puget Sound, Washington Current	NOS	PUG1517_21	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	350	244	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.612	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64795	Anderson Point, east of, Colvos Passage (Depth 153.5ft), Puget Sound, Washington Current	NOS	PUG1518_10	47.43943	-122.52578	:America/Los_Angeles	USA	knots	351	181	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.524	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, east of, Colvos Passage	WA
64796	Anderson Point, east of, Colvos Passage (Depth 61.7ft), Puget Sound, Washington Current	NOS	PUG1518_17	47.43943	-122.52578	:America/Los_Angeles	USA	knots	353	185	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.548	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, east of, Colvos Passage	WA
64798	Point Richmond, east of, Colvos Passage (Depth 267.4ft), Puget Sound, Washington Current	NOS	PUG1519_1	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.469	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64799	Point Richmond, east of, Colvos Passage (Depth 254.3ft), Puget Sound, Washington Current	NOS	PUG1519_2	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.485	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64800	Point Richmond, east of, Colvos Passage (Depth 241.1ft), Puget Sound, Washington Current	NOS	PUG1519_3	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	4	157	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.498	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64801	Point Richmond, east of, Colvos Passage (Depth 228ft), Puget Sound, Washington Current	NOS	PUG1519_4	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64802	Point Richmond, east of, Colvos Passage (Depth 214.9ft), Puget Sound, Washington Current	NOS	PUG1519_5	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.522	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64803	Point Richmond, east of, Colvos Passage (Depth 201.8ft), Puget Sound, Washington Current	NOS	PUG1519_6	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.534	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64804	Point Richmond, east of, Colvos Passage (Depth 188.6ft), Puget Sound, Washington Current	NOS	PUG1519_7	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.545	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64805	Point Richmond, east of, Colvos Passage (Depth 175.5ft), Puget Sound, Washington Current	NOS	PUG1519_8	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.555	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64806	Point Richmond, east of, Colvos Passage (Depth 162.4ft), Puget Sound, Washington Current	NOS	PUG1519_9	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.565	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64807	Point Richmond, east of, Colvos Passage (Depth 149.3ft), Puget Sound, Washington Current	NOS	PUG1519_10	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.573	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64808	Point Richmond, east of, Colvos Passage (Depth 136.2ft), Puget Sound, Washington Current	NOS	PUG1519_11	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.581	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64809	Point Richmond, east of, Colvos Passage (Depth 123ft), Puget Sound, Washington Current	NOS	PUG1519_12	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.586	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64872	Dalco Passage (Depth 82.2ft), Puget Sound, Washington Current	NOS	PUG1522_19	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64875	Dalco Passage (Depth 62.5ft), Puget Sound, Washington Current	NOS	PUG1522_22	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.496	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64810	Point Richmond, east of, Colvos Passage (Depth 109.9ft), Puget Sound, Washington Current	NOS	PUG1519_13	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	359	162	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.589	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64811	Point Richmond, east of, Colvos Passage (Depth 96.8ft), Puget Sound, Washington Current	NOS	PUG1519_14	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.591	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64812	Point Richmond, east of, Colvos Passage (Depth 83.7ft), Puget Sound, Washington Current	NOS	PUG1519_15	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.591	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64814	Point Richmond, east of, Colvos Passage (Depth 57.4ft), Puget Sound, Washington Current	NOS	PUG1519_17	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.584	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64815	Point Richmond, east of, Colvos Passage (Depth 44.3ft), Puget Sound, Washington Current	NOS	PUG1519_18	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	356	143	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.571	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64816	Point Richmond, east of, Colvos Passage (Depth 31.2ft), Puget Sound, Washington Current	NOS	PUG1519_19	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.548	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64817	Dolphin Point, 1.3 miles east of (Depth 218.1ft), Puget Sound, Washington Current	NOS	PUG1520_22	47.5015487670898	-122.42357635498	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles east of	WA
64818	Dolphin Point, 1.3 miles east of (Depth 139.3ft), Puget Sound, Washington Current	NOS	PUG1520_28	47.5015487670898	-122.42357635498	:America/Los_Angeles	USA	knots	343	184	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles east of	WA
64819	Dolphin Point, 1.3 miles east of (Depth 47.5ft), Puget Sound, Washington Current	NOS	PUG1520_35	47.5015487670898	-122.42357635498	:America/Los_Angeles	USA	knots	343	186	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles east of	WA
64820	Browns Point, 1.6 miles north of (Depth 460.9ft), Puget Sound, Washington Current	NOS	PUG1521_1	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64821	Browns Point, 1.6 miles north of (Depth 447.8ft), Puget Sound, Washington Current	NOS	PUG1521_2	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64822	Browns Point, 1.6 miles north of (Depth 434.7ft), Puget Sound, Washington Current	NOS	PUG1521_3	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64823	Browns Point, 1.6 miles north of (Depth 421.6ft), Puget Sound, Washington Current	NOS	PUG1521_4	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64824	Browns Point, 1.6 miles north of (Depth 408.4ft), Puget Sound, Washington Current	NOS	PUG1521_5	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64825	Browns Point, 1.6 miles north of (Depth 395.3ft), Puget Sound, Washington Current	NOS	PUG1521_6	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.214	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64826	Browns Point, 1.6 miles north of (Depth 382.2ft), Puget Sound, Washington Current	NOS	PUG1521_7	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.218	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64827	Browns Point, 1.6 miles north of (Depth 369.1ft), Puget Sound, Washington Current	NOS	PUG1521_8	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64828	Browns Point, 1.6 miles north of (Depth 355.9ft), Puget Sound, Washington Current	NOS	PUG1521_9	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64874	Dalco Passage (Depth 69.1ft), Puget Sound, Washington Current	NOS	PUG1522_21	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.492	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64829	Browns Point, 1.6 miles north of (Depth 342.8ft), Puget Sound, Washington Current	NOS	PUG1521_10	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64830	Browns Point, 1.6 miles north of (Depth 329.7ft), Puget Sound, Washington Current	NOS	PUG1521_11	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.218	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64831	Browns Point, 1.6 miles north of (Depth 316.6ft), Puget Sound, Washington Current	NOS	PUG1521_12	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.212	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64834	Browns Point, 1.6 miles north of (Depth 277.2ft), Puget Sound, Washington Current	NOS	PUG1521_15	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64835	Browns Point, 1.6 miles north of (Depth 264.1ft), Puget Sound, Washington Current	NOS	PUG1521_16	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64836	Browns Point, 1.6 miles north of (Depth 251ft), Puget Sound, Washington Current	NOS	PUG1521_17	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64837	Browns Point, 1.6 miles north of (Depth 237.8ft), Puget Sound, Washington Current	NOS	PUG1521_18	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64838	Browns Point, 1.6 miles north of (Depth 224.7ft), Puget Sound, Washington Current	NOS	PUG1521_19	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64839	Browns Point, 1.6 miles north of (Depth 211.6ft), Puget Sound, Washington Current	NOS	PUG1521_20	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64840	Browns Point, 1.6 miles north of (Depth 198.5ft), Puget Sound, Washington Current	NOS	PUG1521_21	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64841	Browns Point, 1.6 miles north of (Depth 185.3ft), Puget Sound, Washington Current	NOS	PUG1521_22	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64842	Browns Point, 1.6 miles north of (Depth 172.2ft), Puget Sound, Washington Current	NOS	PUG1521_23	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64843	Browns Point, 1.6 miles north of (Depth 159.1ft), Puget Sound, Washington Current	NOS	PUG1521_24	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	49	232	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64844	Browns Point, 1.6 miles north of (Depth 146ft), Puget Sound, Washington Current	NOS	PUG1521_25	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64845	Browns Point, 1.6 miles north of (Depth 132.8ft), Puget Sound, Washington Current	NOS	PUG1521_26	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64846	Browns Point, 1.6 miles north of (Depth 119.7ft), Puget Sound, Washington Current	NOS	PUG1521_27	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64847	Browns Point, 1.6 miles north of (Depth 106.6ft), Puget Sound, Washington Current	NOS	PUG1521_28	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64848	Browns Point, 1.6 miles north of (Depth 93.5ft), Puget Sound, Washington Current	NOS	PUG1521_29	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64849	Browns Point, 1.6 miles north of (Depth 80.3ft), Puget Sound, Washington Current	NOS	PUG1521_30	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64850	Browns Point, 1.6 miles north of (Depth 67.2ft), Puget Sound, Washington Current	NOS	PUG1521_31	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64851	Browns Point, 1.6 miles north of (Depth 54.1ft), Puget Sound, Washington Current	NOS	PUG1521_32	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64853	Browns Point, 1.6 miles north of (Depth 27.9ft), Puget Sound, Washington Current	NOS	PUG1521_34	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	42	234	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64854	Dalco Passage (Depth 200.3ft), Puget Sound, Washington Current	NOS	PUG1522_1	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.247	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64855	Dalco Passage (Depth 193.7ft), Puget Sound, Washington Current	NOS	PUG1522_2	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64856	Dalco Passage (Depth 187.2ft), Puget Sound, Washington Current	NOS	PUG1522_3	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	124	288	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.278	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64857	Dalco Passage (Depth 180.6ft), Puget Sound, Washington Current	NOS	PUG1522_4	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64858	Dalco Passage (Depth 174ft), Puget Sound, Washington Current	NOS	PUG1522_5	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64859	Dalco Passage (Depth 167.5ft), Puget Sound, Washington Current	NOS	PUG1522_6	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.324	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64860	Dalco Passage (Depth 160.9ft), Puget Sound, Washington Current	NOS	PUG1522_7	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.339	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64861	Dalco Passage (Depth 154.4ft), Puget Sound, Washington Current	NOS	PUG1522_8	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.354	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64862	Dalco Passage (Depth 147.8ft), Puget Sound, Washington Current	NOS	PUG1522_9	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.369	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64863	Dalco Passage (Depth 141.2ft), Puget Sound, Washington Current	NOS	PUG1522_10	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.383	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64864	Dalco Passage (Depth 134.7ft), Puget Sound, Washington Current	NOS	PUG1522_11	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64866	Dalco Passage (Depth 121.6ft), Puget Sound, Washington Current	NOS	PUG1522_13	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64867	Dalco Passage (Depth 115ft), Puget Sound, Washington Current	NOS	PUG1522_14	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64868	Dalco Passage (Depth 108.4ft), Puget Sound, Washington Current	NOS	PUG1522_15	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.444	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64869	Dalco Passage (Depth 101.9ft), Puget Sound, Washington Current	NOS	PUG1522_16	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.454	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64870	Dalco Passage (Depth 95.3ft), Puget Sound, Washington Current	NOS	PUG1522_17	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.463	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64871	Dalco Passage (Depth 88.7ft), Puget Sound, Washington Current	NOS	PUG1522_18	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.472	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64876	Dalco Passage (Depth 55.9ft), Puget Sound, Washington Current	NOS	PUG1522_23	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.498	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64877	Dalco Passage (Depth 49.4ft), Puget Sound, Washington Current	NOS	PUG1522_24	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.499	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64878	Dalco Passage (Depth 42.8ft), Puget Sound, Washington Current	NOS	PUG1522_25	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.499	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64879	Dalco Passage (Depth 36.3ft), Puget Sound, Washington Current	NOS	PUG1522_26	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64880	Dalco Passage (Depth 29.7ft), Puget Sound, Washington Current	NOS	PUG1522_27	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64881	Dalco Passage (Depth 23.1ft), Puget Sound, Washington Current	NOS	PUG1522_28	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64882	Gig Harbor entrance (Depth 53.5ft), Puget Sound, Washington Current	NOS	PUG1523_1	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	3	192	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64883	Gig Harbor entrance (Depth 50.2ft), Puget Sound, Washington Current	NOS	PUG1523_2	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64884	Gig Harbor entrance (Depth 46.9ft), Puget Sound, Washington Current	NOS	PUG1523_3	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64885	Gig Harbor entrance (Depth 43.7ft), Puget Sound, Washington Current	NOS	PUG1523_4	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64887	Gig Harbor entrance (Depth 37.1ft), Puget Sound, Washington Current	NOS	PUG1523_6	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64888	Gig Harbor entrance (Depth 33.8ft), Puget Sound, Washington Current	NOS	PUG1523_7	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64889	Gig Harbor entrance (Depth 30.5ft), Puget Sound, Washington Current	NOS	PUG1523_8	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	357	198	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64890	Gig Harbor entrance (Depth 27.3ft), Puget Sound, Washington Current	NOS	PUG1523_9	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64891	Gig Harbor entrance (Depth 24ft), Puget Sound, Washington Current	NOS	PUG1523_10	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64892	Gig Harbor entrance (Depth 20.7ft), Puget Sound, Washington Current	NOS	PUG1523_11	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64893	Gig Harbor entrance (Depth 17.4ft), Puget Sound, Washington Current	NOS	PUG1523_12	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64900	The Narrows, north end (east side) (Depth 58.2ft), Washington Current	NOS	PUG1525_1	47.30778	-122.54213	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-1.484	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (east side)	WA
64901	The Narrows, north end (east side) (Depth 32ft), Washington Current	NOS	PUG1525_9	47.30778	-122.54213	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-1.693	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (east side)	WA
64902	The Narrows, north end (east side) (Depth 12.3ft), Washington Current	NOS	PUG1525_15	47.30778	-122.54213	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-1.755	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (east side)	WA
64895	Gig Harbor entrance (Depth 10.9ft), Puget Sound, Washington Current	NOS	PUG1523_14	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	7	198	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64896	Gig Harbor entrance (Depth 7.6ft), Puget Sound, Washington Current	NOS	PUG1523_15	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64897	The Narrows, north end (midstream) (Depth 139.2ft), Puget Sound, Washington Current	NOS	PUG1524_1	47.3059997558593	-122.550033569335	:America/Los_Angeles	USA	knots	331	132	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (midstream)	WA
64898	The Narrows, north end (midstream) (Depth 86.7ft), Puget Sound, Washington Current	NOS	PUG1524_9	47.3059997558593	-122.550033569335	:America/Los_Angeles	USA	knots	335	141	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (midstream)	WA
64899	The Narrows, north end (midstream) (Depth 40.7ft), Puget Sound, Washington Current	NOS	PUG1524_16	47.3059997558593	-122.550033569335	:America/Los_Angeles	USA	knots	337	145	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (midstream)	WA
64903	The Narrows, north end (west side) (Depth 193.3ft), Puget Sound, Washington Current	NOS	PUG1526_5	47.3040008544921	-122.556747436523	:America/Los_Angeles	USA	knots	324	144	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (west side)	WA
64904	The Narrows, north end (west side) (Depth 94.8ft), Puget Sound, Washington Current	NOS	PUG1526_20	47.3040008544921	-122.556747436523	:America/Los_Angeles	USA	knots	326	148	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.933	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (west side)	WA
64905	The Narrows, north end (west side) (Depth 42.4ft), Puget Sound, Washington Current	NOS	PUG1526_28	47.3040008544921	-122.556747436523	:America/Los_Angeles	USA	knots	329	152	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (west side)	WA
64906	The Narrows, 0.3 miles north of bridge (Depth 140.9ft), Puget Sound, Washington Current	NOS	PUG1527_1	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	42	213	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64907	The Narrows, 0.3 miles north of bridge (Depth 134.3ft), Puget Sound, Washington Current	NOS	PUG1527_2	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64908	The Narrows, 0.3 miles north of bridge (Depth 127.8ft), Puget Sound, Washington Current	NOS	PUG1527_3	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64910	The Narrows, 0.3 miles north of bridge (Depth 114.6ft), Puget Sound, Washington Current	NOS	PUG1527_5	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64911	The Narrows, 0.3 miles north of bridge (Depth 108.1ft), Puget Sound, Washington Current	NOS	PUG1527_6	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64912	The Narrows, 0.3 miles north of bridge (Depth 101.5ft), Puget Sound, Washington Current	NOS	PUG1527_7	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64914	The Narrows, 0.3 miles north of bridge (Depth 88.4ft), Puget Sound, Washington Current	NOS	PUG1527_9	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64915	The Narrows, 0.3 miles north of bridge (Depth 81.8ft), Puget Sound, Washington Current	NOS	PUG1527_10	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64916	The Narrows, 0.3 miles north of bridge (Depth 75.3ft), Puget Sound, Washington Current	NOS	PUG1527_11	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64917	The Narrows, 0.3 miles north of bridge (Depth 68.7ft), Puget Sound, Washington Current	NOS	PUG1527_12	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	42	204	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64918	The Narrows, 0.3 miles north of bridge (Depth 62.1ft), Puget Sound, Washington Current	NOS	PUG1527_13	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64919	The Narrows, 0.3 miles north of bridge (Depth 55.6ft), Puget Sound, Washington Current	NOS	PUG1527_14	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64920	The Narrows, 0.3 miles north of bridge (Depth 49ft), Puget Sound, Washington Current	NOS	PUG1527_15	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64921	The Narrows, 0.3 miles north of bridge (Depth 42.5ft), Puget Sound, Washington Current	NOS	PUG1527_16	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64922	The Narrows, 0.3 miles north of bridge (Depth 35.9ft), Puget Sound, Washington Current	NOS	PUG1527_17	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64924	The Narrows, 0.3 miles north of bridge (Depth 22.8ft), Puget Sound, Washington Current	NOS	PUG1527_19	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	40	198	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64925	The Narrows, 0.3 miles north of bridge (Depth 16.2ft), Puget Sound, Washington Current	NOS	PUG1527_20	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64926	The Narrows, south end (midstream) (Depth 131.2ft), Puget Sound, Washington Current	NOS	PUG1528_1	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	32	222	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64927	The Narrows, south end (midstream) (Depth 124.6ft), Puget Sound, Washington Current	NOS	PUG1528_2	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64928	The Narrows, south end (midstream) (Depth 118ft), Puget Sound, Washington Current	NOS	PUG1528_3	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64929	The Narrows, south end (midstream) (Depth 111.5ft), Puget Sound, Washington Current	NOS	PUG1528_4	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64930	The Narrows, south end (midstream) (Depth 104.9ft), Puget Sound, Washington Current	NOS	PUG1528_5	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64931	The Narrows, south end (midstream) (Depth 98.4ft), Puget Sound, Washington Current	NOS	PUG1528_6	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64934	The Narrows, south end (midstream) (Depth 78.7ft), Puget Sound, Washington Current	NOS	PUG1528_9	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64935	The Narrows, south end (midstream) (Depth 72.1ft), Puget Sound, Washington Current	NOS	PUG1528_10	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64936	The Narrows, south end (midstream) (Depth 65.6ft), Puget Sound, Washington Current	NOS	PUG1528_11	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64937	The Narrows, south end (midstream) (Depth 59ft), Puget Sound, Washington Current	NOS	PUG1528_12	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
65230	Rosario Strait (Depth 155.1ft), Washington Current	NOS	PUG1702_5	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
64938	The Narrows, south end (midstream) (Depth 52.4ft), Puget Sound, Washington Current	NOS	PUG1528_13	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	28	221	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64939	The Narrows, south end (midstream) (Depth 45.9ft), Puget Sound, Washington Current	NOS	PUG1528_14	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64940	The Narrows, south end (midstream) (Depth 39.3ft), Puget Sound, Washington Current	NOS	PUG1528_15	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64941	The Narrows, south end (midstream) (Depth 32.7ft), Puget Sound, Washington Current	NOS	PUG1528_16	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64942	The Narrows, south end (midstream) (Depth 26.2ft), Puget Sound, Washington Current	NOS	PUG1528_17	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	26	220	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64943	The Narrows, south end (midstream) (Depth 19.6ft), Puget Sound, Washington Current	NOS	PUG1528_18	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64944	Hale Passage, east end (Depth 77ft), Puget Sound, Washington Current	NOS	PUG1529_1	47.2478981018066	-122.595596313476	:America/Los_Angeles	USA	knots	151	334	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.241	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east end	WA
64945	Hale Passage, east end (Depth 44.2ft), Puget Sound, Washington Current	NOS	PUG1529_6	47.2478981018066	-122.595596313476	:America/Los_Angeles	USA	knots	145	330	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east end	WA
64946	Hale Passage, east end (Depth 11.4ft), Puget Sound, Washington Current	NOS	PUG1529_11	47.2478981018066	-122.595596313476	:America/Los_Angeles	USA	knots	145	325	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east end	WA
64947	Hale Passage, west end (Depth 69.7ft), Puget Sound, Washington Current	NOS	PUG1530_1	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	113	282	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.349	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64948	Hale Passage, west end (Depth 66.4ft), Puget Sound, Washington Current	NOS	PUG1530_2	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.384	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64949	Hale Passage, west end (Depth 63.1ft), Puget Sound, Washington Current	NOS	PUG1530_3	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.404	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64950	Hale Passage, west end (Depth 59.8ft), Puget Sound, Washington Current	NOS	PUG1530_4	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64951	Hale Passage, west end (Depth 56.5ft), Puget Sound, Washington Current	NOS	PUG1530_5	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.427	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64953	Hale Passage, west end (Depth 50ft), Puget Sound, Washington Current	NOS	PUG1530_7	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.444	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64954	Hale Passage, west end (Depth 46.7ft), Puget Sound, Washington Current	NOS	PUG1530_8	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.451	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64955	Hale Passage, west end (Depth 43.4ft), Puget Sound, Washington Current	NOS	PUG1530_9	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.456	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64956	Hale Passage, west end (Depth 40.1ft), Puget Sound, Washington Current	NOS	PUG1530_10	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	99	283	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.461	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64957	Hale Passage, west end (Depth 36.8ft), Puget Sound, Washington Current	NOS	PUG1530_11	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.464	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64958	Hale Passage, west end (Depth 33.6ft), Puget Sound, Washington Current	NOS	PUG1530_12	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.466	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64959	Hale Passage, west end (Depth 30.3ft), Puget Sound, Washington Current	NOS	PUG1530_13	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.467	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64960	Hale Passage, west end (Depth 27ft), Puget Sound, Washington Current	NOS	PUG1530_14	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.467	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64961	Hale Passage, west end (Depth 23.7ft), Puget Sound, Washington Current	NOS	PUG1530_15	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.468	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64962	Hale Passage, west end (Depth 20.4ft), Puget Sound, Washington Current	NOS	PUG1530_16	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.468	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64963	Hale Passage, west end (Depth 17.2ft), Puget Sound, Washington Current	NOS	PUG1530_17	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.469	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64965	Hale Passage, west end (Depth 10.6ft), Puget Sound, Washington Current	NOS	PUG1530_19	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.472	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64966	Gibson Point, 0.8 miles east of (Depth 198.6ft), Puget Sound, Washington Current	NOS	PUG1531_1	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64967	Gibson Point, 0.8 miles east of (Depth 188.7ft), Puget Sound, Washington Current	NOS	PUG1531_2	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64968	Gibson Point, 0.8 miles east of (Depth 178.9ft), Puget Sound, Washington Current	NOS	PUG1531_3	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64969	Gibson Point, 0.8 miles east of (Depth 169.1ft), Puget Sound, Washington Current	NOS	PUG1531_4	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64970	Gibson Point, 0.8 miles east of (Depth 159.2ft), Puget Sound, Washington Current	NOS	PUG1531_5	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.166	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64971	Gibson Point, 0.8 miles east of (Depth 149.4ft), Puget Sound, Washington Current	NOS	PUG1531_6	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	29	205	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64974	Gibson Point, 0.8 miles east of (Depth 119.8ft), Puget Sound, Washington Current	NOS	PUG1531_9	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64975	Gibson Point, 0.8 miles east of (Depth 110ft), Puget Sound, Washington Current	NOS	PUG1531_10	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64976	Gibson Point, 0.8 miles east of (Depth 100.2ft), Puget Sound, Washington Current	NOS	PUG1531_11	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64977	Gibson Point, 0.8 miles east of (Depth 90.3ft), Puget Sound, Washington Current	NOS	PUG1531_12	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64978	Gibson Point, 0.8 miles east of (Depth 80.5ft), Puget Sound, Washington Current	NOS	PUG1531_13	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	34	204	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64979	Gibson Point, 0.8 miles east of (Depth 70.6ft), Puget Sound, Washington Current	NOS	PUG1531_14	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64980	Gibson Point, 0.8 miles east of (Depth 60.8ft), Puget Sound, Washington Current	NOS	PUG1531_15	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64981	Gibson Point, 0.8 miles east of (Depth 51ft), Puget Sound, Washington Current	NOS	PUG1531_16	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64982	Gibson Point, 0.8 miles east of (Depth 41.1ft), Puget Sound, Washington Current	NOS	PUG1531_17	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64983	Gibson Point, 0.8 miles east of (Depth 31.3ft), Puget Sound, Washington Current	NOS	PUG1531_18	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	42	204	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64984	Steilacoom, 0.8 miles north of (Depth 242.4ft), Puget Sound, Washington Current	NOS	PUG1532_1	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64985	Steilacoom, 0.8 miles north of (Depth 229.3ft), Puget Sound, Washington Current	NOS	PUG1532_2	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64986	Steilacoom, 0.8 miles north of (Depth 216.1ft), Puget Sound, Washington Current	NOS	PUG1532_3	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64987	Steilacoom, 0.8 miles north of (Depth 203ft), Puget Sound, Washington Current	NOS	PUG1532_4	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64988	Steilacoom, 0.8 miles north of (Depth 189.9ft), Puget Sound, Washington Current	NOS	PUG1532_5	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64989	Steilacoom, 0.8 miles north of (Depth 176.8ft), Puget Sound, Washington Current	NOS	PUG1532_6	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	37	205	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64990	Steilacoom, 0.8 miles north of (Depth 163.6ft), Puget Sound, Washington Current	NOS	PUG1532_7	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64991	Steilacoom, 0.8 miles north of (Depth 150.5ft), Puget Sound, Washington Current	NOS	PUG1532_8	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64993	Steilacoom, 0.8 miles north of (Depth 124.3ft), Puget Sound, Washington Current	NOS	PUG1532_10	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64994	Steilacoom, 0.8 miles north of (Depth 111.2ft), Puget Sound, Washington Current	NOS	PUG1532_11	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64995	Steilacoom, 0.8 miles north of (Depth 98ft), Puget Sound, Washington Current	NOS	PUG1532_12	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64996	Steilacoom, 0.8 miles north of (Depth 84.9ft), Puget Sound, Washington Current	NOS	PUG1532_13	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	55	213	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64997	Steilacoom, 0.8 miles north of (Depth 71.8ft), Puget Sound, Washington Current	NOS	PUG1532_14	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64998	Steilacoom, 0.8 miles north of (Depth 58.7ft), Puget Sound, Washington Current	NOS	PUG1532_15	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64999	Steilacoom, 0.8 miles north of (Depth 45.5ft), Puget Sound, Washington Current	NOS	PUG1532_16	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	51	215	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
65000	Steilacoom, 0.8 miles north of (Depth 32.4ft), Puget Sound, Washington Current	NOS	PUG1532_17	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
65001	Ketron Island, west of (Depth 260.9ft), Puget Sound, Washington Current	NOS	PUG1533_1	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65002	Ketron Island, west of (Depth 247.8ft), Puget Sound, Washington Current	NOS	PUG1533_2	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65004	Ketron Island, west of (Depth 221.6ft), Puget Sound, Washington Current	NOS	PUG1533_4	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65005	Ketron Island, west of (Depth 208.4ft), Puget Sound, Washington Current	NOS	PUG1533_5	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65006	Ketron Island, west of (Depth 195.3ft), Puget Sound, Washington Current	NOS	PUG1533_6	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65007	Ketron Island, west of (Depth 182.2ft), Puget Sound, Washington Current	NOS	PUG1533_7	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65008	Ketron Island, west of (Depth 169.1ft), Puget Sound, Washington Current	NOS	PUG1533_8	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65009	Ketron Island, west of (Depth 155.9ft), Puget Sound, Washington Current	NOS	PUG1533_9	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65010	Ketron Island, west of (Depth 142.8ft), Puget Sound, Washington Current	NOS	PUG1533_10	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	12	206	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65011	Ketron Island, west of (Depth 129.7ft), Puget Sound, Washington Current	NOS	PUG1533_11	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65013	Ketron Island, west of (Depth 103.4ft), Puget Sound, Washington Current	NOS	PUG1533_13	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65014	Ketron Island, west of (Depth 90.3ft), Puget Sound, Washington Current	NOS	PUG1533_14	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	12	208	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65015	Ketron Island, west of (Depth 77.2ft), Puget Sound, Washington Current	NOS	PUG1533_15	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65016	Ketron Island, west of (Depth 64.1ft), Puget Sound, Washington Current	NOS	PUG1533_16	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65018	Ketron Island, west of (Depth 37.8ft), Puget Sound, Washington Current	NOS	PUG1533_18	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	10	193	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65019	Balch Passage, NE of Eagle Island (Depth 59.8ft), Puget Sound, Washington Current	NOS	PUG1535_1	47.1906204223632	-122.691551208496	:America/Los_Angeles	USA	knots	108	288	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
65020	Balch Passage, NE of Eagle Island (Depth 30.3ft), Puget Sound, Washington Current	NOS	PUG1535_10	47.1906204223632	-122.691551208496	:America/Los_Angeles	USA	knots	108	288	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.315	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
65021	Balch Passage, NE of Eagle Island (Depth 10.6ft), Puget Sound, Washington Current	NOS	PUG1535_16	47.1906204223632	-122.691551208496	:America/Los_Angeles	USA	knots	104	287	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
65022	Pitt Passage, NE of Pitt Island (Depth 23.1ft), Puget Sound, Washington Current	NOS	PUG1536_1	47.2238311767578	-122.711372375488	:America/Los_Angeles	USA	knots	23	202	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.287	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pitt Passage, NE of Pitt Island	WA
65023	Pitt Passage, NE of Pitt Island (Depth 6.7ft), Puget Sound, Washington Current	NOS	PUG1536_6	47.2238311767578	-122.711372375488	:America/Los_Angeles	USA	knots	29	196	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.318	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pitt Passage, NE of Pitt Island	WA
65024	Drayton Passage (Depth 117.5ft), Puget Sound, Washington Current	NOS	PUG1537_5	47.1725807189941	-122.741477966308	:America/Los_Angeles	USA	knots	34	213	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
65025	Drayton Passage (Depth 51.8ft), Puget Sound, Washington Current	NOS	PUG1537_15	47.1725807189941	-122.741477966308	:America/Los_Angeles	USA	knots	23	210	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
65026	Drayton Passage (Depth 19ft), Puget Sound, Washington Current	NOS	PUG1537_20	47.1725807189941	-122.741477966308	:America/Los_Angeles	USA	knots	31	215	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
65027	Devils Head, west of (Depth 190.9ft), Puget Sound, Washington Current	NOS	PUG1538_5	47.1606712341308	-122.789367675781	:America/Los_Angeles	USA	knots	159	324	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, west of	WA
65028	Devils Head, west of (Depth 82.6ft), Puget Sound, Washington Current	NOS	PUG1538_16	47.1606712341308	-122.789367675781	:America/Los_Angeles	USA	knots	153	336	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, west of	WA
65029	Devils Head, west of (Depth 23.6ft), Puget Sound, Washington Current	NOS	PUG1538_22	47.1606712341308	-122.789367675781	:America/Los_Angeles	USA	knots	156	334	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.227	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, west of	WA
65030	Dana Passage (Depth 88.4ft), Puget Sound, Washington Current	NOS	PUG1539_1	47.163101196289	-122.868103027343	:America/Los_Angeles	USA	knots	43	232	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
65031	Dana Passage (Depth 42.5ft), Puget Sound, Washington Current	NOS	PUG1539_8	47.163101196289	-122.868103027343	:America/Los_Angeles	USA	knots	48	239	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.167	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
65033	Budd Inlet entrance (Depth 71.2ft), Puget Sound, Washington Current	NOS	PUG1540_1	47.1401596069335	-122.921447753906	:America/Los_Angeles	USA	knots	2	170	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet entrance	WA
65034	Budd Inlet entrance (Depth 31.9ft), Puget Sound, Washington Current	NOS	PUG1540_7	47.1401596069335	-122.921447753906	:America/Los_Angeles	USA	knots	4	172	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet entrance	WA
65035	Budd Inlet entrance (Depth 12.2ft), Puget Sound, Washington Current	NOS	PUG1540_10	47.1401596069335	-122.921447753906	:America/Los_Angeles	USA	knots	10	184	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet entrance	WA
65036	Peale Passage, south end (Depth 35.3ft), Puget Sound, Washington Current	NOS	PUG1541_1	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	159	338	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65037	Peale Passage, south end (Depth 32.1ft), Puget Sound, Washington Current	NOS	PUG1541_2	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65038	Peale Passage, south end (Depth 28.8ft), Puget Sound, Washington Current	NOS	PUG1541_3	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65039	Peale Passage, south end (Depth 25.5ft), Puget Sound, Washington Current	NOS	PUG1541_4	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65040	Peale Passage, south end (Depth 22.2ft), Puget Sound, Washington Current	NOS	PUG1541_5	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	157	347	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65041	Peale Passage, south end (Depth 18.9ft), Puget Sound, Washington Current	NOS	PUG1541_6	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65042	Peale Passage, south end (Depth 15.6ft), Puget Sound, Washington Current	NOS	PUG1541_7	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65043	Peale Passage, south end (Depth 12.4ft), Puget Sound, Washington Current	NOS	PUG1541_8	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65044	Peale Passage, south end (Depth 9.1ft), Puget Sound, Washington Current	NOS	PUG1541_9	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	16	346	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65045	Peale Passage, south end (Depth 5.8ft), Puget Sound, Washington Current	NOS	PUG1541_10	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65047	Peale Passage, north end (Depth 13.8ft), Puget Sound, Washington Current	NOS	PUG1542_2	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65048	Peale Passage, north end (Depth 10.5ft), Puget Sound, Washington Current	NOS	PUG1542_3	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65049	Peale Passage, north end (Depth 7.3ft), Puget Sound, Washington Current	NOS	PUG1542_4	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65050	Peale Passage, north end (Depth 4ft), Puget Sound, Washington Current	NOS	PUG1542_5	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	135	326	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65051	Peale Passage, north end (Depth 0.7ft), Puget Sound, Washington Current	NOS	PUG1542_6	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65053	Squaxin Passage, north of Hunter Point (Depth 18.4ft), Puget Sound, Washington Current	NOS	PUG1543_5	47.17626953125	-122.918998718261	:America/Los_Angeles	USA	knots	108	298	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, north of Hunter Point	WA
65054	Squaxin Passage, north of Hunter Point (Depth 5.3ft), Puget Sound, Washington Current	NOS	PUG1543_9	47.17626953125	-122.918998718261	:America/Los_Angeles	USA	knots	110	305	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, north of Hunter Point	WA
65055	Totten Inlet entrance (Depth 66.9ft), Puget Sound, Washington Current	NOS	PUG1544_3	47.1882514953613	-122.945373535156	:America/Los_Angeles	USA	knots	52	229	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet entrance	WA
65056	Totten Inlet entrance (Depth 40.7ft), Puget Sound, Washington Current	NOS	PUG1544_7	47.1882514953613	-122.945373535156	:America/Los_Angeles	USA	knots	39	227	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet entrance	WA
65057	Totten Inlet entrance (Depth 14.4ft), Puget Sound, Washington Current	NOS	PUG1544_11	47.1882514953613	-122.945373535156	:America/Los_Angeles	USA	knots	31	222	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet entrance	WA
65058	Libby Point, Hammersley Inlet (Depth 19.4ft), Puget Sound, Washington Current	NOS	PUG1545_1	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	77	261	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65059	Libby Point, Hammersley Inlet (Depth 17.8ft), Puget Sound, Washington Current	NOS	PUG1545_2	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.301	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65060	Libby Point, Hammersley Inlet (Depth 16.1ft), Puget Sound, Washington Current	NOS	PUG1545_3	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65061	Libby Point, Hammersley Inlet (Depth 14.5ft), Puget Sound, Washington Current	NOS	PUG1545_4	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.352	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65062	Libby Point, Hammersley Inlet (Depth 12.9ft), Puget Sound, Washington Current	NOS	PUG1545_5	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65063	Libby Point, Hammersley Inlet (Depth 11.2ft), Puget Sound, Washington Current	NOS	PUG1545_6	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.399	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65064	Libby Point, Hammersley Inlet (Depth 9.6ft), Puget Sound, Washington Current	NOS	PUG1545_7	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65065	Libby Point, Hammersley Inlet (Depth 7.9ft), Puget Sound, Washington Current	NOS	PUG1545_8	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.437	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65066	Libby Point, Hammersley Inlet (Depth 6.3ft), Puget Sound, Washington Current	NOS	PUG1545_9	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.452	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65067	Libby Point, Hammersley Inlet (Depth 4.7ft), Puget Sound, Washington Current	NOS	PUG1545_10	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	84	254	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.448	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65069	Pickering Passage, west of Squaxin Island (Depth 29.1ft), Puget Sound, Washington Current	NOS	PUG1546_8	47.2192802429199	-122.934516906738	:America/Los_Angeles	USA	knots	6	194	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, west of Squaxin Island	WA
65070	Pickering Passage, west of Squaxin Island (Depth 9.4ft), Puget Sound, Washington Current	NOS	PUG1546_14	47.2192802429199	-122.934516906738	:America/Los_Angeles	USA	knots	3	194	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, west of Squaxin Island	WA
65072	Pickering Passage, off Graham Point (Depth 55.7ft), Puget Sound, Washington Current	NOS	PUG1547_2	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65073	Pickering Passage, off Graham Point (Depth 52.5ft), Puget Sound, Washington Current	NOS	PUG1547_3	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65074	Pickering Passage, off Graham Point (Depth 49.2ft), Puget Sound, Washington Current	NOS	PUG1547_4	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65075	Pickering Passage, off Graham Point (Depth 45.9ft), Puget Sound, Washington Current	NOS	PUG1547_5	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65076	Pickering Passage, off Graham Point (Depth 42.6ft), Puget Sound, Washington Current	NOS	PUG1547_6	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65077	Pickering Passage, off Graham Point (Depth 39.3ft), Puget Sound, Washington Current	NOS	PUG1547_7	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65078	Pickering Passage, off Graham Point (Depth 36.1ft), Puget Sound, Washington Current	NOS	PUG1547_8	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65079	Pickering Passage, off Graham Point (Depth 32.8ft), Puget Sound, Washington Current	NOS	PUG1547_9	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65080	Pickering Passage, off Graham Point (Depth 29.5ft), Puget Sound, Washington Current	NOS	PUG1547_10	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	22	198	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65081	Pickering Passage, off Graham Point (Depth 26.2ft), Puget Sound, Washington Current	NOS	PUG1547_11	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65082	Pickering Passage, off Graham Point (Depth 22.9ft), Puget Sound, Washington Current	NOS	PUG1547_12	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65083	Pickering Passage, off Graham Point (Depth 19.7ft), Puget Sound, Washington Current	NOS	PUG1547_13	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65084	Pickering Passage, off Graham Point (Depth 16.4ft), Puget Sound, Washington Current	NOS	PUG1547_14	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65085	Pickering Passage, off Graham Point (Depth 13.1ft), Puget Sound, Washington Current	NOS	PUG1547_15	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65086	Pickering Passage, off Graham Point (Depth 9.8ft), Puget Sound, Washington Current	NOS	PUG1547_16	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	19	198	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65087	Pickering Passage, off Graham Point (Depth 6.5ft), Puget Sound, Washington Current	NOS	PUG1547_17	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65088	Pickering Passage, north end (Depth 77.9ft), Puget Sound, Washington Current	NOS	PUG1548_1	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	69	258	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65089	Pickering Passage, north end (Depth 71.3ft), Puget Sound, Washington Current	NOS	PUG1548_2	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65105	Hood Canal Bridge (Depth 208.9ft), Washington Current	NOS	PUG1603_1	47.8547401428222	-122.629417419433	:America/Los_Angeles	USA	knots	37	223	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
65106	Hood Canal Bridge (Depth 110.5ft), Washington Current	NOS	PUG1603_11	47.8547401428222	-122.629417419433	:America/Los_Angeles	USA	knots	45	223	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
65107	Hood Canal Bridge (Depth 21.9ft), Washington Current	NOS	PUG1603_20	47.8547401428222	-122.629417419433	:America/Los_Angeles	USA	knots	46	219	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
65091	Pickering Passage, north end (Depth 58.2ft), Puget Sound, Washington Current	NOS	PUG1548_4	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65092	Pickering Passage, north end (Depth 51.6ft), Puget Sound, Washington Current	NOS	PUG1548_5	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65093	Pickering Passage, north end (Depth 45ft), Puget Sound, Washington Current	NOS	PUG1548_6	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	64	260	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65094	Pickering Passage, north end (Depth 38.5ft), Puget Sound, Washington Current	NOS	PUG1548_7	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65095	Pickering Passage, north end (Depth 31.9ft), Puget Sound, Washington Current	NOS	PUG1548_8	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65096	Pickering Passage, north end (Depth 25.4ft), Puget Sound, Washington Current	NOS	PUG1548_9	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65097	Pickering Passage, north end (Depth 18.8ft), Puget Sound, Washington Current	NOS	PUG1548_10	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	52	258	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65098	Pickering Passage, north end (Depth 12.2ft), Puget Sound, Washington Current	NOS	PUG1548_11	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65099	Hazel Point (Depth 153.7ft), Hood Canal, Washington Current	NOS	PUG1601_1	47.6912384033203	-122.762786865234	:America/Los_Angeles	USA	knots	20	193	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
65100	Hazel Point (Depth 88.1ft), Hood Canal, Washington Current	NOS	PUG1601_11	47.6912384033203	-122.762786865234	:America/Los_Angeles	USA	knots	23	200	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
65101	Hazel Point (Depth 22.5ft), Hood Canal, Washington Current	NOS	PUG1601_21	47.6912384033203	-122.762786865234	:America/Los_Angeles	USA	knots	13	181	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
65232	Rosario Strait (Depth 135.4ft), Washington Current	NOS	PUG1702_7	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.276	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65102	South Point (Depth 177.9ft), Hood Canal, Washington Current	NOS	PUG1602_1	47.8216590881347	-122.676719665527	:America/Los_Angeles	USA	knots	41	234	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
65103	South Point (Depth 43.4ft), Hood Canal, Washington Current	NOS	PUG1602_42	47.8216590881347	-122.676719665527	:America/Los_Angeles	USA	knots	42	231	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
65104	South Point (Depth 23.7ft), Hood Canal, Washington Current	NOS	PUG1602_48	47.8216590881347	-122.676719665527	:America/Los_Angeles	USA	knots	41	230	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
65108	Port Gamble Bay entrance (Depth 32.4ft), Hood Canal, Washington Current	NOS	PUG1604_1	47.8547210693359	-122.578178405761	:America/Los_Angeles	USA	knots	20	204	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gamble Bay entrance	WA
65110	Possession Sound entrance (Depth 321.5ft), Washington Current	NOS	PUG1605_20	47.8992805480957	-122.360076904296	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound entrance	WA
65111	Possession Sound entrance (Depth 190.2ft), Washington Current	NOS	PUG1605_30	47.8992805480957	-122.360076904296	:America/Los_Angeles	USA	knots	198	8	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound entrance	WA
65112	Possession Sound entrance (Depth 59ft), Washington Current	NOS	PUG1605_40	47.8992805480957	-122.360076904296	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound entrance	WA
65119	Hood Canal entrance (Depth 255ft), Washington Current	NOS	PUG1608_1	47.9283790588378	-122.638816833496	:America/Los_Angeles	USA	knots	0	173	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal entrance	WA
65120	Hood Canal entrance (Depth 77.8ft), Washington Current	NOS	PUG1608_28	47.9283790588378	-122.638816833496	:America/Los_Angeles	USA	knots	352	164	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal entrance	WA
65121	Hood Canal entrance (Depth 31.9ft), Washington Current	NOS	PUG1608_35	47.9283790588378	-122.638816833496	:America/Los_Angeles	USA	knots	340	153	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal entrance	WA
65122	West of Mukilteo (Depth 271.5ft), Washington Current	NOS	PUG1609_20	47.9489517211914	-122.328460693359	:America/Los_Angeles	USA	knots	205	17	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
65123	West of Mukilteo (Depth 140.2ft), Washington Current	NOS	PUG1609_30	47.9489517211914	-122.328460693359	:America/Los_Angeles	USA	knots	205	16	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
65124	West of Mukilteo (Depth 61.5ft), Washington Current	NOS	PUG1609_36	47.9489517211914	-122.328460693359	:America/Los_Angeles	USA	knots	198	13	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
65115	Point No Point, 1.2 mi. E of (Depth 68.6ft), Puget Sound, Washington Current	NOS	PUG1606_39	47.9124908447265	-122.501968383789	:America/Los_Angeles	USA	knots	336	164	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.321	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
65116	Point No Point, 2.1 mi. E of (Depth 240.5ft), Puget Sound, Washington Current	NOS	PUG1607_1	47.91888	-122.48413	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
65117	Point No Point, 2.1 mi. E of (Depth 56.8ft), Puget Sound, Washington Current	NOS	PUG1607_29	47.91888	-122.48413	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
65118	Point No Point, 2.1 mi. E of (Depth 30.5ft), Puget Sound, Washington Current	NOS	PUG1607_33	47.91888	-122.48413	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
65125	Foulweather Bluff, 1.9 mi. NE of (Depth 124.9ft), Puget Sound, Washington Current	NOS	PUG1610_17	47.9542999267578	-122.57859802246	:America/Los_Angeles	USA	knots	305	141	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
65126	Foulweather Bluff, 1.9 mi. NE of (Depth 26.5ft), Puget Sound, Washington Current	NOS	PUG1610_32	47.9542999267578	-122.57859802246	:America/Los_Angeles	USA	knots	304	125	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.297	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
65233	Rosario Strait (Depth 125.6ft), Washington Current	NOS	PUG1702_8	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65127	Foulweather Bluff, 1.9 mi. NE of (Depth 19.9ft), Puget Sound, Washington Current	NOS	PUG1610_33	47.9542999267578	-122.57859802246	:America/Los_Angeles	USA	knots	302	125	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
65128	Olele Point, 1.8 mi. ENE of (Depth 148.3ft), Admiralty Inlet, Washington Current	NOS	PUG1611_10	47.9788093566894	-122.64549255371	:America/Los_Angeles	USA	knots	333	189	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
65129	Olele Point, 1.8 mi. ENE of (Depth 66.2ft), Admiralty Inlet, Washington Current	NOS	PUG1611_35	47.9788093566894	-122.64549255371	:America/Los_Angeles	USA	knots	340	169	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
65132	Clinton Ferry Terminal (Depth 79.6ft), Washington Current	NOS	PUG1612_1	47.96899	-122.34507	:America/Los_Angeles	USA	knots	184	16	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
65227	Rosario Strait (Depth 184.6ft), Washington Current	NOS	PUG1702_2	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65133	Clinton Ferry Terminal (Depth 46.8ft), Washington Current	NOS	PUG1612_6	47.96899	-122.34507	:America/Los_Angeles	USA	knots	187	349	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
65134	Clinton Ferry Terminal (Depth 20.5ft), Washington Current	NOS	PUG1612_10	47.96899	-122.34507	:America/Los_Angeles	USA	knots	178	4	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
65135	Everett (Depth 24.6ft), Washington Current	NOS	PUG1613_29	47.9762382507324	-122.238220214843	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Everett	WA
65141	Admiralty Inlet (off Bush Point) (Depth 193.1ft), Washington Current	NOS	PUG1616_6	48.0334815979003	-122.637649536132	:America/Los_Angeles	USA	knots	0	176	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
65142	Admiralty Inlet (off Bush Point) (Depth 68.4ft), Washington Current	NOS	PUG1616_25	48.0334815979003	-122.637649536132	:America/Los_Angeles	USA	knots	349	181	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.312	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
65143	Admiralty Inlet (off Bush Point) (Depth 29ft), Washington Current	NOS	PUG1616_31	48.0334815979003	-122.637649536132	:America/Los_Angeles	USA	knots	347	180	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.529	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
65147	Camano Head-Sandy Point, passage (Depth 209.1ft), Washington Current	NOS	PUG1618_15	48.04785	-122.38897	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
65131	Olele Point, 1.8 mi. ENE of (Depth 20.3ft), Admiralty Inlet, Washington Current	NOS	PUG1611_49	47.9788093566894	-122.64549255371	:America/Los_Angeles	USA	knots	342	149	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
65136	Port Townsend Canal (Depth 15ft), Admiralty Inlet, Washington Current	NOS	PUG1614_1	48.032470703125	-122.732612609863	:America/Los_Angeles	USA	knots	323	145	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend Canal	WA
65137	Port Townsend Canal (Depth 5.1ft), Admiralty Inlet, Washington Current	NOS	PUG1614_7	48.032470703125	-122.732612609863	:America/Los_Angeles	USA	knots	323	140	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.836	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend Canal	WA
65138	Nodule Point, 0.5 mi. SE of (Depth 64.8ft), Admiralty Inlet, Washington Current	NOS	PUG1615_1	48.028709411621	-122.660888671875	:America/Los_Angeles	USA	knots	347	162	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.214	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
65139	Nodule Point, 0.5 mi. SE of (Depth 25.4ft), Admiralty Inlet, Washington Current	NOS	PUG1615_13	48.028709411621	-122.660888671875	:America/Los_Angeles	USA	knots	353	162	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.573	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
65140	Nodule Point, 0.5 mi. SE of (Depth 9ft), Admiralty Inlet, Washington Current	NOS	PUG1615_18	48.028709411621	-122.660888671875	:America/Los_Angeles	USA	knots	357	162	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.589	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
65144	Bush Point Light, 0.5 mile NW of (Depth 208ft), Admiralty Inlet, Washington Current	NOS	PUG1617_14	48.0308418273925	-122.613342285156	:America/Los_Angeles	USA	knots	348	187	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
65145	Bush Point Light, 0.5 mile NW of (Depth 76.7ft), Admiralty Inlet, Washington Current	NOS	PUG1617_34	48.0308418273925	-122.613342285156	:America/Los_Angeles	USA	knots	338	189	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
65146	Bush Point Light, 0.5 mile NW of (Depth 43.9ft), Admiralty Inlet, Washington Current	NOS	PUG1617_39	48.0308418273925	-122.613342285156	:America/Los_Angeles	USA	knots	336	189	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
65148	Camano Head-Sandy Point, passage (Depth 77.8ft), Washington Current	NOS	PUG1618_35	48.04785	-122.38897	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
65149	Camano Head-Sandy Point, passage (Depth 31.9ft), Washington Current	NOS	PUG1618_42	48.04785	-122.38897	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
65156	West of Camano Island (Depth 180ft), Washington Current	NOS	PUG1622_3	48.1696815490722	-122.553199768066	:America/Los_Angeles	USA	knots	159	354	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
65157	West of Camano Island (Depth 68.5ft), Washington Current	NOS	PUG1622_20	48.1696815490722	-122.553199768066	:America/Los_Angeles	USA	knots	151	341	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
65158	West of Camano Island (Depth 22.5ft), Washington Current	NOS	PUG1622_27	48.1696815490722	-122.553199768066	:America/Los_Angeles	USA	knots	159	352	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
65151	Marrowstone Point, 0.8 mi. NE of (Depth 62.2ft), Admiralty Inlet, Washington Current	NOS	PUG1619_36	48.106330871582	-122.672470092773	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
65152	Marrowstone Point, 0.8 mi. NE of (Depth 29.4ft), Admiralty Inlet, Washington Current	NOS	PUG1619_46	48.106330871582	-122.672470092773	:America/Los_Angeles	USA	knots	349	129	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
65153	Marrowstone Point, 1.65 mi. NE of (Depth 144.2ft), Admiralty Inlet, Washington Current	NOS	PUG1620_10	48.1193008422851	-122.662269592285	:America/Los_Angeles	USA	knots	315	139	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.301	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
65154	Marrowstone Point, 1.65 mi. NE of (Depth 78.5ft), Admiralty Inlet, Washington Current	NOS	PUG1620_20	48.1193008422851	-122.662269592285	:America/Los_Angeles	USA	knots	326	142	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
65155	Marrowstone Point, 1.65 mi. NE of (Depth 26ft), Admiralty Inlet, Washington Current	NOS	PUG1620_28	48.1193008422851	-122.662269592285	:America/Los_Angeles	USA	knots	333	145	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
65159	Point Wilson, 0.6 mi. NE of (Depth 118.4ft), Admiralty Inlet, Washington Current	NOS	PUG1623_14	48.1501083374023	-122.745361328125	:America/Los_Angeles	USA	knots	325	132	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
65160	Point Wilson, 0.6 mi. NE of (Depth 56.1ft), Admiralty Inlet, Washington Current	NOS	PUG1623_33	48.1501083374023	-122.745361328125	:America/Los_Angeles	USA	knots	322	124	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
65161	Point Wilson, 0.6 mi. NE of (Depth 16.7ft), Admiralty Inlet, Washington Current	NOS	PUG1623_45	48.1501083374023	-122.745361328125	:America/Los_Angeles	USA	knots	321	120	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
65162	Point Wilson, 1.6 mi. NE of (Depth 148.8ft), Admiralty Inlet, Washington Current	NOS	PUG1624_8	48.1568717956543	-122.726028442382	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
65163	Point Wilson, 1.6 mi. NE of (Depth 86.5ft), Admiralty Inlet, Washington Current	NOS	PUG1624_27	48.1568717956543	-122.726028442382	:America/Los_Angeles	USA	knots	316	117	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
65164	Point Wilson, 1.6 mi. NE of (Depth 20.9ft), Admiralty Inlet, Washington Current	NOS	PUG1624_47	48.1568717956543	-122.726028442382	:America/Los_Angeles	USA	knots	319	126	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
65231	Rosario Strait (Depth 145.2ft), Washington Current	NOS	PUG1702_6	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65166	Point Wilson, 2.7 mi. NE of (Depth 55.9ft), Admiralty Inlet, Washington Current	NOS	PUG1625_34	48.1670684814453	-122.707389831542	:America/Los_Angeles	USA	knots	333	137	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
65168	Skagit Bay, 1 mi. north of Rocky Point (Depth 54.4ft), Washington Current	NOS	PUG1626_7	48.2671203613281	-122.529571533203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
65169	Skagit Bay, 1 mi. north of Rocky Point (Depth 28.1ft), Washington Current	NOS	PUG1626_15	48.2671203613281	-122.529571533203	:America/Los_Angeles	USA	knots	246	51	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
65170	Skagit Bay, 1 mi. north of Rocky Point (Depth 11.7ft), Washington Current	NOS	PUG1626_20	48.2671203613281	-122.529571533203	:America/Los_Angeles	USA	knots	234	59	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
65171	Skagit Bay, 1 mi. south of Goat Island (Depth 51.6ft), Washington Current	NOS	PUG1627_5	48.3447799682617	-122.545051574707	:America/Los_Angeles	USA	knots	154	332	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
65172	Skagit Bay, 1 mi. south of Goat Island (Depth 32ft), Washington Current	NOS	PUG1627_11	48.3447799682617	-122.545051574707	:America/Los_Angeles	USA	knots	149	333	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
65173	Skagit Bay, 1 mi. south of Goat Island (Depth 12.3ft), Washington Current	NOS	PUG1627_17	48.3447799682617	-122.545051574707	:America/Los_Angeles	USA	knots	147	329	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
65174	Skagit Bay channel, SW of Hope Island (Depth 39ft), Washington Current	NOS	PUG1628_4	48.3978309631347	-122.579551696777	:America/Los_Angeles	USA	knots	174	345	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
65175	Skagit Bay channel, SW of Hope Island (Depth 25.9ft), Washington Current	NOS	PUG1628_8	48.3978309631347	-122.579551696777	:America/Los_Angeles	USA	knots	168	345	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
65176	Skagit Bay channel, SW of Hope Island (Depth 9.5ft), Washington Current	NOS	PUG1628_13	48.3978309631347	-122.579551696777	:America/Los_Angeles	USA	knots	170	345	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
65180	Kanem Point, 1.5 mi. SW of Protection Island (Depth 97.3ft), Washington Current	NOS	PUG1630_30	48.1076507568359	-122.973648071289	:America/Los_Angeles	USA	knots	289	121	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
65181	Kanem Point, 1.5 mi. SW of Protection Island (Depth 54.7ft), Washington Current	NOS	PUG1630_43	48.1076507568359	-122.973648071289	:America/Los_Angeles	USA	knots	284	125	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
65182	Kanem Point, 1.5 mi. SW of Protection Island (Depth 21.9ft), Washington Current	NOS	PUG1630_53	48.1076507568359	-122.973648071289	:America/Los_Angeles	USA	knots	279	117	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
65183	Violet Point, 3.7 mi. NW of Protection Island (Depth 111.8ft), Washington Current	NOS	PUG1631_4	48.1613998413085	-122.968101501464	:America/Los_Angeles	USA	knots	304	107	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
65184	Violet Point, 3.7 mi. NW of Protection Island (Depth 39.7ft), Washington Current	NOS	PUG1631_26	48.1613998413085	-122.968101501464	:America/Los_Angeles	USA	knots	297	103	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
65177	Yokeko Point, Deception Pass (Depth 26.7ft), Rosario Strait, Washington Current	NOS	PUG1629_3	48.4127197265625	-122.613166809082	:America/Los_Angeles	USA	knots	226	52	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
65178	Yokeko Point, Deception Pass (Depth 13.6ft), Rosario Strait, Washington Current	NOS	PUG1629_7	48.4127197265625	-122.613166809082	:America/Los_Angeles	USA	knots	228	54	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
65179	Yokeko Point, Deception Pass (Depth 7ft), Rosario Strait, Washington Current	NOS	PUG1629_9	48.4127197265625	-122.613166809082	:America/Los_Angeles	USA	knots	230	55	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
65185	Violet Point, 3.7 mi. NW of Protection Island (Depth 16.7ft), Washington Current	NOS	PUG1631_33	48.1613998413085	-122.968101501464	:America/Los_Angeles	USA	knots	290	102	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
65189	Point Partridge, 2.4 mi. NW of (Depth 130ft), Washington Current	NOS	PUG1633_15	48.25562	-122.79303	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.353	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Partridge, 2.4 mi. NW of	WA
65190	Point Partridge, 2.4 mi. NW of (Depth 77.5ft), Washington Current	NOS	PUG1633_23	48.25562	-122.79303	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.463	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Partridge, 2.4 mi. NW of	WA
65191	Point Partridge, 2.4 mi. NW of (Depth 25ft), Washington Current	NOS	PUG1633_31	48.25562	-122.79303	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Partridge, 2.4 mi. NW of	WA
65198	New Dungeness Light, 2.8 mi. NNW of (Depth 360.1ft), Washington Current	NOS	PUG1635_11	48.2334785461425	-123.133430480957	:America/Los_Angeles	USA	knots	244	73	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
65199	New Dungeness Light, 2.8 mi. NNW of (Depth 71.4ft), Washington Current	NOS	PUG1635_55	48.2334785461425	-123.133430480957	:America/Los_Angeles	USA	knots	273	69	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.346	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
65200	New Dungeness Light, 2.8 mi. NNW of (Depth 51.7ft), Washington Current	NOS	PUG1635_58	48.2334785461425	-123.133430480957	:America/Los_Angeles	USA	knots	273	66	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.405	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
65201	Discovery Island, 7.6 mi. SSE of (Depth 244.3ft), Washington Current	NOS	PUG1636_1	48.3001518249511	-123.167160034179	:America/Los_Angeles	USA	knots	220	54	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
65202	Discovery Island, 7.6 mi. SSE of (Depth 119.6ft), Washington Current	NOS	PUG1636_20	48.3001518249511	-123.167160034179	:America/Los_Angeles	USA	knots	245	72	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
65203	Discovery Island, 7.6 mi. SSE of (Depth 27.7ft), Washington Current	NOS	PUG1636_34	48.3001518249511	-123.167160034179	:America/Los_Angeles	USA	knots	240	69	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.187	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
65187	Smith Island, 5.5 mi. WNW of (Depth 141.2ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1632_26	48.3245506286621	-122.964752197265	:America/Los_Angeles	USA	knots	253	60	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
65188	Smith Island, 5.5 mi. WNW of (Depth 42.8ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1632_41	48.3245506286621	-122.964752197265	:America/Los_Angeles	USA	knots	255	58	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
65192	Smith Island, 3.4 mi. ESE of (Depth 134.4ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_1	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	230	102	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65193	Smith Island, 3.4 mi. ESE of (Depth 88.5ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_15	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.465	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65194	Smith Island, 3.4 mi. ESE of (Depth 62.2ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_23	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.596	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65195	Smith Island, 3.4 mi. ESE of (Depth 55.6ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_25	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	218	109	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.617	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65196	Smith Island, 3.4 mi. ESE of (Depth 36ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_31	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.652	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65204	Ediz Hook Light, 5.3 mi. ENE of (Depth 179.2ft), Washington Current	NOS	PUG1637_5	48.1822700500488	-123.281501770019	:America/Los_Angeles	USA	knots	260	78	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
65205	Ediz Hook Light, 5.3 mi. ENE of (Depth 28.3ft), Washington Current	NOS	PUG1637_28	48.1822700500488	-123.281501770019	:America/Los_Angeles	USA	knots	258	88	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
65206	Ediz Hook Light, 5.3 mi. ENE of (Depth 21.8ft), Washington Current	NOS	PUG1637_29	48.1822700500488	-123.281501770019	:America/Los_Angeles	USA	knots	257	88	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.517	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
65207	Ediz Hook Light, 1.2 miles N of (Depth 183.6ft), Washington Current	NOS	PUG1638_7	48.166690826416	-123.415817260742	:America/Los_Angeles	USA	knots	279	112	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
65208	Ediz Hook Light, 1.2 miles N of (Depth 85.1ft), Washington Current	NOS	PUG1638_17	48.166690826416	-123.415817260742	:America/Los_Angeles	USA	knots	282	90	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
65209	Ediz Hook Light, 1.2 miles N of (Depth 35.9ft), Washington Current	NOS	PUG1638_22	48.166690826416	-123.415817260742	:America/Los_Angeles	USA	knots	283	89	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.358	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
65219	Strait of Juan de Fuca entrance (Depth 705.4ft), Washington Current	NOS	PUG1642_3	48.4499816894531	-124.583801269531	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca entrance	WA
65220	Strait of Juan de Fuca entrance (Depth 456.1ft), Washington Current	NOS	PUG1642_22	48.4499816894531	-124.583801269531	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca entrance	WA
65221	Strait of Juan de Fuca entrance (Depth 101.8ft), Washington Current	NOS	PUG1642_49	48.4499816894531	-124.583801269531	:America/Los_Angeles	USA	knots	306	113	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.564	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca entrance	WA
65222	Strait of Juan de Fuca entrance (Depth 88.6ft), Washington Current	NOS	PUG1642_50	48.4499816894531	-124.583801269531	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca entrance	WA
65211	Angeles Pt., 2 mi. NNE of (Depth 24.8ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1639_12	48.1769981384277	-123.526947021484	:America/Los_Angeles	USA	knots	300	75	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.257	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
65212	Angeles Pt., 2 mi. NNE of (Depth 11.7ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1639_16	48.1769981384277	-123.526947021484	:America/Los_Angeles	USA	knots	300	75	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
65213	Race Rocks, 4.5 mi. S of (Depth 394.4ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1640_1	48.2232017517089	-123.532302856445	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
65214	Race Rocks, 4.5 mi. S of (Depth 236.9ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1640_9	48.2232017517089	-123.532302856445	:America/Los_Angeles	USA	knots	274	82	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
65215	Race Rocks, 4.5 mi. S of (Depth 59.7ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1640_18	48.2232017517089	-123.532302856445	:America/Los_Angeles	USA	knots	268	91	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.596	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
65216	Pillar Point, 6 mi. NNE of (Depth 296.6ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1641_36	48.2999992370605	-124.037399291992	:America/Los_Angeles	USA	knots	273	93	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
65217	Pillar Point, 6 mi. NNE of (Depth 73.5ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1641_70	48.2999992370605	-124.037399291992	:America/Los_Angeles	USA	knots	293	114	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
65218	Pillar Point, 6 mi. NNE of (Depth 40.7ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1641_75	48.2999992370605	-124.037399291992	:America/Los_Angeles	USA	knots	290	115	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.288	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
65226	Rosario Strait (Depth 194.5ft), Washington Current	NOS	PUG1702_1	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65228	Rosario Strait (Depth 174.8ft), Washington Current	NOS	PUG1702_3	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65229	Rosario Strait (Depth 164.9ft), Washington Current	NOS	PUG1702_4	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65234	Rosario Strait (Depth 115.7ft), Washington Current	NOS	PUG1702_9	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	183	0	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65235	Rosario Strait (Depth 105.9ft), Washington Current	NOS	PUG1702_10	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.376	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65236	Rosario Strait (Depth 96ft), Washington Current	NOS	PUG1702_11	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.406	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65237	Rosario Strait (Depth 86.2ft), Washington Current	NOS	PUG1702_12	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65238	Rosario Strait (Depth 76.3ft), Washington Current	NOS	PUG1702_13	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	187	0	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.458	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65239	Rosario Strait (Depth 66.5ft), Washington Current	NOS	PUG1702_14	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.478	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65240	Rosario Strait (Depth 56.7ft), Washington Current	NOS	PUG1702_15	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.493	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65241	Rosario Strait (Depth 46.8ft), Washington Current	NOS	PUG1702_16	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	190	357	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65242	Rosario Strait (Depth 37ft), Washington Current	NOS	PUG1702_17	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65243	San Juan Channel, south entrance (Depth 141ft), Washington Current	NOS	PUG1703_13	48.461009979248	-122.952026367187	:America/Los_Angeles	USA	knots	169	311	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
65244	San Juan Channel, south entrance (Depth 91.8ft), Washington Current	NOS	PUG1703_16	48.461009979248	-122.952026367187	:America/Los_Angeles	USA	knots	169	346	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.507	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
65224	Deception Pass (Narrows) (Depth 47.1ft), Rosario Strait, Washington Current	NOS	PUG1701_24	48.4061889648437	-122.643119812011	:America/Los_Angeles	USA	knots	270	98	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.647	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
65225	Deception Pass (Narrows) (Depth 17.6ft), Rosario Strait, Washington Current	NOS	PUG1701_33	48.4061889648437	-122.643119812011	:America/Los_Angeles	USA	knots	277	108	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.618	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
65245	San Juan Channel, south entrance (Depth 75.4ft), Washington Current	NOS	PUG1703_17	48.461009979248	-122.952026367187	:America/Los_Angeles	USA	knots	168	347	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.494	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
65249	Obstruction Pass, north of Obstruction Island (Depth 53.9ft), Washington Current	NOS	PUG1705_1	48.603271484375	-122.812728881835	:America/Los_Angeles	USA	knots	274	100	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
65250	Obstruction Pass, north of Obstruction Island (Depth 14.5ft), Washington Current	NOS	PUG1705_13	48.603271484375	-122.812728881835	:America/Los_Angeles	USA	knots	286	88	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
65251	Obstruction Pass, north of Obstruction Island (Depth 7.9ft), Washington Current	NOS	PUG1705_15	48.603271484375	-122.812728881835	:America/Los_Angeles	USA	knots	286	87	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
65247	Peavine Pass, west entrance (Depth 18.5ft), Rosario Strait, Washington Current	NOS	PUG1704_10	48.5870780944824	-122.819259643554	:America/Los_Angeles	USA	knots	232	56	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.613	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
65305	Parker Reef Light, north of (Depth 97ft), Rosario Strait, Washington Current	NOS	PUG1712_15	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65477	Burrows Pass (Depth 100.4ft), Washington Current	NOS	PUG1738_1	48.48952	-122.68672	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.465	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
65248	Peavine Pass, west entrance (Depth 8.7ft), Rosario Strait, Washington Current	NOS	PUG1704_13	48.5870780944824	-122.819259643554	:America/Los_Angeles	USA	knots	231	56	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.629	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
65252	Peapod Rocks Light, 1.2 nm south of (Depth 170ft), Rosario Strait, Washington Current	NOS	PUG1706_1	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	218	35	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65253	Peapod Rocks Light, 1.2 nm south of (Depth 156.9ft), Rosario Strait, Washington Current	NOS	PUG1706_2	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65254	Peapod Rocks Light, 1.2 nm south of (Depth 143.7ft), Rosario Strait, Washington Current	NOS	PUG1706_3	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65256	Peapod Rocks Light, 1.2 nm south of (Depth 117.5ft), Rosario Strait, Washington Current	NOS	PUG1706_5	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65257	Peapod Rocks Light, 1.2 nm south of (Depth 104.4ft), Rosario Strait, Washington Current	NOS	PUG1706_6	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.264	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65258	Peapod Rocks Light, 1.2 nm south of (Depth 91.2ft), Rosario Strait, Washington Current	NOS	PUG1706_7	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65259	Peapod Rocks Light, 1.2 nm south of (Depth 78.1ft), Rosario Strait, Washington Current	NOS	PUG1706_8	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	218	26	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.296	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65260	Peapod Rocks Light, 1.2 nm south of (Depth 65ft), Rosario Strait, Washington Current	NOS	PUG1706_9	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65261	Peapod Rocks Light, 1.2 nm south of (Depth 51.9ft), Rosario Strait, Washington Current	NOS	PUG1706_10	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65262	Peapod Rocks Light, 1.2 nm south of (Depth 38.7ft), Rosario Strait, Washington Current	NOS	PUG1706_11	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	220	22	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.358	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65266	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 233.5ft), Washington Current	NOS	PUG1708_1	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65267	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 220.4ft), Washington Current	NOS	PUG1708_2	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65268	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 207.3ft), Washington Current	NOS	PUG1708_3	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65269	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 194.2ft), Washington Current	NOS	PUG1708_4	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65270	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 181ft), Washington Current	NOS	PUG1708_5	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65271	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 167.9ft), Washington Current	NOS	PUG1708_6	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65272	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 154.8ft), Washington Current	NOS	PUG1708_7	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65478	Burrows Pass (Depth 28.2ft), Washington Current	NOS	PUG1738_23	48.48952	-122.68672	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
65273	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 141.7ft), Washington Current	NOS	PUG1708_8	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65274	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 128.5ft), Washington Current	NOS	PUG1708_9	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65275	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 115.4ft), Washington Current	NOS	PUG1708_10	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	152	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65276	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 102.3ft), Washington Current	NOS	PUG1708_11	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65277	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 89.2ft), Washington Current	NOS	PUG1708_12	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65278	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 76ft), Washington Current	NOS	PUG1708_13	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65279	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 62.9ft), Washington Current	NOS	PUG1708_14	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	152	349	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65280	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 49.8ft), Washington Current	NOS	PUG1708_15	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65264	Sinclair Island, 1.0 nm NE of (Depth 98.5ft), Rosario Strait, Washington Current	NOS	PUG1707_17	48.6441993713378	-122.658721923828	:America/Los_Angeles	USA	knots	131	327	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.292	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
65299	Parker Reef Light, north of (Depth 136.4ft), Rosario Strait, Washington Current	NOS	PUG1712_9	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65281	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 36.7ft), Washington Current	NOS	PUG1708_16	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	151	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65283	Clark Island, 1.6 nm north of (Depth 48.4ft), Rosario Strait, Washington Current	NOS	PUG1709_30	48.7312583923339	-122.773376464843	:America/Los_Angeles	USA	knots	157	336	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
65284	Clark Island, 1.6 nm north of (Depth 28.7ft), Rosario Strait, Washington Current	NOS	PUG1709_33	48.7312583923339	-122.773376464843	:America/Los_Angeles	USA	knots	159	335	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
65344	Wasp Passage narrows (Depth 53.6ft), San Juan Channel, Washington Current	NOS	PUG1721_4	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65285	Hale Passage, east of Lummi Point (Depth 43.7ft), Rosario Strait, Washington Current	NOS	PUG1710_3	48.7348518371582	-122.680168151855	:America/Los_Angeles	USA	knots	158	350	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
65286	Hale Passage, east of Lummi Point (Depth 27.3ft), Rosario Strait, Washington Current	NOS	PUG1710_8	48.7348518371582	-122.680168151855	:America/Los_Angeles	USA	knots	167	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
65287	Hale Passage, east of Lummi Point (Depth 7.6ft), Rosario Strait, Washington Current	NOS	PUG1710_14	48.7348518371582	-122.680168151855	:America/Los_Angeles	USA	knots	177	349	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
65288	Matia Island, west of (Depth 335.9ft), Rosario Strait, Washington Current	NOS	PUG1711_4	48.7748794555664	-122.84097290039	:America/Los_Angeles	USA	knots	135	299	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
65289	Matia Island, west of (Depth 86.5ft), Rosario Strait, Washington Current	NOS	PUG1711_23	48.7748794555664	-122.84097290039	:America/Los_Angeles	USA	knots	149	325	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
65290	Matia Island, west of (Depth 47.1ft), Rosario Strait, Washington Current	NOS	PUG1711_26	48.7748794555664	-122.84097290039	:America/Los_Angeles	USA	knots	153	327	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
65291	Parker Reef Light, north of (Depth 188.8ft), Rosario Strait, Washington Current	NOS	PUG1712_1	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65292	Parker Reef Light, north of (Depth 182.3ft), Rosario Strait, Washington Current	NOS	PUG1712_2	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65293	Parker Reef Light, north of (Depth 175.7ft), Rosario Strait, Washington Current	NOS	PUG1712_3	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65294	Parker Reef Light, north of (Depth 169.2ft), Rosario Strait, Washington Current	NOS	PUG1712_4	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65295	Parker Reef Light, north of (Depth 162.6ft), Rosario Strait, Washington Current	NOS	PUG1712_5	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65296	Parker Reef Light, north of (Depth 156ft), Rosario Strait, Washington Current	NOS	PUG1712_6	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65297	Parker Reef Light, north of (Depth 149.5ft), Rosario Strait, Washington Current	NOS	PUG1712_7	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65298	Parker Reef Light, north of (Depth 142.9ft), Rosario Strait, Washington Current	NOS	PUG1712_8	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65301	Parker Reef Light, north of (Depth 123.2ft), Rosario Strait, Washington Current	NOS	PUG1712_11	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65302	Parker Reef Light, north of (Depth 116.7ft), Rosario Strait, Washington Current	NOS	PUG1712_12	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65303	Parker Reef Light, north of (Depth 110.1ft), Rosario Strait, Washington Current	NOS	PUG1712_13	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65306	Parker Reef Light, north of (Depth 90.4ft), Rosario Strait, Washington Current	NOS	PUG1712_16	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65307	Parker Reef Light, north of (Depth 83.9ft), Rosario Strait, Washington Current	NOS	PUG1712_17	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65308	Parker Reef Light, north of (Depth 77.3ft), Rosario Strait, Washington Current	NOS	PUG1712_18	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65309	Parker Reef Light, north of (Depth 70.7ft), Rosario Strait, Washington Current	NOS	PUG1712_19	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65310	Parker Reef Light, north of (Depth 64.2ft), Rosario Strait, Washington Current	NOS	PUG1712_20	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65311	Parker Reef Light, north of (Depth 57.6ft), Rosario Strait, Washington Current	NOS	PUG1712_21	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65312	Parker Reef Light, north of (Depth 51ft), Rosario Strait, Washington Current	NOS	PUG1712_22	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65313	Parker Reef Light, north of (Depth 44.5ft), Rosario Strait, Washington Current	NOS	PUG1712_23	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	257	81	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65314	Parker Reef Light, north of (Depth 37.9ft), Rosario Strait, Washington Current	NOS	PUG1712_24	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65315	Parker Reef Light, north of (Depth 31.4ft), Rosario Strait, Washington Current	NOS	PUG1712_25	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	254	79	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.268	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65316	Parker Reef Light, north of (Depth 24.8ft), Rosario Strait, Washington Current	NOS	PUG1712_26	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65317	Patos Island, south of Toe Point (Depth 62.7ft), Rosario Strait, Washington Current	NOS	PUG1713_10	48.7720603942871	-122.933700561523	:America/Los_Angeles	USA	knots	196	46	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.267	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
65318	Patos Island, south of Toe Point (Depth 29.9ft), Rosario Strait, Washington Current	NOS	PUG1713_20	48.7720603942871	-122.933700561523	:America/Los_Angeles	USA	knots	191	52	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.356	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
65319	Patos Island, south of Toe Point (Depth 13.5ft), Rosario Strait, Washington Current	NOS	PUG1713_25	48.7720603942871	-122.933700561523	:America/Los_Angeles	USA	knots	188	54	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
65320	Patos Island Light, 1.4 nm west of (Depth 190.7ft), Rosario Strait, Washington Current	NOS	PUG1714_16	48.7731285095214	-123.005790710449	:America/Los_Angeles	USA	knots	225	40	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
65323	President Channel, east of Point Disney (Depth 200.2ft), Washington Current	NOS	PUG1715_28	48.6733512878418	-123.005989074707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, east of Point Disney	WA
65324	President Channel, east of Point Disney (Depth 108.3ft), Washington Current	NOS	PUG1715_35	48.6733512878418	-123.005989074707	:America/Los_Angeles	USA	knots	219	39	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.369	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, east of Point Disney	WA
65325	President Channel, east of Point Disney (Depth 69ft), Washington Current	NOS	PUG1715_38	48.6733512878418	-123.005989074707	:America/Los_Angeles	USA	knots	218	37	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.502	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, east of Point Disney	WA
65326	Waldron Island, 1.7 nm west of (Depth 158.5ft), Washington Current	NOS	PUG1716_3	48.7042198181152	-123.104766845703	:America/Los_Angeles	USA	knots	232	28	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.328	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island, 1.7 nm west of	WA
65327	Waldron Island, 1.7 nm west of (Depth 92.8ft), Washington Current	NOS	PUG1716_13	48.7042198181152	-123.104766845703	:America/Los_Angeles	USA	knots	227	31	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island, 1.7 nm west of	WA
65328	Waldron Island, 1.7 nm west of (Depth 27.2ft), Washington Current	NOS	PUG1716_23	48.7042198181152	-123.104766845703	:America/Los_Angeles	USA	knots	252	325	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.22	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island, 1.7 nm west of	WA
65329	Turn Point, Boundary Pass (Depth 207.5ft), Washington Current	NOS	PUG1717_28	48.6912117004394	-123.245010375976	:America/Los_Angeles	USA	knots	232	358	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
65330	Turn Point, Boundary Pass (Depth 168.1ft), Washington Current	NOS	PUG1717_31	48.6912117004394	-123.245010375976	:America/Los_Angeles	USA	knots	235	359	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.393	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
65331	Turn Point, Boundary Pass (Depth 115.6ft), Washington Current	NOS	PUG1717_35	48.6912117004394	-123.245010375976	:America/Los_Angeles	USA	knots	236	3	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.297	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
65350	Wasp Passage narrows (Depth 33.9ft), San Juan Channel, Washington Current	NOS	PUG1721_10	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65332	Haro Strait, 1.2 nm west of Kellett Bluff (Depth 204.2ft), Washington Current	NOS	PUG1718_29	48.5887184143066	-123.225830078125	:America/Los_Angeles	USA	knots	178	340	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
65333	Haro Strait, 1.2 nm west of Kellett Bluff (Depth 105.8ft), Washington Current	NOS	PUG1718_34	48.5887184143066	-123.225830078125	:America/Los_Angeles	USA	knots	179	345	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
65334	Haro Strait, 1.2 nm west of Kellett Bluff (Depth 66.4ft), Washington Current	NOS	PUG1718_36	48.5887184143066	-123.225830078125	:America/Los_Angeles	USA	knots	179	346	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.384	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
65335	Spieden Channel, north of Limestone Point (Depth 204.8ft), Washington Current	NOS	PUG1719_7	48.627830505371	-123.11164855957	:America/Los_Angeles	USA	knots	282	82	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
65336	Spieden Channel, north of Limestone Point (Depth 60.4ft), Washington Current	NOS	PUG1719_18	48.627830505371	-123.11164855957	:America/Los_Angeles	USA	knots	282	85	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.634	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
65337	Spieden Channel, north of Limestone Point (Depth 47.3ft), Washington Current	NOS	PUG1719_19	48.627830505371	-123.11164855957	:America/Los_Angeles	USA	knots	281	85	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.665	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
65322	Patos Island Light, 1.4 nm west of (Depth 46.4ft), Rosario Strait, Washington Current	NOS	PUG1714_27	48.7731285095214	-123.005790710449	:America/Los_Angeles	USA	knots	209	45	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.443	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
65338	Spring Passage, south entrance (Depth 62.3ft), San Juan Channel, Washington Current	NOS	PUG1720_11	48.6115417480468	-123.034103393554	:America/Los_Angeles	USA	knots	151	359	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
65358	Harney Channel, north of Point Hudson (Depth 98.5ft), Washington Current	NOS	PUG1722_1	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65359	Harney Channel, north of Point Hudson (Depth 95.2ft), Washington Current	NOS	PUG1722_2	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65340	Spring Passage, south entrance (Depth 13.1ft), San Juan Channel, Washington Current	NOS	PUG1720_26	48.6115417480468	-123.034103393554	:America/Los_Angeles	USA	knots	148	5	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
65341	Wasp Passage narrows (Depth 63.5ft), San Juan Channel, Washington Current	NOS	PUG1721_1	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65342	Wasp Passage narrows (Depth 60.2ft), San Juan Channel, Washington Current	NOS	PUG1721_2	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	66	264	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65343	Wasp Passage narrows (Depth 56.9ft), San Juan Channel, Washington Current	NOS	PUG1721_3	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65345	Wasp Passage narrows (Depth 50.3ft), San Juan Channel, Washington Current	NOS	PUG1721_5	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65346	Wasp Passage narrows (Depth 47ft), San Juan Channel, Washington Current	NOS	PUG1721_6	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65347	Wasp Passage narrows (Depth 43.8ft), San Juan Channel, Washington Current	NOS	PUG1721_7	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65348	Wasp Passage narrows (Depth 40.5ft), San Juan Channel, Washington Current	NOS	PUG1721_8	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65349	Wasp Passage narrows (Depth 37.2ft), San Juan Channel, Washington Current	NOS	PUG1721_9	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65351	Wasp Passage narrows (Depth 30.6ft), San Juan Channel, Washington Current	NOS	PUG1721_11	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	62	259	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65352	Wasp Passage narrows (Depth 27.4ft), San Juan Channel, Washington Current	NOS	PUG1721_12	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65353	Wasp Passage narrows (Depth 24.1ft), San Juan Channel, Washington Current	NOS	PUG1721_13	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65354	Wasp Passage narrows (Depth 20.8ft), San Juan Channel, Washington Current	NOS	PUG1721_14	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65355	Wasp Passage narrows (Depth 17.5ft), San Juan Channel, Washington Current	NOS	PUG1721_15	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65356	Wasp Passage narrows (Depth 14.2ft), San Juan Channel, Washington Current	NOS	PUG1721_16	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65357	Wasp Passage narrows (Depth 11ft), San Juan Channel, Washington Current	NOS	PUG1721_17	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	60	256	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65360	Harney Channel, north of Point Hudson (Depth 91.9ft), Washington Current	NOS	PUG1722_3	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65361	Harney Channel, north of Point Hudson (Depth 88.6ft), Washington Current	NOS	PUG1722_4	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65362	Harney Channel, north of Point Hudson (Depth 85.3ft), Washington Current	NOS	PUG1722_5	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65363	Harney Channel, north of Point Hudson (Depth 82.1ft), Washington Current	NOS	PUG1722_6	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	72	267	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65364	Harney Channel, north of Point Hudson (Depth 78.8ft), Washington Current	NOS	PUG1722_7	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65365	Harney Channel, north of Point Hudson (Depth 75.5ft), Washington Current	NOS	PUG1722_8	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65366	Harney Channel, north of Point Hudson (Depth 72.2ft), Washington Current	NOS	PUG1722_9	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65367	Harney Channel, north of Point Hudson (Depth 68.9ft), Washington Current	NOS	PUG1722_10	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65368	Harney Channel, north of Point Hudson (Depth 65.6ft), Washington Current	NOS	PUG1722_11	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65369	Harney Channel, north of Point Hudson (Depth 62.4ft), Washington Current	NOS	PUG1722_12	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65370	Harney Channel, north of Point Hudson (Depth 59.1ft), Washington Current	NOS	PUG1722_13	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65371	Harney Channel, north of Point Hudson (Depth 55.8ft), Washington Current	NOS	PUG1722_14	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65372	Harney Channel, north of Point Hudson (Depth 52.5ft), Washington Current	NOS	PUG1722_15	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65373	Harney Channel, north of Point Hudson (Depth 49.2ft), Washington Current	NOS	PUG1722_16	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65375	Harney Channel, north of Point Hudson (Depth 42.7ft), Washington Current	NOS	PUG1722_18	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65376	Harney Channel, north of Point Hudson (Depth 39.4ft), Washington Current	NOS	PUG1722_19	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65377	Harney Channel, north of Point Hudson (Depth 36.1ft), Washington Current	NOS	PUG1722_20	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	78	265	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65378	Harney Channel, north of Point Hudson (Depth 32.8ft), Washington Current	NOS	PUG1722_21	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65379	Harney Channel, north of Point Hudson (Depth 29.6ft), Washington Current	NOS	PUG1722_22	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65380	Harney Channel, north of Point Hudson (Depth 26.3ft), Washington Current	NOS	PUG1722_23	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65382	Harney Channel, north of Point Hudson (Depth 19.7ft), Washington Current	NOS	PUG1722_25	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65383	Harney Channel, north of Point Hudson (Depth 16.4ft), Washington Current	NOS	PUG1722_26	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65384	Harney Channel, north of Point Hudson (Depth 13.2ft), Washington Current	NOS	PUG1722_27	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	78	263	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65385	Harney Channel, north of Point Hudson (Depth 9.9ft), San Juan Channel, Washington Current	NOS	PUG1722_28	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65386	Upright Channel narrows (Depth 136ft), San Juan Channel, Washington Current	NOS	PUG1723_1	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65387	Upright Channel narrows (Depth 129.4ft), San Juan Channel, Washington Current	NOS	PUG1723_2	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65388	Upright Channel narrows (Depth 122.8ft), San Juan Channel, Washington Current	NOS	PUG1723_3	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65389	Upright Channel narrows (Depth 116.3ft), San Juan Channel, Washington Current	NOS	PUG1723_4	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65390	Upright Channel narrows (Depth 109.7ft), San Juan Channel, Washington Current	NOS	PUG1723_5	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65391	Upright Channel narrows (Depth 103.1ft), San Juan Channel, Washington Current	NOS	PUG1723_6	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65393	Upright Channel narrows (Depth 90ft), San Juan Channel, Washington Current	NOS	PUG1723_8	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.366	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65394	Upright Channel narrows (Depth 83.5ft), San Juan Channel, Washington Current	NOS	PUG1723_9	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.363	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65395	Upright Channel narrows (Depth 76.9ft), San Juan Channel, Washington Current	NOS	PUG1723_10	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.359	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65396	Upright Channel narrows (Depth 70.3ft), San Juan Channel, Washington Current	NOS	PUG1723_11	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65397	Upright Channel narrows (Depth 63.8ft), San Juan Channel, Washington Current	NOS	PUG1723_12	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65398	Upright Channel narrows (Depth 57.2ft), San Juan Channel, Washington Current	NOS	PUG1723_13	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	231	41	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65404	South Haro Strait, south of Lime Kiln Light (Depth 211.8ft), Washington Current	NOS	PUG1724_27	48.4979705810546	-123.159896850585	:America/Los_Angeles	USA	knots	145	319	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
65405	South Haro Strait, south of Lime Kiln Light (Depth 159.4ft), Washington Current	NOS	PUG1724_29	48.4979705810546	-123.159896850585	:America/Los_Angeles	USA	knots	144	315	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
65406	South Haro Strait, south of Lime Kiln Light (Depth 106.9ft), Washington Current	NOS	PUG1724_31	48.4979705810546	-123.159896850585	:America/Los_Angeles	USA	knots	147	310	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
65410	Strait of Georgia, 4.5 nm SW of Point Roberts (Depth 188.5ft), Washington Current	NOS	PUG1726_11	48.9388885498046	-123.165130615234	:America/Los_Angeles	USA	knots	107	313	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
65411	Strait of Georgia, 4.5 nm SW of Point Roberts (Depth 70.4ft), Washington Current	NOS	PUG1726_29	48.9388885498046	-123.165130615234	:America/Los_Angeles	USA	knots	120	326	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
65412	Strait of Georgia, 4.5 nm SW of Point Roberts (Depth 31ft), Washington Current	NOS	PUG1726_35	48.9388885498046	-123.165130615234	:America/Los_Angeles	USA	knots	129	332	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
65413	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of) (Depth 165ft), Washington Current	NOS	PUG1727_10	48.4124908447265	-122.740257263183	:America/Los_Angeles	USA	knots	174	24	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of)	WA
65414	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of) (Depth 46.9ft), Washington Current	NOS	PUG1727_28	48.4124908447265	-122.740257263183	:America/Los_Angeles	USA	knots	186	20	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of)	WA
65415	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of) (Depth 33.7ft), Washington Current	NOS	PUG1727_30	48.4124908447265	-122.740257263183	:America/Los_Angeles	USA	knots	186	21	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of)	WA
65400	Upright Channel narrows (Depth 44.1ft), San Juan Channel, Washington Current	NOS	PUG1723_15	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65401	Upright Channel narrows (Depth 37.5ft), San Juan Channel, Washington Current	NOS	PUG1723_16	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65402	Upright Channel narrows (Depth 31ft), San Juan Channel, Washington Current	NOS	PUG1723_17	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65403	Upright Channel narrows (Depth 24.4ft), San Juan Channel, Washington Current	NOS	PUG1723_18	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	230	40	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65407	Cherry Point, 1.8 nm southeast of (Depth 40.8ft), Rosario Strait, Washington Current	NOS	PUG1725_10	48.8337898254394	-122.727928161621	:America/Los_Angeles	USA	knots	167	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
65408	Cherry Point, 1.8 nm southeast of (Depth 24.4ft), Rosario Strait, Washington Current	NOS	PUG1725_20	48.8337898254394	-122.727928161621	:America/Los_Angeles	USA	knots	161	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
65409	Cherry Point, 1.8 nm southeast of (Depth 8ft), Rosario Strait, Washington Current	NOS	PUG1725_30	48.8337898254394	-122.727928161621	:America/Los_Angeles	USA	knots	156	346	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
65416	Point Colville, 1.4 nm east of (Depth 134.3ft), Rosario Strait, Washington Current	NOS	PUG1728_10	48.418098449707	-122.781196594238	:America/Los_Angeles	USA	knots	205	38	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
65418	Point Colville, 1.4 nm east of (Depth 29.3ft), Rosario Strait, Washington Current	NOS	PUG1728_26	48.418098449707	-122.781196594238	:America/Los_Angeles	USA	knots	207	39	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
65419	Belle Rock Light, east of (Depth 114.7ft), Rosario Strait, Washington Current	NOS	PUG1729_7	48.4967918395996	-122.730796813964	:America/Los_Angeles	USA	knots	202	7	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
65420	Belle Rock Light, east of (Depth 62.2ft), Rosario Strait, Washington Current	NOS	PUG1729_15	48.4967918395996	-122.730796813964	:America/Los_Angeles	USA	knots	211	15	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.331	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
65421	Belle Rock Light, east of (Depth 22.8ft), Rosario Strait, Washington Current	NOS	PUG1729_21	48.4967918395996	-122.730796813964	:America/Los_Angeles	USA	knots	219	16	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.431	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
65422	Lopez Pass (Depth 57.9ft), Rosario Strait, Washington Current	NOS	PUG1730_4	48.4797401428222	-122.818908691406	:America/Los_Angeles	USA	knots	92	265	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
65423	Lopez Pass (Depth 35ft), Rosario Strait, Washington Current	NOS	PUG1730_11	48.4797401428222	-122.818908691406	:America/Los_Angeles	USA	knots	91	276	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
65424	Lopez Pass (Depth 15.3ft), Rosario Strait, Washington Current	NOS	PUG1730_17	48.4797401428222	-122.818908691406	:America/Los_Angeles	USA	knots	90	286	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
65425	Fauntleroy Point Light, east of (Depth 92.9ft), Rosario Strait, Washington Current	NOS	PUG1731_7	48.52158	-122.77066	:America/Los_Angeles	USA	knots	146	331	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
65426	Fauntleroy Point Light, east of (Depth 53.6ft), Rosario Strait, Washington Current	NOS	PUG1731_13	48.52158	-122.77066	:America/Los_Angeles	USA	knots	153	334	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.357	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
65427	Fauntleroy Point Light, east of (Depth 20.8ft), Rosario Strait, Washington Current	NOS	PUG1731_18	48.52158	-122.77066	:America/Los_Angeles	USA	knots	157	334	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.394	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
65428	Strawberry Island, west of (Depth 164.3ft), Rosario Strait, Washington Current	NOS	PUG1732_5	48.5609588623046	-122.754302978515	:America/Los_Angeles	USA	knots	156	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
65429	Strawberry Island, west of (Depth 46.2ft), Rosario Strait, Washington Current	NOS	PUG1732_23	48.5609588623046	-122.754302978515	:America/Los_Angeles	USA	knots	172	357	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.464	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
65430	Strawberry Island, west of (Depth 33.1ft), Rosario Strait, Washington Current	NOS	PUG1732_25	48.5609588623046	-122.754302978515	:America/Los_Angeles	USA	knots	174	356	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.463	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
65431	Thatcher Pass (Depth 146.1ft), Rosario Strait, Washington Current	NOS	PUG1733_4	48.5274314880371	-122.803970336914	:America/Los_Angeles	USA	knots	84	256	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.238	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
65432	Thatcher Pass (Depth 60.8ft), Rosario Strait, Washington Current	NOS	PUG1733_17	48.5274314880371	-122.803970336914	:America/Los_Angeles	USA	knots	90	255	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.386	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
65433	Thatcher Pass (Depth 28ft), Rosario Strait, Washington Current	NOS	PUG1733_22	48.5274314880371	-122.803970336914	:America/Los_Angeles	USA	knots	93	256	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
65434	Guemes Channel, west entrance (Depth 53.4ft), Rosario Strait, Washington Current	NOS	PUG1734_1	48.521240234375	-122.652183532714	:America/Los_Angeles	USA	knots	253	85	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, west entrance	WA
65437	Guemes Channel, east entrance (Depth 51.6ft), Rosario Strait, Washington Current	NOS	PUG1735_1	48.5276908874511	-122.606010437011	:America/Los_Angeles	USA	knots	253	75	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, east entrance	WA
65438	Guemes Channel, east entrance (Depth 25.4ft), Rosario Strait, Washington Current	NOS	PUG1735_9	48.5276908874511	-122.606010437011	:America/Los_Angeles	USA	knots	263	74	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, east entrance	WA
65439	Guemes Channel, east entrance (Depth 9ft), Rosario Strait, Washington Current	NOS	PUG1735_14	48.5276908874511	-122.606010437011	:America/Los_Angeles	USA	knots	268	75	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, east entrance	WA
65440	Saddle Bag Island Passage (Depth 238ft), Rosario Strait, Washington Current	NOS	PUG1736_1	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65441	Saddle Bag Island Passage (Depth 231.5ft), Rosario Strait, Washington Current	NOS	PUG1736_2	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65442	Saddle Bag Island Passage (Depth 224.9ft), Rosario Strait, Washington Current	NOS	PUG1736_3	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65443	Saddle Bag Island Passage (Depth 218.3ft), Rosario Strait, Washington Current	NOS	PUG1736_4	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.296	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65444	Saddle Bag Island Passage (Depth 211.8ft), Rosario Strait, Washington Current	NOS	PUG1736_5	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.283	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65445	Saddle Bag Island Passage (Depth 205.2ft), Rosario Strait, Washington Current	NOS	PUG1736_6	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65446	Saddle Bag Island Passage (Depth 198.7ft), Rosario Strait, Washington Current	NOS	PUG1736_7	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65447	Saddle Bag Island Passage (Depth 192.1ft), Rosario Strait, Washington Current	NOS	PUG1736_8	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.252	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65448	Saddle Bag Island Passage (Depth 185.5ft), Rosario Strait, Washington Current	NOS	PUG1736_9	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65450	Saddle Bag Island Passage (Depth 172.4ft), Rosario Strait, Washington Current	NOS	PUG1736_11	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65451	Saddle Bag Island Passage (Depth 165.8ft), Rosario Strait, Washington Current	NOS	PUG1736_12	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65452	Saddle Bag Island Passage (Depth 159.3ft), Rosario Strait, Washington Current	NOS	PUG1736_13	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65453	Saddle Bag Island Passage (Depth 152.7ft), Rosario Strait, Washington Current	NOS	PUG1736_14	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.216	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65454	Saddle Bag Island Passage (Depth 146.2ft), Rosario Strait, Washington Current	NOS	PUG1736_15	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65455	Saddle Bag Island Passage (Depth 139.6ft), Rosario Strait, Washington Current	NOS	PUG1736_16	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65474	Allan Pass (Depth 92.9ft), Washington Current	NOS	PUG1737_1	48.47159	-122.69982	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
65475	Allan Pass (Depth 20.8ft), Washington Current	NOS	PUG1737_23	48.47159	-122.69982	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.495	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
65457	Saddle Bag Island Passage (Depth 126.5ft), Rosario Strait, Washington Current	NOS	PUG1736_18	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65458	Saddle Bag Island Passage (Depth 119.9ft), Rosario Strait, Washington Current	NOS	PUG1736_19	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65459	Saddle Bag Island Passage (Depth 113.4ft), Rosario Strait, Washington Current	NOS	PUG1736_20	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65460	Saddle Bag Island Passage (Depth 106.8ft), Rosario Strait, Washington Current	NOS	PUG1736_21	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65461	Saddle Bag Island Passage (Depth 100.2ft), Rosario Strait, Washington Current	NOS	PUG1736_22	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65462	Saddle Bag Island Passage (Depth 93.7ft), Rosario Strait, Washington Current	NOS	PUG1736_23	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.167	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65463	Saddle Bag Island Passage (Depth 87.1ft), Rosario Strait, Washington Current	NOS	PUG1736_24	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	179	351	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65464	Saddle Bag Island Passage (Depth 80.5ft), Rosario Strait, Washington Current	NOS	PUG1736_25	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65465	Saddle Bag Island Passage (Depth 74ft), Rosario Strait, Washington Current	NOS	PUG1736_26	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65466	Saddle Bag Island Passage (Depth 67.4ft), Rosario Strait, Washington Current	NOS	PUG1736_27	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65467	Saddle Bag Island Passage (Depth 60.9ft), Rosario Strait, Washington Current	NOS	PUG1736_28	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65468	Saddle Bag Island Passage (Depth 54.3ft), Rosario Strait, Washington Current	NOS	PUG1736_29	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65469	Saddle Bag Island Passage (Depth 47.7ft), Rosario Strait, Washington Current	NOS	PUG1736_30	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	173	344	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65470	Saddle Bag Island Passage (Depth 41.2ft), Rosario Strait, Washington Current	NOS	PUG1736_31	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65471	Saddle Bag Island Passage (Depth 34.6ft), Rosario Strait, Washington Current	NOS	PUG1736_32	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.115	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65472	Saddle Bag Island Passage (Depth 28.1ft), Rosario Strait, Washington Current	NOS	PUG1736_33	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65476	Allan Pass (Depth 10.9ft), Washington Current	NOS	PUG1737_26	48.47159	-122.69982	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.475	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
65479	Burrows Pass (Depth 15.1ft), Washington Current	NOS	PUG1738_27	48.48952	-122.68672	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.423	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
65483	Bellingham Channel, off Cypress Head Light (Depth 119.2ft), Washington Current	NOS	PUG1740_10	48.5585403442382	-122.661758422851	:America/Los_Angeles	USA	knots	194	17	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.302	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
65484	Bellingham Channel, off Cypress Head Light (Depth 50.3ft), Washington Current	NOS	PUG1740_17	48.5585403442382	-122.661758422851	:America/Los_Angeles	USA	knots	191	18	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.457	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
65485	Bellingham Channel, off Cypress Head Light (Depth 30.6ft), Washington Current	NOS	PUG1740_19	48.5585403442382	-122.661758422851	:America/Los_Angeles	USA	knots	190	20	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.484	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
65495	Discovery Island, 3.0 nm NE of (Depth 159.5ft), Washington Current	NOS	PUG1744_13	48.4520683288574	-123.155441284179	:America/Los_Angeles	USA	knots	153	16	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.322	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
65482	Bellingham Channel South (Depth 19.4ft), Rosario Strait, Washington Current	NOS	PUG1739_31	48.53963	-122.68343	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.381	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
65486	Bellingham Channel North (Depth 171.2ft), Rosario Strait, Washington Current	NOS	PUG1741_5	48.5928115844726	-122.657676696777	:America/Los_Angeles	USA	knots	212	10	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North	WA
65487	Bellingham Channel North (Depth 46.5ft), Rosario Strait, Washington Current	NOS	PUG1741_24	48.5928115844726	-122.657676696777	:America/Los_Angeles	USA	knots	228	9	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North	WA
65488	Bellingham Channel North (Depth 26.8ft), Rosario Strait, Washington Current	NOS	PUG1741_27	48.5928115844726	-122.657676696777	:America/Los_Angeles	USA	knots	230	8	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North	WA
65489	Cattle Point, 1.2 nm SE of (Depth 117.4ft), San Juan Channel, Washington Current	NOS	PUG1742_15	48.4343681335449	-122.94660949707	:America/Los_Angeles	USA	knots	186	346	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
65490	Cattle Point, 1.2 nm SE of (Depth 78ft), San Juan Channel, Washington Current	NOS	PUG1742_18	48.4343681335449	-122.94660949707	:America/Los_Angeles	USA	knots	183	353	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
65491	Cattle Point, 1.2 nm SE of (Depth 38.6ft), San Juan Channel, Washington Current	NOS	PUG1742_21	48.4343681335449	-122.94660949707	:America/Los_Angeles	USA	knots	183	2	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
65492	Cattle Point, 4.6 nm SW of (Depth 186.6ft), San Juan Channel, Washington Current	NOS	PUG1743_14	48.3840103149414	-123.015670776367	:America/Los_Angeles	USA	knots	179	47	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
65493	Cattle Point, 4.6 nm SW of (Depth 104.6ft), San Juan Channel, Washington Current	NOS	PUG1743_19	48.3840103149414	-123.015670776367	:America/Los_Angeles	USA	knots	227	63	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
65494	Cattle Point, 4.6 nm SW of (Depth 55.4ft), San Juan Channel, Washington Current	NOS	PUG1743_22	48.3840103149414	-123.015670776367	:America/Los_Angeles	USA	knots	228	54	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.143	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
65496	Discovery Island, 3.0 nm NE of (Depth 67.7ft), Washington Current	NOS	PUG1744_20	48.4520683288574	-123.155441284179	:America/Los_Angeles	USA	knots	157	19	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
65497	Discovery Island, 3.0 nm NE of (Depth 41.4ft), Washington Current	NOS	PUG1744_22	48.4520683288574	-123.155441284179	:America/Los_Angeles	USA	knots	160	17	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
64653	Edmonds, 2.5 miles west of (Depth 251ft), Puget Sound, Washington Current	NOS	PUG1503_20	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64584	Agate Passage, south end (Depth 12ft), Puget Sound, Washington Current	NOS	PUG1501_5	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64590	Alki Point, 1 mile west of (Depth 614.2ft), Puget Sound, Washington Current	NOS	PUG1502_3	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64609	Alki Point, 1 mile west of (Depth 364.9ft), Puget Sound, Washington Current	NOS	PUG1502_22	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64610	Alki Point, 1 mile west of (Depth 351.8ft), Puget Sound, Washington Current	NOS	PUG1502_23	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64629	Alki Point, 1 mile west of (Depth 102.4ft), Puget Sound, Washington Current	NOS	PUG1502_42	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64630	Alki Point, 1 mile west of (Depth 89.3ft), Puget Sound, Washington Current	NOS	PUG1502_43	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64647	Edmonds, 2.5 miles west of (Depth 329.8ft), Puget Sound, Washington Current	NOS	PUG1503_14	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64650	Edmonds, 2.5 miles west of (Depth 290.4ft), Puget Sound, Washington Current	NOS	PUG1503_17	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64670	Ballard Locks entrance (Depth 25.7ft), Puget Sound, Washington Current	NOS	PUG1504_2	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64671	Ballard Locks entrance (Depth 22.4ft), Puget Sound, Washington Current	NOS	PUG1504_3	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64677	Eagle Harbor entrance (Depth 31.6ft), Puget Sound, Washington Current	NOS	PUG1505_1	47.619571685791	-122.495300292968	:America/Los_Angeles	USA	knots	0	0	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Harbor entrance	WA
65500	Point George, west of (Depth 52.9ft), San Juan Channel, Washington Current	NOS	PUG1745_24	48.5567092895507	-122.998481750488	:America/Los_Angeles	USA	knots	152	321	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
65501	Pear Point, east of (Depth 111.7ft), San Juan Channel, Washington Current	NOS	PUG1746_4	48.5113983154296	-122.952903747558	:America/Los_Angeles	USA	knots	203	30	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
65502	Pear Point, east of (Depth 59.2ft), San Juan Channel, Washington Current	NOS	PUG1746_8	48.5113983154296	-122.952903747558	:America/Los_Angeles	USA	knots	196	29	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.247	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
65503	Pear Point, east of (Depth 32.9ft), San Juan Channel, Washington Current	NOS	PUG1746_10	48.5113983154296	-122.952903747558	:America/Los_Angeles	USA	knots	192	22	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.291	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
64692	Harbor Island West (Depth 14.9ft), Puget Sound, Washington Current	NOS	PUG1507_11	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64695	Liberty Bay (entrance), Port Orchard (Depth 36.7ft), Puget Sound, Washington Current	NOS	PUG1508_1	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	110	296	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64712	Point Jefferson, east of (Depth 25.1ft), Puget Sound, Washington Current	NOS	PUG1509_8	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.176	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
65550	Camp Ellis, Saco River entrance, Maine	NOS	8418606	43.4617	-70.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.820000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP ELLIS, SACO RIVER	ME
64716	President Point, 1.5 miles east of (Depth 307.6ft), Puget Sound, Washington Current	NOS	PUG1511_20	47.76712	-122.4319	:America/Los_Angeles	USA	knots	331	161	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
69773	Point Phipp, Pearse Canal, Alaska Current	NOS	PCT2676_1	54.78333	-130.63333	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.3	00:23:00	\N	0.9	00:31:00	00:13:00	Point Phipp	AK
64731	Rich Passage, east end (Depth 11.2ft), Puget Sound, Washington Current	NOS	PUG1513_10	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	139	326	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64752	West Point, west of (Depth 28.9ft), Puget Sound, Washington Current	NOS	PUG1515_13	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64761	Alki Point, west of (Depth 168.9ft), Puget Sound, Washington Current	NOS	PUG1516_7	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64773	Blake Island, S of (Depth 240.6ft), Puget Sound, Washington Current	NOS	PUG1517_1	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.372	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64783	Blake Island, S of (Depth 142.1ft), Puget Sound, Washington Current	NOS	PUG1517_11	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64794	Blake Island, S of (Depth 33.9ft), Puget Sound, Washington Current	NOS	PUG1517_22	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.562	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64797	Anderson Point, east of, Colvos Passage (Depth 35.4ft), Puget Sound, Washington Current	NOS	PUG1518_19	47.43943	-122.52578	:America/Los_Angeles	USA	knots	356	183	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.537	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, east of, Colvos Passage	WA
64813	Point Richmond, east of, Colvos Passage (Depth 70.5ft), Puget Sound, Washington Current	NOS	PUG1519_16	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.589	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64832	Browns Point, 1.6 miles north of (Depth 303.4ft), Puget Sound, Washington Current	NOS	PUG1521_13	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.204	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64833	Browns Point, 1.6 miles north of (Depth 290.3ft), Puget Sound, Washington Current	NOS	PUG1521_14	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	47	228	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64852	Browns Point, 1.6 miles north of (Depth 41ft), Puget Sound, Washington Current	NOS	PUG1521_33	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.209	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64865	Dalco Passage (Depth 128.1ft), Puget Sound, Washington Current	NOS	PUG1522_12	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	130	293	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.408	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64873	Dalco Passage (Depth 75.6ft), Puget Sound, Washington Current	NOS	PUG1522_20	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.486	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64886	Gig Harbor entrance (Depth 40.4ft), Puget Sound, Washington Current	NOS	PUG1523_5	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64894	Gig Harbor entrance (Depth 14.1ft), Puget Sound, Washington Current	NOS	PUG1523_13	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64909	The Narrows, 0.3 miles north of bridge (Depth 121.2ft), Puget Sound, Washington Current	NOS	PUG1527_4	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64913	The Narrows, 0.3 miles north of bridge (Depth 94.9ft), Puget Sound, Washington Current	NOS	PUG1527_8	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64923	The Narrows, 0.3 miles north of bridge (Depth 29.3ft), Puget Sound, Washington Current	NOS	PUG1527_18	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64932	The Narrows, south end (midstream) (Depth 91.8ft), Puget Sound, Washington Current	NOS	PUG1528_7	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64933	The Narrows, south end (midstream) (Depth 85.2ft), Puget Sound, Washington Current	NOS	PUG1528_8	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64952	Hale Passage, west end (Depth 53.2ft), Puget Sound, Washington Current	NOS	PUG1530_6	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.436	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64964	Hale Passage, west end (Depth 13.9ft), Puget Sound, Washington Current	NOS	PUG1530_18	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	105	283	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64972	Gibson Point, 0.8 miles east of (Depth 139.5ft), Puget Sound, Washington Current	NOS	PUG1531_7	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64973	Gibson Point, 0.8 miles east of (Depth 129.7ft), Puget Sound, Washington Current	NOS	PUG1531_8	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64992	Steilacoom, 0.8 miles north of (Depth 137.4ft), Puget Sound, Washington Current	NOS	PUG1532_9	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
65003	Ketron Island, west of (Depth 234.7ft), Puget Sound, Washington Current	NOS	PUG1533_3	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.162	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65012	Ketron Island, west of (Depth 116.6ft), Puget Sound, Washington Current	NOS	PUG1533_12	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65017	Ketron Island, west of (Depth 51ft), Puget Sound, Washington Current	NOS	PUG1533_17	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65032	Dana Passage (Depth 16.2ft), Puget Sound, Washington Current	NOS	PUG1539_12	47.163101196289	-122.868103027343	:America/Los_Angeles	USA	knots	49	242	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.176	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
65046	Peale Passage, north end (Depth 17.1ft), Puget Sound, Washington Current	NOS	PUG1542_1	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	132	326	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65052	Squaxin Passage, north of Hunter Point (Depth 31.5ft), Puget Sound, Washington Current	NOS	PUG1543_1	47.17626953125	-122.918998718261	:America/Los_Angeles	USA	knots	107	291	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, north of Hunter Point	WA
65068	Pickering Passage, west of Squaxin Island (Depth 52.1ft), Puget Sound, Washington Current	NOS	PUG1546_1	47.2192802429199	-122.934516906738	:America/Los_Angeles	USA	knots	13	191	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, west of Squaxin Island	WA
65071	Pickering Passage, off Graham Point (Depth 59ft), Puget Sound, Washington Current	NOS	PUG1547_1	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	27	207	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65090	Pickering Passage, north end (Depth 64.7ft), Puget Sound, Washington Current	NOS	PUG1548_3	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65109	Port Gamble Bay entrance (Depth 9.5ft), Hood Canal, Washington Current	NOS	PUG1604_8	47.8547210693359	-122.578178405761	:America/Los_Angeles	USA	knots	14	197	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gamble Bay entrance	WA
65113	Point No Point, 1.2 mi. E of (Depth 567.3ft), Puget Sound, Washington Current	NOS	PUG1606_1	47.9124908447265	-122.501968383789	:America/Los_Angeles	USA	knots	321	149	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
65114	Point No Point, 1.2 mi. E of (Depth 107.9ft), Puget Sound, Washington Current	NOS	PUG1606_36	47.9124908447265	-122.501968383789	:America/Los_Angeles	USA	knots	338	164	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.285	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
65130	Olele Point, 1.8 mi. ENE of (Depth 23.6ft), Admiralty Inlet, Washington Current	NOS	PUG1611_48	47.9788093566894	-122.64549255371	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.166	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
65150	Marrowstone Point, 0.8 mi. NE of (Depth 150.8ft), Admiralty Inlet, Washington Current	NOS	PUG1619_9	48.106330871582	-122.672470092773	:America/Los_Angeles	USA	knots	344	119	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.269	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
65165	Point Wilson, 2.7 mi. NE of (Depth 118.2ft), Admiralty Inlet, Washington Current	NOS	PUG1625_15	48.1670684814453	-122.707389831542	:America/Los_Angeles	USA	knots	333	135	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
65167	Point Wilson, 2.7 mi. NE of (Depth 19.8ft), Admiralty Inlet, Washington Current	NOS	PUG1625_45	48.1670684814453	-122.707389831542	:America/Los_Angeles	USA	knots	333	138	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
65186	Smith Island, 5.5 mi. WNW of (Depth 220ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1632_14	48.3245506286621	-122.964752197265	:America/Los_Angeles	USA	knots	253	78	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
65197	Smith Island, 3.4 mi. ESE of (Depth 19.6ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_36	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	218	114	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.663	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65210	Angeles Pt., 2 mi. NNE of (Depth 60.9ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1639_1	48.1769981384277	-123.526947021484	:America/Los_Angeles	USA	knots	304	69	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
65223	Deception Pass (Narrows) (Depth 66.8ft), Rosario Strait, Washington Current	NOS	PUG1701_18	48.4061889648437	-122.643119812011	:America/Los_Angeles	USA	knots	270	96	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
65246	Peavine Pass, west entrance (Depth 48.1ft), Rosario Strait, Washington Current	NOS	PUG1704_1	48.5870780944824	-122.819259643554	:America/Los_Angeles	USA	knots	235	50	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.401	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
65255	Peapod Rocks Light, 1.2 nm south of (Depth 130.6ft), Rosario Strait, Washington Current	NOS	PUG1706_4	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.225	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65263	Sinclair Island, 1.0 nm NE of (Depth 170.7ft), Rosario Strait, Washington Current	NOS	PUG1707_6	48.6441993713378	-122.658721923828	:America/Los_Angeles	USA	knots	131	327	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
65265	Sinclair Island, 1.0 nm NE of (Depth 26.3ft), Rosario Strait, Washington Current	NOS	PUG1707_28	48.6441993713378	-122.658721923828	:America/Los_Angeles	USA	knots	131	324	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
65282	Clark Island, 1.6 nm north of (Depth 179.6ft), Rosario Strait, Washington Current	NOS	PUG1709_10	48.7312583923339	-122.773376464843	:America/Los_Angeles	USA	knots	150	333	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
65300	Parker Reef Light, north of (Depth 129.8ft), Rosario Strait, Washington Current	NOS	PUG1712_10	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	280	91	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65304	Parker Reef Light, north of (Depth 103.5ft), Rosario Strait, Washington Current	NOS	PUG1712_14	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65321	Patos Island Light, 1.4 nm west of (Depth 98.9ft), Rosario Strait, Washington Current	NOS	PUG1714_23	48.7731285095214	-123.005790710449	:America/Los_Angeles	USA	knots	215	44	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.469	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
65339	Spring Passage, south entrance (Depth 26.2ft), San Juan Channel, Washington Current	NOS	PUG1720_22	48.6115417480468	-123.034103393554	:America/Los_Angeles	USA	knots	149	2	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
65374	Harney Channel, north of Point Hudson (Depth 46ft), San Juan Channel, Washington Current	NOS	PUG1722_17	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65381	Harney Channel, north of Point Hudson (Depth 23ft), San Juan Channel, Washington Current	NOS	PUG1722_24	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65392	Upright Channel narrows (Depth 96.6ft), San Juan Channel, Washington Current	NOS	PUG1723_7	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	232	43	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65399	Upright Channel narrows (Depth 50.7ft), San Juan Channel, Washington Current	NOS	PUG1723_14	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.339	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65417	Point Colville, 1.4 nm east of (Depth 55.5ft), Rosario Strait, Washington Current	NOS	PUG1728_22	48.418098449707	-122.781196594238	:America/Los_Angeles	USA	knots	207	41	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
65435	Guemes Channel, west entrance (Depth 23.9ft), Rosario Strait, Washington Current	NOS	PUG1734_10	48.521240234375	-122.652183532714	:America/Los_Angeles	USA	knots	253	83	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, west entrance	WA
65436	Guemes Channel, west entrance (Depth 10.8ft), Rosario Strait, Washington Current	NOS	PUG1734_14	48.521240234375	-122.652183532714	:America/Los_Angeles	USA	knots	252	83	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.739	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, west entrance	WA
65449	Saddle Bag Island Passage (Depth 179ft), Rosario Strait, Washington Current	NOS	PUG1736_10	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65456	Saddle Bag Island Passage (Depth 133ft), Rosario Strait, Washington Current	NOS	PUG1736_17	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65473	Saddle Bag Island Passage (Depth 21.5ft), Rosario Strait, Washington Current	NOS	PUG1736_34	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	166	342	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65480	Bellingham Channel South (Depth 117.8ft), Rosario Strait, Washington Current	NOS	PUG1739_1	48.53963	-122.68343	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
65481	Bellingham Channel South (Depth 32.5ft), Rosario Strait, Washington Current	NOS	PUG1739_27	48.53963	-122.68343	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
65498	Point George, west of (Depth 282.6ft), San Juan Channel, Washington Current	NOS	PUG1745_10	48.5567092895507	-122.998481750488	:America/Los_Angeles	USA	knots	139	327	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
65499	Point George, west of (Depth 118.5ft), San Juan Channel, Washington Current	NOS	PUG1745_20	48.5567092895507	-122.998481750488	:America/Los_Angeles	USA	knots	155	318	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
69074	Old Man Shoal, Nantucket Shoals, Massachusetts Current	NOS	ACT1591_1	41.22667	-69.98333	:America/New_York	USA	knots	225	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:14:00	\N	0.9	01:03:00	\N	0.9	01:23:00	01:17:00	Old Man Shoal, Nantucket Shoals	MA
69075	Miacomet Pond, 3.0 miles SSE of, Massachusetts Current	NOS	ACT1596_1	41.19	-70.09667	:America/New_York	USA	knots	280	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:16:00	\N	0.8	02:03:00	\N	0.6	02:19:00	02:22:00	Miacomet Pond, 3.0 miles SSE of	MA
69076	Tuckernuck Island, 4.2 miles SSW of, Massachusetts Current	NOS	ACT1601_1	41.22617	-70.28167	:America/New_York	USA	knots	280	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:56:00	\N	0.6	03:13:00	\N	0.3	04:08:00	02:17:00	Tuckernuck Island, 4.2 miles SSW of	MA
69077	Pollock Rip Channel, east end, Nantucket Sound entrance, Massachusetts Current	NOS	ACT1611_1	41.565	-69.92333	:America/New_York	USA	knots	212	53	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:38:00	\N	1.1	-00:39:00	\N	1	-00:14:00	-00:23:00	Pollock Rip Channel, east end	MA
69078	Monomoy Pt., channel 0.2 mile west of, Nantucket Sound, Massachusetts Current	NOS	ACT1626_1	41.55	-70.02167	:America/New_York	USA	knots	346	170	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:23:00	\N	1.2	00:39:00	\N	0.8	00:00:00	00:18:00	Monomoy Pt., channel 0.2 mile west of	MA
69079	Stage Harbor, west of Morris Island, Nantucket Sound, Massachusetts Current	NOS	ACT1636_1	41.65667	-69.975	:America/New_York	USA	knots	144	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:28:00	\N	0.6	01:29:00	\N	0.3	03:07:00	02:24:00	Stage Harbor, west of Morris Island	MA
69080	Dennis Port, 2.2 miles south of, Nantucket Sound, Massachusetts Current	NOS	ACT1641_1	41.61667	-70.115	:America/New_York	USA	knots	269	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:04:00	\N	0.2	00:52:00	\N	0.2	01:28:00	00:27:00	Dennis Port, 2.2 miles south of	MA
69081	Monomoy Point, 6 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1646_1	41.55833	-70.15	:America/New_York	USA	knots	275	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:22:00	\N	0.3	01:52:00	\N	0.2	01:22:00	01:09:00	Monomoy Point, 6 miles west of	MA
69082	Handkerchief Lighted Whistle Buoy 'H', Nantucket Sound, Massachusetts Current	NOS	ACT1651_1	41.48833	-70.06667	:America/New_York	USA	knots	251	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:59:00	\N	0.8	01:10:00	\N	0.6	01:08:00	00:49:00	Handkerchief Lighted Whistle Buoy 'H'	MA
69083	Halfmoon Shoal, 1.9 miles northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1656_1	41.48417	-70.1925	:America/New_York	USA	knots	265	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:44:00	\N	0.3	01:49:00	\N	0.4	01:42:00	01:24:00	Halfmoon Shoal, 1.9 miles northeast of	MA
69084	Halfmoon Shoal, 3.5 miles east of, Nantucket Sound, Massachusetts Current	NOS	ACT1661_1	41.46833	-70.15333	:America/New_York	USA	knots	295	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:11:00	\N	0.6	01:23:00	\N	0.5	01:13:00	01:06:00	Halfmoon Shoal, 3.5 miles east of	MA
69085	Great Point, 0.5 mile west of, Nantucket Sound, Massachusetts Current	NOS	ACT1666_1	41.39333	-70.06167	:America/New_York	USA	knots	195	29	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:33:00	\N	0.7	01:37:00	\N	0.6	00:25:00	01:13:00	Great Point, 0.5 mile west of	MA
69086	Great Point, 3 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1671_1	41.39	-70.11333	:America/New_York	USA	knots	248	66	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:08:00	\N	0.5	01:23:00	\N	0.4	01:15:00	00:51:00	Great Point, 3 miles west of	MA
69087	Tuckernuck Shoal, off east end, Nantucket Sound, Massachusetts Current	NOS	ACT1676_1	41.405	-70.17333	:America/New_York	USA	knots	287	113	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:10:00	\N	0.5	01:34:00	\N	0.5	01:22:00	01:09:00	Tuckernuck Shoal, off east end	MA
69088	Nantucket Harbor entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1686_1	41.30667	-70.1	:America/New_York	USA	knots	350	171	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:58:00	\N	0.9	01:55:00	\N	0.6	03:22:00	02:44:00	Nantucket Harbor entrance channel	MA
69089	Eel Pt., Nantucket I. 2.5 miles NE of, Nantucket Sound, Massachusetts Current	NOS	ACT1691_1	41.32167	-70.17	:America/New_York	USA	knots	284	94	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:15:00	\N	0.2	01:12:00	\N	0.3	01:13:00	01:02:00	Eel Pt., Nantucket I. 2.5 miles NE of	MA
69090	Muskeget I., channel 1 mile northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1696_1	41.35	-70.285	:America/New_York	USA	knots	295	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:56:00	\N	0.9	00:45:00	\N	0.6	01:29:00	00:57:00	Muskeget I., channel 1 mile northeast of	MA
69091	Muskeget Rock, 1.3 miles southwest of, Nantucket Sound, Massachusetts Current	NOS	ACT1701_1	41.32	-70.39333	:America/New_York	USA	knots	192	24	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:18:00	\N	0.6	00:23:00	\N	0.6	01:10:00	00:57:00	Muskeget Rock, 1.3 miles southwest of	MA
69092	Muskeget Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1706_1	41.34833	-70.42	:America/New_York	USA	knots	200	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:02:00	\N	1.9	00:38:00	\N	1.9	01:40:00	01:29:00	Muskeget Channel	MA
69093	Long Shoal-Norton Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1716_1	41.40833	-70.33333	:America/New_York	USA	knots	260	100	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:13:00	\N	0.6	01:12:00	\N	0.7	01:31:00	01:26:00	Long Shoal-Norton Shoal, between	MA
69094	Cape Poge Lt., 1.7 miles SSE of, Nantucket Sound, Massachusetts Current	NOS	ACT1721_1	41.4	-70.42667	:America/New_York	USA	knots	215	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:48:00	\N	0.7	-00:07:00	\N	0.8	00:58:00	00:49:00	Cape Poge Lt., 1.7 miles SSE of	MA
69095	Cross Rip Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1726_1	41.44833	-70.29167	:America/New_York	USA	knots	272	91	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:59:00	\N	0.5	01:48:00	\N	0.6	01:48:00	01:55:00	Cross Rip Channel	MA
69096	Cape Poge Lt., 3.2 miles northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1731_1	41.45833	-70.4	:America/New_York	USA	knots	300	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:37:00	\N	0.7	02:03:00	\N	0.8	02:42:00	02:33:00	Cape Poge Lt., 3.2 miles northeast of	MA
69097	Broken Ground-Horseshoe Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1736_1	41.55	-70.285	:America/New_York	USA	knots	276	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:20:00	\N	0.5	01:55:00	\N	0.5	01:46:00	01:15:00	Broken Ground-Horseshoe Shoal, between	MA
69098	Point Gammon, 1.2 miles south of, Nantucket Sound, Massachusetts Current	NOS	ACT1741_1	41.58833	-70.25667	:America/New_York	USA	knots	260	105	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:02:00	\N	0.6	01:03:00	\N	0.5	01:15:00	01:06:00	Point Gammon, 1.2 miles south of	MA
69099	Lewis Bay entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1751_1	41.63167	-70.27333	:America/New_York	USA	knots	184	4	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:22:00	\N	0.8	00:53:00	\N	0.5	02:46:00	02:44:00	Lewis Bay entrance channel	MA
69100	Cotuit Bay entrance (Bluff Point), Nantucket Sound, Massachusetts Current	NOS	ACT1756_1	41.61	-70.43	:America/New_York	USA	knots	218	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:35:00	\N	0.4	02:33:00	\N	0.3	02:44:00	02:51:00	Cotuit Bay entrance (Bluff Point)	MA
69101	Wreck Shoal-Eldridge Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1761_1	41.53333	-70.42833	:America/New_York	USA	knots	245	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:45:00	\N	0.8	01:32:00	\N	0.8	01:47:00	01:44:00	Wreck Shoal-Eldridge Shoal, between	MA
69102	Hedge Fence Lighted Gong Buoy 22, Nantucket Sound, Massachusetts Current	NOS	ACT1766_1	41.47167	-70.48333	:America/New_York	USA	knots	268	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:44:00	\N	0.7	02:34:00	\N	0.7	02:48:00	02:38:00	Hedge Fence Lighted Gong Buoy 22	MA
69103	Cape Poge Light, 1.4 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1771_1	41.42417	-70.48333	:America/New_York	USA	knots	250	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:39:00	\N	0.1	01:54:00	\N	0.2	02:13:00	01:26:00	Cape Poge Light, 1.4 miles west of	MA
69104	East Chop-Squash Meadow, between, Nantucket Sound, Massachusetts Current	NOS	ACT1786_1	41.465	-70.53667	:America/New_York	USA	knots	329	131	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:04:00	\N	1.1	00:55:00	\N	0.7	02:07:00	01:43:00	East Chop-Squash Meadow, between	MA
69105	East Chop, 1 mile north of, Nantucket Sound, Massachusetts Current	NOS	ACT1791_1	41.485	-70.55833	:America/New_York	USA	knots	297	116	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	1.3	01:52:00	\N	1.1	02:40:00	02:17:00	East Chop, 1 mile north of	MA
69106	West Chop, 0.8 mile north of, Nantucket Sound, Massachusetts Current	NOS	ACT1801_1	41.49333	-70.595	:America/New_York	USA	knots	282	96	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:35:00	\N	1.8	01:58:00	\N	1.6	02:49:00	02:20:00	West Chop, 0.8 mile north of	MA
69107	Hedge Fence-L'Hommedieu Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1806_1	41.505	-70.53667	:America/New_York	USA	knots	276	106	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:52:00	\N	1.3	01:38:00	\N	1	02:27:00	02:01:00	Hedge Fence-L'Hommedieu Shoal, between	MA
69108	Waquoit Bay entrance, Nantucket Sound, Massachusetts Current	NOS	ACT1811_1	41.54833	-70.53	:America/New_York	USA	knots	203	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:01:00	\N	0.8	02:14:00	\N	0.8	03:21:00	03:40:00	Waquoit Bay entrance	MA
69109	L'Hommedieu Shoal, north of west end, Nantucket Sound, Massachusetts Current	NOS	ACT1816_1	41.52667	-70.57667	:America/New_York	USA	knots	268	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	1.4	02:03:00	\N	1.2	02:30:00	02:12:00	L'Hommedieu Shoal, north of west end	MA
69110	Nobska Point, 1.8 miles east of, Nantucket Sound, Massachusetts Current	NOS	ACT1821_1	41.51833	-70.61833	:America/New_York	USA	knots	240	63	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:49:00	\N	1	01:45:00	\N	1.2	02:13:00	01:55:00	Nobska Point, 1.8 miles east of	MA
69111	West Chop, 0.2 mile west of, Vineyard Sound, Massachusetts Current	NOS	ACT1826_1	41.48333	-70.61	:America/New_York	USA	knots	241	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:16:00	\N	0.8	01:34:00	\N	1.3	01:19:00	01:50:00	West Chop, 0.2 mile west of	MA
69112	Nobska Point, 1 mile southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1831_1	41.50167	-70.64333	:America/New_York	USA	knots	259	71	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:19:00	\N	1.4	02:15:00	\N	1.3	02:33:00	02:25:00	Nobska Point, 1 mile southeast of	MA
69113	Norton Point, 0.5 mile north of, Vineyard Sound, Massachusetts Current	NOS	ACT1836_1	41.46833	-70.665	:America/New_York	USA	knots	240	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:12:00	\N	1.4	01:44:00	\N	1.7	01:55:00	02:01:00	Norton Point, 0.5 mile north of	MA
69114	Tarpaulin Cove, 1.5 miles east of, Vineyard Sound, Massachusetts Current	NOS	ACT1841_1	41.47167	-70.725	:America/New_York	USA	knots	232	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:33:00	\N	1.4	02:07:00	\N	1	02:49:00	02:12:00	Tarpaulin Cove, 1.5 miles east of	MA
69115	Robinsons Hole, 1.2 miles southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1846_1	41.435	-70.78	:America/New_York	USA	knots	240	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:02:00	\N	1.2	01:51:00	\N	1	02:30:00	02:11:00	Robinsons Hole, 1.2 miles southeast of	MA
69116	Gay Head, 3 miles northeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1851_1	41.385	-70.78333	:America/New_York	USA	knots	238	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	0.8	01:50:00	\N	0.5	02:25:00	01:42:00	Gay Head, 3 miles northeast of	MA
69117	Gay Head, 3 miles north of, Vineyard Sound, Massachusetts Current	NOS	ACT1861_1	41.40167	-70.85333	:America/New_York	USA	knots	255	74	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:17:00	\N	0.7	01:24:00	\N	0.6	02:13:00	01:55:00	Gay Head, 3 miles north of	MA
69118	Gay Head, 1.5 miles northwest of, Vineyard Sound, Massachusetts Current	NOS	ACT1866_1	41.36333	-70.86333	:America/New_York	USA	knots	249	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:16:00	\N	1.2	00:54:00	\N	1	01:30:00	01:42:00	Gay Head, 1.5 miles northwest of	MA
69119	Black Point, SW of, Sakonnet River (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2071_1	41.50667	-71.22	:America/New_York	USA	knots	194	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:26:00	\N	0.2	-01:55:00	\N	0.2	-02:54:00	-02:13:00	Black Point, SW of, Sakonnet River	RI
69120	Almy Point Bridge, south of, Sakonnet River (Depth 15ft), Rhode Island Current	NOS	ACT2076_1	41.62167	-71.22	:America/New_York	USA	knots	180	34	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-03:13:00	\N	0.8	-02:10:00	\N	0.2	-03:00:00	-02:30:00	Almy Point Bridge, south of, Sakonnet River	RI
69121	Brenton Point, 1.4 n.mi. southwest of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2096_1	41.43167	-71.37667	:America/New_York	USA	knots	170	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:04:00	\N	0.4	-00:38:00	\N	0.2	-01:03:00	-01:20:00	Brenton Point, 1.4 n.mi. southwest of	RI
69122	Castle Hill, west of, East Passage (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2101_1	41.45667	-71.37833	:America/New_York	USA	knots	237	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:29:00	\N	0.7	-00:42:00	\N	0.4	-00:06:00	-01:07:00	Castle Hill, west of, East Passage	RI
69123	Bull Point, east of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2106_1	41.48	-71.35	:America/New_York	USA	knots	206	1	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:33:00	\N	0.8	-00:47:00	\N	0.6	-01:10:00	-01:10:00	Bull Point, east of	RI
69124	Rose Island, northeast of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2121_1	41.50333	-71.33167	:America/New_York	USA	knots	124	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:08:00	\N	0.5	-00:07:00	\N	0.4	-01:57:00	-01:17:00	Rose Island, northeast of	RI
69125	Rose Island, northwest of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2126_1	41.50667	-71.35167	:America/New_York	USA	knots	190	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:39:00	\N	0.5	-00:26:00	\N	0.4	-01:38:00	-01:38:00	Rose Island, northwest of	RI
69126	Rose Island, west of, Narragansett Bay, Rhode Island Current	NOS	ACT2131_1	41.49667	-71.35	:America/New_York	USA	knots	172	1	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:28:00	\N	0.6	-00:34:00	\N	0.4	-00:42:00	-01:20:00	Rose Island, west of	RI
69127	Gould Island, southeast of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2136_1	41.525	-71.33667	:America/New_York	USA	knots	217	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:16:00	\N	0.4	-01:28:00	\N	0.3	-01:40:00	-01:14:00	Gould Island, southeast of	RI
69128	Gould Island, west of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2141_1	41.53167	-71.35833	:America/New_York	USA	knots	193	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:07:00	\N	0.4	-00:32:00	\N	0.3	-00:16:00	-01:13:00	Gould Island, west of	RI
69129	Dyer Island-Carrs Point (between), Narragansett Bay, Rhode Island Current	NOS	ACT2146_1	41.575	-71.29667	:America/New_York	USA	knots	236	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:37:00	\N	0.4	-01:13:00	\N	0.4	-01:56:00	-00:50:00	Dyer Island-Carrs Point (between)	RI
69130	Conanicut Point, ENE of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2151_1	41.575	-71.34167	:America/New_York	USA	knots	183	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:13:00	\N	0.2	-00:24:00	\N	0.2	-02:05:00	-01:18:00	Conanicut Point, ENE of	RI
69131	Dyer Island, west of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2156_1	41.58667	-71.30833	:America/New_York	USA	knots	216	23	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:34:00	\N	0.6	-00:46:00	\N	0.4	-01:04:00	-00:53:00	Dyer Island, west of	RI
69132	Mount Hope Bridge (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2166_1	41.64	-71.25833	:America/New_York	USA	knots	230	47	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:58:00	\N	0.8	-01:34:00	\N	0.6	-01:22:00	-01:08:00	Mount Hope Bridge	RI
69133	Hog Island, northwest of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2171_1	41.64667	-71.295	:America/New_York	USA	knots	199	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:04:00	\N	0.2	-00:04:00	\N	0.2	-02:16:00	-00:30:00	Hog Island, northwest of	RI
69134	Common Fence Point, west of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2176_1	41.65	-71.245	:America/New_York	USA	knots	224	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:37:00	\N	0.4	00:08:00	\N	0.2	-01:13:00	-01:00:00	Common Fence Point, west of	RI
69135	Mount Hope Point, northeast of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2181_1	41.68	-71.21167	:America/New_York	USA	knots	217	38	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:57:00	\N	0.2	-00:20:00	\N	0.2	-02:01:00	-01:03:00	Mount Hope Point, northeast of	RI
69136	Warren, Warren River, Narragansett Bay, Rhode Island Current	NOS	ACT2196_1	41.72833	-71.28833	:America/New_York	USA	knots	171	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:05:00	\N	0.5	00:11:00	\N	0.5	-00:14:00	-00:22:00	Warren, Warren River	RI
69137	Beavertail Point, 0.8 mile northwest of, Narragansett Bay, Rhode Island Current	NOS	ACT2201_1	41.45833	-71.41167	:America/New_York	USA	knots	188	3	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:19:00	\N	0.6	-00:54:00	\N	0.3	-00:11:00	-01:31:00	Beavertail Point, 0.8 mile northwest of	RI
69138	Dutch Island and Beaver Head, between, Narragansett Bay, Rhode Island Current	NOS	ACT2211_1	41.49667	-71.40333	:America/New_York	USA	knots	233	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:47:00	\N	0.6	-01:32:00	\N	0.5	-01:56:00	-01:58:00	Dutch Island and Beaver Head, between	RI
69139	Dutch Island, west of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2216_1	41.505	-71.41	:America/New_York	USA	knots	206	14	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:16:00	\N	0.7	-01:49:00	\N	0.7	-01:33:00	-01:21:00	Dutch Island, west of	RI
69140	Patience Island, narrows east of, Narragansett Bay, Rhode Island Current	NOS	ACT2236_1	41.65833	-71.35333	:America/New_York	USA	knots	157	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:37:00	\N	0.5	-02:29:00	\N	0.4	-02:41:00	-02:44:00	Patience Island, narrows east of	RI
69141	Patience I. and Warwick Neck, between, Narragansett Bay, Rhode Island Current	NOS	ACT2241_1	41.66333	-71.37333	:America/New_York	USA	knots	224	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:13:00	\N	0.5	-01:21:00	\N	0.3	-01:40:00	-01:18:00	Patience I. and Warwick Neck, between	RI
69142	Nayatt Point, WNW of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2246_1	41.72833	-71.36	:America/New_York	USA	knots	128	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:11:00	\N	0.1	00:47:00	\N	0.1	-02:24:00	-01:00:00	Nayatt Point, WNW of	RI
69143	Cryders Point, 0.4 mile NNW of, East River, New York Current	NOS	ACT3341_1	40.80033	-73.79867	:America/New_York	USA	knots^2	285	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:00:00	\N	0.2	-00:43:00	\N	0.4	-00:29:00	-00:30:00	Cryders Point, 0.4 mile NNW of	NY
69144	Bronx-Whitestone Bridge, East of (Depth 14ft), East River, New York Current	NOS	ACT3346_1	40.80167	-73.82667	:America/New_York	USA	knots^2	247	76	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:27:00	\N	0.2	-00:46:00	\N	0.5	-00:34:00	-00:10:00	Bronx-Whitestone Bridge, East of	NY
69145	College Point Reef, 0.25 n.mi. NW of (Depth 15ft), East River, New York Current	NOS	ACT3356_1	40.801	-73.85467	:America/New_York	USA	knots^2	261	74	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:00:00	\N	0.3	-00:47:00	\N	0.4	-00:27:00	-00:32:00	College Point Reef, 0.25 n.mi. NW of	NY
69146	Rikers I. chan., off La Guardia Field, East River, New York Current	NOS	ACT3366_1	40.78333	-73.88333	:America/New_York	USA	knots^2	261	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:08:00	\N	0.3	-00:04:00	\N	0.3	00:04:00	00:04:00	Rikers I. chan., off La Guardia Field	NY
69147	Hunts Point, southwest of, East River, New York Current	NOS	ACT3376_1	40.8	-73.88333	:America/New_York	USA	knots^2	280	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:05:00	\N	0.3	-00:10:00	\N	0.5	00:01:00	00:01:00	Hunts Point, southwest of	NY
69148	South Brother Island, NW of (Depth 15ft), East River, New York Current	NOS	ACT3381_1	40.79667	-73.90167	:America/New_York	USA	knots^2	252	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:12:00	\N	0.3	00:04:00	\N	0.4	-00:17:00	-00:06:00	South Brother Island, NW of	NY
69149	Off Winthrop Ave., Astoria, East River, New York Current	NOS	ACT3386_1	40.78667	-73.91667	:America/New_York	USA	knots^2	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.5	00:02:00	\N	1	00:04:00	-00:01:00	Off Winthrop Ave., Astoria	NY
69150	Mill Rock, northeast of, East River, New York Current	NOS	ACT3391_1	40.78167	-73.93667	:America/New_York	USA	knots^2	288	103	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:32:00	\N	0.1	00:05:00	\N	0.7	-00:23:00	-00:29:00	Mill Rock, northeast of	NY
69151	Mill Rock, west of, East River, New York Current	NOS	ACT3396_1	40.78	-73.94167	:America/New_York	USA	knots^2	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:17:00	\N	0.2	00:08:00	\N	0.4	-00:26:00	-00:02:00	Mill Rock, west of	NY
69152	Roosevelt Island, west of, off 75th Street, East River, New York Current	NOS	ACT3406_1	40.76667	-73.95	:America/New_York	USA	knots^2	215	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	1	-00:04:00	\N	1.1	-00:02:00	-00:08:00	west of, off 75th Street	NY
69153	Roosevelt Island, east of, off 36th Avenue, East River, New York Current	NOS	ACT3411_1	40.76667	-73.95	:America/New_York	USA	knots^2	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.7	-00:04:00	\N	1	-00:08:00	-00:08:00	east of, off 36th Avenue	NY
69154	Roosevelt Island, west of, off 67th Street, East River, New York Current	NOS	ACT3416_1	40.76233	-73.954	:America/New_York	USA	knots^2	230	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:11:00	\N	0.9	-00:08:00	\N	1.1	00:13:00	00:06:00	west of, off 67th Street	NY
69155	Roosevelt Island, west of, off 63rd Street, East River, New York Current	NOS	ACT3421_1	40.75967	-73.9545	:America/New_York	USA	knots^2	223	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:03:00	\N	0.6	-00:08:00	\N	0.8	-00:10:00	00:00:00	west of, off 63rd Street	NY
69156	Roosevelt Island, east of, East River, New York Current	NOS	ACT3426_1	40.75817	-73.95133	:America/New_York	USA	knots^2	200	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	0.6	-00:06:00	\N	0.8	00:00:00	00:02:00	east of	NY
69157	Manhattan, off 31st Street, East River, New York Current	NOS	ACT3431_1	40.73967	-73.9695	:America/New_York	USA	knots^2	175	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:36:00	\N	0.5	-00:11:00	\N	0.4	00:09:00	-00:02:00	Manhattan, off 31st Street	NY
69158	Pier 67, off 19th Street, East River, New York Current	NOS	ACT3441_1	40.73333	-73.96667	:America/New_York	USA	knots^2	179	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	0.4	00:08:00	\N	0.5	-00:08:00	-00:08:00	Pier 67, off 19th Street	NY
69159	Williamsburg Bridge, 0.3 mile north of, East River, New York Current	NOS	ACT3446_1	40.718	-73.97067	:America/New_York	USA	knots^2	220	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:10:00	\N	0.6	00:12:00	\N	0.8	-00:05:00	-00:01:00	Williamsburg Bridge, 0.3 mile north of	NY
69160	Manhattan Bridge, East of (Depth 15ft), East River, New York Current	NOS	ACT3451_1	40.70833	-73.99	:America/New_York	USA	knots^2	259	83	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:03:00	\N	0.5	00:19:00	\N	0.7	-00:28:00	-00:13:00	Manhattan Bridge, East of	NY
69161	Brooklyn Bridge, 0.1 mile southwest of, East River, New York Current	NOS	ACT3461_1	40.70333	-74	:America/New_York	USA	knots^2	222	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:07:00	\N	0.8	00:08:00	\N	0.9	-00:18:00	-00:04:00	Brooklyn Bridge, 0.1 mile southwest of	NY
69162	East 107th Street (Depth 15ft), Harlem River, New York Current	NOS	ACT3476_1	40.79	-73.935	:America/New_York	USA	knots^2	30	206	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:39:00	\N	0.2	-00:03:00	\N	0.2	-00:08:00	-01:09:00	East 107th Street	NY
69163	Willis Ave. Bridge, 0.1 mile NW of, Harlem River, New York Current	NOS	ACT3481_1	40.805	-73.93	:America/New_York	USA	knots^2	330	140	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:13:00	\N	0.3	00:00:00	\N	0.4	-00:30:00	-00:12:00	Willis Ave. Bridge, 0.1 mile NW of	NY
69164	Madison Ave. Bridge, Harlem River, New York Current	NOS	ACT3486_1	40.81333	-73.935	:America/New_York	USA	knots^2	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:14:00	\N	0.4	00:18:00	\N	0.5	-00:20:00	-00:21:00	Madison Ave. Bridge	NY
69165	Macombs Dam Bridge, Harlem River, New York Current	NOS	ACT3491_1	40.82833	-73.935	:America/New_York	USA	knots^2	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.3	00:14:00	\N	0.5	-00:20:00	-00:22:00	Macombs Dam Bridge	NY
69166	High Bridge, Harlem River, New York Current	NOS	ACT3496_1	40.84167	-73.93167	:America/New_York	USA	knots^2	15	189	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:08:00	\N	0.4	00:08:00	\N	0.6	-00:20:00	-00:23:00	High Bridge	NY
69167	West 207th Street Bridge, Harlem River, New York Current	NOS	ACT3501_1	40.86333	-73.915	:America/New_York	USA	knots^2	35	215	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:02:00	\N	0.4	00:05:00	\N	0.6	-00:22:00	-00:22:00	West 207th Street Bridge	NY
69168	Broadway Bridge, Harlem River, New York Current	NOS	ACT3506_1	40.87333	-73.91167	:America/New_York	USA	knots^2	299	116	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:04:00	\N	0.5	00:08:00	\N	0.6	-00:23:00	-00:20:00	Broadway Bridge	NY
69169	Henry Hudson Bridge, 0.7 nmi. SE of (Depth 16ft), Harlem River, New York Current	NOS	ACT3511_1	40.87667	-73.92167	:America/New_York	USA	knots^2	326	137	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:41:00	\N	0.3	00:31:00	\N	0.2	00:12:00	-00:31:00	Henry Hudson Bridge, 0.7 nmi. SE of	NY
69170	Bergen Point Reach (Bayonne Bridge) (Depth 29ft), Kill Van Kull, New York Current	NOS	ACT3951_2	40.641700744628906	-74.14330291748047	:America/New_York	USA	knots	79	263	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16145	-00:04:00	\N	0.9	00:02:00	\N	0.8	-00:15:00	00:14:00	BERGEN POINT REACH (BAYONNE BRIDGE)	NY
69171	Cedar Point, 2.9 n.mi. ENE of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_1	38.31083	-76.31333	:America/New_York	USA	knots	164	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:55:00	\N	0.8	-02:34:00	\N	0.5	-02:35:00	-03:16:00	Cedar Point, 2.9 n.mi. ENE of	MD
69172	Cedar Point, 2.9 n.mi. ENE of (Depth 50ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_2	38.31083	-76.31333	:America/New_York	USA	knots	141	326	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:15:00	\N	0.3	-03:30:00	\N	0.5	-04:08:00	-03:05:00	Cedar Point, 2.9 n.mi. ENE of	MD
69173	Cedar Point, 1.1 miles ENE of, Chesapeake Bay, Maryland Current	NOS	ACT4851_1	38.3045	-76.35167	:America/New_York	USA	knots	185	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.8	-02:50:00	\N	0.5	-03:23:00	-02:36:00	Cedar Point, 1.1 miles ENE of	MD
69174	Cove Point, 1.1 n.mi. east of (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_1	38.38133	-76.36033	:America/New_York	USA	knots	165	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:14:00	\N	0.9	-02:42:00	\N	0.9	-02:57:00	-02:40:00	Cove Point, 1.1 n.mi. east of	MD
69175	Cove Point, 1.1 n.mi. east of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_2	38.38133	-76.36033	:America/New_York	USA	knots	165	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:26:00	\N	0.7	-03:19:00	\N	0.8	-03:22:00	-02:38:00	Cove Point, 1.1 n.mi. east of	MD
69176	Cove Point, 2.7 n.mi. east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_1	38.38	-76.32533	:America/New_York	USA	knots	169	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:40:00	\N	0.9	-02:41:00	\N	0.5	-02:23:00	-02:59:00	Cove Point, 2.7 n.mi. east of	MD
69177	Cove Point, 2.7 n.mi. east of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_2	38.38	-76.32533	:America/New_York	USA	knots	170	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:40:00	\N	0.6	-02:39:00	\N	0.9	-03:15:00	-01:53:00	Cove Point, 2.7 n.mi. east of	MD
69178	Cove Point, 2.7 n.mi. east of (Depth 98ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_3	38.38	-76.32533	:America/New_York	USA	knots	165	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:36:00	\N	0.5	-04:02:00	\N	0.7	-03:49:00	-03:13:00	Cove Point, 2.7 n.mi. east of	MD
69179	Cove Point, 3.9 n.mi. east of (Depth 11ft), Chesapeake Bay, Maryland Current	NOS	ACT4871_1	38.37533	-76.29867	:America/New_York	USA	knots	171	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:44:00	\N	0.6	-03:36:00	\N	0.4	-03:29:00	-04:08:00	Cove Point, 3.9 n.mi. east of	MD
69180	Cove Point, 4.9 n.mi. NNE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_1	38.46717	-76.37667	:America/New_York	USA	knots	159	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:26:00	\N	0.7	-02:29:00	\N	0.7	-02:57:00	-02:24:00	Cove Point, 4.9 n.mi. NNE of	MD
69181	Cove Point, 4.9 n.mi. NNE of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_2	38.46717	-76.37667	:America/New_York	USA	knots	149	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:17:00	\N	0.4	-02:47:00	\N	1	-03:23:00	-01:58:00	Cove Point, 4.9 n.mi. NNE of	MD
69182	Cove Point, 4.9 n.mi. NNE of (Depth 67ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_3	38.46717	-76.37667	:America/New_York	USA	knots	135	321	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:58:00	\N	0.4	-03:38:00	\N	0.6	-03:55:00	-02:14:00	Cove Point, 4.9 n.mi. NNE of	MD
69183	Kenwood Beach, 1.5 miles northeast of, Chesapeake Bay, Maryland Current	NOS	ACT4881_1	38.51833	-76.48167	:America/New_York	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:37:00	\N	0.4	-02:41:00	\N	0.2	-01:56:00	-02:46:00	Kenwood Beach, 1.5 miles northeast of	MD
69184	James Island, 3.4 miles west of, Chesapeake Bay, Maryland Current	NOS	ACT4891_1	38.525	-76.42	:America/New_York	USA	knots	175	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:02:00	\N	0.4	-02:39:00	\N	0.5	-02:16:00	-03:01:00	James Island, 3.4 miles west of	MD
69185	James Island, 2.5 miles WNW of, Chesapeake Bay, Maryland Current	NOS	ACT4896_1	38.53333	-76.39333	:America/New_York	USA	knots	175	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:36:00	\N	0.6	-02:42:00	\N	0.5	-02:31:00	-02:18:00	James Island, 2.5 miles WNW of	MD
69186	Plum Point, 1.4 miles ESE of, Chesapeake Bay, Maryland Current	NOS	ACT4901_1	38.6125	-76.4775	:America/New_York	USA	knots	155	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:04:00	\N	0.7	-01:37:00	\N	0.2	-01:31:00	-02:20:00	Plum Point, 1.4 miles ESE of	MD
69187	Sharp Island Lt., 2.3 n.mi. SE of (Depth 20ft), Chesapeake Bay, Maryland Current	NOS	ACT4906_1	38.60717	-76.348	:America/New_York	USA	knots	203	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:54:00	\N	0.7	-03:34:00	\N	0.8	-03:15:00	-03:07:00	Sharp Island Lt., 2.3 n.mi. SE of	MD
69188	Sharp Island Lt., 2.1 n.mi. west of (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT4911_1	38.64333	-76.42033	:America/New_York	USA	knots	183	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:33:00	\N	0.5	-01:36:00	\N	0.4	-01:49:00	-01:33:00	Sharp Island Lt., 2.1 n.mi. west of	MD
69189	Sharp Island Lt., 3.4 n.mi. west of (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_1	38.64383	-76.448	:America/New_York	USA	knots	186	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:43:00	\N	0.5	-01:41:00	\N	0.4	-01:39:00	-01:57:00	Sharp Island Lt., 3.4 n.mi. west of	MD
69190	Sharp Island Lt., 3.4 n.mi. west of (Depth 35ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_2	38.64383	-76.448	:America/New_York	USA	knots	183	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:24:00	\N	0.4	-02:23:00	\N	0.4	-02:34:00	-02:23:00	Sharp Island Lt., 3.4 n.mi. west of	MD
69191	Plum Point, 2.1 n.mi. NNE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4921_1	38.645	-76.48717	:America/New_York	USA	knots	174	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:01:00	\N	0.5	-01:51:00	\N	0.4	-01:50:00	-01:51:00	Plum Point, 2.1 n.mi. NNE of	MD
69192	Poplar Island, 2.2 n.mi. WSW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT4926_1	38.75617	-76.4295	:America/New_York	USA	knots	185	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:49:00	\N	0.8	-01:26:00	\N	0.6	-00:44:00	-00:57:00	Poplar Island, 2.2 n.mi. WSW of	MD
69193	Poplar Island, 3.0 n.mi. WSW of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_1	38.74967	-76.4455	:America/New_York	USA	knots	189	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:08:00	\N	0.5	-01:22:00	\N	0.6	-01:08:00	-00:59:00	Poplar Island, 3.0 n.mi. WSW of	MD
69194	Poplar Island, 3.0 n.mi. WSW of (Depth 48ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_2	38.74967	-76.4455	:America/New_York	USA	knots	172	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:13:00	\N	0.4	01:21:00	\N	0.5	00:58:00	02:01:00	Poplar Island, 3.0 n.mi. WSW of	MD
69195	Holland Point, 2.0 n.mi east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4936_1	38.75167	-76.49883	:America/New_York	USA	knots	180	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:39:00	\N	0.4	-01:24:00	\N	0.2	-01:20:00	-01:45:00	Holland Point, 2.0 n.mi east of	MD
69196	Kent Point, 4 miles southwest of, Chesapeake Bay, Maryland Current	NOS	ACT4941_1	38.79167	-76.43333	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:05:00	\N	0.6	-01:04:00	\N	0.6	-01:03:00	-01:11:00	Kent Point, 4 miles southwest of	MD
69197	Kent Point, 1.3 miles south of, Chesapeake Bay, Maryland Current	NOS	ACT4946_1	38.81667	-76.36417	:America/New_York	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:47:00	\N	0.5	-03:38:00	\N	0.6	-03:27:00	-03:53:00	Kent Point, 1.3 miles south of	MD
69198	Horseshoe Point, 1.7 miles east of, Chesapeake Bay, Maryland Current	NOS	ACT4951_1	38.83833	-76.45333	:America/New_York	USA	knots	200	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:10:00	\N	0.6	-00:39:00	\N	0.6	-00:52:00	-00:49:00	Horseshoe Point, 1.7 miles east of	MD
69199	Bloody Point Bar Light, 0.6 mi. NW of (Depth 19ft), Chesapeake Bay, Maryland Current	NOS	ACT4956_1	38.8395	-76.40283	:America/New_York	USA	knots	190	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:05:00	\N	0.6	-00:23:00	\N	0.9	-00:08:00	00:02:00	Bloody Point Bar Light, 0.6 mi. NW of	MD
69200	Thomas Pt. Shoal Lt., 1.8 mi. SW of, Chesapeake Bay, Maryland Current	NOS	ACT4961_1	38.875	-76.46167	:America/New_York	USA	knots	190	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:17:00	\N	0.4	-02:27:00	\N	0.5	-02:24:00	-01:43:00	Thomas Pt. Shoal Lt., 1.8 mi. SW of	MD
69201	Thomas Pt. Shoal Lt., 2.0 n.mi. east of (Depth 22ft), Chesapeake Bay, Maryland Current	NOS	ACT4966_1	38.89583	-76.38683	:America/New_York	USA	knots	186	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:20:00	\N	0.6	-00:14:00	\N	0.6	-01:05:00	-00:22:00	Thomas Pt. Shoal Lt., 2.0 n.mi. east of	MD
69202	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_1	38.891	-76.427	:America/New_York	USA	knots	191	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:41:00	\N	1.3	-00:09:00	\N	1	-00:25:00	-00:43:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
69203	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of (Depth 33ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_2	38.891	-76.427	:America/New_York	USA	knots	196	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:20:00	\N	0.7	-01:18:00	\N	0.7	-00:54:00	-01:25:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
69204	Tolly Point, 1.6 miles east of, Chesapeake Bay, Maryland Current	NOS	ACT4976_1	38.9345	-76.417	:America/New_York	USA	knots	190	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:24:00	\N	0.9	-00:19:00	\N	0.6	-00:03:00	-00:32:00	Tolly Point, 1.6 miles east of	MD
69205	Chesapeake Bay Bridge, main channel, Chesapeake Bay, Maryland Current	NOS	ACT4981_1	38.99167	-76.385	:America/New_York	USA	knots	230	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:13:00	\N	1.1	00:08:00	\N	0.9	00:16:00	-00:17:00	Chesapeake Bay Bridge, main channel	MD
69206	Sandy Point, 2.3 n.mi. east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_1	39.00267	-76.34883	:America/New_York	USA	knots	199	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:29:00	\N	0.9	00:15:00	\N	1.1	00:19:00	00:13:00	Sandy Point, 2.3 n.mi. east of	MD
69207	Sandy Point, 2.3 n.mi. east of (Depth 41ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_2	39.00267	-76.34883	:America/New_York	USA	knots	210	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:39:00	\N	0.6	-01:14:00	\N	0.8	-01:33:00	-00:48:00	Sandy Point, 2.3 n.mi. east of	MD
69208	Sandy Point, 0.8 n.mi. ESE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_1	39.004	-76.38	:America/New_York	USA	knots	199	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:05:00	\N	1.5	00:24:00	\N	1.2	-00:11:00	-00:15:00	Sandy Point, 0.8 n.mi. ESE of	MD
69209	Sandy Point, 0.8 n.mi. ESE of (Depth 43ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_2	39.004	-76.38	:America/New_York	USA	knots	197	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:02:00	\N	1	-01:10:00	\N	1	-00:59:00	-00:59:00	Sandy Point, 0.8 n.mi. ESE of	MD
69210	Craighill Channel entrance, Buoy '2C' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_1	39.04033	-76.37783	:America/New_York	USA	knots	182	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:09:00	\N	0.9	00:26:00	\N	1	-00:04:00	00:01:00	Craighill Channel entrance, Buoy '2C'	MD
69211	Craighill Channel entrance, Buoy '2C' (Depth 38ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_2	39.04033	-76.37783	:America/New_York	USA	knots	147	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:18:00	\N	0.6	00:01:00	\N	0.5	00:00:00	-00:06:00	Craighill Channel entrance, Buoy '2C'	MD
69212	Love Point, 2.5 miles north of, Chesapeake Bay, Maryland Current	NOS	ACT5011_1	39.07967	-76.31217	:America/New_York	USA	knots	240	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:07:00	\N	0.5	00:19:00	\N	0.8	-00:48:00	00:27:00	Love Point, 2.5 miles north of	MD
69213	Craighill Channel, NE of Mountain Pt, Chesapeake Bay, Maryland Current	NOS	ACT5021_1	39.08133	-76.3945	:America/New_York	USA	knots	175	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:34:00	\N	0.9	00:40:00	\N	0.8	00:28:00	00:25:00	Craighill Channel, NE of Mountain Pt	MD
69214	Craighill Channel, Belvidere Shoal (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT5026_1	39.09467	-76.393	:America/New_York	USA	knots	186	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:19:00	\N	0.6	00:46:00	\N	0.7	00:10:00	00:33:00	Craighill Channel, Belvidere Shoal	MD
69215	Craighill Angle, right outside quarter, Chesapeake Bay, Maryland Current	NOS	ACT5031_1	39.12833	-76.38783	:America/New_York	USA	knots	170	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:23:00	\N	0.6	00:27:00	\N	0.6	00:12:00	00:34:00	Craighill Angle, right outside quarter	MD
69216	Swan Point, 2.7 n.mi. SW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_1	39.108	-76.30533	:America/New_York	USA	knots	170	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.5	00:42:00	\N	0.6	00:18:00	00:38:00	Swan Point, 2.7 n.mi. SW of	MD
69217	Swan Point, 2.7 n.mi. SW of (Depth 27ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_2	39.108	-76.30533	:America/New_York	USA	knots	142	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.4	00:30:00	\N	0.6	-00:27:00	01:17:00	Swan Point, 2.7 n.mi. SW of	MD
69218	Swan Point, 1.6 miles northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5046_1	39.1625	-76.30467	:America/New_York	USA	knots	215	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:57:00	\N	0.9	00:44:00	\N	0.8	00:53:00	00:38:00	Swan Point, 1.6 miles northwest of	MD
69219	Brewerton Channel Eastern Ext., Buoy '7' (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5051_1	39.163	-76.38967	:America/New_York	USA	knots	175	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:05:00	\N	0.4	-00:02:00	\N	0.5	00:16:00	-00:14:00	Brewerton Channel Eastern Ext., Buoy '7'	MD
69220	Tolchester Channel, SW of Bouy '58B' (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_1	39.1825	-76.28117	:America/New_York	USA	knots	229	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:54:00	\N	1.1	00:20:00	\N	1.1	00:44:00	00:48:00	Tolchester Channel, SW of Bouy '58B'	MD
69221	Tolchester Channel, SW of Bouy '58B' (Depth 25ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_2	39.1825	-76.28117	:America/New_York	USA	knots	217	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:48:00	\N	0.7	00:02:00	\N	0.9	-00:09:00	00:38:00	Tolchester Channel, SW of Bouy '58B'	MD
69222	Tolchester Channel, Buoy '22' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5061_1	39.19117	-76.26583	:America/New_York	USA	knots	231	61	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:23:00	\N	0.8	01:10:00	\N	0.9	01:43:00	00:59:00	Tolchester Channel, Buoy '22'	MD
69223	Tolchester Channel, south of Buoy '38B' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5066_1	39.19283	-76.28783	:America/New_York	USA	knots	208	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:50:00	\N	0.8	01:08:00	\N	0.7	00:51:00	00:59:00	Tolchester Channel, south of Buoy '38B'	MD
69224	North Point, 2.5 miles northeast of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5071_1	39.2145	-76.39533	:America/New_York	USA	knots	225	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:06:00	\N	0.5	01:00:00	\N	0.4	01:25:00	00:53:00	North Point, 2.5 miles northeast of	MD
69225	Tolchester Beach, 0.33 n.mi. west of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5076_1	39.21717	-76.24833	:America/New_York	USA	knots	201	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:24:00	\N	1.1	01:20:00	\N	1.2	00:49:00	01:22:00	Tolchester Beach, 0.33 n.mi. west of	MD
69226	Pooles Island, 4 miles southwest of, Chesapeake Bay, Maryland Current	NOS	ACT5081_1	39.22667	-76.33133	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:12:00	\N	0.8	00:48:00	\N	0.6	00:59:00	00:56:00	Pooles Island, 4 miles southwest of	MD
69227	Pooles Island 2.0 n.mi. SSW of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5086_1	39.24633	-76.29667	:America/New_York	USA	knots	238	38	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:29:00	\N	0.7	00:58:00	\N	0.7	01:01:00	01:03:00	Pooles Island 2.0 n.mi. SSW of	MD
69228	Pooles Island, 0.8 mile south of, Chesapeake Bay, Maryland Current	NOS	ACT5091_1	39.26167	-76.27333	:America/New_York	USA	knots	255	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:20:00	\N	1.2	01:24:00	\N	0.9	01:29:00	01:12:00	Pooles Island, 0.8 mile south of	MD
69229	Miller Island, 1.5 miles ENE of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5096_1	39.275	-76.33167	:America/New_York	USA	knots	185	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.3	00:15:00	\N	0.6	00:11:00	00:37:00	Miller Island, 1.5 miles ENE of	MD
69230	Pooles Island, 1.6 n.mi. east of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT5101_1	39.2745	-76.22617	:America/New_York	USA	knots	208	14	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:03:00	\N	1.1	01:34:00	\N	1.1	01:28:00	01:45:00	Pooles Island, 1.6 n.mi. east of	MD
69231	Robins Point, 0.7 mile ESE of (Depth 5ft), Chesapeake Bay, Maryland Current	NOS	ACT5106_1	39.29583	-76.26833	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:13:00	\N	1	-00:14:00	\N	1.4	-00:03:00	00:37:00	Robins Point, 0.7 mile ESE of	MD
69232	Worton Point, 1.5 n.mi. WSW of (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT5111_1	39.31167	-76.21717	:America/New_York	USA	knots	211	23	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:36:00	\N	1.1	01:45:00	\N	1	02:04:00	01:27:00	Worton Point, 1.5 n.mi. WSW of	MD
69233	Worton Point, 1.1 miles northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5116_1	39.33167	-76.2	:America/New_York	USA	knots	245	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:32:00	\N	1.5	01:43:00	\N	1.4	01:43:00	01:38:00	Worton Point, 1.1 miles northwest of	MD
69234	Howell Point, 0.8 n.mi. west of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5121_1	39.3705	-76.13	:America/New_York	USA	knots	235	51	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:33:00	\N	1.3	01:48:00	\N	1	02:30:00	01:19:00	Howell Point, 0.8 n.mi. west of	MD
69235	Howell Point, 0.4 mile NNW of, Chesapeake Bay, Maryland Current	NOS	ACT5126_1	39.37667	-76.115	:America/New_York	USA	knots	245	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:18:00	\N	1.1	01:24:00	\N	1.1	01:28:00	01:20:00	Howell Point, 0.4 mile NNW of	MD
69236	Grove Point, 0.7 n.mi.NW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5131_1	39.39633	-76.05033	:America/New_York	USA	knots	211	34	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	02:03:00	\N	1	02:01:00	\N	0.6	02:40:00	01:31:00	Grove Point, 0.7 n.mi.NW of	MD
69237	Turkey Point, 1.2 n.mi. SW of (Depth 9ft), Chesapeake Bay, Maryland Current	NOS	ACT5136_1	39.44333	-76.03383	:America/New_York	USA	knots	193	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:00:00	\N	0.8	01:30:00	\N	0.6	02:39:00	00:58:00	Turkey Point, 1.2 n.mi. SW of	MD
69238	Spesutie Island, channel north of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5141_1	39.4805	-76.08167	:America/New_York	USA	knots	100	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:40:00	\N	0.6	01:20:00	\N	0.8	01:42:00	01:49:00	Spesutie Island, channel north of	MD
69239	Rocky Pt. (Elk Neck), 0.25 n.mi. SW of (Depth 9ft), Chesapeake Bay, Maryland Current	NOS	ACT5146_1	39.48833	-75.9975	:America/New_York	USA	knots	196	9	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:49:00	\N	0.7	01:28:00	\N	0.6	02:42:00	01:14:00	Rocky Pt. (Elk Neck), 0.25 n.mi. SW of	MD
69240	Red Point, 0.2 mile W of, Northeast River (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5151_1	39.52917	-75.98467	:America/New_York	USA	knots	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:47:00	\N	0.6	01:28:00	\N	0.9	01:42:00	01:57:00	Red Point, 0.2 mile W of, Northeast River	MD
69241	Swan Point, Potomac River, Virginia Current	NOS	ACT5846_1	38.27333	-76.945	:America/New_York	USA	knots	140	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:09:00	\N	1	-02:04:00	\N	0.4	-01:54:00	-02:32:00	Swan Point	VA
69242	Persimmon Point, Potomac River, Maryland Current	NOS	ACT5861_1	38.36833	-76.99	:America/New_York	USA	knots	175	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:24:00	\N	1.8	-01:19:00	\N	1.5	-01:09:00	-01:47:00	Persimmon Point	MD
69243	Potomac River Bridge, 0.4 mile south of, Potomac River, Maryland Current	NOS	ACT5866_1	38.35633	-76.98667	:America/New_York	USA	knots	165	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:17:00	\N	1.8	-01:28:00	\N	1.1	-01:25:00	-01:38:00	Potomac River Bridge, 0.4 mile south of	MD
69244	Maryland Point, Potomac River, Maryland Current	NOS	ACT5876_1	38.34667	-77.19667	:America/New_York	USA	knots	80	270	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:19:00	\N	1.8	-01:14:00	\N	1.4	-01:04:00	-01:42:00	Maryland Point	MD
69245	Quantico, Potomac River, Virginia Current	NOS	ACT5881_1	38.52167	-77.27667	:America/New_York	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:09:00	\N	1.1	-01:04:00	\N	0.9	-00:54:00	-01:32:00	Quantico	VA
69246	Quantico Creek entrance, Potomac River, Virginia Current	NOS	ACT5886_1	38.52833	-77.28833	:America/New_York	USA	knots	115	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:34:00	\N	0.6	-01:29:00	\N	0.6	-01:19:00	-01:57:00	Quantico Creek entrance	VA
69247	Freestone Point, 2.3 miles east of, Potomac River, Maryland Current	NOS	ACT5891_1	38.59633	-77.198	:America/New_York	USA	knots	229	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:06:00	\N	0.9	-00:01:00	\N	0.9	-00:03:00	-00:28:00	Freestone Point, 2.3 miles east of	MD
69248	Hallowing Point, Potomac River, Maryland Current	NOS	ACT5896_1	38.645	-77.1275	:America/New_York	USA	knots	149	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:15:00	\N	1.4	-00:05:00	\N	1.4	00:12:00	-00:24:00	Hallowing Point	MD
69249	Jones Point, Alexandria, Potomac River, Virginia Current	NOS	ACT5901_1	38.79367	-77.03717	:America/New_York	USA	knots	171	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:07:00	\N	1.1	00:01:00	\N	1.2	00:36:00	00:09:00	Jones Point, Alexandria	VA
69250	Hains Point, Potomac River, DC Current	NOS	ACT5906_1	38.85133	-77.022	:America/New_York	USA	knots	176	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:18:00	\N	0.4	00:31:00	\N	0.8	00:20:00	00:04:00	Hains Point	DC
69251	Hog Point, 0.6 n.mi. north of (Depth 13ft), Patuxent River, Maryland Current	NOS	ACT5931_1	38.318	-76.40117	:America/New_York	USA	knots	70	258	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:00:00	\N	0.6	-05:29:00	\N	0.5	-04:45:00	-05:59:00	Hog Point, 0.6 n.mi. north of	MD
69252	Hog Point, 0.6 n.mi. north of (Depth 41ft), Patuxent River, Maryland Current	NOS	ACT5931_2	38.318	-76.40117	:America/New_York	USA	knots	61	263	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:38:00	\N	0.3	-05:38:00	\N	0.5	-06:24:00	-05:36:00	Hog Point, 0.6 n.mi. north of	MD
69253	Drum Point, 0.3 mile SSE of, Patuxent River, Maryland Current	NOS	ACT5936_1	38.3155	-76.41917	:America/New_York	USA	knots	65	245	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-05:16:00	\N	0.5	-05:20:00	\N	0.5	-05:19:00	-05:25:00	Drum Point, 0.3 mile SSE of	MD
69254	Sandy Point, 0.5 mile south of, Patuxent River, Maryland Current	NOS	ACT5941_1	38.30833	-76.455	:America/New_York	USA	knots	125	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:55:00	\N	0.6	-05:49:00	\N	0.5	-05:08:00	-05:53:00	Sandy Point, 0.5 mile south of	MD
69255	Point Patience, 0.1 mile southwest of (Depth 15ft), Patuxent River, Maryland Current	NOS	ACT5946_1	38.32833	-76.48667	:America/New_York	USA	knots	145	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:01:00	\N	1	-06:12:00	\N	0.6	-05:07:00	-06:46:00	Point Patience, 0.1 mile southwest of	MD
69256	Broomes Island, 0.4 mile south of, Patuxent River, Maryland Current	NOS	ACT5951_1	38.395	-76.55417	:America/New_York	USA	knots	110	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-05:02:00	\N	0.6	-05:16:00	\N	0.5	-05:01:00	-05:02:00	Broomes Island, 0.4 mile south of	MD
69257	Sheridan Point, 0.1 mile southwest of, Patuxent River, Maryland Current	NOS	ACT5956_1	38.46617	-76.648	:America/New_York	USA	knots	135	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:16:00	\N	0.8	-04:54:00	\N	0.8	-04:33:00	-04:38:00	Sheridan Point, 0.1 mile southwest of	MD
69258	Benedict, highway bridge, Patuxent River, Maryland Current	NOS	ACT5961_1	38.51167	-76.67217	:America/New_York	USA	knots	190	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:35:00	\N	0.6	-04:38:00	\N	1	-04:45:00	-04:09:00	Benedict, highway bridge	MD
69259	Lyons Creek Wharf, Patuxent River, Maryland Current	NOS	ACT5966_1	38.74667	-76.685	:America/New_York	USA	knots	140	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:29:00	\N	1.1	-03:24:00	\N	1.4	-03:14:00	-03:52:00	Lyons Creek Wharf	MD
69260	Ragged Point, 1.5 miles east of, Little Choptank River, Maryland Current	NOS	ACT5976_1	38.53	-76.24417	:America/New_York	USA	knots	235	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:57:00	\N	0.2	-05:15:00	\N	0.5	-04:53:00	-04:29:00	Ragged Point, 1.5 miles east of	MD
69261	Cook Point, 1.4 n.mi. NNW of (Depth 15ft), Choptank River, Maryland Current	NOS	ACT5981_1	38.64717	-76.30667	:America/New_York	USA	knots	241	49	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:24:00	\N	0.7	-04:06:00	\N	0.8	-03:52:00	-04:06:00	Cook Point, 1.4 n.mi. NNW of	MD
69262	Cook Point, 1.4 n.mi. NNW of (Depth 45ft), Choptank River, Maryland Current	NOS	ACT5981_2	38.64717	-76.30667	:America/New_York	USA	knots	232	68	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:12:00	\N	0.6	-04:05:00	\N	0.6	-04:09:00	-04:03:00	Cook Point, 1.4 n.mi. NNW of	MD
69263	Holland Point, 2.0 n.mi. SSW of (Depth 14ft), Choptank River, Maryland Current	NOS	ACT5986_1	38.67383	-76.2575	:America/New_York	USA	knots	262	89	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:00:00	\N	0.2	-04:21:00	\N	0.3	-03:54:00	-03:26:00	Holland Point, 2.0 n.mi. SSW of	MD
69264	Chlora Point, 0.5 n.mi. SSW of (Depth 17ft), Choptank River, Maryland Current	NOS	ACT5991_1	38.62833	-76.15167	:America/New_York	USA	knots	332	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:58:00	\N	0.5	-03:32:00	\N	0.6	-03:45:00	-03:22:00	Chlora Point, 0.5 n.mi. SSW of	MD
69265	Chlora Point, 0.5 n.mi. SSW of (Depth 24ft), Choptank River, Maryland Current	NOS	ACT5991_2	38.62833	-76.15167	:America/New_York	USA	knots	323	143	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.4	-03:33:00	\N	0.4	-03:48:00	-03:13:00	Chlora Point, 0.5 n.mi. SSW of	MD
69266	Martin Point, 0.6 n.mi. west of (Depth 18ft), Choptank River, Maryland Current	NOS	ACT5996_1	38.62717	-76.13583	:America/New_York	USA	knots	341	155	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:34:00	\N	0.2	-03:42:00	\N	0.3	-03:18:00	-03:22:00	Martin Point, 0.6 n.mi. west of	MD
69267	Howell Point, 0.5 n.mi. south of (Depth 7ft), Choptank River, Maryland Current	NOS	ACT6001_1	38.60383	-76.1145	:America/New_York	USA	knots	274	122	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.5	-04:04:00	\N	0.4	-03:17:00	-03:52:00	Howell Point, 0.5 n.mi. south of	MD
69268	Cambridge hwy. bridge, W. of Swing Span (Depth 18ft), Choptank River, Maryland Current	NOS	ACT6006_1	38.57967	-76.06117	:America/New_York	USA	knots	316	132	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:13:00	\N	0.3	-03:05:00	\N	0.6	-02:48:00	-01:07:00	Cambridge hwy. bridge, W. of Swing Span	MD
69269	Off Jamaica Point, Choptank River, Maryland Current	NOS	ACT6011_1	38.60967	-75.98283	:America/New_York	USA	knots	205	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:26:00	\N	0.8	-02:32:00	\N	0.6	-02:13:00	-02:44:00	Off Jamaica Point	MD
69270	Poplar Point, south of, Choptank River, Maryland Current	NOS	ACT6016_1	38.67533	-75.96633	:America/New_York	USA	knots	100	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:15:00	\N	1	-02:05:00	\N	1	-01:52:00	-01:56:00	Poplar Point, south of	MD
69271	Dover Bridge, Choptank River, Maryland Current	NOS	ACT6021_1	38.75667	-75.99867	:America/New_York	USA	knots	235	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:47:00	\N	1	-01:50:00	\N	1.1	-01:19:00	-01:25:00	Dover Bridge	MD
69272	Bald Eagle Pt., east of, Harris Creek, Choptank River, Maryland Current	NOS	ACT6041_1	38.72917	-76.305	:America/New_York	USA	knots	175	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:14:00	\N	0.5	-04:27:00	\N	0.5	-04:07:00	-04:07:00	Bald Eagle Pt., east of, Harris Creek	MD
69273	Poplar Island, east of south end, Eastern Bay, Maryland Current	NOS	ACT6046_1	38.74833	-76.35333	:America/New_York	USA	knots	170	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:20:00	\N	0.8	-02:20:00	\N	1.2	-02:20:00	-02:20:00	Poplar Island, east of south end	MD
69274	Kent Point, 1.4 n.mi. east of (Depth 15ft), Eastern Bay, Maryland Current	NOS	ACT6051_1	38.83883	-76.3375	:America/New_York	USA	knots	233	43	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:12:00	\N	0.4	-03:18:00	\N	0.5	-03:04:00	-03:49:00	Kent Point, 1.4 n.mi. east of	MD
69275	Long Point, 1 mile southeast of, Eastern Bay, Maryland Current	NOS	ACT6056_1	38.84333	-76.32667	:America/New_York	USA	knots	235	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:40:00	\N	0.5	-03:40:00	\N	0.6	-03:40:00	-03:40:00	Long Point, 1 mile southeast of	MD
69276	Wye River, west of Bruffs Island (Depth 9ft), Eastern Bay, Maryland Current	NOS	ACT6081_1	38.85467	-76.198	:America/New_York	USA	knots	190	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:00:00	\N	0.9	-03:18:00	\N	0.8	-02:33:00	-03:17:00	Wye River, west of Bruffs Island	MD
69277	Deepwater Point, Miles River, Eastern Bay, Maryland Current	NOS	ACT6086_1	38.8055	-76.20917	:America/New_York	USA	knots	25	215	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:14:00	\N	0.6	-03:52:00	\N	0.6	-03:48:00	-03:43:00	Deepwater Point, Miles River	MD
69278	Greenbury Point, 1.8 miles east of (Depth 8ft), Maryland Current	NOS	ACT6106_1	38.97333	-76.41667	:America/New_York	USA	knots	245	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:47:00	\N	0.8	-01:05:00	\N	0.8	-00:57:00	-00:51:00	Greenbury Point, 1.8 miles east of	MD
69279	Mountain Point, Magothy River entrance, Maryland Current	NOS	ACT6121_1	39.05783	-76.43717	:America/New_York	USA	knots	125	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:04:00	\N	0.4	-02:00:00	\N	0.8	-02:20:00	-01:29:00	Mountain Point, Magothy River entrance	MD
69280	Love Point, 1.6 n.mi. east of (Depth 16ft), Chester River, Maryland Current	NOS	ACT6126_1	39.03417	-76.26783	:America/New_York	USA	knots	341	202	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:15:00	\N	0.4	-01:15:00	\N	0.6	-01:42:00	-00:47:00	Love Point, 1.6 n.mi. east of	MD
69281	Kent Island Narrows (highway bridge) (Depth 4ft), Chester River, Maryland Current	NOS	ACT6131_1	38.9705	-76.24717	:America/New_York	USA	knots	190	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:56:00	\N	1.1	-02:25:00	\N	1.2	-02:07:00	-02:11:00	Kent Island Narrows (highway bridge)	MD
69282	Hail Point, 0.7 n.mi.east of (Depth 16ft), Chester River, Maryland Current	NOS	ACT6136_1	39.0105	-76.1825	:America/New_York	USA	knots	168	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:37:00	\N	0.6	-01:08:00	\N	0.5	-00:51:00	-01:12:00	Hail Point, 0.7 n.mi.east of	MD
69283	Deep Point, Chester River, Maryland Current	NOS	ACT6141_1	39.10633	-76.1205	:America/New_York	USA	knots	260	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:18:00	\N	0.9	-00:33:00	\N	0.6	-00:31:00	-00:32:00	Deep Point	MD
69284	Chestertown, Chester River, Maryland Current	NOS	ACT6146_1	39.20717	-76.06117	:America/New_York	USA	knots	220	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:17:00	\N	0.6	00:05:00	\N	0.8	-00:21:00	-00:02:00	Chestertown	MD
69285	Lynch Point, Back River, Maryland Current	NOS	ACT6186_1	39.25	-76.43833	:America/New_York	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:10:00	\N	0.5	-00:10:00	\N	0.7	00:00:00	00:00:00	Lynch Point, Back River	MD
69286	Gunpowder River entrance, Maryland Current	NOS	ACT6191_1	39.31167	-76.30833	:America/New_York	USA	knots	205	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:05:00	\N	0.4	-00:41:00	\N	0.5	-00:24:00	00:25:00	Gunpowder River entrance	MD
69287	Bush River, 0.4 mi. SW of Bush Point, Maryland Current	NOS	ACT6196_1	39.35667	-76.25667	:America/New_York	USA	knots	165	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:20:00	\N	0.6	-00:24:00	\N	0.8	00:07:00	00:21:00	Bush River, 0.4 mi. SW of Bush Point	MD
69288	Grove Point, Sassafrass River, Maryland Current	NOS	ACT6201_1	39.37833	-76.04333	:America/New_York	USA	knots	288	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:44:00	\N	0.4	00:46:00	\N	0.5	00:46:00	00:51:00	Grove Point	MD
69289	Ordinary Point, 0.4 mile west of, Sassafrass River, Maryland Current	NOS	ACT6206_1	39.37417	-75.9875	:America/New_York	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:58:00	\N	0.5	00:37:00	\N	0.6	00:50:00	01:17:00	Ordinary Point, 0.4 mile west of	MD
69290	Georgetown, Sassafrass River, Maryland Current	NOS	ACT6211_1	39.36117	-75.88617	:America/New_York	USA	knots	200	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:25:00	\N	0.5	00:25:00	\N	0.4	01:00:00	00:56:00	Georgetown	MD
69291	Arnold Point, 0.4 mile west of, Elk River, Maryland Current	NOS	ACT6216_1	39.46383	-75.97417	:America/New_York	USA	knots	215	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:32:00	\N	1	01:45:00	\N	1	01:39:00	01:24:00	Arnold Point, 0.4 mile west of	MD
69292	Old Town Point Wharf, northwest of (Depth 17ft), Elk River, Maryland Current	NOS	ACT6221_1	39.50383	-75.91867	:America/New_York	USA	knots	242	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:45:00	\N	1.6	01:53:00	\N	1.3	02:00:00	01:49:00	Old Town Point Wharf, northwest of	MD
69293	Old Town Point Wharf, northwest of (Depth 29ft), Elk River, Maryland Current	NOS	ACT6221_2	39.50383	-75.91867	:America/New_York	USA	knots	237	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:45:00	\N	1.4	02:04:00	\N	1.2	02:07:00	01:47:00	Old Town Point Wharf, northwest of	MD
69294	Hendersons Point, Elk River, Maryland Current	NOS	ACT6226_1	39.55333	-75.86	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	02:05:00	\N	0.9	02:05:00	\N	0.6	02:05:00	02:05:00	Hendersons Point	MD
69295	Bodie Island-Pea Island, between (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6271_1	35.77667	-75.535	:America/New_York	USA	knots	28	202	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:52:00	\N	0.6	02:20:00	\N	1.2	02:38:00	02:03:00	Bodie Island-Pea Island, between	NC
69296	Bodie Island-Pea Island, between (Depth 12ft), Oregon Inlet, North Carolina Current	NOS	ACT6271_2	35.77667	-75.535	:America/New_York	USA	knots	36	204	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.6	02:36:00	\N	1.2	02:49:00	02:02:00	Bodie Island-Pea Island, between	NC
69297	Coast Guard Tower, southwest of (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6276_1	35.76167	-75.53167	:America/New_York	USA	knots	28	205	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:18:00	\N	0.8	02:30:00	\N	0.8	03:04:00	01:53:00	Coast Guard Tower, southwest of	NC
69298	Coast Guard Tower, southwest of (Depth 12ft), Oregon Inlet, North Carolina Current	NOS	ACT6276_2	35.76167	-75.53167	:America/New_York	USA	knots	33	212	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:33:00	\N	0.7	02:33:00	\N	0.8	03:01:00	01:57:00	Coast Guard Tower, southwest of	NC
69299	Herbert C. Bonner Bridge, WSW of (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6281_1	35.77	-75.54667	:America/New_York	USA	knots	87	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:46:00	\N	0.9	02:55:00	\N	0.6	03:32:00	01:30:00	Herbert C. Bonner Bridge, WSW of	NC
69300	Hatteras Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6286_1	35.2	-75.75	:America/New_York	USA	knots	148	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:38:00	\N	1	02:42:00	\N	1.2	02:42:00	02:18:00	Hatteras Inlet	NC
69301	Channel entrance, Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6296_1	35.06533	-76.01883	:America/New_York	USA	knots	145	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:40:00	\N	1.2	02:24:00	\N	1	02:48:00	01:43:00	channel entrance	NC
69302	Teaches Hole Channel (Depth 10ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6301_1	35.07917	-76.00467	:America/New_York	USA	knots	195	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:47:00	\N	0.8	02:27:00	\N	0.6	02:49:00	01:42:00	Teaches Hole Channel	NC
69303	Blair Channel (Depth 10ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6306_1	35.08133	-76.03383	:America/New_York	USA	knots	140	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:03:00	\N	0.9	02:33:00	\N	0.6	02:52:00	01:48:00	Blair Channel	NC
69304	Wallace Channel (Depth 9ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6311_1	35.07967	-76.052	:America/New_York	USA	knots	140	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:13:00	\N	0.9	02:57:00	\N	0.9	02:51:00	02:03:00	Wallace Channel	NC
69305	Sheep Island Slue, Pamlico Sound, North Carolina Current	NOS	ACT6316_1	35.06667	-76.1	:America/New_York	USA	knots	95	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:56:00	\N	0.2	03:18:00	\N	0.1	02:33:00	01:35:00	Sheep Island Slue	NC
69306	Shackleford Banks, 0.8 mile S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6326_1	34.66633	-76.6555	:America/New_York	USA	knots	145	314	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.7	01:16:00	\N	0.8	01:19:00	00:30:00	Shackleford Banks, 0.8 mile S of	NC
69307	Approach, Beaufort Inlet, North Carolina Current	NOS	ACT6331_1	34.67167	-76.67	:America/New_York	USA	knots	161	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:57:00	\N	0.7	01:19:00	\N	0.2	02:03:00	00:37:00	Approach	NC
69308	Fort Macon, 0.6 mile SE of, Beaufort Inlet, North Carolina Current	NOS	ACT6336_1	34.68583	-76.66833	:America/New_York	USA	knots	154	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:38:00	\N	0.9	01:47:00	\N	0.7	01:42:00	00:51:00	Fort Macon, 0.6 mile SE of	NC
69309	Fort Macon, 0.2 mile NE of (Depth 10ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_1	34.69967	-76.67533	:America/New_York	USA	knots	151	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:21:00	\N	0.9	01:20:00	\N	1.1	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
69310	Fort Macon, 0.2 mile NE of (Depth 20ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_2	34.69967	-76.67533	:America/New_York	USA	knots	153	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:39:00	\N	0.9	01:18:00	\N	1.1	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
69311	Tombstone Point, 0.1 mile E of (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6346_1	34.70383	-76.68617	:America/New_York	USA	knots	128	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:27:00	\N	0.8	01:25:00	\N	0.9	01:13:00	00:34:00	Tombstone Point, 0.1 mile E of	NC
69312	Turning Basin (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_1	34.713	-76.69417	:America/New_York	USA	knots	144	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:32:00	\N	0.5	01:34:00	\N	0.8	01:11:00	00:50:00	Turning Basin	NC
69313	Turning Basin (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_2	34.713	-76.69417	:America/New_York	USA	knots	138	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:32:00	\N	0.5	01:34:00	\N	0.7	01:09:00	00:59:00	Turning Basin	NC
69314	Sugarloaf Island, 0.2 mile S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6356_1	34.7125	-76.71383	:America/New_York	USA	knots	94	266	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:14:00	\N	0.8	01:39:00	\N	0.7	01:58:00	01:22:00	Sugarloaf Island, 0.2 mile S of	NC
69315	Morehead City, S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6361_1	34.71667	-76.73283	:America/New_York	USA	knots	110	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:42:00	\N	0.7	01:47:00	\N	0.8	02:12:00	01:29:00	Morehead City, S of	NC
69316	Morehead City, RR. bridge, N of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6366_1	34.72283	-76.69383	:America/New_York	USA	knots	185	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:03:00	\N	0.5	01:01:00	\N	0.6	00:44:00	00:09:00	Morehead City, RR. bridge, N of	NC
67368	Deep Creek entrance, Elizabeth River, Virginia	NOS	8639414	36.755	-76.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65810	00:18:00	\N	1.25	00:22:00	\N	1.21	\N	\N	Deep Creek Entrance	VA
69317	Newport Marshes, SE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_1	34.73133	-76.68333	:America/New_York	USA	knots	215	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:08:00	\N	0.6	01:02:00	\N	0.8	00:57:00	00:18:00	Newport Marshes, SE of	NC
69318	Newport Marshes, SE of (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_2	34.73133	-76.68333	:America/New_York	USA	knots	226	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:08:00	\N	0.6	01:15:00	\N	0.8	00:53:00	00:21:00	Newport Marshes, SE of	NC
69319	Newport Marshes, E of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6376_1	34.73783	-76.6805	:America/New_York	USA	knots	224	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.5	00:11:00	\N	0.6	00:07:00	-00:37:00	Newport Marshes, E of	NC
69320	Radio Island, E of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6381_1	34.71167	-76.67967	:America/New_York	USA	knots	202	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.6	00:55:00	\N	0.7	00:55:00	00:20:00	Radio Island, E of	NC
69321	Bird Shoal, SE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6391_1	34.7005	-76.65383	:America/New_York	USA	knots	304	126	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.4	01:34:00	\N	0.5	01:40:00	01:10:00	Bird Shoal, SE of	NC
69322	Shackleford Point, NE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6396_1	34.69217	-76.65217	:America/New_York	USA	knots	305	135	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:46:00	\N	0.6	01:28:00	\N	0.8	01:32:00	01:10:00	Shackleford Point, NE of	NC
69323	Carrot Island (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6401_1	34.70217	-76.6175	:America/New_York	USA	knots	262	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:49:00	\N	0.7	01:34:00	\N	0.5	01:49:00	01:15:00	Carrot Island	NC
69324	Middle Marshes, S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6406_1	34.67833	-76.61383	:America/New_York	USA	knots	275	123	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:18:00	\N	0.5	01:04:00	\N	0.8	00:59:00	01:03:00	Middle Marshes, S of	NC
69325	Winyah Bay entrance, Winyah Bay, South Carolina Current	NOS	ACT6531_1	33.20717	-79.1845	:America/New_York	USA	knots	140	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:20:00	\N	1	01:35:00	\N	1.1	01:47:00	01:05:00	Winyah Bay entrance	SC
69326	Range D, off Mosquito Creek, Winyah Bay, South Carolina Current	NOS	ACT6536_1	33.24417	-79.20583	:America/New_York	USA	knots	130	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:42:00	\N	1.1	01:57:00	\N	1.2	02:00:00	01:13:00	Range D, off Mosquito Creek	SC
69327	Frazier Point, south of, Winyah Bay, South Carolina Current	NOS	ACT6541_1	33.295	-79.27283	:America/New_York	USA	knots	115	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:59:00	\N	0.5	01:52:00	\N	1.1	01:52:00	02:20:00	Frazier Point, south of	SC
69328	Frazier Point, west of, Winyah Bay, South Carolina Current	NOS	ACT6546_1	33.30967	-79.28667	:America/New_York	USA	knots	170	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:41:00	\N	1	02:19:00	\N	0.9	02:23:00	02:01:00	Frazier Point, west of	SC
69329	Rabbit Island, northwest of, Winyah Bay, South Carolina Current	NOS	ACT6551_1	33.3395	-79.28133	:America/New_York	USA	knots	215	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:25:00	\N	0.9	02:46:00	\N	1.2	02:39:00	02:14:00	Rabbit Island, northwest of	SC
69330	Sampit River entrance, Winyah Bay, South Carolina Current	NOS	ACT6556_1	33.35133	-79.28033	:America/New_York	USA	knots	135	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:53:00	\N	0.7	01:20:00	\N	0.6	01:33:00	01:39:00	Sampit River entrance	SC
69331	Georgetown, Sampit River, Winyah Bay, South Carolina Current	NOS	ACT6561_1	33.35917	-79.2875	:America/New_York	USA	knots	80	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.6	01:18:00	\N	0.5	02:00:00	00:56:00	Georgetown, Sampit River	SC
69332	Pee Dee River, swing bridge, Winyah Bay, South Carolina Current	NOS	ACT6566_1	33.3705	-79.26383	:America/New_York	USA	knots	210	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:43:00	\N	0.5	03:13:00	\N	0.4	03:03:00	01:57:00	Pee Dee River, swing bridge	SC
69333	Lafayette swing bridge, Waccamaw River, Winyah Bay, South Carolina Current	NOS	ACT6571_1	33.36867	-79.252	:America/New_York	USA	knots	200	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:31:00	\N	0.6	03:04:00	\N	0.4	03:23:00	01:56:00	Lafayette swing bridge, Waccamaw River	SC
69334	Butler Island, 0.3 mile south of, Winyah Bay, South Carolina Current	NOS	ACT6576_1	33.41667	-79.212	:America/New_York	USA	knots	205	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:55:00	\N	0.5	03:34:00	\N	0.4	03:36:00	02:11:00	Butler Island, 0.3 mile south of	SC
69335	North Santee River entrance (Depth 6ft), South Carolina Current	NOS	ACT6581_1	33.13583	-79.24083	:America/New_York	USA	knots	165	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:01:00	\N	0.9	00:33:00	\N	0.9	01:00:00	00:03:00	North Santee River entrance	SC
69336	South Santee River entrance (Depth 5ft), South Carolina Current	NOS	ACT6586_1	33.12	-79.275	:America/New_York	USA	knots	240	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.8	00:38:00	\N	0.9	00:20:00	00:27:00	South Santee River entrance	SC
69337	Fort Sumter Range, Buoy '2', Charleston Harbor, South Carolina Current	NOS	ACT6611_1	32.683	-79.726	:America/New_York	USA	knots	104	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:03:00	\N	0.2	-00:51:00	\N	0.2	-01:05:00	-01:11:00	Fort Sumter Range, Buoy '2'	SC
69338	Fort Sumter Range, Buoy '4', Charleston Harbor, South Carolina Current	NOS	ACT6616_1	32.69767	-79.75567	:America/New_York	USA	knots	117	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:38:00	\N	0.2	-00:59:00	\N	0.3	-00:49:00	-01:10:00	Fort Sumter Range, Buoy '4'	SC
69339	Fort Sumter Range, Buoy '8', Charleston Harbor, South Carolina Current	NOS	ACT6621_1	32.715	-79.79233	:America/New_York	USA	knots	128	299	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.5	-00:16:00	\N	0.4	-00:15:00	00:17:00	Fort Sumter Range, Buoy '8'	SC
69340	Fort Sumter Range, Buoy '14', Charleston Harbor, South Carolina Current	NOS	ACT6626_1	32.72433	-79.81	:America/New_York	USA	knots	116	287	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:01:00	\N	0.8	-00:04:00	\N	0.6	-00:10:00	00:16:00	Fort Sumter Range, Buoy '14'	SC
69342	Charleston Hbr. ent. (between jetties), Charleston Harbor, South Carolina Current	NOS	ACT6636_1	32.73333	-79.83333	:America/New_York	USA	knots	121	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.9	00:04:00	\N	1.1	-00:01:00	00:05:00	Charleston Hbr. ent. (between jetties)	SC
69343	Fort Sumter Range, Buoy '20', Charleston Harbor, South Carolina Current	NOS	ACT6641_1	32.7405	-79.8445	:America/New_York	USA	knots	128	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:51:00	\N	0.9	-00:15:00	\N	0.9	-00:33:00	-00:33:00	Fort Sumter Range, Buoy '20'	SC
69345	Ft. Sumter, 0.6 n.mi. NW of, Charleston Harbor, South Carolina Current	NOS	ACT6656_1	32.76117	-79.86717	:America/New_York	USA	knots	138	322	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:24:00	\N	0.9	-00:03:00	\N	0.9	-00:05:00	00:01:00	Ft. Sumter, 0.6 n.mi. NW of	SC
69346	South Chan., 0.8 mi. ENE of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6661_1	32.75867	-79.88467	:America/New_York	USA	knots	115	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:13:00	\N	1.3	00:11:00	\N	0.5	00:43:00	-00:12:00	South Chan., 0.8 mi. ENE of Ft. Johnson	SC
69347	South Chan., 0.4 mi. NW of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6666_1	32.758	-79.90633	:America/New_York	USA	knots	104	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	1	00:58:00	\N	0.4	01:10:00	00:16:00	South Chan., 0.4 mi. NW of Ft. Johnson	SC
69348	Sullivans I., 0.7 mi. NE of Ft. Sumter, Charleston Harbor, South Carolina Current	NOS	ACT6671_1	32.762	-79.8675	:America/New_York	USA	knots	132	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:03:00	\N	0.8	00:37:00	\N	0.8	00:17:00	00:01:00	Sullivans I., 0.7 mi. NE of Ft. Sumter	SC
69349	Castle Pinckney, 0.4 mile south of, Charleston Harbor, South Carolina Current	NOS	ACT6676_1	32.767	-79.91167	:America/New_York	USA	knots	98	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:58:00	\N	0.9	01:00:00	\N	0.5	00:40:00	00:14:00	Castle Pinckney, 0.4 mile south of	SC
69350	South Channel, Buoy '32', Charleston Harbor, South Carolina Current	NOS	ACT6681_1	32.76217	-79.911	:America/New_York	USA	knots	125	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.5	-00:04:00	\N	0.5	-00:01:00	00:18:00	South Channel, Buoy '32'	SC
69351	Castle Pinckney, 0.6 mile southwest of, Charleston Harbor, South Carolina Current	NOS	ACT6686_1	32.76633	-79.9195	:America/New_York	USA	knots	156	318	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:40:00	\N	0.7	01:20:00	\N	0.4	01:21:00	00:24:00	Castle Pinckney, 0.6 mile southwest of	SC
69352	Shutes Folly Island, 0.4 mile west of, Charleston Harbor, South Carolina Current	NOS	ACT6691_1	32.77633	-79.92083	:America/New_York	USA	knots	164	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:08:00	\N	1.1	00:59:00	\N	0.5	00:53:00	00:20:00	Shutes Folly Island, 0.4 mile west of	SC
69353	Customhouse Reach, off Customhouse, Charleston Harbor, South Carolina Current	NOS	ACT6696_1	32.7795	-79.9225	:America/New_York	USA	knots	190	9	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:23:00	\N	0.7	01:03:00	\N	0.6	00:49:00	00:59:00	Customhouse Reach, off Customhouse	SC
69344	South jetty, break in, Charleston Harbor, South Carolina Current	NOS	ACT6646_1	32.73117	-79.85033	:America/New_York	USA	knots	204	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	1.4	00:31:00	\N	0.7	00:38:00	00:06:00	South Jetty, break in	SC
69354	Customhouse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6701_1	32.7825	-79.92	:America/New_York	USA	knots	153	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.9	00:37:00	\N	0.6	00:46:00	00:37:00	Customhouse Reach	SC
69355	Town Creek Lower Reach, Charleston Harbor, South Carolina Current	NOS	ACT6706_1	32.7925	-79.9245	:America/New_York	USA	knots	172	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:07:00	\N	1.1	00:24:00	\N	0.6	00:34:00	00:02:00	Town Creek Lower Reach	SC
69356	Town Creek, 0.2 mile above bridge, Charleston Harbor, South Carolina Current	NOS	ACT6711_1	32.80533	-79.93167	:America/New_York	USA	knots	166	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	1.3	00:54:00	\N	0.5	01:06:00	00:03:00	Town Creek, 0.2 mile above bridge	SC
69357	Rebellion Reach, 0.8 n.mi. N. of Ft. Sumter, Charleston Harbor, South Carolina Current	NOS	ACT6716_1	32.76633	-79.87333	:America/New_York	USA	knots	143	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:48:00	\N	0.4	00:27:00	\N	0.4	-00:06:00	-00:25:00	Rebellion Reach, 0.8 n.mi. N. of Ft. Sumter	SC
69358	The Cove, entrance on the Cove Range, Charleston Harbor, South Carolina Current	NOS	ACT6721_1	32.7675	-79.872	:America/New_York	USA	knots	151	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:10:00	\N	0.5	01:14:00	\N	0.7	00:28:00	00:06:00	The Cove, entrance on the Cove Range	SC
69359	Hog Island Channel, Charleston Harbor, South Carolina Current	NOS	ACT6726_1	32.78117	-79.87633	:America/New_York	USA	knots	125	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:20:00	\N	0.4	00:03:00	\N	0.5	-00:39:00	-00:29:00	Hog Island Channel	SC
69360	Folly I. Channel, N of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6731_1	32.76967	-79.90117	:America/New_York	USA	knots	104	301	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:59:00	\N	0.6	-00:03:00	\N	0.7	-01:09:00	-00:04:00	Folly I. Channel, N of Ft. Johnson	SC
69361	Folly Reach, Buoy '5', Charleston Harbor, South Carolina Current	NOS	ACT6736_1	32.77633	-79.89917	:America/New_York	USA	knots	110	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:13:00	\N	0.8	00:35:00	\N	0.7	00:02:00	00:18:00	Folly Reach, Buoy '5'	SC
69362	Shutes Reach, Buoy '8', Charleston Harbor, South Carolina Current	NOS	ACT6741_1	32.78217	-79.91083	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:25:00	\N	0.8	00:22:00	\N	0.7	00:18:00	00:15:00	Shutes Reach, Buoy '8'	SC
69363	Horse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6746_1	32.78617	-79.915	:America/New_York	USA	knots	146	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	1	00:23:00	\N	0.8	00:36:00	-00:12:00	Horse Reach	SC
69364	Hog Island Reach, Buoy '12', Charleston Harbor, South Carolina Current	NOS	ACT6751_1	32.7945	-79.915	:America/New_York	USA	knots	193	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:12:00	\N	0.7	00:28:00	\N	0.7	00:13:00	00:14:00	Hog Island Reach, Buoy '12'	SC
69365	Drum Island, 0.4 mile SSE of, Charleston Harbor, South Carolina Current	NOS	ACT6756_1	32.7945	-79.92083	:America/New_York	USA	knots	155	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.9	00:53:00	\N	0.8	00:34:00	00:11:00	Drum Island, 0.4 mile SSE of	SC
69366	Drum Island, east of (bridge), Charleston Harbor, South Carolina Current	NOS	ACT6761_1	32.8045	-79.91533	:America/New_York	USA	knots	183	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:06:00	\N	1	00:42:00	\N	0.7	00:30:00	00:15:00	Drum Island, east of (bridge)	SC
69367	Hog Island Reach, SW of Remley Point, Charleston Harbor, South Carolina Current	NOS	ACT6766_1	32.81183	-79.912	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:51:00	\N	0.7	00:44:00	\N	0.7	00:30:00	00:43:00	Hog Island Reach, SW of Remley Point	SC
69368	Drum Island Reach, off Drum I., Buoy '45', Charleston Harbor, South Carolina Current	NOS	ACT6771_1	32.81617	-79.92283	:America/New_York	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:00:00	\N	0.5	01:00:00	\N	0.4	00:26:00	01:06:00	Drum Island Reach, off Drum I., Buoy '45'	SC
69369	Drum Island, 0.2 mile above, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6776_1	32.81967	-79.92917	:America/New_York	USA	knots	152	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:37:00	\N	1.2	01:09:00	\N	0.6	01:12:00	00:01:00	Drum Island, 0.2 mile above	SC
69370	Daniel Island Reach, Buoy '48', Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6781_1	32.82717	-79.92883	:America/New_York	USA	knots	182	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:55:00	\N	0.7	01:29:00	\N	0.7	01:01:00	00:53:00	Daniel Island Reach, Buoy '48'	SC
69371	Shipyard Creek entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6786_1	32.83	-79.935	:America/New_York	USA	knots	197	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.8	01:06:00	\N	0.3	00:41:00	-00:29:00	Shipyard Creek entrance	SC
69372	Daniel Island Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6791_1	32.83283	-79.93	:America/New_York	USA	knots	190	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:51:00	\N	1.2	01:49:00	\N	0.8	01:29:00	00:42:00	Daniel Island Reach	SC
69373	Daniel Island Bend, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6796_1	32.84833	-79.92917	:America/New_York	USA	knots	153	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:39:00	\N	1.1	01:29:00	\N	0.7	00:55:00	00:55:00	Daniel Island Bend	SC
69374	North Charleston, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6806_1	32.86367	-79.95883	:America/New_York	USA	knots	142	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:17:00	\N	0.9	02:28:00	\N	0.6	01:26:00	01:04:00	North Charleston	SC
69375	Filbin Creek Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6811_1	32.88867	-79.96533	:America/New_York	USA	knots	180	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:27:00	\N	0.9	02:06:00	\N	0.7	01:31:00	01:08:00	Filbin Creek Reach	SC
69376	Filbin Creek Reach, 0.2 mile east of, Cooper River, South Carolina Current	NOS	ACT6816_1	32.888	-79.9605	:America/New_York	USA	knots	197	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:29:00	\N	0.7	01:47:00	\N	0.4	01:16:00	00:32:00	Filbin Creek Reach, 0.2 mile east of	SC
69377	Filbin Creek Reach, Buoy '58', Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6821_1	32.89633	-79.96117	:America/New_York	USA	knots	214	31	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:09:00	\N	0.7	02:04:00	\N	0.6	01:18:00	01:24:00	Filbin Creek Reach, Buoy '58'	SC
69378	Ordnance Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6826_1	32.90633	-79.95283	:America/New_York	USA	knots	242	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:07:00	\N	0.6	02:34:00	\N	0.6	01:35:00	01:05:00	Ordnance Reach	SC
69379	Yellow House Creek, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6831_1	32.90883	-79.93633	:America/New_York	USA	knots	270	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:12:00	\N	0.7	02:41:00	\N	0.4	02:06:00	00:57:00	Yellow House Creek	SC
69380	Yellow House Landing, 1 mile NW of, Cooper River, South Carolina Current	NOS	ACT6836_1	32.91967	-79.9305	:America/New_York	USA	knots	170	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:06:00	\N	0.9	02:43:00	\N	0.4	02:26:00	00:58:00	Yellow House Landing, 1 mile NW of	SC
69381	Woods Point, SE of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6841_1	32.92583084106445	-79.93283081054688	:America/New_York	USA	knots	157	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:09:00	\N	0.5	01:55:00	\N	0.5	01:48:00	01:55:00	Woods Point, SE of	SC
69382	Woods Point, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6846_1	32.93167	-79.93833	:America/New_York	USA	knots	201	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:43:00	\N	0.7	03:02:00	\N	0.5	02:41:00	01:11:00	Woods Point	SC
69383	Snow Point, 0.5 mile north of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6851_1	32.95167	-79.93	:America/New_York	USA	knots	210	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:33:00	\N	0.7	02:36:00	\N	0.6	02:15:00	01:48:00	Snow Point, 0.5 mile north of	SC
69384	Back River entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6856_1	32.96833	-79.93333	:America/New_York	USA	knots	67	252	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:34:00	\N	0.6	00:45:00	\N	0.6	00:46:00	00:48:00	Back River entrance	SC
69385	Amoco Pier, off, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6861_1	32.95917	-79.918	:America/New_York	USA	knots	191	24	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.5	02:49:00	\N	0.4	02:09:00	02:10:00	Amoco Pier, off	SC
69386	Moreland, 0.5 n.mi. below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6866_1	33.0005	-79.90467	:America/New_York	USA	knots	216	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:19:00	\N	1	02:58:00	\N	1.1	02:39:00	02:28:00	Moreland, 0.5 n.mi. below	SC
69387	Hagan Island, 1 n.mi. below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6871_1	33.03333	-79.91333	:America/New_York	USA	knots	134	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:37:00	\N	0.7	03:52:00	\N	0.8	02:39:00	02:27:00	Hagan Island, 1 n.mi. below	SC
69388	The Tee, 0.4 mile southwest of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6876_1	33.06333	-79.92967	:America/New_York	USA	knots	98	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:20:00	\N	0.9	04:20:00	\N	0.6	04:22:00	02:29:00	The Tee, 0.4 mile southwest of	SC
69389	The Tee, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6881_1	33.06583	-79.923	:America/New_York	USA	knots	161	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:43:00	\N	0.5	03:09:00	\N	0.6	03:00:00	02:36:00	The Tee	SC
69390	Childsbury, S.A.L. RR. bridge, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6886_1	33.09383	-79.9425	:America/New_York	USA	knots	141	309	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:34:00	\N	0.9	04:27:00	\N	0.4	04:43:00	02:15:00	Childsbury, S.A.L. RR. bridge	SC
69391	East Branch, 0.2 mile above entrance, Cooper River, South Carolina Current	NOS	ACT6891_1	33.06833	-79.92	:America/New_York	USA	knots	262	84	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:06:00	\N	0.9	03:07:00	\N	1.1	03:01:00	02:59:00	East Branch, 0.2 mile above entrance	SC
69392	Bonneau Ferry, east of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6896_1	33.07167	-79.88333	:America/New_York	USA	knots	197	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:36:00	\N	0.4	03:10:00	\N	0.4	03:27:00	02:44:00	Bonneau Ferry, east of	SC
69393	Remley Point, 0.2 mile northwest of, Wando River, South Carolina Current	NOS	ACT6901_1	32.81617	-79.9095	:America/New_York	USA	knots	191	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:04:00	\N	0.9	00:36:00	\N	0.8	-00:14:00	00:20:00	Remley Point, 0.2 mile northwest of	SC
69394	Wando River Upper Reach, Turning Basin, Wando River, South Carolina Current	NOS	ACT6906_1	32.83333	-79.89667	:America/New_York	USA	knots	192	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.6	-00:12:00	\N	0.6	-00:14:00	-00:09:00	Wando River Upper Reach, Turning Basin	SC
69395	Rathall Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6911_1	32.8595	-79.89617	:America/New_York	USA	knots	216	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:18:00	\N	0.9	00:35:00	\N	0.8	00:25:00	00:18:00	Rathall Creek entrance	SC
69396	Horlbeck Creek, 0.2 mile above entrance, Wando River, South Carolina Current	NOS	ACT6916_1	32.885	-79.845	:America/New_York	USA	knots	218	26	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.5	00:29:00	\N	0.6	00:28:00	00:31:00	Horlbeck Creek, 0.2 mile above entrance	SC
69397	Nowell Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6921_1	32.87833	-79.875	:America/New_York	USA	knots	171	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:39:00	\N	0.6	00:42:00	\N	0.4	-00:02:00	-00:12:00	Nowell Creek entrance	SC
69398	Buoy '19', off Nowell Creek, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6926_1	32.872	-79.8655	:America/New_York	USA	knots	261	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:19:00	\N	0.5	-00:06:00	\N	0.5	-00:08:00	00:04:00	Buoy '19', off Nowell Creek	SC
69399	Horlbeck Creek, 2.5 miles north of, Wando River, South Carolina Current	NOS	ACT6931_1	32.91833	-79.83833	:America/New_York	USA	knots	207	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:28:00	\N	0.7	00:41:00	\N	0.5	00:30:00	00:26:00	Horlbeck Creek, 2.5 miles north of	SC
69400	Battery, southwest of, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6936_1	32.76717	-79.93383	:America/New_York	USA	knots	114	303	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	0.9	00:09:00	\N	0.7	00:16:00	-00:24:00	Battery, southwest of	SC
69401	Wappoo Creek, off of, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6941_1	32.773	-79.95	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:41:00	\N	0.6	-00:05:00	\N	0.7	00:07:00	-00:06:00	Wappoo Creek, off of	SC
69402	Highway Bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6946_1	32.782	-79.96	:America/New_York	USA	knots	138	321	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:18:00	\N	0.6	00:30:00	\N	0.7	-00:09:00	-00:03:00	Highway Bridge	SC
69403	S.C.L. RR. bridge, 0.1 mile below, Ashley River, South Carolina Current	NOS	ACT6951_1	32.7955	-79.97333	:America/New_York	USA	knots	150	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:28:00	\N	0.6	00:44:00	\N	0.6	-00:06:00	-00:12:00	S.C.L. RR. bridge, 0.1 mile below	SC
69404	S.C.L. RR. bridge, 1.5 miles above, Ashley River, South Carolina Current	NOS	ACT6956_1	32.82	-79.965	:America/New_York	USA	knots	178	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.8	00:19:00	\N	0.7	00:22:00	00:17:00	S.C.L. RR. bridge, 1.5 miles above	SC
69405	State Hwy. 7 bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6961_1	32.83717	-79.982	:America/New_York	USA	knots	114	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:05:00	\N	0.5	-00:04:00	\N	0.6	00:06:00	00:05:00	State Hwy. 7 bridge	SC
69406	West Marsh Island, 0.1 mile east of, Ashley River, South Carolina Current	NOS	ACT6966_1	32.82833	-80.00833	:America/New_York	USA	knots	86	250	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:25:00	\N	0.5	00:30:00	\N	0.4	00:23:00	00:14:00	West Marsh Island, 0.1 mile east of	SC
69407	Bees Ferry Bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6971_1	32.84667	-80.05	:America/New_York	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	1.2	00:44:00	\N	1.1	01:13:00	00:37:00	Bees Ferry Bridge	SC
69408	Stono Inlet, Stono River, South Carolina Current	NOS	ACT6976_1	32.62667	-79.99333	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:45:00	\N	1.4	00:44:00	\N	1.1	-00:14:00	-00:09:00	Stono Inlet	SC
69409	Snake Island (Depth 12ft), Stono River, South Carolina Current	NOS	ACT6981_1	32.64	-80.02	:America/New_York	USA	knots	179	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:38:00	\N	0.5	-00:42:00	\N	0.7	-00:44:00	-00:30:00	Snake Island	SC
69410	Johns Island Airport, south of (Depth 12ft), Stono River, South Carolina Current	NOS	ACT6986_1	32.68333	-80.00333	:America/New_York	USA	knots	192	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:34:00	\N	0.8	-00:46:00	\N	0.9	-00:15:00	-00:13:00	Johns Island Airport, south of	SC
69411	Johns Island Bridge (Depth 14ft), Stono River, South Carolina Current	NOS	ACT6991_1	32.75333	-80.01	:America/New_York	USA	knots	182	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:10:00	\N	0.5	00:21:00	\N	0.5	00:40:00	00:33:00	Johns Island Bridge	SC
69412	Elliott Cut, west end, Stono River, South Carolina Current	NOS	ACT6996_1	32.76667	-80	:America/New_York	USA	knots	80	260	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:18:00	\N	1	-01:00:00	\N	0.9	00:10:00	-00:46:00	Elliott Cut, west end	SC
69413	Johns Island (Depth 12ft), Stono River, South Carolina Current	NOS	ACT7001_1	32.78667	-80.10667	:America/New_York	USA	knots	68	249	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:32:00	\N	0.4	01:48:00	\N	0.4	-00:24:00	00:29:00	Johns Island	SC
69414	Pleasant Point (Depth 12ft), Stono River, South Carolina Current	NOS	ACT7006_1	32.75	-80.13333	:America/New_York	USA	knots	196	8	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:37:00	\N	0.4	00:34:00	\N	0.3	02:04:00	03:54:00	Pleasant Point	SC
69415	Deveaux Banks, off North Edisto River entrance (Depth 12ft), South Carolina Current	NOS	ACT7021_1	32.545	-80.15667	:America/New_York	USA	knots	126	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:26:00	\N	1	-00:01:00	\N	0.8	-00:16:00	-00:04:00	Deveaux Banks, off North Edisto River entrance	SC
69416	North Edisto River entrance, South Carolina Current	NOS	ACT7026_1	32.56167	-80.18667	:America/New_York	USA	knots	142	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	1.9	01:10:00	\N	1.7	00:56:00	01:11:00	North Edisto River entrance	SC
69417	Wadmalaw Island, Wadmalaw River entrance (Depth 12ft), South Carolina Current	NOS	ACT7031_1	32.665	-80.235	:America/New_York	USA	knots	165	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:29:00	\N	0.4	00:11:00	\N	0.7	-01:02:00	00:06:00	Wadmalaw Island, Wadmalaw River entrance	SC
69418	Goshen Point, SE of, Wadmalaw River (Depth 12ft), South Carolina Current	NOS	ACT7036_1	32.71	-80.17167	:America/New_York	USA	knots	249	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.4	02:18:00	\N	0.5	00:51:00	01:47:00	Goshen Point, SE of, Wadmalaw River	SC
69419	Goshen Point, south of, Wadmalaw River (Depth 12ft), South Carolina Current	NOS	ACT7041_1	32.71333	-80.18667	:America/New_York	USA	knots	235	48	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:53:00	\N	0.5	02:03:00	\N	0.4	01:24:00	01:35:00	Goshen Point, south of, Wadmalaw River	SC
69420	White Point, south of, Dawho River (Depth 12ft), South Carolina Current	NOS	ACT7046_1	32.625	-80.28167	:America/New_York	USA	knots	44	234	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.4	00:02:00	\N	0.4	00:31:00	00:29:00	White Point, south of, Dawho River	SC
69421	Whooping Island, Dawho River (Depth 12ft), South Carolina Current	NOS	ACT7051_1	32.63667	-80.34	:America/New_York	USA	knots	70	246	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:37:00	\N	0.3	00:36:00	\N	0.5	01:36:00	01:35:00	Whooping Island, Dawho River	SC
69422	South Edisto River entrance, South Carolina Current	NOS	ACT7056_1	32.48833	-80.34833	:America/New_York	USA	knots	146	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	1.1	-00:14:00	\N	1.1	00:19:00	-00:09:00	South Edisto River entrance	SC
69423	Pine Island, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7061_1	32.50667	-80.36167	:America/New_York	USA	knots	163	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:37:00	\N	0.5	-00:09:00	\N	0.7	00:00:00	00:12:00	Pine Island, South Edisto River	SC
69424	Fenwick Island Cut, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7066_1	32.535	-80.41333	:America/New_York	USA	knots	23	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:26:00	\N	0.4	-00:55:00	\N	0.4	-02:43:00	-03:20:00	Fenwick Island Cut, South Edisto River	SC
69425	Sampson Island, S end, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7071_1	32.56333	-80.39167	:America/New_York	USA	knots	244	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.8	00:34:00	\N	0.8	00:59:00	00:59:00	Sampson Island, S end, South Edisto River	SC
69426	Sampson Island, NE end, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7076_1	32.61667	-80.38667	:America/New_York	USA	knots	156	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.8	01:15:00	\N	0.8	01:35:00	01:02:00	Sampson Island, NE end, South Edisto River	SC
69427	Jehossee Island, S tip, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7081_1	32.60333	-80.42	:America/New_York	USA	knots	69	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:05:00	\N	0.7	00:48:00	\N	0.7	01:44:00	00:53:00	Jehossee Island, S tip, South Edisto River	SC
69428	Smuggedy Swamp, South Edisto River (Depth 6ft), South Carolina Current	NOS	ACT7086_1	32.66	-80.41167	:America/New_York	USA	knots	166	349	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:25:00	\N	0.7	01:14:00	\N	0.5	02:26:00	01:01:00	Smuggedy Swamp, South Edisto River	SC
69429	Hutchinson Island, Ashepoo River (Depth 10ft), South Carolina Current	NOS	ACT7091_1	32.53167	-80.435	:America/New_York	USA	knots	68	278	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:56:00	\N	0.7	01:14:00	\N	0.6	01:21:00	00:54:00	Hutchinson Island, Ashepoo River	SC
69430	Ashepoo Coosaw Cutoff (Depth 6ft), South Carolina Current	NOS	ACT7096_1	32.525	-80.45333	:America/New_York	USA	knots	265	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:12:00	\N	0.6	00:36:00	\N	0.5	01:22:00	00:56:00	Ashepoo Coosaw Cutoff	SC
69431	Pelican Bank, St. Helena Sound (Depth 15ft), South Carolina Current	NOS	ACT7101_1	32.455	-80.42833	:America/New_York	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:35:00	\N	0.8	-00:33:00	\N	0.9	00:05:00	00:17:00	Pelican Bank, St. Helena Sound	SC
69432	Ashepoo River, off Jefford Creek entrance, South Carolina Current	NOS	ACT7106_1	32.50667	-80.41	:America/New_York	USA	knots	197	16	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	0.8	00:46:00	\N	0.9	01:04:00	01:00:00	Ashepoo River, off Jefford Creek entrance	SC
69433	Egg Bank, St. Helena Sound (Depth 10ft), South Carolina Current	NOS	ACT7111_1	32.435	-80.44333	:America/New_York	USA	knots	128	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:20:00	\N	0.8	-01:24:00	\N	0.8	-00:12:00	-00:06:00	Egg Bank, St. Helena Sound	SC
69434	Morgan Island, NE of, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7116_1	32.48833	-80.47333	:America/New_York	USA	knots	125	303	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:19:00	\N	1	00:27:00	\N	0.8	00:28:00	00:36:00	Morgan Island, NE of, Coosaw River	SC
69435	Ashe Island Cut, SW of, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7121_1	32.51	-80.505	:America/New_York	USA	knots	134	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.6	-00:09:00	\N	0.6	00:32:00	00:43:00	Ashe Island Cut, SW of, Coosaw River	SC
69436	Ashe Island Cut, St. Helena Sound (Depth 6ft), South Carolina Current	NOS	ACT7126_1	32.52	-80.48833	:America/New_York	USA	knots	34	232	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:13:00	\N	0.4	01:41:00	\N	0.5	00:31:00	01:01:00	Ashe Island Cut, St. Helena Sound	SC
69437	Combahee River (Depth 8ft), South Carolina Current	NOS	ACT7131_1	32.52667	-80.53667	:America/New_York	USA	knots	147	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:53:00	\N	0.8	00:59:00	\N	0.6	00:55:00	01:04:00	Combahee River	SC
69438	Combahee River (Depth 15ft), South Carolina Current	NOS	ACT7136_1	32.55	-80.56333	:America/New_York	USA	knots	73	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:03:00	\N	1	01:35:00	\N	0.8	01:36:00	01:33:00	Combahee River	SC
69439	Parrot Creek, Coosaw Island (Depth 15ft), South Carolina Current	NOS	ACT7141_1	32.47333	-80.545	:America/New_York	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:54:00	\N	0.6	-00:48:00	\N	0.7	00:12:00	00:24:00	Parrot Creek, Coosaw Island	SC
69440	Morgan Island, North end, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7146_1	32.50333	-80.53667	:America/New_York	USA	knots	85	271	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:30:00	\N	0.9	00:41:00	\N	0.8	00:34:00	00:27:00	Morgan Island, North end, Coosaw River	SC
69441	Williman Creek (Depth 10ft), South Carolina Current	NOS	ACT7151_1	32.56167	-80.59167	:America/New_York	USA	knots	160	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:04:00	\N	0.8	01:27:00	\N	0.6	00:40:00	01:02:00	Williman Creek	SC
69442	Coosaw Island, South of, Morgan River (Depth 10ft), South Carolina Current	NOS	ACT7156_1	32.45167	-80.58333	:America/New_York	USA	knots	58	252	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	0.7	00:55:00	\N	0.7	00:09:00	00:15:00	Coosaw Island, South of, Morgan River	SC
69443	Sams Point, Northwest of, Coosaw River (Depth 10ft), South Carolina Current	NOS	ACT7161_1	32.49333	-80.59333	:America/New_York	USA	knots	117	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.6	00:36:00	\N	0.5	00:34:00	00:31:00	Sams Point, Northwest of, Coosaw River	SC
69444	Whale Branch River (Depth 10ft), South Carolina Current	NOS	ACT7166_1	32.52667	-80.69167	:America/New_York	USA	knots	111	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.7	-00:09:00	\N	0.5	01:12:00	00:51:00	Whale Branch River	SC
69445	Fripps Inlet, Fripps Island (Depth 15ft), South Carolina Current	NOS	ACT7171_1	32.34	-80.465	:America/New_York	USA	knots	104	299	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:29:00	\N	0.6	01:12:00	\N	0.7	-00:29:00	-00:22:00	Fripps Inlet, Fripps Island	SC
69774	Narrows, Pearse Canal, Alaska Current	NOS	PCT2681_1	54.83467	-130.4855	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:47:00	\N	1.3	00:26:00	\N	0.9	00:34:00	00:31:00	Narrows	AK
69446	Southeast Channel entrance, Port Royal Sound, South Carolina Current	NOS	ACT7181_1	32.13333	-80.58333	:America/New_York	USA	knots	150	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:12:00	\N	0.8	-00:38:00	\N	0.8	-00:30:00	-00:09:00	Southeast Channel entrance	SC
69447	Port Royal Plantation Tower, east of (Depth 15ft), South Carolina Current	NOS	ACT7186_1	32.22333	-80.65667	:America/New_York	USA	knots	147	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	1	-00:16:00	\N	0.9	00:33:00	00:19:00	Port Royal Plantation Tower, east of	SC
69448	Bay Point Island, S of, Broad River entrance (Depth 15ft), South Carolina Current	NOS	ACT7191_1	32.23333	-80.63	:America/New_York	USA	knots	128	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:46:00	\N	0.9	-01:09:00	\N	0.7	00:39:00	00:06:00	Bay Point Island, S of, Broad River entrance	SC
69450	Hilton Head, Port Royal Sound, South Carolina Current	NOS	ACT7201_1	32.25	-80.66667	:America/New_York	USA	knots	146	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:01:00	\N	0.9	00:49:00	\N	1.1	00:16:00	00:32:00	Hilton Head	SC
69452	Parris Island, Beaufort River (Depth 10ft), Port Royal Sound, South Carolina Current	NOS	ACT7211_1	32.32667	-80.65667	:America/New_York	USA	knots	175	356	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:00:00	\N	0.8	01:12:00	\N	0.7	00:29:00	00:11:00	Parris Island, Beaufort River	SC
69453	Chowan Creek (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7216_1	32.37	-80.63833	:America/New_York	USA	knots	246	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:34:00	\N	0.6	01:53:00	\N	0.6	00:24:00	00:23:00	Chowan Creek	SC
69454	Parris Island, Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7221_1	32.36	-80.675	:America/New_York	USA	knots	149	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	0.7	01:19:00	\N	0.7	00:56:00	00:51:00	Parris Island, Beaufort River	SC
69455	Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7226_1	32.40333	-80.67167	:America/New_York	USA	knots	200	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:33:00	\N	0.5	01:19:00	\N	0.5	01:04:00	01:01:00	Beaufort River	SC
69456	Beaufort, Beaufort River (Depth 12ft), Port Royal Sound, South Carolina Current	NOS	ACT7231_1	32.43	-80.67667	:America/New_York	USA	knots	257	73	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:17:00	\N	0.6	01:18:00	\N	0.7	00:55:00	01:08:00	Beaufort, Beaufort River	SC
69457	Beaufort Airport, Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7236_1	32.45	-80.66333	:America/New_York	USA	knots	152	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:08:00	\N	0.5	01:39:00	\N	0.5	01:25:00	01:21:00	Beaufort Airport, Beaufort River	SC
69458	Brickyard Creek (Depth 10ft), Port Royal Sound, South Carolina Current	NOS	ACT7241_1	32.47333	-80.69167	:America/New_York	USA	knots	171	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:58:00	\N	0.4	00:30:00	\N	0.5	01:48:00	02:50:00	Brickyard Creek	SC
69459	Skull Creek, north entrance, Port Royal Sound, South Carolina Current	NOS	ACT7246_1	32.26333	-80.74167	:America/New_York	USA	knots	35	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-02:14:00	\N	0.6	-01:20:00	\N	0.4	-01:50:00	-01:58:00	Skull Creek, north entrance	SC
69460	Daws Island, SE of, Broad River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7251_1	32.30167	-80.725	:America/New_York	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.8	00:05:00	\N	0.8	00:46:00	00:39:00	Daws Island, SE of, Broad River	SC
69461	Parris Island Lookout Tower, Broad River (Depth 15ft), South Carolina Current	NOS	ACT7256_1	32.31167	-80.70667	:America/New_York	USA	knots	152	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.7	-00:07:00	\N	0.7	00:39:00	00:29:00	Parris Island Lookout Tower, Broad River	SC
69462	Daws Island, south of, Chechessee River (Depth 15ft), South Carolina Current	NOS	ACT7261_1	32.28667	-80.74333	:America/New_York	USA	knots	142	317	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.7	-00:22:00	\N	0.6	00:31:00	00:34:00	Daws Island, south of, Chechessee River	SC
69463	Lemon Island South, Chechessee River (Depth 10ft), South Carolina Current	NOS	ACT7266_1	32.35	-80.80667	:America/New_York	USA	knots	175	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.7	01:19:00	\N	0.6	00:33:00	00:39:00	Lemon Island South, Chechessee River	SC
69464	Broad River Bridge, S of, Broad River (Depth 15ft), South Carolina Current	NOS	ACT7271_1	32.38167	-80.77667	:America/New_York	USA	knots	156	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:07:00	\N	0.8	-00:15:00	\N	0.6	00:52:00	00:49:00	Broad River Bridge, S of, Broad River	SC
69466	Little Barnwell I., E of, Whale Branch River (Depth 6ft), South Carolina Current	NOS	ACT7281_1	32.50167	-80.78667	:America/New_York	USA	knots	175	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:40:00	\N	0.4	03:03:00	\N	0.6	01:41:00	01:54:00	Little Barnwell I., E of, Whale Branch River	SC
69467	Braddock Point, SW of, Calibogue Sound (Depth 10ft), South Carolina Current	NOS	ACT7286_1	32.105	-80.83667	:America/New_York	USA	knots	183	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:04:00	\N	1	00:16:00	\N	0.8	-00:15:00	-00:04:00	Braddock Point, SW of, Calibogue Sound	SC
69468	Haig Point Light, NW of, Cooper River (Depth 10ft), South Carolina Current	NOS	ACT7291_1	32.14833	-80.84167	:America/New_York	USA	knots	94	278	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.7	-00:05:00	\N	0.4	-00:51:00	-00:40:00	Haig Point Light, NW of, Cooper River	SC
69469	Ramshorn Creek Light, E of, Cooper River (Depth 6ft), South Carolina Current	NOS	ACT7296_1	32.13	-80.88167	:America/New_York	USA	knots	98	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:17:00	\N	0.7	-00:53:00	\N	0.5	00:06:00	00:15:00	Ramshorn Creek Light, E of, Cooper River	SC
69470	Spanish Wells, Calibogue Sound (Depth 30ft), Calibogue Sound, South Carolina Current	NOS	ACT7301_1	32.18667	-80.785	:America/New_York	USA	knots	204	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.7	00:51:00	\N	0.7	-00:14:00	00:12:00	Spanish Wells, Calibogue Sound	SC
69471	Skull Creek, south entrance (Depth 10ft), Calibogue Sound, South Carolina Current	NOS	ACT7306_1	32.22333	-80.785	:America/New_York	USA	knots	231	53	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:55:00	\N	0.4	02:57:00	\N	0.4	00:38:00	01:23:00	Skull Creek, south entrance	SC
69472	MacKay Creek, south entrance (Depth 10ft), Calibogue Sound, South Carolina Current	NOS	ACT7311_1	32.22	-80.79	:America/New_York	USA	knots	212	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:26:00	\N	0.6	00:03:00	\N	0.3	00:06:00	00:12:00	MacKay Creek, south entrance	SC
69473	Bloody Pt., 0.5 mile north of, New River, South Carolina Current	NOS	ACT7316_1	32.08833	-80.88	:America/New_York	USA	knots	147	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:13:00	\N	0.6	00:00:00	\N	0.6	-01:03:00	-00:53:00	Bloody Pt., 0.5 mile north of, New River	SC
69474	Bloody Pt., 0.5 mile west of, New River, South Carolina Current	NOS	ACT7321_1	32.08167	-80.88333	:America/New_York	USA	knots	92	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:26:00	\N	0.9	-00:21:00	\N	0.9	-00:47:00	-00:36:00	Bloody Pt., 0.5 mile west of, New River	SC
69475	Wright R., 0.2 mile above Walls Cut, South Carolina Current	NOS	ACT7326_1	32.085	-80.92167	:America/New_York	USA	knots	142	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.8	-00:16:00	\N	0.6	-00:38:00	-00:38:00	Wright R., 0.2 mile above Walls Cut	SC
69476	Walls Cut, Turtle Island (Depth 6ft), South Carolina Current	NOS	ACT7336_1	32.08167	-80.91667	:America/New_York	USA	knots	100	294	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-03:05:00	\N	0.5	-00:57:00	\N	0.5	-02:29:00	-01:12:00	Walls Cut, Turtle Island	SC
69477	Daufuskie Landing Light, south of (Depth 10ft), South Carolina Current	NOS	ACT7341_1	32.10167	-80.89833	:America/New_York	USA	knots	226	43	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:45:00	\N	0.8	01:04:00	\N	0.7	00:07:00	00:02:00	Daufuskie Landing Light, south of	SC
69478	Fort Pulaski, Savannah River, Georgia Current	NOS	ACT7356_1	32.03667	-80.90167	:America/New_York	USA	knots	98	283	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:09:00	\N	1.5	00:51:00	\N	0.9	00:42:00	00:15:00	Fort Pulaski	GA
69479	Fort Pulaski, 1.8 miles above, Savannah River, Georgia Current	NOS	ACT7361_1	32.045	-80.93167	:America/New_York	USA	knots	140	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:12:00	\N	1.4	00:18:00	\N	1.1	00:25:00	-00:01:00	Fort Pulaski, 1.8 miles above	GA
69480	Fort Pulaski, 4.8 miles above, Savannah River, Georgia Current	NOS	ACT7366_1	32.075	-80.97667	:America/New_York	USA	knots	116	296	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:16:00	\N	1.5	00:31:00	\N	1.1	00:36:00	00:06:00	Fort Pulaski, 4.8 miles above	GA
69481	McQueen Island Cut (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7371_1	32.065	-80.98667	:America/New_York	USA	knots	69	251	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:44:00	\N	0.6	-02:45:00	\N	0.3	-02:39:00	-01:04:00	McQueen Island Cut	GA
69482	Elba Island Cut, NE of, Savannah River (Depth 10ft), South Carolina Current	NOS	ACT7376_1	32.07333	-80.965	:America/New_York	USA	knots	104	288	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:14:00	\N	1.3	00:15:00	\N	0.7	00:26:00	-00:37:00	Elba Island Cut, NE of, Savannah River	SC
69483	Elba Island, NE of, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7381_1	32.09	-80.99333	:America/New_York	USA	knots	149	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:27:00	\N	1.2	00:40:00	\N	0.6	01:01:00	-00:35:00	Elba Island, NE of, Savannah River	GA
69484	Elba Island, west of, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7386_1	32.095	-81.02	:America/New_York	USA	knots	40	219	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:53:00	\N	0.8	00:52:00	\N	0.5	00:37:00	-00:30:00	Elba Island, west of, Savannah River	GA
69485	Fig Island, north of, Back River, Savannah River, Georgia Current	NOS	ACT7391_1	32.085	-81.05	:America/New_York	USA	knots	94	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	0.7	01:06:00	\N	0.5	00:14:00	-00:25:00	Fig Island, north of, Back River	GA
69486	South Channel, western end, Savannah River, Georgia Current	NOS	ACT7396_1	32.08833	-81.01667	:America/New_York	USA	knots	122	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:35:00	\N	0.7	00:18:00	\N	0.5	00:42:00	-00:33:00	South Channel, western end	GA
69487	Wilmington R. ent., south channel, Savannah River, Georgia Current	NOS	ACT7401_1	32.07667	-81.00167	:America/New_York	USA	knots	206	32	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	01:25:00	\N	0.8	-00:36:00	\N	0.5	00:42:00	01:28:00	Wilmington R. ent., south channel	GA
69488	Savannah, southeast of highway bridge (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7406_1	32.08667	-81.09667	:America/New_York	USA	knots	146	319	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:05:00	\N	1.3	00:41:00	\N	0.6	01:36:00	-00:24:00	Savannah, southeast of highway bridge	GA
69489	Savannah, Savannah River, Georgia Current	NOS	ACT7411_1	32.08333	-81.08333	:America/New_York	USA	knots	106	279	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:18:00	\N	1.1	00:45:00	\N	0.8	01:12:00	00:01:00	Savannah	GA
69490	Kings Island Channel, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7416_1	32.12667	-81.13667	:America/New_York	USA	knots	152	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	1	00:45:00	\N	0.8	01:21:00	00:06:00	Kings Island Channel, Savannah River	GA
69491	Seaboard Coast Line Railroad, Savannah River, Georgia Current	NOS	ACT7421_1	32.10333	-81.11833	:America/New_York	USA	knots	150	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:59:00	\N	1.7	00:45:00	\N	1.2	01:06:00	00:29:00	Seaboard Coast Line Railroad	GA
69492	King Island, west of, Savannah River, Georgia Current	NOS	ACT7426_1	32.12333	-81.135	:America/New_York	USA	knots	160	337	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:48:00	\N	1	00:54:00	\N	0.7	01:21:00	00:33:00	King Island, west of	GA
69493	Port Wentworth, 0.2 mile above, Savannah River, Georgia Current	NOS	ACT7431_1	32.14667	-81.14	:America/New_York	USA	knots	210	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	01:19:00	\N	0.7	01:36:00	\N	0.5	02:00:00	00:24:00	Port Wentworth, 0.2 mile above	GA
69494	Wassaw Island, N of E end, Wassaw Sound (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7441_1	31.915	-80.93833	:America/New_York	USA	knots	108	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:33:00	\N	1	-00:50:00	\N	0.7	-00:48:00	-00:45:00	Wassaw Island, N of E end, Wassaw Sound	GA
69495	Entrance, off Beach Hammock, Wassaw Sound, Georgia Current	NOS	ACT7446_1	31.94167	-80.93167	:America/New_York	USA	knots	156	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:44:00	\N	1.1	-01:00:00	\N	0.9	-00:41:00	-00:54:00	Entrance, off Beach Hammock	GA
69496	Wilmington Island, SSE of, Bull River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7451_1	31.96667	-80.93	:America/New_York	USA	knots	218	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:00:00	\N	0.7	00:38:00	\N	0.4	-00:35:00	-00:40:00	Wilmington Island, SSE of, Bull River	GA
69498	Bull River, 2 miles below hwy. bridge, Wassaw Sound, Georgia Current	NOS	ACT7461_1	32.01833	-80.94	:America/New_York	USA	knots	151	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:57:00	\N	0.8	-00:18:00	\N	0.6	-00:18:00	-00:25:00	Bull River, 2 miles below hwy. bridge	GA
69499	Entrance, off Wassaw Island, Wassaw Sound, Georgia Current	NOS	ACT7466_1	31.91667	-80.94667	:America/New_York	USA	knots	105	277	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.9	-01:11:00	\N	0.7	-00:46:00	-00:42:00	Entrance, off Wassaw Island	GA
69500	Wilmington River ent. off Cabbage Island, Wassaw Sound, Georgia Current	NOS	ACT7471_1	31.93833	-80.97667	:America/New_York	USA	knots	138	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.8	-00:36:00	\N	0.6	-00:44:00	-00:45:00	Wilmington River ent. off Cabbage Island	GA
69501	Joe's Cut, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7476_1	31.94333	-80.985	:America/New_York	USA	knots	123	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:44:00	\N	1	-00:48:00	\N	0.6	-00:54:00	-00:34:00	Joe's Cut, Wilmington River	GA
69502	Wilmington R., 0.5 mi. S of Turners Creek, Wassaw Sound, Georgia Current	NOS	ACT7481_1	32.005	-81.00333	:America/New_York	USA	knots	154	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.7	-00:10:00	\N	0.5	-00:31:00	-00:37:00	Wilmington R., 0.5 mi. S of Turners Creek	GA
69503	Thunderbolt, SE of, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7486_1	32.02333	-81.045	:America/New_York	USA	knots	121	298	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:25:00	\N	0.5	-01:04:00	\N	0.4	-00:20:00	00:12:00	Thunderbolt, SE of, Wilmington River	GA
69504	Oatland Island, north tip (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7491_1	32.07333	-81.01	:America/New_York	USA	knots	138	317	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:32:00	\N	0.5	-02:14:00	\N	0.3	-03:20:00	-00:43:00	Oatland Island, north tip	GA
69505	Skidaway River, north entrance, Wassaw Sound, Georgia Current	NOS	ACT7496_1	32.00833	-81.01667	:America/New_York	USA	knots	16	204	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:11:00	\N	0.7	-00:02:00	\N	0.6	-00:46:00	-00:49:00	Skidaway River, north entrance	GA
69506	Skidaway Island, N End, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7501_1	32.01	-81.00833	:America/New_York	USA	knots	119	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:49:00	\N	0.9	00:16:00	\N	0.6	-00:33:00	-00:23:00	Skidaway Island, N End, Wilmington River	GA
69507	Dutch Island, SE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7506_1	31.99167	-81.02	:America/New_York	USA	knots	61	245	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:02:00	\N	0.6	00:16:00	\N	0.5	-00:40:00	-00:33:00	Dutch Island, SE of, Skidaway River	GA
69508	Isle of Hope City, SE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7511_1	31.97667	-81.04667	:America/New_York	USA	knots	72	268	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:40:00	\N	0.3	-00:30:00	\N	0.2	-00:17:00	-00:32:00	Isle of Hope City, SE of, Skidaway River	GA
69509	Isle of Hope City, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7516_1	31.98	-81.055	:America/New_York	USA	knots	28	212	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:25:00	\N	0.3	00:00:00	\N	0.4	-00:34:00	-00:19:00	Isle of Hope City, Skidaway River	GA
69510	Burntpot Island, west of, Skidaway River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7521_1	31.96833	-81.05333	:America/New_York	USA	knots	18	194	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:03:00	\N	0.5	-00:41:00	\N	0.5	-00:27:00	-00:13:00	Burntpot Island, west of, Skidaway River	GA
69511	Skidaway Narrows, Wassaw Sound, Georgia Current	NOS	ACT7526_1	31.95333	-81.065	:America/New_York	USA	knots	42	218	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.5	-00:24:00	\N	0.5	00:03:00	00:26:00	Skidaway Narrows	GA
69512	Long Island, NNE of, Skidaway River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7531_1	31.95667	-81.06	:America/New_York	USA	knots	47	226	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:17:00	\N	0.4	-01:09:00	\N	0.4	-00:13:00	01:02:00	Long Island, NNE of, Skidaway River	GA
69513	Long Island, south of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7536_1	31.94333	-81.07333	:America/New_York	USA	knots	258	75	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-08:05:00	\N	0.3	-04:43:00	\N	0.2	-04:25:00	-06:07:00	Long Island, south of, Skidaway River	GA
69514	Pigeon Island, SSE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7541_1	31.93667	-81.07667	:America/New_York	USA	knots	150	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:16:00	\N	0.5	-02:43:00	\N	0.2	-02:37:00	-00:56:00	Pigeon Island, SSE of, Skidaway River	GA
69515	Burnside Island, SE of, Burnside River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7546_1	31.92167	-81.08	:America/New_York	USA	knots	295	114	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:05:00	\N	0.6	00:53:00	\N	0.4	-00:40:00	-00:20:00	Burnside Island, SE of, Burnside River	GA
69516	Little Don Island, east of, Vernon River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7551_1	31.87	-81.07333	:America/New_York	USA	knots	153	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:38:00	\N	0.7	-01:16:00	\N	0.7	-00:17:00	-00:03:00	Little Don Island, east of, Vernon River	GA
69519	Montgomery, Vernon River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7561_1	31.935	-81.12833	:America/New_York	USA	knots	89	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:30:00	\N	0.6	00:00:00	\N	0.3	-00:32:00	-00:24:00	Montgomery, Vernon River	GA
69522	Wassaw Island, SSW of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_1	31.85667	-81.00833	:America/New_York	USA	knots	123	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:01:00	\N	1.1	-01:04:00	\N	0.8	-00:26:00	-00:27:00	Wassaw Island, SSW of	GA
69523	Wassaw Island, SSW of (Depth 20ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_2	31.85667	-81.00833	:America/New_York	USA	knots	132	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:01:00	\N	0.9	-00:58:00	\N	0.7	-00:46:00	-00:33:00	Wassaw Island, SSW of	GA
69524	Bradley Point, NNE of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7576_1	31.83167	-81.03833	:America/New_York	USA	knots	125	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.8	-00:58:00	\N	0.6	-00:48:00	-00:48:00	Bradley Point, NNE of	GA
69525	Raccoon Key (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7581_1	31.86167	-81.055	:America/New_York	USA	knots	117	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:35:00	\N	0.9	-01:23:00	\N	0.8	-00:45:00	-00:36:00	Raccoon Key	GA
69526	Little Wassaw Island, SW of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7586_1	31.87	-81.05	:America/New_York	USA	knots	116	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.7	-00:17:00	\N	0.9	-01:05:00	-00:21:00	Little Wassaw Island, SW of	GA
69527	Vernon R., 1.2 miles S of Possum Point, Ossabaw Sound, Georgia Current	NOS	ACT7591_1	31.89833	-81.09833	:America/New_York	USA	knots	166	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:33:00	\N	0.8	00:02:00	\N	0.6	-00:24:00	-00:12:00	Vernon R., 1.2 miles S of Possum Point	GA
69529	Raccoon Key & Egg Island Shoal, between (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7601_1	31.84283	-81.0675	:America/New_York	USA	knots	129	254	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:57:00	\N	1	00:17:00	\N	0.8	00:20:00	-00:23:00	Raccoon Key & Egg Island Shoal, between	GA
69530	Florida Passage, N of, Ogeechee River (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7606_1	31.85667	-81.14333	:America/New_York	USA	knots	127	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:05:00	\N	1	00:01:00	\N	0.7	00:10:00	-00:01:00	Florida Passage, N of, Ogeechee River	GA
69531	Florida Passage (south) (Depth 6ft), Ossabaw Sound, Georgia Current	NOS	ACT7611_1	31.82967	-81.15783	:America/New_York	USA	knots	18	187	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.7	-01:13:00	\N	0.5	-01:48:00	-00:23:00	Florida Passage (south)	GA
69532	610 Statute Mile Mark (Depth 6ft), Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7616_1	31.8105	-81.17667	:America/New_York	USA	knots	175	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:39:00	\N	0.7	00:48:00	\N	0.5	00:20:00	-00:05:00	610 Statute Mile Mark	GA
69536	Medway River at Marsh Island (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7636_1	31.74333	-81.22	:America/New_York	USA	knots	117	313	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:56:00	\N	0.8	-00:18:00	\N	0.3	00:20:00	-00:15:00	Medway River at Marsh Island	GA
69538	Medway River, northwest of Cedar Point (Depth 10ft), Georgia Current	NOS	ACT7646_1	31.7145	-81.19083	:America/New_York	USA	knots	146	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	0.8	-00:43:00	\N	0.7	-00:40:00	-00:23:00	Medway River, northwest of Cedar Point	GA
69539	N. Newport River, NE of Vandyke Creek (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7651_1	31.69117	-81.187	:America/New_York	USA	knots	45	233	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:21:00	\N	0.8	00:12:00	\N	0.7	-00:27:00	00:00:00	N. Newport River, NE of Vandyke Creek	GA
69540	N. Newport River, above Walburg Creek (Depth 6ft), St. Catherines Sound, Georgia Current	NOS	ACT7656_1	31.67383	-81.19533	:America/New_York	USA	knots	11	195	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:40:00	\N	0.8	00:30:00	\N	0.6	-00:34:00	-00:39:00	N. Newport River, above Walburg Creek	GA
69541	N. Newport River, NW of Johnson Creek (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7661_1	31.663	-81.2105	:America/New_York	USA	knots	138	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:27:00	\N	0.9	-01:01:00	\N	0.5	00:20:00	-00:37:00	N. Newport River, NW of Johnson Creek	GA
69542	N. Newport River, ESE of S. Newport Cut (Depth 6ft), Georgia Current	NOS	ACT7666_1	31.66533	-81.2645	:America/New_York	USA	knots	147	319	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:15:00	\N	0.7	-00:13:00	\N	0.5	00:32:00	00:27:00	N. Newport River, ESE of S. Newport Cut	GA
69543	S. Newport River, below S. Newport Cut (Depth 10ft), Georgia Current	NOS	ACT7671_1	31.65033	-81.302	:America/New_York	USA	knots	134	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	02:15:00	\N	0.5	01:30:00	\N	0.5	01:20:00	02:41:00	S. Newport River, below S. Newport Cut	GA
69544	S. Newport River, above Swain River Ent (Depth 10ft), Georgia Current	NOS	ACT7676_1	31.6245	-81.21667	:America/New_York	USA	knots	156	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:43:00	\N	0.6	-01:13:00	\N	0.6	-00:22:00	00:00:00	S. Newport River, above Swain River Ent	GA
69545	Entrance (Depth 19ft), Sapelo Sound, Georgia Current	NOS	ACT7681_1	31.54	-81.18	:America/New_York	USA	knots	118	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:59:00	\N	1.1	00:28:00	\N	0.9	-00:30:00	-00:06:00	Entrance	GA
69546	Entrance (Depth 29ft), Sapelo Sound, Georgia Current	NOS	ACT7681_2	31.54	-81.18	:America/New_York	USA	knots	116	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:02:00	\N	0.9	-00:36:00	\N	0.7	-00:48:00	-00:17:00	Entrance	GA
69547	Johnson Creek, midway between ends, Sapelo Sound, Georgia Current	NOS	ACT7686_1	31.62667	-81.18833	:America/New_York	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:59:00	\N	0.4	-01:08:00	\N	0.4	-01:50:00	-00:35:00	Johnson Creek, midway between ends	GA
69548	Cedar Hammock, south of (Depth 12ft), Sapelo Sound, Georgia Current	NOS	ACT7691_1	31.545	-81.24667	:America/New_York	USA	knots	96	277	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:38:00	\N	0.6	-01:00:00	\N	0.7	-00:26:00	-00:12:00	Cedar Hammock, south of	GA
69550	Sutherland Bluff, Sapelo River, Sapelo Sound, Georgia Current	NOS	ACT7701_1	31.54833	-81.33333	:America/New_York	USA	knots	104	281	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.6	00:10:00	\N	0.5	-00:30:00	-00:12:00	Sutherland Bluff, Sapelo River	GA
69551	Front River (Depth 13ft), Sapelo Sound, Georgia Current	NOS	ACT7706_1	31.51333	-81.29833	:America/New_York	USA	knots	56	227	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:05:00	\N	0.5	01:16:00	\N	0.4	-00:33:00	-00:25:00	Front River	GA
69552	New Teakettle Cr., 0.8 mi. N of, Mud River, Sapelo Sound, Georgia Current	NOS	ACT7711_1	31.49667	-81.29	:America/New_York	USA	knots	53	236	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:11:00	\N	0.5	-00:29:00	\N	0.4	-00:54:00	-01:08:00	New Teakettle Cr., 0.8 mi. N of	GA
69553	Crescent River (Depth 11ft), Sapelo Sound, Georgia Current	NOS	ACT7716_1	31.48667	-81.30667	:America/New_York	USA	knots	133	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:21:00	\N	0.5	01:07:00	\N	0.2	-01:27:00	-00:34:00	Crescent River	GA
69554	Old Teakettle Creek (north) (Depth 13ft), Sapelo Sound, Georgia Current	NOS	ACT7721_1	31.47833	-81.32833	:America/New_York	USA	knots	256	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:37:00	\N	0.6	00:01:00	\N	0.5	-00:35:00	00:14:00	Old Teakettle Creek (north)	GA
69555	Bar, Doboy Sound, Georgia Current	NOS	ACT7726_1	31.345	-81.235	:America/New_York	USA	knots	114	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:53:00	\N	0.7	-00:29:00	\N	0.7	-00:29:00	-00:09:00	Bar	GA
69556	Entrance (Depth 14ft), Doboy Sound, Georgia Current	NOS	ACT7731_1	31.34167	-81.26333	:America/New_York	USA	knots	106	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:49:00	\N	0.9	-00:10:00	\N	0.8	-00:32:00	-00:24:00	Entrance	GA
69557	Entrance (Depth 22ft), Doboy Sound, Georgia Current	NOS	ACT7731_2	31.34167	-81.26333	:America/New_York	USA	knots	99	276	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:26:00	\N	0.8	-00:05:00	\N	0.8	-00:56:00	-00:20:00	Entrance	GA
69559	Old Teakettle Creek (south) (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7741_1	31.43667	-81.30833	:America/New_York	USA	knots	207	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:44:00	\N	0.4	-01:45:00	\N	0.5	-03:12:00	-02:16:00	Old Teakettle Creek (south)	GA
69560	Folly River and Cardigan River, between (Depth 10ft), Doboy Sound, Georgia Current	NOS	ACT7746_1	31.44167	-81.33667	:America/New_York	USA	knots	150	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	0.3	-00:56:00	\N	0.3	-00:55:00	-00:16:00	Folly River and Cardigan River, between	GA
69561	South River (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7751_1	31.36667	-81.31167	:America/New_York	USA	knots	95	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.7	-00:25:00	\N	0.6	-00:22:00	-00:32:00	South River	GA
69562	South River (Depth 21ft), Doboy Sound, Georgia Current	NOS	ACT7751_2	31.36667	-81.31167	:America/New_York	USA	knots	95	286	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.4	-00:33:00	\N	0.5	-00:41:00	-00:29:00	South River	GA
69563	North River at Darien River (Depth 9ft), Doboy Sound, Georgia Current	NOS	ACT7756_1	31.38333	-81.335	:America/New_York	USA	knots	29	247	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:22:00	\N	0.2	-00:33:00	\N	0.2	-00:10:00	00:08:00	North River at Darien River	GA
69564	Doboy Island (North River) (Depth 12ft), Doboy Sound, Georgia Current	NOS	ACT7761_1	31.40333	-81.32833	:America/New_York	USA	knots	37	224	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:13:00	\N	0.5	-00:06:00	\N	0.6	-00:14:00	00:47:00	Doboy Island (North River)	GA
69565	Doboy Island (North River) (Depth 20ft), Doboy Sound, Georgia Current	NOS	ACT7761_2	31.40333	-81.32833	:America/New_York	USA	knots	43	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:22:00	\N	0.3	00:36:00	\N	0.5	-00:20:00	00:46:00	Doboy Island (North River)	GA
69566	Buzzard Roost Creek (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7766_1	31.415	-81.375	:America/New_York	USA	knots	2	177	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:28:00	\N	0.2	00:12:00	\N	0.3	00:22:00	00:56:00	Buzzard Roost Creek	GA
69567	Little Egg Island, northwest of (Depth 12ft), Altamaha Sound, Georgia Current	NOS	ACT7771_1	31.31833	-81.305	:America/New_York	USA	knots	110	296	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.6	-00:53:00	\N	0.6	-00:33:00	-00:25:00	Little Egg Island, northwest of	GA
69568	Little Mud River Range (Depth 9ft), Altamaha Sound, Georgia Current	NOS	ACT7776_1	31.32667	-81.31833	:America/New_York	USA	knots	116	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:06:00	\N	0.5	-01:05:00	\N	0.3	-00:38:00	-00:23:00	Little Mud River Range	GA
69569	Little St. Simon Island (north) (Depth 11ft), Altamaha Sound, Georgia Current	NOS	ACT7781_1	31.31167	-81.35333	:America/New_York	USA	knots	89	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:29:00	\N	0.8	00:06:00	\N	0.6	00:10:00	-00:15:00	Little St. Simon Island (north)	GA
69570	Onemile Cut, 1 mile southeast of, Altamaha Sound, Georgia Current	NOS	ACT7786_1	31.31333	-81.35167	:America/New_York	USA	knots	92	272	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:32:00	\N	0.9	00:03:00	\N	0.5	00:46:00	-01:09:00	Onemile Cut, 1 mile southeast of	GA
69571	Broughton Island (south) (Depth 9ft), Buttermilk Sound, Altamaha Sound, Georgia Current	NOS	ACT7791_1	31.31	-81.41333	:America/New_York	USA	knots	30	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.4	00:12:00	\N	0.4	-02:06:00	-00:01:00	Broughton Island (south)	GA
69572	Bar Channel (Depth 12ft), St. Simons Sound, Georgia Current	NOS	ACT7796_1	31.105	-81.33833	:America/New_York	USA	knots	119	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:02:00	\N	0.8	-00:44:00	\N	0.4	-00:13:00	00:09:00	Bar Channel	GA
69573	Entrance, north of channel (Depth 13ft), St. Simons Sound, Georgia Current	NOS	ACT7801_1	31.1335	-81.404	:America/New_York	USA	knots	107	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:11:00	\N	0.6	00:18:00	\N	0.9	-00:32:00	00:07:00	Entrance, north of channel	GA
69574	Entrance, south of channel (Depth 11ft), St. Simons Sound, Georgia Current	NOS	ACT7806_1	31.12667	-81.40333	:America/New_York	USA	knots	80	262	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:59:00	\N	1.1	-00:32:00	\N	0.8	-00:27:00	-00:21:00	Entrance, south of channel	GA
69575	Entrance, south of channel (Depth 29ft), St. Simons Sound, Georgia Current	NOS	ACT7806_2	31.12667	-81.40333	:America/New_York	USA	knots	92	257	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	0.8	-00:03:00	\N	0.6	-00:18:00	00:06:00	Entrance, south of channel	GA
69576	Back River entrance (Depth 10ft), St. Simons Sound, Georgia Current	NOS	ACT7811_1	31.14833	-81.44167	:America/New_York	USA	knots	111	288	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.5	01:34:00	\N	0.5	-00:37:00	00:06:00	Back River entrance	GA
69577	Back River entrance (Depth 18ft), St. Simons Sound, Georgia Current	NOS	ACT7811_2	31.14833	-81.44167	:America/New_York	USA	knots	109	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:15:00	\N	0.4	01:36:00	\N	0.5	-01:29:00	00:08:00	Back River entrance	GA
69578	Mackay R., 0.5 mi. N of Troup Creek entrance, St. Simons Sound, Georgia Current	NOS	ACT7816_1	31.225	-81.43333	:America/New_York	USA	knots	166	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:24:00	\N	0.7	00:09:00	\N	0.5	00:56:00	00:35:00	Mackay R., 0.5 mi. N of Troup Creek entrance	GA
69579	Brunswick River, off Quarantine Dock, St. Simons Sound, Georgia Current	NOS	ACT7821_1	31.11167	-81.47333	:America/New_York	USA	knots	125	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:39:00	\N	1	-00:03:00	\N	0.7	00:10:00	00:11:00	Brunswick River, off Quarantine Dock	GA
69580	Brunswick River Bridge, southeast of (Depth 13ft), St. Simons Sound, Georgia Current	NOS	ACT7826_1	31.115	-81.47667	:America/New_York	USA	knots	132	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:09:00	\N	0.7	00:13:00	\N	0.5	-00:15:00	00:26:00	Brunswick River Bridge, southeast of	GA
69581	Brunswick River Bridge, southeast of (Depth 21ft), St. Simons Sound, Georgia Current	NOS	ACT7826_2	31.115	-81.47667	:America/New_York	USA	knots	129	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:02:00	\N	0.7	00:42:00	\N	0.5	00:19:00	00:56:00	Brunswick River Bridge, southeast of	GA
69582	Brunswick, off Prince Street Dock, St. Simons Sound, Georgia Current	NOS	ACT7831_1	31.13833	-81.49667	:America/New_York	USA	knots	166	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:08:00	\N	0.6	00:55:00	\N	0.5	-00:01:00	00:06:00	Brunswick, off Prince Street Dock	GA
69583	Turtle River, off Allied Chemical Corp, St. Simons Sound, Georgia Current	NOS	ACT7836_1	31.17667	-81.525	:America/New_York	USA	knots	165	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:33:00	\N	0.8	00:18:00	\N	0.7	00:16:00	00:36:00	Turtle River, off Allied Chemical Corp	GA
69584	Turtle River, off Andrews Island (Depth 20ft), St. Simons Sound, Georgia Current	NOS	ACT7841_1	31.14333	-81.52667	:America/New_York	USA	knots	153	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:23:00	\N	0.7	00:40:00	\N	0.5	-00:21:00	00:31:00	Turtle River, off Andrews Island	GA
69585	Entrance, St. Andrews Sound, Georgia Current	NOS	ACT7846_1	30.98667	-81.405	:America/New_York	USA	knots	103	268	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	1.1	00:13:00	\N	1.1	-00:18:00	00:02:00	Entrance	GA
69586	Jekyll Creek, south entrance, St. Andrews Sound, Georgia Current	NOS	ACT7851_1	31.035	-81.43333	:America/New_York	USA	knots	232	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:20:00	\N	0.7	-00:21:00	\N	0.5	-00:21:00	-00:25:00	Jekyll Creek, south entrance	GA
69587	Cumberland River, north entrance, St. Andrews Sound, Georgia Current	NOS	ACT7856_1	30.95833	-81.43167	:America/New_York	USA	knots	18	191	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:18:00	\N	0.7	00:32:00	\N	0.7	-00:29:00	-00:17:00	Cumberland River, north entrance	GA
69588	Cabin Bluff, Cumberland River, St. Andrews Sound, Georgia Current	NOS	ACT7861_1	30.88167	-81.51333	:America/New_York	USA	knots	355	171	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:45:00	\N	0.6	01:29:00	\N	0.7	00:21:00	00:51:00	Cabin Bluff, Cumberland River	GA
69589	Mayport (Depth 7ft), St. Johns River, Florida Current	NOS	ACT7971_1	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-00:04:00	\N	1.6	01:02:00	\N	1.1	00:06:00	00:15:00	Mayport	FL
69590	Mayport (Depth 17ft), St. Johns River, Florida Current	NOS	ACT7971_2	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:05:00	\N	1.3	00:38:00	\N	1.1	-00:03:00	00:12:00	Mayport	FL
69591	Mayport (Depth 27ft), St. Johns River, Florida Current	NOS	ACT7971_3	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:14:00	\N	0.9	00:26:00	\N	0.9	-00:27:00	00:15:00	Mayport	FL
69592	Mile Point, southeast of (Depth 7ft), St. Johns River, Florida Current	NOS	ACT7976_1	30.38167	-81.445	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:44:00	\N	1.6	00:38:00	\N	1.5	00:06:00	00:48:00	Mile Point, southeast of	FL
69593	Mile Point, southeast of (Depth 18ft), St. Johns River, Florida Current	NOS	ACT7976_2	30.38167	-81.445	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:56:00	\N	1.2	00:38:00	\N	1.2	-00:12:00	00:54:00	Mile Point, southeast of	FL
69594	Mile Point, southeast of (Depth 29ft), St. Johns River, Florida Current	NOS	ACT7976_3	30.38167	-81.445	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:38:00	\N	0.9	00:38:00	\N	1.1	-00:42:00	01:00:00	Mile Point, southeast of	FL
69595	Pablo Creek bascule bridge (Depth 3ft), St. Johns River, Florida Current	NOS	ACT7986_1	30.32333	-81.43833	:America/New_York	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:59:00	\N	2.5	-00:18:00	\N	1.7	-00:14:00	00:49:00	Pablo Creek bascule bridge	FL
69596	Sisters Creek entrance (bridge) (Depth 4ft), St. Johns River, Florida Current	NOS	ACT7991_1	30.39	-81.46167	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-02:34:00	\N	0.8	-03:14:00	\N	0.8	-03:30:00	-02:13:00	Sisters Creek entrance (bridge)	FL
69597	Sisters Creek entrance (bridge) (Depth 10ft), St. Johns River, Florida Current	NOS	ACT7991_2	30.39	-81.46167	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-02:34:00	\N	0.6	-03:04:00	\N	0.6	-03:36:00	-02:07:00	Sisters Creek entrance (bridge)	FL
69598	Drummond Point, channel south of (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8016_1	30.40917	-81.60283	:America/New_York	USA	knots	60	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:00:00	\N	0.8	02:32:00	\N	0.7	01:51:00	02:44:00	Drummond Point, channel south of	FL
69599	Drummond Point, channel south of (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8016_2	30.40917	-81.60283	:America/New_York	USA	knots	61	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:01:00	\N	0.7	02:35:00	\N	0.7	01:34:00	02:51:00	Drummond Point, channel south of	FL
69600	Drummond Point, channel south of (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8016_3	30.40917	-81.60283	:America/New_York	USA	knots	57	243	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	02:51:00	\N	0.5	02:20:00	\N	0.6	01:21:00	02:46:00	Drummond Point, channel south of	FL
69601	Terminal Channel (north end) (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8031_1	30.357	-81.618	:America/New_York	USA	knots	1	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.6	03:16:00	\N	0.5	02:39:00	03:02:00	Terminal Channel (north end)	FL
69602	Terminal Channel (north end) (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8031_2	30.357	-81.618	:America/New_York	USA	knots	1	183	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:33:00	\N	0.5	03:06:00	\N	0.6	02:16:00	03:20:00	Terminal Channel (north end)	FL
69603	Terminal Channel (north end) (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8031_3	30.357	-81.618	:America/New_York	USA	knots	1	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:23:00	\N	0.3	03:28:00	\N	0.5	01:51:00	03:16:00	Terminal Channel (north end)	FL
69604	Commodore Point, terminal channel (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8036_1	30.3175	-81.62633	:America/New_York	USA	knots	72	197	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:37:00	\N	0.5	03:28:00	\N	0.5	02:39:00	03:10:00	Commodore Point, terminal channel	FL
69605	Commodore Point, terminal channel (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8036_2	30.3175	-81.62633	:America/New_York	USA	knots	51	221	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:25:00	\N	0.4	03:13:00	\N	0.5	02:12:00	03:23:00	Commodore Point, terminal channel	FL
69606	Commodore Point, terminal channel (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8036_3	30.3175	-81.62633	:America/New_York	USA	knots	35	221	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:08:00	\N	0.4	02:30:00	\N	0.6	01:43:00	03:38:00	Commodore Point, terminal channel	FL
69607	Jacksonville, off Washington St, St. Johns River, Florida Current	NOS	ACT8041_1	30.32167	-81.65333	:America/New_York	USA	knots	118	281	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:23:00	\N	0.9	03:10:00	\N	0.9	02:59:00	02:54:00	Jacksonville, off Washington St	FL
69608	Winter Point, St. Johns River, Florida Current	NOS	ACT8051_1	30.30833	-81.675	:America/New_York	USA	knots	15	200	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:59:00	\N	0.5	03:22:00	\N	0.6	02:59:00	04:04:00	Winter Point	FL
69609	Mandarin Point (Depth 6ft), St. Johns River, Florida Current	NOS	ACT8056_1	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.4	03:39:00	\N	0.3	03:07:00	03:24:00	Mandarin Point	FL
69610	Mandarin Point (Depth 15ft), St. Johns River, Florida Current	NOS	ACT8056_2	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.3	03:33:00	\N	0.3	03:13:00	03:24:00	Mandarin Point	FL
69611	Mandarin Point (Depth 24ft), St. Johns River, Florida Current	NOS	ACT8056_3	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:32:00	\N	0.3	03:33:00	\N	0.3	02:48:00	03:24:00	Mandarin Point	FL
69612	Red Bay Point, draw bridge (Depth 4ft), St. Johns River, Florida Current	NOS	ACT8061_1	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:02:00	\N	0.3	03:57:00	\N	0.5	02:48:00	05:24:00	Red Bay Point, draw bridge	FL
69613	Red Bay Point, draw bridge (Depth 6ft), St. Johns River, Florida Current	NOS	ACT8061_2	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:08:00	\N	0.3	03:57:00	\N	0.5	02:42:00	05:18:00	Red Bay Point, draw bridge	FL
69614	Red Bay Point, draw bridge (Depth 14ft), St. Johns River, Florida Current	NOS	ACT8061_3	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:08:00	\N	0.2	03:57:00	\N	0.4	02:48:00	05:30:00	Red Bay Point, draw bridge	FL
69615	Point Ybel, 0.4 mile northwest of, Florida Current	NOS	ACT8306_1	26.45667	-82.01867	:America/New_York	USA	knots	80	255	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:35:00	\N	0.7	-00:52:00	\N	0.8	-00:25:00	00:17:00	Point Ybel, 0.4 mile northwest of	FL
69616	Captiva Pass, Florida Current	NOS	ACT8311_1	26.60933	-82.22233	:America/New_York	USA	knots	251	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:23:00	\N	0.9	-01:29:00	\N	1.4	-00:53:00	-01:14:00	Captiva Pass	FL
69617	Boca Grande Pass, Charlotte Harbor, Florida Current	NOS	ACT8316_1	26.71433	-82.25667	:America/New_York	USA	knots	251	57	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:05:00	\N	1.3	-00:37:00	\N	1.7	-00:15:00	-00:15:00	Boca Grande Pass, Charlotte Harbor	FL
69618	Cape Haze, 2.3 mi. S of, Charlotte Hbr, Florida Current	NOS	ACT8331_1	26.745	-82.15167	:America/New_York	USA	knots	268	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	01:18:00	\N	0.4	00:41:00	\N	0.4	00:30:00	-00:20:00	Cape Haze, 2.3 mi. S of, Charlotte Hbr	FL
69619	Gasparilla Pass, Florida Current	NOS	ACT8346_1	26.81233	-82.281	:America/New_York	USA	knots	236	66	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:41:00	\N	0.8	-01:13:00	\N	0.8	-01:15:00	-00:35:00	Gasparilla Pass	FL
69620	Venice Inlet, Florida Current	NOS	ACT8351_1	27.11333	-82.46667	:America/New_York	USA	knots	262	87	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:59:00	\N	0.7	-02:08:00	\N	0.8	-02:05:00	-01:57:00	Venice Inlet	FL
69621	Blackburn Bay, south end, bridge, Florida Current	NOS	ACT8356_1	27.12333	-82.47	:America/New_York	USA	knots	180	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:10:00	\N	0.5	-01:20:00	\N	0.7	-00:55:00	-01:28:00	Blackburn Bay, south end, bridge	FL
69622	Little Sarasota Bay, south end, bridge, Florida Current	NOS	ACT8361_1	27.18	-82.495	:America/New_York	USA	knots	357	167	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:06:00	\N	0.5	-00:56:00	\N	1.1	-01:19:00	-00:57:00	Little Sarasota Bay, south end, bridge	FL
69623	Midnight Pass entrance, Florida Current	NOS	ACT8366_1	27.20667	-82.51	:America/New_York	USA	knots	242	61	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:13:00	\N	1.1	-01:59:00	\N	1.4	-01:43:00	-01:49:00	Midnight Pass entrance	FL
69624	Big Sarasota Pass, Sarasota Bay, Florida Current	NOS	ACT8371_1	27.3	-82.56333	:America/New_York	USA	knots	183	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-02:03:00	\N	0.8	-01:49:00	\N	1.2	-01:54:00	-01:34:00	Big Sarasota Pass	FL
69625	Sarasota Bay, south end, bridge, Sarasota Bay, Florida Current	NOS	ACT8376_1	27.30167	-82.54667	:America/New_York	USA	knots	13	196	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:32:00	\N	0.2	-01:39:00	\N	0.2	-01:25:00	-01:13:00	Sarasota Bay, south end, bridge	FL
69626	New Pass, Sarasota Bay, Florida Current	NOS	ACT8381_1	27.33167	-82.58167	:America/New_York	USA	knots	231	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:25:00	\N	0.8	-02:48:00	\N	1.2	-02:06:00	-01:18:00	New Pass	FL
69627	Golden Gate Point, off, Sarasota Bay, Florida Current	NOS	ACT8386_1	27.32833	-82.55667	:America/New_York	USA	knots	159	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:19:00	\N	0.2	-01:57:00	\N	0.3	-01:38:00	-01:25:00	Golden Gate Point, off	FL
69628	Longboat Pass, Sarasota Bay, Florida Current	NOS	ACT8391_1	27.44167	-82.69	:America/New_York	USA	knots	267	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:56:00	\N	1.2	-02:42:00	\N	1.4	-02:32:00	-01:51:00	Longboat Pass	FL
69629	Cortez, north of bridge, Sarasota Bay, Florida Current	NOS	ACT8396_1	27.47	-82.69333	:America/New_York	USA	knots	162	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:11:00	\N	0.1	-01:10:00	\N	0.5	-01:47:00	-00:25:00	Cortez, north of bridge	FL
69630	Egmont Channel, marker '10' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8401_1	27.6005	-82.86767	:America/New_York	USA	knots	259	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:31:00	\N	0.2	-03:17:00	\N	0.2	-02:04:00	-02:22:00	Egmont Channel, marker '10'	FL
69631	Egmont Channel (3 mi. W of Egmont Key Lt.), Tampa Bay, Florida Current	NOS	ACT8406_1	27.60833	-82.81833	:America/New_York	USA	knots	260	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:29:00	\N	0.5	-00:28:00	\N	0.4	-00:30:00	-00:30:00	Egmont Channel (3 mi. W of Egmont Key Lt.)	FL
69632	Southwest Channel (S of Egmont Key) (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8416_1	27.56167	-82.76733	:America/New_York	USA	knots	269	87	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:30:00	\N	0.9	-00:53:00	\N	0.6	-00:46:00	-00:40:00	Southwest Channel (S of Egmont Key)	FL
69633	Mullet Key Channel entrance, Tampa Bay, Florida Current	NOS	ACT8421_1	27.6045	-82.72383	:America/New_York	USA	knots	255	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:08:00	\N	0.8	-00:01:00	\N	0.8	-00:03:00	-00:23:00	Mullet Key Channel entrance	FL
69634	Passage Key Inlet (off Bean Pt.) (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8426_1	27.53933	-82.74767	:America/New_York	USA	knots	247	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:08:00	\N	0.7	-01:50:00	\N	0.6	-01:29:00	-01:13:00	Passage Key Inlet (off Bean Pt.)	FL
69635	Rattlesnake Key, 3.1 miles west of, Tampa Bay, Florida Current	NOS	ACT8431_1	27.55333	-82.68833	:America/New_York	USA	knots	250	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:04:00	\N	0.4	-00:05:00	\N	0.3	00:20:00	-00:51:00	Rattlesnake Key, 3.1 miles west of	FL
69636	Rattlesnake Key, 1.1 miles northwest of, Tampa Bay, Florida Current	NOS	ACT8436_1	27.57083	-82.64383	:America/New_York	USA	knots	210	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:09:00	\N	0.1	-00:34:00	\N	0.2	-00:28:00	-00:34:00	Rattlesnake Key, 1.1 miles northwest of	FL
69637	Mullet Key Channel, marker '24' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8441_1	27.60833	-82.694	:America/New_York	USA	knots	255	73	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:06:00	\N	0.7	-00:07:00	\N	0.7	-00:14:00	-00:06:00	Mullet Key Channel, marker '24'	FL
69638	Bunces Pass (West of Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8446_1	27.647	-82.7395	:America/New_York	USA	knots	315	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:02:00	\N	0.7	-00:46:00	\N	0.8	-00:47:00	-01:07:00	Bunces Pass (West of Bayway bridge)	FL
69639	Pine Key (Pinellas Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8451_1	27.6925	-82.71717	:America/New_York	USA	knots	280	100	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:00:00	\N	0.6	-00:29:00	\N	0.3	-00:32:00	-01:07:00	Pine Key (Pinellas Bayway bridge)	FL
69640	Cats Point (bridge west of), Tampa Bay, Florida Current	NOS	ACT8456_1	27.70833	-82.72467	:America/New_York	USA	knots	150	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:23:00	\N	0.5	-02:41:00	\N	0.5	-01:27:00	-02:12:00	Cats Point (bridge west of)	FL
69641	Cut A & B, Channel Junction, Tampa Bay, Florida Current	NOS	ACT8466_1	27.63883	-82.6255	:America/New_York	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:46:00	\N	0.7	00:07:00	\N	0.8	00:25:00	00:23:00	Cut A & B, Channel Junction	FL
69642	Joe Island, 1.8 miles northwest of, Tampa Bay, Florida Current	NOS	ACT8471_1	27.6125	-82.625	:America/New_York	USA	knots	245	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:02:00	\N	0.7	-00:07:00	\N	0.5	00:03:00	-00:24:00	Joe Island, 1.8 miles northwest of	FL
69643	Harbor Key, 1.3 miles west of, Tampa Bay, Florida Current	NOS	ACT8476_1	27.61117	-82.5945	:America/New_York	USA	knots	160	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:38:00	\N	0.3	-00:56:00	\N	0.2	-00:50:00	-01:06:00	Harbor Key, 1.3 miles west of	FL
69644	2.6 miles south of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8486_1	27.6605	-82.64167	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:34:00	\N	0.7	-00:23:00	\N	0.6	-00:46:00	-00:16:00	2.6 miles south of	FL
69645	0.5 mile southeast of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8491_1	27.697	-82.6325	:America/New_York	USA	knots	220	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:57:00	\N	0.2	-01:19:00	\N	0.2	-01:28:00	-01:53:00	0.5 mile southeast of	FL
69646	1.9 miles SE of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8496_1	27.68467	-82.60967	:America/New_York	USA	knots	180	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:20:00	\N	0.6	-00:32:00	\N	0.5	00:29:00	-00:06:00	1.9 miles SE of	FL
69647	3 miles southeast of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8501_1	27.673	-82.593	:America/New_York	USA	knots	200	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:47:00	\N	0.6	00:23:00	\N	0.6	00:29:00	00:20:00	3 miles southeast of	FL
69648	Port Manatee Channel entrance (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8506_1	27.662	-82.59917	:America/New_York	USA	knots	216	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:23:00	\N	0.6	00:08:00	\N	0.6	-00:01:00	00:24:00	Port Manatee Channel entrance	FL
69649	Port Manatee Channel, marker '4' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8511_1	27.6535	-82.58983	:America/New_York	USA	knots	242	56	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:01:00	\N	0.3	-00:11:00	\N	0.2	-00:34:00	-00:22:00	Port Manatee Channel, marker '4'	FL
69650	Piney Point, 0.6 mile NNW of, Tampa Bay, Florida Current	NOS	ACT8516_1	27.65367	-82.56217	:America/New_York	USA	knots	215	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:01:00	\N	0.4	-00:29:00	\N	0.3	00:12:00	-00:45:00	Piney Point, 0.6 mile NNW of	FL
69651	Pass-a-Grille Channel, Florida Current	NOS	ACT8606_1	27.685	-82.735	:America/New_York	USA	knots	186	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:17:00	\N	1	-00:43:00	\N	0.9	-00:30:00	-00:30:00	Pass-a-Grille Channel	FL
69652	Bridge, 0.8 mi. south of Maximo Pt., Florida Current	NOS	ACT8611_1	27.69333	-82.68	:America/New_York	USA	knots	255	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:50:00	\N	1	-01:22:00	\N	0.9	-01:05:00	-01:05:00	Bridge, 0.8 mi. south of Maximo Pt.	FL
69653	Blind Pass (north end), Florida Current	NOS	ACT8621_1	27.75667	-82.76167	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:12:00	\N	0.3	-01:25:00	\N	0.5	-01:20:00	-01:20:00	Blind Pass (north end)	FL
69654	The Narrows (Indian Rocks Beach Bridge), Florida Current	NOS	ACT8651_1	27.876670837402344	-82.8499984741211	:America/New_York	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:54:00	\N	0.1	-00:25:00	\N	0.5	-00:23:00	-01:17:00	The Narrows (Indian Rocks Beach Bridge)	FL
69655	Clearwater Pass, 0.2 mi. NE of Sand Key, Florida Current	NOS	ACT8656_1	27.95667	-82.82333	:America/New_York	USA	knots	348	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:50:00	\N	0.8	-02:49:00	\N	1	-02:24:00	-02:18:00	Clearwater Pass, 0.2 mi. NE of Sand Key	FL
69656	St. Marks River approach, Apalachee Bay, Florida Current	NOS	ACT8666_1	30.04667	-84.18	:America/New_York	USA	knots	170	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:08:00	\N	0.4	-00:46:00	\N	0.5	-00:57:00	-00:10:00	St. Marks River approach	FL
69657	Four Mile Point, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8671_1	30.11167	-84.20333	:America/New_York	USA	knots	187	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:26:00	\N	0.3	-00:14:00	\N	0.3	-00:13:00	00:24:00	Four Mile Point, St. Marks River	FL
69658	St. Marks, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8676_1	30.155	-84.20167	:America/New_York	USA	knots	247	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:23:00	\N	0.3	01:10:00	\N	0.2	01:38:00	-00:23:00	St. Marks, St. Marks River	FL
69659	Bolivar Roads (Depth 8ft), Galveston Bay, Texas Current	NOS	ACT8856_1	29.343299865722656	-94.78130340576172	:America/Chicago	USA	knots	125	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-00:01:00	\N	1.1	00:07:00	\N	1	00:09:00	-00:16:00	Bolivar Roads	TX
69660	Bolivar Roads (Depth 31ft), Galveston Bay, Texas Current	NOS	ACT8856_3	29.343299865722656	-94.78130340576172	:America/Chicago	USA	knots	115	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-00:08:00	\N	0.6	-00:11:00	\N	0.8	-00:32:00	00:17:00	Bolivar Roads	TX
69661	Houston Channel, W of Port Bolivar (Depth 3ft), Galveston Bay, Texas Current	NOS	ACT8876_1	29.36467	-94.79667	:America/Chicago	USA	knots	135	313	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:41:00	\N	1	-00:18:00	\N	1.1	-00:05:00	-02:14:00	Houston Channel, W of Port Bolivar	TX
69662	Houston Channel, W of Port Bolivar (Depth 14ft), Galveston Bay, Texas Current	NOS	ACT8876_2	29.36467	-94.79667	:America/Chicago	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:55:00	\N	0.9	-00:11:00	\N	1	-00:03:00	-02:15:00	Houston Channel, W of Port Bolivar	TX
69663	Houston Channel, W of Port Bolivar (Depth 26ft), Galveston Bay, Texas Current	NOS	ACT8876_3	29.36467	-94.79667	:America/Chicago	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:41:00	\N	0.8	-00:14:00	\N	0.9	-00:06:00	-02:12:00	Houston Channel, W of Port Bolivar	TX
69664	Houston Ship Channel (Red Fish Bar) (Depth 7ft), Galveston Bay, Texas Current	NOS	ACT8881_1	29.50733	-94.87467	:America/Chicago	USA	knots	154	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	00:50:00	\N	0.5	01:13:00	\N	0.5	00:41:00	01:13:00	Houston Ship Channel (Red Fish Bar)	TX
69665	Houston Ship Channel (Red Fish Bar) (Depth 14ft), Galveston Bay, Texas Current	NOS	ACT8881_2	29.50733	-94.87467	:America/Chicago	USA	knots	148	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:10:00	\N	0.7	01:28:00	\N	0.7	00:45:00	01:17:00	Houston Ship Channel (Red Fish Bar)	TX
69666	Houston Ship Channel (Red Fish Bar) (Depth 24ft), Galveston Bay, Texas Current	NOS	ACT8881_3	29.50733	-94.87467	:America/Chicago	USA	knots	144	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:42:00	\N	0.5	01:15:00	\N	0.5	00:48:00	01:20:00	Houston Ship Channel (Red Fish Bar)	TX
69667	Morgans Point (Depth 6ft), Galveston Bay, Texas Current	NOS	ACT8886_1	29.67983	-94.98167	:America/Chicago	USA	knots	163	336	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:16:00	\N	0.5	01:43:00	\N	0.3	02:15:00	-01:05:00	Morgans Point	TX
69668	Morgans Point (Depth 15ft), Galveston Bay, Texas Current	NOS	ACT8886_2	29.67983	-94.98167	:America/Chicago	USA	knots	159	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:11:00	\N	0.4	01:23:00	\N	0.3	01:44:00	-00:50:00	Morgans Point	TX
69669	Morgans Point (Depth 25ft), Galveston Bay, Texas Current	NOS	ACT8886_3	29.67983	-94.98167	:America/Chicago	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:20:00	\N	0.3	00:58:00	\N	0.2	00:47:00	-01:02:00	Morgans Point	TX
69670	Aransas Pass (Depth 15ft), Texas Current	NOS	ACT8896_1	27.833799362182617	-97.04419708251953	:America/Chicago	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	00:00:00	\N	1.5	00:00:00	\N	1.1	00:00:00	00:00:00	Aransas Pass	TX
69671	Aransas Pass (Depth 50ft), Texas Current	NOS	ACT8896_3	27.833799362182617	-97.04419708251953	:America/Chicago	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	00:00:00	\N	0.8	00:00:00	\N	0.9	00:00:00	00:00:00	Aransas Pass	TX
69672	Port Ingleside (Depth 5ft), Texas Current	NOS	ACT8901_1	27.815	-97.23	:America/Chicago	USA	knots	102	286	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	01:09:00	\N	0.5	01:48:00	\N	0.7	00:24:00	02:11:00	Port Ingleside	TX
69673	Punta Ostiones, 1.5 miles west of, Puerto Rico Current	NOS	ACT8921_1	18.08667	-67.22667	:America/Puerto_Rico	USA	knots	1	187	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-00:35:00	\N	1.3	-00:52:00	\N	1.7	-00:26:00	-00:04:00	Punta Ostiones, 1.5 miles west of	PR
69674	Vieques Sound, Puerto Rico Current	NOS	ACT8931_1	18.2645	-65.57	:America/Puerto_Rico	USA	knots	355	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:05:00	\N	0.9	-01:16:00	\N	0.7	-00:44:00	-01:28:00	Vieques Sound	PR
69675	Largo Shoals, west of, Puerto Rico Current	NOS	ACT8936_1	18.31667	-65.58333	:America/Puerto_Rico	USA	knots	330	186	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:08:00	\N	1	-01:28:00	\N	0.7	-00:52:00	-01:33:00	Largo Shoals, west of	PR
69676	Fajardo Harbor (channel), Puerto Rico Current	NOS	ACT8951_1	18.33333	-65.61667	:America/Puerto_Rico	USA	knots	339	162	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:45:00	\N	1.6	-01:52:00	\N	0.5	-01:13:00	-02:27:00	Fajardo Harbor (channel)	PR
69677	Point Loma Light, 0.8 nmi. east of (Depth 15ft), San Diego Bay, California Current	NOS	PCT0026_1	32.66583	-117.22617	:America/Los_Angeles	USA	knots	174	328	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:45:00	\N	0.4	-00:43:00	\N	0.5	-00:18:00	-00:05:00	Point Loma Light, 0.8 nmi. east of	CA
69678	Point Loma Light, 0.8 nmi. east of (Depth 33ft), San Diego Bay, California Current	NOS	PCT0026_2	32.66583	-117.22617	:America/Los_Angeles	USA	knots	166	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:23:00	\N	0.2	-00:46:00	\N	0.4	-01:08:00	-00:08:00	Point Loma Light, 0.8 nmi. east of	CA
69679	Ballast Point, south of (Depth 5ft), San Diego Bay, California Current	NOS	PCT0036_1	32.6845	-117.23217	:America/Los_Angeles	USA	knots	238	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-02:03:00	\N	0.2	-01:02:00	\N	0.4	-01:04:00	-01:01:00	Ballast Point, south of	CA
69680	Ballast Point, 100 yards north of, San Diego Bay, California Current	NOS	PCT0041_1	32.68333	-117.23333	:America/Los_Angeles	USA	knots	133	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:02:00	\N	0.9	-00:24:00	\N	1	-00:27:00	-00:23:00	Ballast Point, 100 yards north of	CA
69681	Ballast Point, 0.55 nmi. north of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0046_1	32.69583	-117.2325	:America/Los_Angeles	USA	knots	193	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:24:00	\N	0.4	-00:39:00	\N	0.5	-00:05:00	-00:34:00	Ballast Point, 0.55 nmi. north of	CA
69682	Ballast Point, 0.55 nmi. north of (Depth 34ft), San Diego Bay, California Current	NOS	PCT0046_2	32.69583	-117.2325	:America/Los_Angeles	USA	knots	147	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:03:00	\N	0.2	00:10:00	\N	0.5	-00:44:00	00:03:00	Ballast Point, 0.55 nmi. north of	CA
69683	Quarantine Station, La Playa, San Diego Bay, California Current	NOS	PCT0051_1	32.7	-117.23333	:America/Los_Angeles	USA	knots	200	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:20:00	\N	0.8	00:15:00	\N	0.8	-00:03:00	00:10:00	Quarantine Station, La Playa	CA
69684	North Island (Depth 14ft), San Diego Bay, California Current	NOS	PCT0056_1	32.713	-117.21283	:America/Los_Angeles	USA	knots	245	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:03:00	\N	0.4	-00:56:00	\N	0.5	-00:26:00	-00:54:00	North Island	CA
69685	North Island (Depth 34ft), San Diego Bay, California Current	NOS	PCT0056_2	32.713	-117.21283	:America/Los_Angeles	USA	knots	241	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:33:00	\N	0.2	-01:05:00	\N	0.3	-00:43:00	-00:44:00	North Island	CA
69686	Harbor Island (east end), SSW of (Depth 15ft), San Diego Bay, California Current	NOS	PCT0061_1	32.71917	-117.19167	:America/Los_Angeles	USA	knots	293	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:23:00	\N	0.3	00:09:00	\N	0.3	00:29:00	-00:24:00	Harbor Island (east end), SSW of	CA
69687	San Diego, 0.5 mile west of, San Diego Bay, California Current	NOS	PCT0066_1	32.71667	-117.18333	:America/Los_Angeles	USA	knots	304	121	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:12:00	\N	0.5	-00:08:00	\N	0.6	-00:16:00	-00:12:00	San Diego, 0.5 mile west of	CA
69688	G St. Pier (San Diego), 0.22 nmi. SW of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0081_1	32.70833	-117.1775	:America/Los_Angeles	USA	knots	304	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:41:00	\N	0.3	00:20:00	\N	0.3	00:10:00	-00:03:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
69689	G St. Pier (San Diego), 0.22 nmi. SW of (Depth 37ft), San Diego Bay, California Current	NOS	PCT0081_2	32.70833	-117.1775	:America/Los_Angeles	USA	knots	301	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:58:00	\N	0.2	00:21:00	\N	0.3	-00:23:00	-00:18:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
69690	Coronado, off northeast end (Depth 14ft), San Diego Bay, California Current	NOS	PCT0091_1	32.698	-117.16383	:America/Los_Angeles	USA	knots	317	128	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:09:00	\N	0.5	-00:58:00	\N	0.7	-00:24:00	-00:51:00	Coronado, off northeast end	CA
69691	Coronado, off northeast end (Depth 38ft), San Diego Bay, California Current	NOS	PCT0091_2	32.698	-117.16383	:America/Los_Angeles	USA	knots	319	130	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:03:00	\N	0.4	-00:59:00	\N	0.5	-00:41:00	-01:01:00	Coronado, off northeast end	CA
69692	28th St. Pier (San Diego), 0.92 nmi. SW (Depth 7ft), San Diego Bay, California Current	NOS	PCT0096_1	32.67467	-117.1495	:America/Los_Angeles	USA	knots	351	182	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:05:00	\N	0.1	-01:17:00	\N	0.2	-00:44:00	-01:10:00	28th St. Pier (San Diego), 0.92 nmi. SW	CA
69693	28th St. Pier (San Diego), 0.35 nmi. SW (Depth 14ft), San Diego Bay, California Current	NOS	PCT0101_1	32.68283	-117.14283	:America/Los_Angeles	USA	knots	317	133	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:13:00	\N	0.2	00:15:00	\N	0.3	-00:14:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
69694	28th St. Pier (San Diego), 0.35 nmi. SW (Depth 28ft), San Diego Bay, California Current	NOS	PCT0101_2	32.68283	-117.14283	:America/Los_Angeles	USA	knots	328	148	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:35:00	\N	0.2	00:24:00	\N	0.2	00:01:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
69695	National City, San Diego Bay, California Current	NOS	PCT0106_1	32.65	-117.11667	:America/Los_Angeles	USA	knots	2	166	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:50:00	\N	0.4	00:00:00	\N	0.4	00:23:00	-00:02:00	National City	CA
69696	National City, WSW of Pier 12 (Depth 32ft), San Diego Bay, California Current	NOS	PCT0111_1	32.66217	-117.1255	:America/Los_Angeles	USA	knots	351	178	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:58:00	\N	0.2	00:34:00	\N	0.2	00:22:00	00:34:00	National City, WSW of Pier 12	CA
69697	Sweetwater Channel, southwest of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0116_1	32.645	-117.12283	:America/Los_Angeles	USA	knots	348	203	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:46:00	\N	0.2	-00:33:00	\N	0.1	00:29:00	-00:05:00	Sweetwater Channel, southwest of	CA
69698	Coquille River entrance, Oregon Current	NOS	PCT1056_1	43.12167	-124.41967	:America/Los_Angeles	USA	knots	290	91	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:17:00	\N	0.6	-01:25:00	\N	0.4	-01:00:00	-01:27:00	Coquille River entrance	OR
69699	Coos Bay entrance, Oregon Current	NOS	PCT1061_1	43.355	-124.34117	:America/Los_Angeles	USA	knots	280	100	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1.1	-00:42:00	\N	0.6	-00:24:00	-00:42:00	Coos Bay entrance	OR
69700	Umpqua River entrance, Oregon Current	NOS	PCT1066_1	43.67833	-124.19333	:America/Los_Angeles	USA	knots	190	10	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.5	-00:32:00	\N	0.3	-00:14:00	-00:32:00	Umpqua River entrance	OR
69701	Heceta Head, Oregon Current	NOS	PCT1071_1	44.13333	-124.13333	:America/Los_Angeles	USA	knots	185	5	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.7	-00:12:00	\N	0.4	00:06:00	-00:12:00	Heceta Head	OR
69702	Yaquina Bay entrance, Yaquina Bay, Oregon Current	NOS	PCT1076_1	44.61667	-124.06667	:America/Los_Angeles	USA	knots	235	50	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:55:00	\N	1.1	-01:04:00	\N	0.8	-01:20:00	-01:17:00	Yaquina Bay entrance	OR
69703	Highway Bridge, Yaquina Bay, Oregon Current	NOS	PCT1081_1	44.62333	-124.057	:America/Los_Angeles	USA	knots	222	44	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:53:00	\N	1	-00:50:00	\N	0.6	-01:31:00	-01:40:00	Highway Bridge	OR
69704	Yaquina, Yaquina River, Yaquina Bay, Oregon Current	NOS	PCT1086_1	44.602	-124.01133	:America/Los_Angeles	USA	knots	2	184	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:33:00	\N	0.5	-00:50:00	\N	0.3	-01:09:00	-01:33:00	Yaquina, Yaquina River	OR
69705	Yaquina River, 1 mile below Toledo, Yaquina Bay, Oregon Current	NOS	PCT1091_1	44.6005	-123.94167	:America/Los_Angeles	USA	knots	132	332	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:02:00	\N	0.7	-00:13:00	\N	0.4	-00:27:00	-00:46:00	Yaquina River, 1 mile below Toledo	OR
69706	Tillamook Bay entrance, Tillamook Bay, Oregon Current	NOS	PCT1096_1	45.56217	-123.93833	:America/Los_Angeles	USA	knots	305	141	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	1.3	-00:47:00	\N	0.9	-00:20:00	-01:05:00	Tillamook Bay entrance	OR
69707	Sand Island Tower, 1nm SE of (midchannel) (Depth 15ft), Washington Current	NOS	PCT1106_1	46.25283	-123.99083	:America/Los_Angeles	USA	knots	275	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:07:00	\N	1.6	01:03:00	\N	1.6	01:12:00	00:38:00	Sand Island Tower, 1nm SE of (midchannel)	WA
69708	Sand Island Tower, 0.9nm SE of (north channel) (Depth 15ft), Washington Current	NOS	PCT1111_1	46.25783	-123.9945	:America/Los_Angeles	USA	knots	262	92	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:44:00	\N	0.7	00:33:00	\N	1.1	00:39:00	00:27:00	Sand Island Tower, 0.9nm SE of (north channel)	WA
69709	Baker Bay entrance, E of Sand Island Tower (Depth 23ft), Washington Current	NOS	PCT1116_1	46.262	-123.998	:America/Los_Angeles	USA	knots	202	8	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:14:00	\N	0.3	00:08:00	\N	0.6	00:28:00	00:20:00	Baker Bay entrance, E of Sand Island Tower	WA
69710	Clatsop Spit, NNE of (Depth 15ft), Washington Current	NOS	PCT1121_1	46.24617	-123.99417	:America/Los_Angeles	USA	knots	289	114	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:20:00	\N	1.1	00:56:00	\N	1.4	00:45:00	00:56:00	Clatsop Spit, NNE of	WA
69711	Sand Island, SSE of (Depth 12ft), Washington Current	NOS	PCT1126_1	46.2555	-123.968	:America/Los_Angeles	USA	knots	265	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:32:00	\N	0.4	-00:25:00	\N	0.3	00:18:00	-00:16:00	Sand Island, SSE of	WA
69712	Youngs Bay Bridge (Depth 9ft), Oregon Current	NOS	PCT1146_1	46.17783	-123.86833	:America/Los_Angeles	USA	knots	320	135	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:28:00	\N	0.3	-00:14:00	\N	0.4	00:10:00	00:50:00	Youngs Bay Bridge	OR
69713	Hammond, northeast of ship channel (Depth 15ft), Oregon Current	NOS	PCT1151_1	46.21117	-123.9345	:America/Los_Angeles	USA	knots	307	134	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:01:00	\N	0.6	00:24:00	\N	0.4	00:57:00	00:26:00	Hammond, northeast of ship channel	OR
69714	McGowan, SSW of (Depth 14ft), Washington Current	NOS	PCT1156_1	46.2395	-123.91533	:America/Los_Angeles	USA	knots	282	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:23:00	\N	1.6	01:14:00	\N	0.9	01:28:00	00:21:00	McGowan, SSW of	WA
69715	Point Ellice, east of (Depth 17ft), Washington Current	NOS	PCT1161_1	46.24167	-123.84833	:America/Los_Angeles	USA	knots	254	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:11:00	\N	0.9	00:25:00	\N	0.8	00:55:00	00:51:00	Point Ellice, east of	WA
69716	Point Adams, NNE OF (Depth 14ft), Oregon Current	NOS	PCT1166_1	46.22783	-123.9675	:America/Los_Angeles	USA	knots	297	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:11:00	\N	0.9	00:13:00	\N	0.8	01:16:00	00:26:00	Point Adams, NNE OF	OR
69717	Chinook Point, WSW of (Depth 14ft), Washington Current	NOS	PCT1171_1	46.24217	-123.96417	:America/Los_Angeles	USA	knots	287	117	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:21:00	\N	0.9	00:25:00	\N	1.2	00:29:00	00:45:00	Chinook Point, WSW of	WA
69718	Tongue Point, northwest of (Depth 15ft), Oregon Current	NOS	PCT1176_1	46.21917	-123.76667	:America/Los_Angeles	USA	knots	249	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:46:00	\N	0.9	01:09:00	\N	0.4	02:31:00	00:24:00	Tongue Point, northwest of	OR
69719	Woody Island Channel (Depth 15ft), Washington Current	NOS	PCT1186_1	46.2395	-123.67333	:America/Los_Angeles	USA	knots	298	118	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:15:00	\N	0.3	01:09:00	\N	0.5	01:12:00	01:36:00	Woody Island Channel	WA
69720	Woody Island Channel (off Seal Island) (Depth 12ft), Oregon Current	NOS	PCT1191_1	46.2175	-123.62917	:America/Los_Angeles	USA	knots	247	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	02:53:00	\N	0.4	01:53:00	\N	0.3	02:38:00	01:25:00	Woody Island Channel (off Seal Island)	OR
69721	Quinn Island, Prairie Channel (Depth 8ft), Washington Current	NOS	PCT1201_1	46.23717	-123.50333	:America/Los_Angeles	USA	knots	281	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:53:00	\N	0.5	01:52:00	\N	0.3	03:19:00	00:55:00	Quinn Island, Prairie Channel	WA
69722	Clifton Channel (Depth 10ft), Washington Current	NOS	PCT1206_1	46.21783	-123.46533	:America/Los_Angeles	USA	knots	301	118	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	02:17:00	\N	0.4	02:27:00	\N	0.3	03:41:00	01:21:00	Clifton Channel	WA
69723	Hunting Island, south of (Depth 20ft), Washington Current	NOS	PCT1216_1	46.20717	-123.40417	:America/Los_Angeles	USA	knots	295	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	03:20:00	\N	0.4	02:56:00	\N	0.2	04:20:00	01:38:00	Hunting Island, south of	WA
69724	Cathlamet Channel, SE of Nassa Point (Depth 19ft), Washington Current	NOS	PCT1231_1	46.15617	-123.315	:America/Los_Angeles	USA	knots	278	103	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	05:38:00	\N	0.6	03:23:00	\N	0.1	05:16:00	01:39:00	Cathlamet Channel, SE of Nassa Point	WA
69725	Walker Island, south of (Depth 12ft), Washington Current	NOS	PCT1251_1	46.14117	-123.04583	:America/Los_Angeles	USA	knots	330	148	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	05:09:00	\N	0.4	04:15:00	\N	0.2	05:46:00	02:41:00	Walker Island, south of	WA
69726	South Bend, Willapa River, Washington Current	NOS	PCT1271_1	46.66467	-123.80133	:America/Los_Angeles	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:06:00	\N	0.5	00:20:00	\N	0.6	00:19:00	00:24:00	South Bend, Willapa River	WA
69727	Entrance, 0.2 mile south of north jetty, Grays Harbor, Washington Current	NOS	PCT1276_1	46.92633	-124.16133	:America/Los_Angeles	USA	knots	243	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:47:00	\N	0.6	00:16:00	\N	1.3	-00:28:00	00:10:00	Entrance, 0.2 mile south of north jetty	WA
69728	Entrance, Point Chehalis Range, Grays Harbor, Washington Current	NOS	PCT1281_1	46.90833	-124.1555	:America/Los_Angeles	USA	knots	268	92	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:21:00	\N	1.1	-00:11:00	\N	0.9	00:08:00	-00:22:00	Entrance, Point Chehalis Range	WA
69729	Entrance, 0.6 mile WNW of Westport, Grays Harbor, Washington Current	NOS	PCT1286_1	46.91467	-124.125	:America/Los_Angeles	USA	knots	238	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:00:00	\N	0.7	00:00:00	\N	1.2	00:00:00	00:06:00	Entrance, 0.6 mile WNW of Westport	WA
69730	Entrance, 1.1 miles NW of Westport, Grays Harbor, Washington Current	NOS	PCT1296_1	46.91667	-124.13333	:America/Los_Angeles	USA	knots	233	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:23:00	\N	0.9	-00:06:00	\N	0.9	00:04:00	-00:05:00	Entrance, 1.1 miles NW of Westport	WA
69731	Channel, 1.5 miles north of Westport, Grays Harbor, Washington Current	NOS	PCT1301_1	46.93333	-124.1	:America/Los_Angeles	USA	knots	226	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:25:00	\N	0.6	-00:04:00	\N	0.7	-00:22:00	-00:04:00	Channel, 1.5 miles north of Westport	WA
69732	Channel, 2.1 miles NNE of Westport, Grays Harbor, Washington Current	NOS	PCT1306_1	46.93333	-124.08333	:America/Los_Angeles	USA	knots	249	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:02:00	\N	0.5	00:00:00	\N	0.6	-00:02:00	-00:02:00	Channel, 2.1 miles NNE of Westport	WA
69733	Westport, channel 0.4 mile NE of, Grays Harbor, Washington Current	NOS	PCT1316_1	46.91417	-124.10833	:America/Los_Angeles	USA	knots	310	113	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:36:00	\N	0.7	-00:04:00	\N	1	-00:41:00	-00:19:00	Westport, channel 0.4 mile NE of	WA
69734	Trial Island, 5.2 miles SSW of (Depth 15ft), Strait of Juan de Fuca, Washington Current	NOS	PCT1391_1	48.31666946411133	-123.36666870117188	:America/Los_Angeles	USA	knots	235	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65215	00:58:00	\N	0.72	00:30:00	\N	1.06	00:00:00	01:08:00	Trial Island, 5.2 miles SSW of	WA
69735	New Dungeness Light, 6 miles NNE of (Depth 15ft), Washington Current	NOS	PCT1401_1	48.26667022705078	-123.05000305175781	:America/Los_Angeles	USA	knots	255	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65215	00:39:00	\N	0.57	00:46:00	\N	0.48	00:59:00	00:13:00	New Dungeness Light, 6 miles NNE of	WA
69775	Blaine Point, Pearse Canal, Alaska Current	NOS	PCT2686_1	55.03333	-130.21667	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Blaine Point	AK
69736	Discovery Island, 3 miles SSE of (Depth 15ft), Strait of Juan de Fuca, Washington Current	NOS	PCT1411_1	48.383331298828125	-123.19999694824219	:America/Los_Angeles	USA	knots	250	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65215	00:13:00	\N	1.18	00:06:00	\N	0.86	00:31:00	-00:12:00	Discovery Island, 3 miles SSE of	WA
69737	Cattle Point, 2.8 miles SSW of, San Juan Channel, Washington Current	NOS	PCT1416_1	48.400001525878906	-123	:America/Los_Angeles	USA	knots	187	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65244	-00:08:00	\N	0.12	01:07:00	\N	0.21	-00:36:00	01:10:00	Cattle Point, 2.8 miles SSW of	WA
69738	Smith Island, 1.4 miles SSW of, Strait of Juan de Fuca, Washington Current	NOS	PCT1451_1	48.29999923706055	-122.8499984741211	:America/Los_Angeles	USA	knots	280	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65164	00:30:00	\N	0.28	00:14:00	\N	0.25	00:33:00	00:03:00	Smith Island, 1.4 miles SSW of	WA
69739	Point Partridge, 3.7 miles west of, Strait of Juan de Fuca, Washington Current	NOS	PCT1466_1	48.23332977294922	-122.86666870117188	:America/Los_Angeles	USA	knots	250	140	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65164	00:47:00	\N	0.59	00:28:00	\N	0.14	01:46:00	-00:50:00	Point Partridge, 3.7 miles west of	WA
69740	Point Wilson, 0.8 mile east of, Admiralty Inlet, Washington Current	NOS	PCT1496_1	48.150001525878906	-122.73332977294922	:America/Los_Angeles	USA	knots	280	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65164	-00:49:00	\N	0.74	-00:09:00	\N	0.87	-00:14:00	00:01:00	Point Wilson, 0.8 mile east of	WA
69741	Marrowstone Point, 1.1 miles northwest of, Admiralty Inlet, Washington Current	NOS	PCT1511_1	48.116668701171875	-122.69999694824219	:America/Los_Angeles	USA	knots	275	100	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65164	-01:37:00	\N	0.37	-02:09:00	\N	0.46	-02:52:00	-01:28:00	Marrowstone Point, 1.1 miles northwest of	WA
69742	Agate Passage, north end, Puget Sound, Washington Current	NOS	PCT1636_1	47.722	-122.555	:America/Los_Angeles	USA	knots	32	230	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65164	-00:54:00	\N	0.51	-00:49:00	\N	0.42	-00:49:00	-00:44:00	Agate Passage, north end	WA
69743	Off Pleasant Beach, Rich Passage, Puget Sound, Washington Current	NOS	PCT1701_1	47.58332824707031	-122.53333282470703	:America/Los_Angeles	USA	knots	132	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65164	00:48:00	\N	0.79	-00:04:00	\N	0.46	00:25:00	00:10:00	Off Pleasant Beach	WA
69744	Eld Inlet entrance (Depth 15ft), Puget Sound, Washington Current	NOS	PCT1861_1	47.146331787109375	-122.9333267211914	:America/Los_Angeles	USA	knots	28	224	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65032	-00:10:00	\N	0.31	00:10:00	\N	0.54	-00:13:00	-00:12:00	Eld Inlet entrance	WA
69745	Hammersley Inlet, west of Skookum Point (Depth 15ft), Puget Sound, Washington Current	NOS	PCT1896_1	47.207000732421875	-123.03949737548828	:America/Los_Angeles	USA	knots	101	287	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65032	01:04:00	\N	0.82	01:30:00	\N	1.01	01:05:00	01:21:00	Hammersley Inlet, west of Skookum Point	WA
69746	Iceberg Point, 2.1 miles SSW of, Rosario Strait, Washington Current	NOS	PCT1966_1	48.383331298828125	-122.91667175292969	:America/Los_Angeles	USA	knots	260	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65241	-00:37:00	\N	0.4	-00:41:00	\N	0.7	-00:44:00	00:52:00	Iceberg Point, 2.1 miles SSW of	WA
69747	Colville Island, 1 mile SSE of, Rosario Strait, Washington Current	NOS	PCT1971_1	48.400001525878906	-122.8166732788086	:America/Los_Angeles	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65241	-00:20:00	\N	1	-00:05:00	\N	0.7	00:09:00	00:17:00	Colville Island, 1 mile SSE of	WA
69748	Burrows Bay, 0.5 mile east of Allan I, Rosario Strait, Washington Current	NOS	PCT2006_1	48.46282958984375	-122.68283081054688	:America/Los_Angeles	USA	knots	209	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65241	-01:10:00	\N	0.2	-01:04:00	\N	0.6	-03:11:00	-00:07:00	Burrows Bay, 0.5 mile east of Allan I	WA
69749	Green Point, 0.8 mile northwest of, Rosario Strait, Washington Current	NOS	PCT2026_1	48.504669189453125	-122.70616912841797	:America/Los_Angeles	USA	knots	190	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65421	-01:30:00	\N	0.75	-01:11:00	\N	1.09	-00:43:00	-00:34:00	Green Point, 0.8 mile northwest of	WA
69750	Frost-Willow Island, between, Rosario Strait, Washington Current	NOS	PCT2046_1	48.53916931152344	-122.8308334350586	:America/Los_Angeles	USA	knots	126	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65241	00:02:00	\N	0.4	00:38:00	\N	0.4	00:36:00	-00:10:00	Frost-Willow Island, between	WA
69751	Barnes Island, 0.8 mile southwest of, Rosario Strait, Washington Current	NOS	PCT2071_1	48.685829162597656	-122.78883361816406	:America/Los_Angeles	USA	knots	140	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65241	-00:19:00	\N	0.4	00:44:00	\N	0.4	00:27:00	-00:36:00	Barnes Island, 0.8 mile southwest of	WA
69752	Raccoon Point, 0.6 mile NNE of, Rosario Strait, Washington Current	NOS	PCT2076_1	48.706329345703125	-122.82917022705078	:America/Los_Angeles	USA	knots	101	286	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65241	-00:47:00	\N	0.4	-01:21:00	\N	0.4	-00:46:00	-02:10:00	Raccoon Point, 0.6 mile NNE of	WA
69753	Matia Island, 0.8 mile west of, Rosario Strait, Washington Current	NOS	PCT2086_1	48.74882888793945	-122.86582946777344	:America/Los_Angeles	USA	knots	206	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65241	-00:13:00	\N	0.7	-00:10:00	\N	0.7	00:12:00	-00:55:00	Matia Island, 0.8 mile west of	WA
69754	Huckleberry Island, 0.5 mile north of, Rosario Strait, Washington Current	NOS	PCT2106_1	48.54583	-122.56633	:America/Los_Angeles	USA	knots	253	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65281	-01:57:00	\N	0.5	-00:47:00	\N	0.5	-03:28:00	-00:25:00	Huckleberry Island, 0.5 mile north of	WA
69755	Towhead Island, 0.4 mile east of, Rosario Strait, Washington Current	NOS	PCT2126_1	48.6121711730957	-122.7021713256836	:America/Los_Angeles	USA	knots	125	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65281	-00:46:00	\N	0.32	00:08:00	\N	0.5	-02:06:00	01:42:00	Towhead Island, 0.4 mile east of	WA
69756	Puffin Island Light, 4.8 miles north of, Rosario Strait, Washington Current	NOS	PCT2166_1	48.82217025756836	-122.8083267211914	:America/Los_Angeles	USA	knots	210	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65281	-00:36:00	\N	0.63	00:25:00	\N	0.31	00:07:00	-00:06:00	Puffin Island Light, 4.8 miles north of	WA
69757	Kings Point, Lopez Island, 1 mile NNW of (Depth 15ft), Washington Current	NOS	PCT2191_1	48.48332977294922	-122.9558334350586	:America/Los_Angeles	USA	knots	185	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65244	00:38:00	\N	0.37	-00:28:00	\N	0.53	00:50:00	00:47:00	Kings Point, Lopez Island, 1 mile NNW of	WA
69758	Johns Island, 0.8 mile north of, Washington Current	NOS	PCT2266_1	48.68333053588867	-123.1500015258789	:America/Los_Angeles	USA	knots	350	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65244	00:51:00	\N	0.17	-00:52:00	\N	0.21	-00:16:00	00:26:00	Johns Island, 0.8 mile north of	WA
69759	Skipjack Island, 1.5 miles northwest of (Depth 15ft), Washington Current	NOS	PCT2276_1	48.7495002746582	-123.06082916259766	:America/Los_Angeles	USA	knots	290	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65244	01:14:00	\N	0.39	00:58:00	\N	0.29	01:16:00	01:28:00	Skipjack Island, 1.5 miles northwest of	WA
69760	Point Hammond, 1.1 miles northwest of (Depth 15ft), Washington Current	NOS	PCT2281_1	48.731998443603516	-123.02532958984375	:America/Los_Angeles	USA	knots	255	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65244	01:15:00	\N	0.65	00:44:00	\N	0.22	01:10:00	00:47:00	Point Hammond, 1.1 miles northwest of	WA
69761	Alden Point, Patos Island, 2 miles S of, Rosario Strait, Washington Current	NOS	PCT2286_1	48.75783157348633	-122.98033142089844	:America/Los_Angeles	USA	knots	185	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65281	-01:40:00	\N	1.66	-01:31:00	\N	0.6	-00:02:00	-00:46:00	Alden Point, Patos Island, 2 miles S of	WA
69763	Cape Muzon, 4 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2621_1	54.6	-132.68333	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	1.2	-00:47:00	\N	0.8	-00:39:00	-00:57:00	Cape Muzon, 4 miles south from	AK
69764	Point Marsh, 5 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2626_1	54.63333	-132.3	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	1.1	-00:47:00	\N	0.7	-00:39:00	-00:57:00	Point Marsh, 5 miles south from	AK
69765	West Devil Rock, 2 miles north of, Dixon Entrance, Alaska Current	NOS	PCT2636_1	54.7	-131.6	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1.2	-00:42:00	\N	0.8	-00:34:00	-00:52:00	West Devil Rock, 2 miles north of	AK
69766	Barren Island Light, 2 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2641_1	54.7	-131.35	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.1	-00:37:00	\N	0.7	-00:29:00	-00:47:00	Barren Island Light, 2 miles south from	AK
69767	East Devil Rock, 1 mile north of, Dixon Entrance, Alaska Current	NOS	PCT2646_1	54.7	-131.08333	:America/Juneau	USA	knots	265	85	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.1	00:23:00	\N	0.7	00:31:00	00:13:00	East Devil Rock, 1 mile north of	AK
69768	Between Dundas Island and Cape Fox, Dixon Entrance, Alaska Current	NOS	PCT2651_1	54.7	-130.83333	:America/Juneau	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	1.4	00:18:00	\N	0.6	00:14:00	00:20:00	Between Dundas Island and Cape Fox	AK
69769	Tongass Islands, east of, Nakat Bay, Dixon Entrance, Alaska Current	NOS	PCT2656_1	54.78233	-130.73717	:America/Juneau	USA	knots	157	326	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:31:00	\N	0.6	-02:40:00	\N	0.3	-01:31:00	-01:38:00	Tongass Islands, east of, Nakat Bay	AK
69770	Boston Islands, 1 mile south from, Dixon Entrance, Alaska Current	NOS	PCT2661_1	54.68333	-130.56667	:America/Juneau	USA	knots	265	85	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.1	-00:37:00	\N	0.7	-00:29:00	-00:47:00	Boston Islands, 1 mile south from	AK
69771	Portland Inlet, 2 miles S. of Wales Pt, Dixon Entrance, Alaska Current	NOS	PCT2666_1	54.66667	-130.48333	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.2	00:28:00	\N	0.8	00:36:00	00:18:00	Portland Inlet, 2 miles S. of Wales Pt	AK
69772	Haystack Island, Tongass Passage, Pearse Canal, Alaska Current	NOS	PCT2671_1	54.71667	-130.61667	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.2	00:23:00	\N	0.8	00:31:00	00:13:00	Haystack Island, Tongass Passage	AK
69776	Wales Point, 2 miles south from, Portland Canal, Alaska Current	NOS	PCT2691_1	54.66667	-130.48333	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.2	00:28:00	\N	0.8	00:36:00	00:18:00	Wales Point, 2 miles south from	AK
69777	Cliff Point, 1 mile east from, Portland Canal, Alaska Current	NOS	PCT2696_1	54.8	-130.31667	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.1	00:28:00	\N	0.7	00:36:00	00:18:00	Cliff Point, 1 mile east from	AK
69778	Flat Point , 1 mile east of, Portland Canal, Alaska Current	NOS	PCT2701_1	54.91667	-130.16667	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	1	00:33:00	\N	0.6	00:41:00	00:23:00	Flat Point , 1 mile east of	AK
69779	Tree Point, 1 mile east of, Portland Canal, Alaska Current	NOS	PCT2706_1	55.03333	-130.16667	:America/Juneau	USA	knots	165	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.9	00:33:00	\N	0.6	00:41:00	00:23:00	Tree Point, 1 mile east of	AK
69780	Dickens Point, Portland Canal, Alaska Current	NOS	PCT2711_1	55.15	-130.15	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.7	00:33:00	\N	0.5	00:41:00	00:23:00	Dickens Point	AK
69781	White Point, Portland Canal, Alaska Current	NOS	PCT2716_1	55.56667	-130.11667	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:59:00	\N	0.5	00:38:00	\N	0.3	00:46:00	00:28:00	White Point	AK
69782	Camp Point, Portland Canal, Alaska Current	NOS	PCT2721_1	55.28333	-129.98333	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.6	-00:22:00	\N	0.4	-00:14:00	-00:32:00	Camp Point	AK
69783	Miners Point, Portland Canal, Alaska Current	NOS	PCT2726_1	55.71667	-130.15	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.4	-00:17:00	\N	0.3	-00:09:00	-00:27:00	Miners Point	AK
69784	Lion Point, Portland Canal, Alaska Current	NOS	PCT2731_1	55.88333	-130.03333	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.2	-00:17:00	\N	0.2	-00:09:00	-00:27:00	Lion Point	AK
69785	Race Point, 0.7 mile ENE of, Revillagigedo Channel, Alaska Current	NOS	PCT2761_1	55.28583	-131.546	:America/Juneau	USA	knots	300	145	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:18:00	\N	0.2	00:22:00	\N	0.2	00:49:00	00:10:00	Race Point, 0.7 mile ENE of	AK
69786	Saxman Spire, 0.2 mile south of, Tongass Narrows, Alaska Current	NOS	PCT2781_1	55.3155	-131.60267	:America/Juneau	USA	knots	110	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:12:00	\N	0.3	-02:00:00	\N	0.2	-00:32:00	-02:02:00	Saxman Spire, 0.2 mile south of	AK
69787	Ketchikan, Tongass Narrows, Alaska Current	NOS	PCT2786_1	55.33617	-131.64417	:America/Juneau	USA	knots	120	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:41:00	\N	0.1	00:08:00	\N	0.3	-00:50:00	00:04:00	Ketchikan	AK
69788	Hotspur Island, 0.5 mile southeast of, Felice Strait, Alaska Current	NOS	PCT2806_1	54.96667	-131.48333	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:56:00	\N	0.4	-01:29:00	\N	0.3	-00:53:00	-01:06:00	Hotspur Island, 0.5 mile southeast of	AK
69789	Point Davidson, 1 mile south of, Felice Strait, Alaska Current	NOS	PCT2811_1	54.98333	-131.6	:America/Juneau	USA	knots	240	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1	-00:37:00	\N	0.6	-00:29:00	-00:47:00	Point Davidson, 1 mile south of	AK
69790	Harris Island, Felice Strait, Alaska Current	NOS	PCT2816_1	55	-131.53333	:America/Juneau	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.8	-00:37:00	\N	1.3	-00:29:00	-00:47:00	Harris Island	AK
69791	Ajax Reef, Felice Strait, Alaska Current	NOS	PCT2821_1	55	-131.46667	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.4	-00:32:00	\N	0.9	-00:24:00	-00:42:00	Ajax Reef	AK
69792	Snipe Island, Felice Strait, Alaska Current	NOS	PCT2831_1	55	-131.38333	:America/Juneau	USA	knots	250	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.8	-00:27:00	\N	1.3	-00:19:00	-00:37:00	Snipe Island	AK
69793	Grass Rock, Tamgas Harbor entrance, Felice Strait, Alaska Current	NOS	PCT2836_1	55.02167	-131.52233	:America/Juneau	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.2	-00:32:00	\N	0.8	-00:24:00	-00:42:00	Grass Rock, Tamgas Harbor entrance	AK
69794	Indian Reef, Felice Strait, Alaska Current	NOS	PCT2841_1	55.03333	-131.35	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.6	-00:27:00	\N	1.1	-00:19:00	-00:37:00	Indian Reef	AK
69929	Eva Islands, Peril Strait, Alaska Current	NOS	PCT4321_1	57.45	-134.93333	:America/Juneau	USA	knots	95	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.6	00:03:00	\N	0.4	00:11:00	-00:07:00	Eva Islands	AK
69795	Customhouse Cove, 1 mile west of, Felice Strait, Alaska Current	NOS	PCT2866_1	55.1	-131.26667	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Customhouse Cove, 1 mile west of	AK
69796	Hid Reef, 2.7 miles south of, Nichols Passage, Alaska Current	NOS	PCT2871_1	55.03333	-131.66667	:America/Juneau	USA	knots	190	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:12:00	\N	0.2	-00:54:00	\N	0.2	-00:18:00	-00:40:00	Hid Reef, 2.7 miles south of	AK
69797	Point McCartey Light, Nichols Passage, Alaska Current	NOS	PCT2876_1	55.11667	-131.7	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1	-00:32:00	\N	0.6	-00:24:00	-00:42:00	Point McCartey Light	AK
69798	Wharburton Island, Nichols Passage, Alaska Current	NOS	PCT2891_1	55.1335	-131.62867	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.1	-00:32:00	\N	0.7	-00:24:00	-00:42:00	Wharburton Island	AK
69799	Driest Point, Nichols Passage, Alaska Current	NOS	PCT2896_1	55.18333	-131.6	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.9	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Driest Point	AK
69800	Blank Point, Nichols Passage, Alaska Current	NOS	PCT2911_1	55.24867	-131.66933	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	1.1	-00:22:00	\N	0.7	-00:14:00	-00:32:00	Blank Point	AK
69801	Point Sykes, Behm Canal, Alaska Current	NOS	PCT2921_1	55.2	-131.11667	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Point Sykes	AK
69802	Behm Narrows, Behm Canal, Alaska Current	NOS	PCT2936_1	55.91367	-131.532	:America/Juneau	USA	knots	264	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-02:58:00	\N	0.6	-03:07:00	\N	0.1	-01:41:00	-03:41:00	Behm Narrows	AK
69803	Helm Point, Behm Canal, Alaska Current	NOS	PCT2941_1	55.6	-131.83333	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.6	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Helm Point	AK
69804	Guard Islands, 2 miles northwest of, Behm Canal, Alaska Current	NOS	PCT2946_1	55.46667	-131.9	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Guard Islands, 2 miles northwest of	AK
69805	Grass Rock, 1 mile south of, Clarence Strait, Alaska Current	NOS	PCT2961_1	55	-131.55	:America/Juneau	USA	knots	235	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:22:00	\N	0.6	-00:29:00	\N	0.2	-00:24:00	-00:02:00	Grass Rock, 1 mile south of	AK
69806	Moira Rock, 2 miles east of, Clarence Strait, Alaska Current	NOS	PCT2966_1	55.08333	-131.93333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.7	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Moira Rock, 2 miles east of	AK
69807	Skin Island, 3 miles east from, Clarence Strait, Alaska Current	NOS	PCT2991_1	55.3	-131.98333	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Skin Island, 3 miles east from	AK
69808	Guard Island Lighthouse, 5.1 miles SW of, Clarence Strait, Alaska Current	NOS	PCT3011_1	55.4	-132	:America/Juneau	USA	knots	164	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:20:00	\N	0.3	-00:03:00	\N	0.2	00:06:00	-00:12:00	Guard Island Lighthouse, 5.1 miles SW of	AK
69809	Guard Islands, 2 miles west of, Clarence Strait, Alaska Current	NOS	PCT3016_1	55.45	-131.95	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Guard Islands, 2 miles west of	AK
69810	Ship Island, Clarence Strait, Alaska Current	NOS	PCT3021_1	55.6	-132.25	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.7	-00:22:00	\N	0.5	-00:14:00	-00:32:00	Ship Island	AK
69811	Narrow Point, Clarence Strait, Alaska Current	NOS	PCT3026_1	55.78333	-132.41667	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.7	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Narrow Point	AK
69812	Mabel Island, 3 miles west from, Clarence Strait, Alaska Current	NOS	PCT3031_1	55.91667	-132.5	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	0.7	-00:07:00	\N	0.5	00:01:00	-00:17:00	Mabel Island, 3 miles west from	AK
69813	Lincoln Rock Light, 1 mile west from, Clarence Strait, Alaska Current	NOS	PCT3036_1	56.05	-132.71667	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Lincoln Rock Light, 1 mile west from	AK
69814	McHenry Ledge, 1 mile north of, Ernest Sound, Alaska Current	NOS	PCT3041_1	55.8	-132.3	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	1	-00:17:00	\N	0.6	-00:09:00	-00:27:00	McHenry Ledge, 1 mile north of	AK
69815	Vixen Point, 3 miles west of, Ernest Sound, Alaska Current	NOS	PCT3046_1	55.85	-132.18333	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.8	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Vixen Point, 3 miles west of	AK
69816	Eaton Point, Ernest Sound, Alaska Current	NOS	PCT3051_1	55.95283	-132.09	:America/Juneau	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	1	-00:07:00	\N	0.7	00:01:00	-00:17:00	Eaton Point	AK
69817	Niblack Islands, Ernest Sound, Alaska Current	NOS	PCT3056_1	56.03333	-132.08333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.7	00:06:00	-00:12:00	Niblack Islands	AK
69818	Blanche Rock, Ernest Sound, Alaska Current	NOS	PCT3061_1	56.08333	-132.08333	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Blanche Rock	AK
69819	Point Warde, Ernest Sound, Alaska Current	NOS	PCT3066_1	56.18333	-131.96667	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	1	00:08:00	\N	0.6	00:16:00	-00:02:00	Point Warde	AK
69820	Blake Island, Alaska Current	NOS	PCT3071_1	56.223	-131.90883	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	1.2	00:13:00	\N	0.8	00:21:00	00:03:00	Blake Island	AK
69821	Berg Bay, Alaska Current	NOS	PCT3076_1	56.34367	-132.00767	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	1.1	00:18:00	\N	0.7	00:26:00	00:08:00	Berg Bay	AK
69822	The Narrows, Alaska Current	NOS	PCT3081_1	56.36783	-132.10267	:America/Juneau	USA	knots	45	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.4	00:23:00	\N	0.9	00:31:00	00:13:00	The Narrows	AK
69823	Channel Island, north of, Alaska Current	NOS	PCT3086_1	56.37517	-132.16967	:America/Juneau	USA	knots	320	140	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1	00:23:00	\N	0.6	00:31:00	00:13:00	Channel Island, north of	AK
69824	Mill Creek, Alaska Current	NOS	PCT3091_1	56.45	-132.21667	:America/Juneau	USA	knots	330	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	0.9	00:23:00	\N	0.6	00:31:00	00:13:00	Mill Creek	AK
69825	Point Highfield, Alaska Current	NOS	PCT3096_1	56.5	-132.38333	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.7	-00:02:00	\N	0.5	00:06:00	-00:12:00	Point Highfield	AK
69826	Found Island, 1 mile northwest of, Zimovia Strait, Alaska Current	NOS	PCT3101_1	56.11667	-132.1	:America/Juneau	USA	knots	140	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.8	00:03:00	\N	0.5	00:11:00	-00:07:00	Found Island, 1 mile northwest of	AK
69827	No Name Island, near Thoms Place, Zimovia Strait, Alaska Current	NOS	PCT3106_1	56.15	-132.15	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.8	00:08:00	\N	0.5	00:16:00	-00:02:00	No Name Island, near Thoms Place	AK
69828	Village Islands, Zimovia Strait, Alaska Current	NOS	PCT3111_1	56.21667	-132.31667	:America/Juneau	USA	knots	135	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	Village Islands	AK
69829	Young Rock, 2 miles south of, Zimovia Strait, Alaska Current	NOS	PCT3116_1	56.33333	-132.38333	:America/Juneau	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.8	00:13:00	\N	0.5	00:21:00	00:03:00	Young Rock, 2 miles south of	AK
69830	East Point, east of, Zimovia Strait, Alaska Current	NOS	PCT3121_1	56.38333	-132.4	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.8	-00:02:00	\N	0.5	00:06:00	-00:12:00	East Point, east of	AK
69831	Wrangell Harbor, 1.6 miles west of, Zimovia Strait, Alaska Current	NOS	PCT3131_1	56.46667	-132.45	:America/Juneau	USA	knots	235	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:33:00	\N	0.4	03:36:00	\N	0.3	02:28:00	02:16:00	Wrangell Harbor, 1.6 miles west of	AK
69832	Cape Muzon, 5 miles east of, Cordova Bay, Alaska Current	NOS	PCT3196_1	54.66667	-132.53333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	0.6	-00:47:00	\N	0.4	-00:39:00	-00:57:00	Cape Muzon, 5 miles east of	AK
69833	Dewey Rocks, 2 miles west of, Cordova Bay, Alaska Current	NOS	PCT3201_1	54.75	-132.53333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	0.5	-00:42:00	\N	0.3	-00:34:00	-00:52:00	Dewey Rocks, 2 miles west of	AK
69834	Boat Rocks, 2 miles west of, Cordova Bay, Alaska Current	NOS	PCT3211_1	54.81667	-132.56667	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	0.5	-00:42:00	\N	0.3	-00:34:00	-00:52:00	Boat Rocks, 2 miles west of	AK
69835	Webster Point, 1 mile west of, Cordova Bay, Alaska Current	NOS	PCT3221_1	54.96667	-132.63333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.8	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Webster Point, 1 mile west of	AK
69836	Mellen Rock, 1 mile east of, Cordova Bay, Alaska Current	NOS	PCT3226_1	55.03333	-132.65	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1	-00:32:00	\N	0.6	-00:24:00	-00:42:00	Mellen Rock, 1 mile east of	AK
69837	Shoe Rock, 1 mile north of, Tlevak Strait, Alaska Current	NOS	PCT3231_1	54.96667	-132.73333	:America/Juneau	USA	knots	105	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.8	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Shoe Rock, 1 mile north of	AK
69838	Grand Island, 2 miles north of, Tlevak Strait, Alaska Current	NOS	PCT3236_1	55	-132.86667	:America/Juneau	USA	knots	115	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.7	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Grand Island, 2 miles north of	AK
69839	High Point, 1 mile east of, Tlevak Strait, Alaska Current	NOS	PCT3241_1	55.01667	-132.93333	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.9	-00:32:00	\N	0.6	-00:24:00	-00:42:00	High Point, 1 mile east of	AK
69840	McFarland Islands, Tlevak Strait, Alaska Current	NOS	PCT3246_1	55.06667	-132.95	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.8	-00:27:00	\N	0.5	-00:19:00	-00:37:00	McFarland Islands	AK
69841	Corlies Islands, Tlevak Strait, Alaska Current	NOS	PCT3251_1	55.13333	-132.96667	:America/Juneau	USA	knots	165	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Corlies Islands	AK
69842	Sukkwan Narrows, Tlevak Strait, Alaska Current	NOS	PCT3256_1	55.19833	-132.824	:America/Juneau	USA	knots	130	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:09:00	\N	0.6	-00:45:00	\N	0.4	-00:29:00	-00:20:00	Sukkwan Narrows	AK
69843	The Sentinels, 1 mile west of, Tlevak Strait, Alaska Current	NOS	PCT3261_1	55.18333	-133.01667	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.8	-00:27:00	\N	0.5	-00:19:00	-00:37:00	The Sentinels, 1 mile west of	AK
69844	Meares Island, south of, Meares Passage, Alaska Current	NOS	PCT3281_1	55.25783	-133.18283	:America/Juneau	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.7	-00:19:00	-00:37:00	Meares Island, south of	AK
69845	Millar Rocks, Meares Passage, Alaska Current	NOS	PCT3291_1	55.2	-133.25	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.6	-00:37:00	\N	0.4	-00:29:00	-00:47:00	Millar Rocks	AK
69846	Diver Islands, Meares Passage, Alaska Current	NOS	PCT3296_1	55.18333	-133.28333	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.5	-00:37:00	\N	0.3	-00:29:00	-00:47:00	Diver Islands	AK
69847	Cape Flores, Ulloa Channel, Alaska Current	NOS	PCT3301_1	55.35	-133.31667	:America/Juneau	USA	knots	330	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.1	-00:27:00	\N	0.7	-00:19:00	-00:37:00	Cape Flores	AK
69848	Waterfall Cannery, Ulloa Channel, Alaska Current	NOS	PCT3311_1	55.3	-133.25	:America/Juneau	USA	knots	335	155	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Waterfall Cannery	AK
69849	Cape Bartolome, 2 miles east of, Alaska Current	NOS	PCT3316_1	55.23333	-133.55	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.6	-00:37:00	\N	0.4	-00:29:00	-00:47:00	Cape Bartolome, 2 miles east of	AK
69850	Point Arboleda, 1 mile west of, Alaska Current	NOS	PCT3326_1	55.31667	-133.48333	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.7	-00:32:00	\N	0.4	-00:24:00	-00:42:00	Point Arboleda, 1 mile west of	AK
69851	Cabras Islands, 1 mile west of, Alaska Current	NOS	PCT3331_1	55.35	-133.41667	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.6	-00:32:00	\N	0.4	-00:24:00	-00:42:00	Cabras Islands, 1 mile west of	AK
69852	Cape Flores, 1 mile north of, Alaska Current	NOS	PCT3336_1	55.36667	-133.3	:America/Juneau	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Cape Flores, 1 mile north of	AK
69853	Toti Island, 1.1 miles west of, Alaska Current	NOS	PCT3346_1	55.41667	-133.15	:America/Juneau	USA	knots	250	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Toti Island, 1.1 miles west of	AK
69854	Coronados Islands, 2 miles west of, Alaska Current	NOS	PCT3351_1	55.43333	-133.16667	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Coronados Islands, 2 miles west of	AK
69855	Craig Cannery, Alaska Current	NOS	PCT3356_1	55.48333	-133.15	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Craig Cannery	AK
69856	Tuxekan Passage, 0.2 mile S of Tuxekan, Alaska Current	NOS	PCT3456_1	55.88267	-133.24233	:America/Juneau	USA	knots	137	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-03:05:00	\N	0.2	-03:32:00	\N	0.3	-03:34:00	-01:42:00	Tuxekan Passage, 0.2 mile S of Tuxekan	AK
69857	Skookumchuck Pass, El Capitan Passage, Alaska Current	NOS	PCT3476_1	55.91467	-133.31233	:America/Juneau	USA	knots	207	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:03:00	\N	1	-00:19:00	\N	0.7	-00:06:00	-00:11:00	Skookumchuck Pass	AK
69858	Brockman Island, east of, El Capitan Passage, Alaska Current	NOS	PCT3481_1	55.96683	-133.30483	:America/Juneau	USA	knots	182	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:31:00	\N	0.2	00:43:00	\N	0.1	00:28:00	-00:13:00	Brockman Island, east of	AK
69859	Tenass Island, 0.3 mile  SSW of, El Capitan Passage, Alaska Current	NOS	PCT3491_1	55.98667	-133.30483	:America/Juneau	USA	knots	220	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:05:00	\N	0.3	-00:48:00	\N	0.2	00:06:00	-01:18:00	Tenass Island, 0.3 mile  SSW of	AK
69860	The Narrows, west of, Aneskett Point, El Capitan Passage, Alaska Current	NOS	PCT3506_1	56.16017	-133.338	:America/Juneau	USA	knots	248	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	05:37:00	\N	0.1	05:37:00	\N	0.2	04:57:00	05:54:00	The Narrows, west of	AK
69861	Cora Point, 2 miles east of, Sumner Strait, Alaska Current	NOS	PCT3521_1	55.91667	-134.05	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1	-00:42:00	\N	0.1	-00:34:00	-00:52:00	Cora Point, 2 miles east of	AK
69862	Point St. Albans, 3 miles SSE of, Sumner Strait, Alaska Current	NOS	PCT3551_1	56.03333	-133.95	:America/Juneau	USA	knots	232	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:28:00	\N	0.4	-01:14:00	\N	0.2	-00:05:00	-01:05:00	Point St. Albans, 3 miles SSE of	AK
69863	Point St. Albans, 4 miles east of, Sumner Strait, Alaska Current	NOS	PCT3556_1	56.08333	-133.85	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1	-00:37:00	\N	0.1	-00:29:00	-00:46:00	Point St. Albans, 4 miles east of	AK
69864	Ruins Point, 2 miles west of, Sumner Strait, Alaska Current	NOS	PCT3561_1	56.06667	-133.75	:America/Juneau	USA	knots	175	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:49:00	\N	0.3	00:38:00	\N	0.2	00:15:00	-00:48:00	Ruins Point, 2 miles west of	AK
69865	Shakan Light, 2.8 miles WNW of, Sumner Strait, Alaska Current	NOS	PCT3576_1	56.16667	-133.7	:America/Juneau	USA	knots	182	19	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:36:00	\N	0.3	-01:48:00	\N	0.2	-01:21:00	-01:34:00	Shakan Light, 2.8 miles WNW of	AK
69866	Beauclerc Island Light, 1 mile east of, Sumner Strait, Alaska Current	NOS	PCT3616_1	56.25	-133.81667	:America/Juneau	USA	knots	205	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:28:00	\N	0.4	-00:41:00	\N	0.1	00:09:00	-01:30:00	Beauclerc Island Light, 1 mile east of	AK
69867	Sumner Island, 1.8 miles south of, Sumner Strait, Alaska Current	NOS	PCT3636_1	56.36667	-133.81667	:America/Juneau	USA	knots	240	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	0.3	-03:33:00	\N	0.3	-02:39:00	-00:54:00	Sumner Island, 1.8 miles south of	AK
69868	Blaquiere Point, 1 mile SSW of, Sumner Strait, Alaska Current	NOS	PCT3681_1	56.55	-132.56667	:America/Juneau	USA	knots	240	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:23:00	\N	0.5	00:23:00	\N	0.3	-00:08:00	-00:20:00	Blaquiere Point, 1 mile SSW of	AK
69869	Southern entrance to Keku Strait, Keku Strait, Alaska Current	NOS	PCT3701_1	56.56667	-133.71667	:America/Juneau	USA	knots	184	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:32:00	\N	0.6	00:13:00	\N	0.3	00:57:00	-00:25:00	Southern entrance to Keku Strait	AK
69870	Eagle Island, 0.5 mile southeast of, Keku Strait, Alaska Current	NOS	PCT3706_1	56.60733	-133.68217	:America/Juneau	USA	knots	130	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:43:00	\N	1	-00:24:00	\N	0.5	-00:04:00	-00:49:00	Eagle Island, 0.5 mile southeast of	AK
69871	Devils Elbow, Keku Strait, Alaska Current	NOS	PCT3711_1	56.63617	-133.6895	:America/Juneau	USA	knots	90	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:13:00	\N	0.8	-00:09:00	\N	0.8	-00:18:00	-00:41:00	Devils Elbow	AK
69872	Summit Island, west of, Keku Strait, Alaska Current	NOS	PCT3716_1	56.6765	-133.7325	:America/Juneau	USA	knots	10	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:46:00	\N	1.2	01:43:00	\N	0.7	01:48:00	02:10:00	Summit Island, west of	AK
69873	High Island, 1.1 miles south of, Keku Strait, Alaska Current	NOS	PCT3721_1	56.70233	-133.733	:America/Juneau	USA	knots	10	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:30:00	\N	0.5	00:40:00	\N	0.3	00:40:00	00:28:00	High Island, 1.1 miles south of	AK
69874	High Island, northwest of, Keku Strait, Alaska Current	NOS	PCT3726_1	56.75	-133.73333	:America/Juneau	USA	knots	325	210	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:18:00	\N	0.4	00:49:00	\N	0.3	00:07:00	00:34:00	High Island, northwest of	AK
69875	Cucumber Reef, 0.2 mile northwest of, Keku Strait, Alaska Current	NOS	PCT3731_1	56.79	-133.767	:America/Juneau	USA	knots	325	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:11:00	\N	0.8	00:16:00	\N	0.4	00:11:00	00:04:00	Cucumber Reef, 0.2 mile northwest of	AK
69876	Point Alexander, Wrangell Narrows, Alaska Current	NOS	PCT3741_1	56.51033	-132.95833	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.5	-00:02:00	\N	0.3	00:06:00	-00:12:00	Point Alexander	AK
69877	Point Deception, Wrangell Narrows, Alaska Current	NOS	PCT3746_1	56.53333	-132.96667	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.5	-00:02:00	\N	0.3	00:06:00	-00:12:00	Point Deception	AK
69878	Point Lockwood, Wrangell Narrows, Alaska Current	NOS	PCT3751_1	56.55583	-132.96183	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.4	-00:02:00	\N	0.9	00:06:00	-00:12:00	Point Lockwood	AK
69879	Spike Rock, Wrangell Narrows, Alaska Current	NOS	PCT3756_1	56.601	-132.976	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	2.1	-00:02:00	\N	1.5	00:06:00	-00:12:00	Spike Rock	AK
69880	Anchor Point, Wrangell Narrows, Alaska Current	NOS	PCT3766_1	56.6395	-132.93117	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.6	-00:02:00	\N	1.1	00:06:00	-00:12:00	Anchor Point	AK
69881	Vexation Point, Woody Island, Wrangell Narrows, Alaska Current	NOS	PCT3771_1	56.65783	-132.927	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.2	-00:02:00	\N	0.8	00:06:00	-00:12:00	Vexation Point, Woody Island	AK
69882	Green Point, Wrangell Narrows, Alaska Current	NOS	PCT3781_1	56.7	-132.95	:America/Juneau	USA	knots	5	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.5	00:03:00	\N	0.3	00:11:00	-00:07:00	Green Point	AK
69883	Mountain Point, Wrangell Narrows, Alaska Current	NOS	PCT3786_1	56.73333	-132.95	:America/Juneau	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	1	00:13:00	\N	0.6	00:21:00	00:03:00	Mountain Point	AK
69884	Blunt Point, Wrangell Narrows, Alaska Current	NOS	PCT3791_1	56.77833	-132.97933	:America/Juneau	USA	knots	340	160	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.6	00:23:00	\N	1.1	00:31:00	00:13:00	Blunt Point	AK
69885	Turn Point, Wrangell Narrows, Alaska Current	NOS	PCT3796_1	56.80783	-132.9835	:America/Juneau	USA	knots	40	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.8	00:23:00	\N	1.4	00:31:00	00:13:00	Turn Point	AK
69886	Prolewy Rocks, Wrangell Narrows, Alaska Current	NOS	PCT3806_1	56.82233	-132.94833	:America/Juneau	USA	knots	60	240	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.6	00:23:00	\N	1.1	00:31:00	00:13:00	Prolewy Rocks	AK
69887	Cosmos Point, 0.5 mile east of, Frederick Sound, Alaska Current	NOS	PCT3811_1	56.66667	-132.6	:America/Juneau	USA	knots	305	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:42:00	\N	0.2	01:15:00	\N	0.1	01:55:00	00:25:00	Cosmos Point, 0.5 mile east of	AK
69888	The Brothers, 2 miles east of, Stephens Passage, Alaska Current	NOS	PCT3826_1	57.3	-133.71667	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.5	00:03:00	\N	0.3	00:11:00	-00:07:00	The Brothers, 2 miles east of	AK
69889	Point Gambier, 2 miles east of, Stephens Passage, Alaska Current	NOS	PCT3841_1	57.43333	-133.76667	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.2	00:08:00	\N	0.2	00:16:00	-00:02:00	Point Gambier, 2 miles east of	AK
69890	Point Hugh, Stephens Passage, Alaska Current	NOS	PCT3846_1	57.61667	-133.76667	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.5	00:13:00	\N	0.3	00:21:00	00:03:00	Point Hugh	AK
66140	Calcasieu Pass, east jetty, Louisiana	NOS	8768094	29.76816666666667	-93.3428888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calcasieu Pass	LA
69891	Midway Island, Stephens Passage, Alaska Current	NOS	PCT3866_1	57.83333	-133.83333	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.5	00:13:00	\N	0.3	00:21:00	00:03:00	Midway Island	AK
69892	Point Arden, Stephens Passage, Alaska Current	NOS	PCT3876_1	58.15	-134.13333	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	0.5	00:18:00	\N	0.3	00:26:00	00:08:00	Point Arden	AK
69893	0.2 mile off Flat Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3896_1	58.33333	-134.05	:America/Juneau	USA	knots	200	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:07:00	\N	0.5	00:11:00	\N	0.2	00:48:00	-00:12:00	0.2 mile off Flat Point	AK
69894	0.2 mile off Taku Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3901_1	58.4	-134.01667	:America/Juneau	USA	knots	203	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:08:00	\N	0.4	00:34:00	\N	0.4	00:53:00	00:10:00	0.2 mile off Taku Point	AK
69895	Douglas, north of (Depth 15ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_1	58.283	-134.39367	:America/Juneau	USA	knots	144	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:32:00	\N	0.2	00:44:00	\N	0.1	02:12:00	00:11:00	Douglas, north of	AK
69896	Douglas, north of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_2	58.283	-134.39367	:America/Juneau	USA	knots	136	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:08:00	\N	0.3	00:41:00	\N	0.1	01:33:00	00:27:00	Douglas, north of	AK
69897	Juneau Harbor, S of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3921_1	58.29117	-134.407	:America/Juneau	USA	knots	102	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:05:00	\N	0.3	02:03:00	\N	0.1	03:19:00	00:34:00	Juneau Harbor, S of	AK
69898	West Juneau, NE of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3936_1	58.29633	-134.4245	:America/Juneau	USA	knots	137	314	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:21:00	\N	0.2	00:49:00	\N	0.1	00:24:00	00:32:00	West Juneau, NE of	AK
69899	Aurora Basin, SW of (Depth 15ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3946_1	58.305	-134.44083	:America/Juneau	USA	knots	163	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:51:00	\N	0.4	00:34:00	\N	0.2	01:01:00	00:10:00	Aurora Basin, SW of	AK
69900	Hazy Islands, Chatham Strait, Alaska Current	NOS	PCT4056_1	55.88333	-134.6	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Hazy Islands	AK
69901	Cape Ommaney Light, 5 miles east of, Chatham Strait, Alaska Current	NOS	PCT4061_1	56.16667	-134.51667	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Cape Ommaney Light, 5 miles east of	AK
69902	Port Walter Light, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4066_1	56.38333	-134.53333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.7	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Port Walter Light, 3 miles east of	AK
69903	Point Ellis, 4 miles west of, Chatham Strait, Alaska Current	NOS	PCT4071_1	56.56667	-134.45	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.7	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Point Ellis, 4 miles west of	AK
69904	Kingsmill Point Light, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4076_1	56.83333	-134.51667	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	1	-00:07:00	\N	0.6	00:01:00	-00:17:00	Kingsmill Point Light, 3 miles west of	AK
69905	Point Gardner Light, 2 miles west of, Chatham Strait, Alaska Current	NOS	PCT4081_1	57.01667	-134.66667	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Gardner Light, 2 miles west of	AK
69906	Point Caution, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4086_1	57.25	-134.73333	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Point Caution, 3 miles west of	AK
69907	Point Thatcher, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4091_1	57.41667	-134.73333	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Point Thatcher, 3 miles east of	AK
69908	Danger Point Light, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4101_1	57.51667	-134.7	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	Danger Point Light, 3 miles west of	AK
69909	Turn Point, Kootznahoo Inlet, Chatham Strait, Alaska Current	NOS	PCT4106_1	57.5	-134.58333	:America/Juneau	USA	knots	285	105	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:09:00	\N	2.9	00:48:00	\N	2.2	00:56:00	00:38:00	Turn Point, Kootznahoo Inlet	AK
69910	South Passage Point, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4111_1	57.76667	-134.83333	:America/Juneau	USA	knots	355	175	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	South Passage Point, 3 miles east of	AK
69911	Point Augusta, ESE of (Depth 70ft), Chatham Strait, Alaska Current	NOS	PCT4116_1	58.025	-134.87333	:America/Juneau	USA	knots	164	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.3	-00:04:00	\N	0.2	-00:02:00	00:01:00	Point Augusta, ESE of	AK
69912	Biorka Channel, Sitka Sound, Alaska Current	NOS	PCT4131_1	56.83333	-135.5	:America/Juneau	USA	knots	232	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:13:00	\N	0.2	00:20:00	\N	0.1	00:47:00	00:15:00	Biorka Channel	AK
69913	Sitka Harbor, channel off Harbor Island, Sitka Sound, Alaska Current	NOS	PCT4166_1	57.05	-135.33333	:America/Juneau	USA	knots	156	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	0.2	-01:17:00	\N	0.1	-00:58:00	-02:02:00	Sitka Harbor, channel off Harbor Island	AK
69914	West Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4171_1	57.15	-135.58333	:America/Juneau	USA	knots	64	242	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:30:00	\N	0.5	-00:51:00	\N	0.4	-00:43:00	-01:01:00	West Channel (narrows)	AK
69915	East Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4176_1	57.16667	-135.55	:America/Juneau	USA	knots	229	51	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:23:00	\N	0.7	-00:32:00	\N	0.4	-00:30:00	-00:48:00	East Channel (narrows)	AK
69916	Allan Pt., 1.5mile W of, Nakwasina Passage, Alaska Current	NOS	PCT4191_1	57.25	-135.43333	:America/Juneau	USA	knots	82	260	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:40:00	\N	0.8	-01:06:00	\N	0.6	-01:06:00	-00:59:00	Allan Pt., 1.5mile W of, Nakwasina Passage	AK
69917	Wyvill Reef, Neva Strait, Alaska Current	NOS	PCT4211_1	57.26667	-135.58333	:America/Juneau	USA	knots	323	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:13:00	\N	0.7	-00:30:00	\N	0.5	-00:27:00	-00:04:00	Wyvill Reef	AK
69918	Highwater Island, west of, Neva Strait, Alaska Current	NOS	PCT4216_1	57.28333	-135.6	:America/Juneau	USA	knots	330	144	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:34:00	\N	0.7	-00:29:00	\N	0.3	-00:15:00	-00:11:00	Highwater Island, west of	AK
69919	Sea Rock, 1 mile north of, Salisbury Sound, Alaska Current	NOS	PCT4236_1	57.35	-135.88333	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Sea Rock, 1 mile north of	AK
69920	Kalinin Point, 1 mile north of, Salisbury Sound, Alaska Current	NOS	PCT4241_1	57.35	-135.8	:America/Juneau	USA	knots	260	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Kalinin Point, 1 mile north of	AK
69921	Sinitsin Island, Salisbury Sound, Alaska Current	NOS	PCT4246_1	57.35	-135.76667	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Sinitsin Island	AK
69922	Otstoia Island Light, 1 mile north of, Peril Strait, Alaska Current	NOS	PCT4286_1	57.58333	-135.45	:America/Juneau	USA	knots	100	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Otstoia Island Light, 1 mile north of	AK
69923	Nismeni Point, 1 mile north of, Peril Strait, Alaska Current	NOS	PCT4291_1	57.58333	-135.41667	:America/Juneau	USA	knots	105	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Nismeni Point, 1 mile north of	AK
69924	Peschani Point, 1 mile east of, Peril Strait, Alaska Current	NOS	PCT4296_1	57.53333	-135.3	:America/Juneau	USA	knots	145	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Peschani Point, 1 mile east of	AK
69925	Point Elizabeth, 1 mile northeast of, Peril Strait, Alaska Current	NOS	PCT4301_1	57.51667	-135.26667	:America/Juneau	USA	knots	135	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Elizabeth, 1 mile northeast of	AK
69926	Point Benham, 1 mile east of, Peril Strait, Alaska Current	NOS	PCT4306_1	57.48333	-135.18333	:America/Juneau	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Benham, 1 mile east of	AK
69927	False Linderberg Head, 1 mile south of, Peril Strait, Alaska Current	NOS	PCT4311_1	57.45	-135.08333	:America/Juneau	USA	knots	125	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	False Linderberg Head, 1 mile south of	AK
69928	Lindenberg Head, Peril Strait, Alaska Current	NOS	PCT4316_1	57.45	-135.03333	:America/Juneau	USA	knots	100	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Lindenberg Head	AK
69930	Fairway Island, Peril Strait, Alaska Current	NOS	PCT4326_1	57.45	-134.88333	:America/Juneau	USA	knots	85	265	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Fairway Island	AK
69931	Morris Reef, south of, Peril Strait, Alaska Current	NOS	PCT4331_1	57.45	-134.81667	:America/Juneau	USA	knots	95	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Morris Reef, south of	AK
69932	Claybluff Point Light, 3.5 nmi. south of (Depth 75ft), Icy Bay, Alaska Current	NOS	PCT4406_1	59.91	-141.595	:America/Anchorage	USA	knots	209	104	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:20:00	\N	0.2	-02:09:00	\N	0.2	-03:02:00	-03:14:00	Claybluff Point Light, 3.5 nmi. south of	AK
69933	Claybluff Point Light, 2.3 nmi. SE of (Depth 206ft), Icy Bay, Alaska Current	NOS	PCT4411_1	59.94667	-141.52	:America/Anchorage	USA	knots	215	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:14:00	\N	0.1	-02:44:00	\N	0.1	-03:10:00	-03:17:00	Claybluff Point Light, 2.3 nmi. SE of	AK
69937	Wingham Island, off northeast corner, Controller Bay, Alaska Current	NOS	PCT4436_1	60.05	-144.38333	:America/Anchorage	USA	knots	288	68	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:06:00	\N	0.6	01:11:00	\N	0.5	00:42:00	00:46:00	Wingham Island, off northeast corner	AK
69938	Kanak Island, southeast of, Controller Bay, Alaska Current	NOS	PCT4441_1	60.08333	-144.3	:America/Anchorage	USA	knots	255	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:53:00	\N	1	00:37:00	\N	0.5	00:58:00	00:38:00	Kanak Island, southeast of	AK
69939	Popof Strait, Shumagin Islands, Alaska Current	NOS	PCT5406_1	55.33333	-160.51667	:America/Anchorage	USA	knots	199	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:11:00	\N	0.2	-02:05:00	\N	0.1	-02:32:00	-01:28:00	Popof Strait	AK
69940	Unga Strait (1.4 miles N of Unga Spit), Shumagin Islands, Alaska Current	NOS	PCT5411_1	55.43333	-160.73333	:America/Anchorage	USA	knots	114	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	05:06:00	\N	0.1	05:42:00	\N	0.5	05:24:00	05:24:00	Unga Strait (1.4 miles N of Unga Spit)	AK
69941	Amak Island, 5 miles north of, Alaska Current	NOS	PCT5426_1	55.5	-163.16667	:America/Nome	USA	knots^2	139	337	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	05:09:00	\N	0.2	05:31:00	\N	0.2	04:52:00	04:50:00	Amak Island, 5 miles north of	AK
69942	Amak Island, 5 miles southeast of, Alaska Current	NOS	PCT5431_1	55.35	-163.01667	:America/Nome	USA	knots^2	200	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	04:35:00	\N	0.2	04:45:00	\N	0.2	04:24:00	04:32:00	Amak Island, 5 miles southeast of	AK
69943	Otter Point, off of, north side, Unimak Island, Alaska Current	NOS	PCT5441_1	55.06667	-163.78333	:America/Nome	USA	knots^2	258	89	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	03:53:00	\N	0.3	03:36:00	\N	0.2	03:36:00	03:35:00	Otter Point, off of, north side	AK
69944	Bechevin Bay, off Rocky Point, Isanotski Strait, Alaska Current	NOS	PCT5451_1	54.98333	-163.43333	:America/Nome	USA	knots^2	139	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	00:02:00	\N	0.5	-00:26:00	\N	0.5	-00:55:00	00:14:00	Bechevin Bay, off Rocky Point	AK
69945	Cape Lieskof, 3 miles west of, Aleutian Islands, Alaska Current	NOS	PCT5741_1	55.75	-162.2	:America/Nome	USA	knots	248	56	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:53:00	\N	0.3	-04:39:00	\N	0.3	-05:39:00	-04:38:00	Cape Lieskof, 3 miles west of	AK
69946	Entrance Point, 3 miles west of, Port Moller, Alaska Current	NOS	PCT5746_1	56	-160.65	:America/Anchorage	USA	knots	2	174	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:34:00	\N	0.8	-04:28:00	\N	0.7	-05:04:00	-04:06:00	Entrance Point, 3 miles west of	AK
69947	Entrance Point, Port Moller, Alaska Current	NOS	PCT5751_1	55.98333	-160.58333	:America/Anchorage	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-05:27:00	\N	0.6	-04:53:00	\N	0.5	-04:57:00	-05:06:00	Entrance Point	AK
69948	Harbor Point, Port Moller, Alaska Current	NOS	PCT5756_1	55.91667	-160.6	:America/Anchorage	USA	knots	335	158	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:26:00	\N	0.8	-04:03:00	\N	0.4	-04:28:00	-04:59:00	Harbor Point	AK
69949	Hague Channel, east of Doe Point, Alaska Current	NOS	PCT5761_1	55.9	-160.76667	:America/Anchorage	USA	knots	33	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-05:21:00	\N	0.6	-04:39:00	\N	0.9	-05:59:00	-04:23:00	Hague Channel, east of Doe Point	AK
69950	Johnston Channel, off Halftide Rock, Alaska Current	NOS	PCT5766_1	55.83333	-160.78333	:America/Anchorage	USA	knots	337	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:24:00	\N	0.5	-04:45:00	\N	0.5	-04:27:00	-05:15:00	Johnston Channel, off Halftide Rock	AK
69951	Port Heiden, Alaska Current	NOS	PCT5771_1	56.98333	-158.88333	:America/Anchorage	USA	knots	233	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:15:00	\N	0.4	-01:05:00	\N	0.4	-02:23:00	-01:14:00	Port Heiden	AK
69952	Morakas Point, Naknek River, Kvichak Bay, Alaska Current	NOS	PCT5781_1	58.73333	-156.93333	:America/Anchorage	USA	knots	294	111	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	01:15:00	\N	0.9	01:05:00	\N	0.5	02:01:00	00:04:00	Morakas Point, Naknek River	AK
69953	Cape Constantine, 4 miles Southeast of, Alaska Current	NOS	PCT5791_1	58.33333	-158.76667	:America/Anchorage	USA	knots	238	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:52:00	\N	0.7	-01:38:00	\N	0.6	-02:08:00	-01:05:00	Cape Constantine, 4 miles Southeast of	AK
69954	Protection Point, 2.5 miles east of, Alaska Current	NOS	PCT5796_1	58.5	-158.61667	:America/Anchorage	USA	knots	180	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:04:00	\N	1	-01:25:00	\N	1	-00:44:00	-00:40:00	Protection Point, 2.5 miles east of	AK
69955	Nushagak Bay entrance, Alaska Current	NOS	PCT5801_1	58.56667	-158.41667	:America/Anchorage	USA	knots	180	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-00:23:00	\N	1	00:03:00	\N	1	-00:59:00	00:19:00	Nushagak Bay entrance	AK
69956	Etolin Point, 8.5 miles west of, Alaska Current	NOS	PCT5806_1	58.63333	-158.58333	:America/Anchorage	USA	knots	173	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	00:05:00	\N	1.2	00:13:00	\N	0.9	-00:19:00	00:08:00	Etolin Point, 8.5 miles west of	AK
69957	Clarks Point, 1 mile west of, Alaska Current	NOS	PCT5811_1	58.83333	-158.58333	:America/Anchorage	USA	knots	213	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-00:02:00	\N	1.4	00:34:00	\N	1.3	-00:07:00	00:41:00	Clarks Point, 1 mile west of	AK
69958	Goodnews Bay entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5821_1	59.06667	-161.78333	:America/Anchorage	USA	knots	213	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-06:02:00	\N	0.9	-06:05:00	\N	0.9	-06:23:00	-05:26:00	Goodnews Bay entrance	AK
69959	Carter Bay, west of, Kuskokwim Bay, Alaska Current	NOS	PCT5826_1	59.28333	-162.36667	:America/Nome	USA	knots	212	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:21:00	\N	0.6	-04:29:00	\N	0.6	-05:10:00	-03:44:00	Carter Bay, west of	AK
69960	Warehouse Bluff, southwest of, Kuskokwim Bay, Alaska Current	NOS	PCT5831_1	59.78333	-162.23333	:America/Nome	USA	knots	188	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:45:00	\N	0.8	-03:21:00	\N	0.6	-03:43:00	-03:21:00	Warehouse Bluff, southwest of	AK
69961	Apokak Creek entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5836_1	60.13333	-162.16667	:America/Nome	USA	knots	205	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:51:00	\N	1.1	-03:42:00	\N	1.1	-05:04:00	-02:04:00	Apokak Creek entrance	AK
69962	Walrus Island, 0.5 mile west of, Pribilof Islands, Alaska Current	NOS	PCT5841_1	57.18333	-169.95	:America/Nome	USA	knots	210	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-06:38:00	\N	0.5	-06:47:00	\N	0.4	-06:40:00	-06:40:00	Walrus Island, 0.5 mile west of	AK
69963	SW Point, St. Paul Island, 1 mile off, Pribilof Islands, Alaska Current	NOS	PCT5861_1	57.15	-170.45	:America/Nome	USA	knots	170	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-08:10:00	\N	0.3	-08:10:00	\N	0.8	-08:55:00	-08:55:00	SW Point, St. Paul Island, 1 mile off	AK
69964	Hooper Bay entrance, Alaska Current	NOS	PCT5866_1	61.5	-166.05	:America/Nome	USA	knots	223	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	11:03:00	\N	0.8	11:16:00	\N	0.7	10:08:00	11:14:00	Hooper Bay entrance	AK
69965	St. Mathew I., southwest coast, Alaska Current	NOS	PCT5871_1	60.35	-172.71667	:America/Nome	USA	knots	119	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	03:07:00	\N	0.4	03:20:00	\N	0.5	02:24:00	03:29:00	St. Mathew I., southwest coast	AK
69966	Apavawook Cape, 1 mile south of, St. Lawrence Island, Alaska Current	NOS	PCT5881_1	63.11667	-168.93333	:America/Adak	USA	knots	272	75	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:23:00	\N	0.4	-02:14:00	\N	0.2	-02:58:00	-02:39:00	Apavawook Cape, 1 mile south of	AK
69967	Off Northeast Cape, St. Lawrence Island, Alaska Current	NOS	PCT5886_1	63.33333	-168.83333	:America/Adak	USA	knots	258	95	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	00:10:00	\N	0.3	00:57:00	\N	0.3	-00:41:00	01:16:00	Off Northeast Cape	AK
69968	Waldron Island, 1.7 nm west of (Depth 27.2ft), Washington Current (sub)	NOS	PUG1716_23	48.704219818115234	-123.10476684570312	:America/Los_Angeles	USA	knots	252	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65244	00:33:00	\N	0.25	-00:27:00	\N	0.48	-01:00:00	00:21:00	Waldron Island, 1.7 nm west of	WA
69969	Waldron Island, 1.7 nm west of (Depth 92.8ft), Washington Current (sub)	NOS	PUG1716_13	48.704219818115234	-123.10476684570312	:America/Los_Angeles	USA	knots	227	31	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65244	-00:30:00	\N	0.2	-00:35:00	\N	0.55	-02:10:00	00:11:00	Waldron Island, 1.7 nm west of	WA
69970	Waldron Island, 1.7 nm west of (Depth 158.5ft), Washington Current (sub)	NOS	PUG1716_3	48.704219818115234	-123.10476684570312	:America/Los_Angeles	USA	knots	232	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65244	-00:40:00	\N	0.22	-00:36:00	\N	0.53	-01:50:00	00:12:00	Waldron Island, 1.7 nm west of	WA
66281	North jetty, Tillamook Bay, Oregon	NOS	9437585	45.56999969482422	-123.96499633789062	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.270000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH JETTY, TILLAMOOK BAY	OR
68368	Columbia River entrance (N. jetty), Washington	NOS	9440574	46.2733	-124.072	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66285	-01:00:00	0.1	\N	-00:44:00	-1	\N	\N	\N	Columbia River entrance (N. Jetty)	WA
69341	North jetty, 0.8 mile southeast of, Charleston Harbor, South Carolina Current	NOS	ACT6631_1	32.7175	-79.8	:America/New_York	USA	knots	110	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:16:00	\N	0.6	-00:48:00	\N	0.2	-00:06:00	-01:09:00	North Jetty, 0.8 mile southeast of	SC
16159	San Diego Bay entrance, California Current	NOS	PCT0031_1	32.681667	-117.23	:America/Los_Angeles	USA	knots	175	355	\N	\N	1      San Diego Bay Entr., California     T.M. 120 W.\n-00090 1 3 1 0 0 0 355 175	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego Bay Entr., California     T.M. 120 W.	CA
16162	Savannah River entrance (between jetties), Georgia Current (11d)	NOS	ACT7351_1	32.035667	-80.890333	:America/New_York	USA	knots	110	286	\N	\N	1      Savannah River Entrance, Georgia    T.M. 75 W.  *** Used 1999 ->\n000000 1 3 1 0 0 0 286 110 0 0 0   0   0   0	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savannah River Entrance, Georgia    T.M. 75 W.  *** Used 1999 ->	GA
16150	Grays Harbor entrance, Washington Current	NOS	PCT1291_1	46.9225	-124.133	:America/Los_Angeles	USA	knots	240	60	\N	\N	1      Grays Harbor Entrance, Washington    T.M. 120 W.\n-00300 1 3 1 0 0 0 060 240	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grays Harbor Entrance, Washington    T.M. 120 W.	WA
16163	St. Johns River entrance (between jetties), Florida Current (16d)	NOS	SJR9801_8	30.400333	-81.385833	:America/New_York	USA	knots	82	262	\N	\N	1      St. Johns River Entrance, Fla.  T.M. 75 W.       ** Use 1999->\n-00128 1 3 1 0 0 0 262 082	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns River Entrance, Fla.  T.M. 75 W.       ** Use 1999->	FL
16165	Tampa Bay entrance (Egmont Channel), Florida Current (15d)	NOS	ACT8411_1	27.604333	-82.760333	:America/New_York	USA	knots	297	118	\N	\N	1       Tampa Bay Entrance (Egmont Channel), Florida  T.M. 75 W.\n000037 1 3 1 0 0 0 118 297             major axis only, k'	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	 Tampa Bay Entrance (Egmont Channel), Florida  T.M. 75 W.	FL
65560	Plum Island, Merrimack River entrance, Merrimack River, Massachusetts	NOS	8440452	42.8167	-70.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND, MERRIMACK  RIVER ENTRANCE	MA
65860	Charleston, Cooper River entrance, South Carolina	NOS	8665530	32.7808333	-79.9236111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston, Cooper River Entrance	SC
65867	Fort Pulaski, Savannah River entrance, Georgia	NOS	8670870	32.0367	-80.9017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pulaski	GA
65951	Government Cut, Miami Harbor entrance, Florida	NOS	8723178	25.7633	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI BEACH, GOVERNMENT CUT	FL
65999	CSX Rockport, Mckay Bay entrance, Florida	NOS	8726667	27.91333333333333	-82.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mckay Bay Entrance	FL
66199	Newport Beach, Newport Bay entrance, Corona del Mar, California	NOS	9410580	33.6033	-117.883	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWPORT BEACH, NEWPORT BAY ENTRANCE	CA
66267	Rink Creek entrance, Coquille River, Oregon	NOS	9432436	43.157901763916016	-124.18180084228516	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.490000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coquille River	OR
66396	Hawk Inlet entrance, Alaska	NOS	9452294	58.085	-134.777	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet	AK
66495	Isanotski Strait entrance, Aleutian Islands, Alaska	NOS	9462961	54.77844444444445	-163.3642777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ISANOTSKI STRAIT ENTRANCE	AK
66518	Mekoryuk, Mekoryuk River entrance, Alaska	NOS	9466217	60.4167	-166.167	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mekoryuk, Mekoryuk River Entrance	AK
65686	Spuyten Duyvil Creek entrance, Hudson River, New York	NOS	8518903	40.8783	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPUYTEN DUYVIL CK, ENT., HUDSON R,	NY
65930	Canaveral Harbor entrance, Florida	NOS	8721608	28.4083	-80.6017	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CANAVERAL HARBOR ENTRANCE	FL
66092	Tchoutacabouffa River entrance, Mississippi	NOS	8744663	30.4417	-88.9733	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tchoutacabouffa River Entrance	MS
66696	Camp Ellis, Saco River entrance, Maine (sub)	NOS	8418606	43.4617	-70.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:10:00	\N	1	00:03:00	\N	0.97	\N	\N	Camp Ellis, Saco River Entrance	ME
66720	Plum Island, Merrimack River entrance, Merrimack River, Massachusetts (sub)	NOS	8440452	42.8167	-70.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65548	00:29:00	\N	0.88	00:06:00	\N	0.88	\N	\N	Plum Island, Merrimack River Entrance	MA
66881	Bay Shore, Watchogue Creek entrance, Great South Bay, New York	NOS	8515102	40.7167	-73.24	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65703	02:27:00	\N	0.37	02:15:00	\N	0.22	\N	\N	Bay Shore, Watchogue Creek Entrance	NY
66932	Spuyten Duyvil Creek entrance, Hudson River, New York (sub)	NOS	8518903	40.8783	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65684	00:48:00	\N	0.84	00:52:00	\N	0.84	\N	\N	Spuyten Duyvil Creek ent., N.Y.	NY
67286	Muddy Creek entrance, Chesapeake Bay, Virginia	NOS	8633604	37.855	-75.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65813	04:51:00	\N	0.83	04:14:00	\N	0.86	\N	\N	Muddy Creek Entrance	VA
67585	Village Creek entrance, Morgan River, South Carolina	NOS	8667927	32.445	-80.5033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:07:00	\N	1	00:17:00	\N	0.93	\N	\N	Village Creek Entrance	SC
67606	Colleton River entrance, South Carolina	NOS	8668619	32.3217	-80.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65867	00:37:00	\N	1.05	00:49:00	\N	1.05	\N	\N	Colleton River Entrance	SC
68046	CSX Rockport, Mckay Bay entrance, Florida (sub)	NOS	8726667	27.91333333333333	-82.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65995	00:28:00	\N	1.26	00:02:00	\N	1.19	\N	\N	McKay Bay entrance	FL
68192	Newport Beach, Newport Bay entrance, Corona del Mar, California (sub)	NOS	9410580	33.6033	-117.883	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66200	-00:04:00	\N	0.98	-00:03:00	\N	0.98	\N	\N	Newport Bay Entrance, Corona del Mar	CA
68440	Barron Point, Little Snookum Inlet entrance, Puget Sound, Washington	NOS	9446742	47.1567	-123.008	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66323	00:59:00	\N	1.06	00:50:00	\N	1.29	\N	\N	Barron Point, Little Snookum Inlet Entrance	WA
68548	Shakan Bay entrance, Alaska	NOS	9450982	56.14	-133.61	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66387	-00:12:00	0	\N	-00:13:00	1.8	\N	\N	\N	Shakan Bay Entrance	AK
68605	Holkham Bay, Tracy Arm entrance, Alaska	NOS	9452067	57.76	-133.603	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	00:02:00	\N	0.96	00:01:00	\N	0.96	\N	\N	Holkham Bay, Tracy Arm Entrance	AK
68613	Hawk Inlet entrance, Alaska (sub)	NOS	9452294	58.085	-134.777	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66395	-00:01:00	\N	0.98	-00:04:00	\N	0.94	\N	\N	Hawk Inlet Entrance	AK
68625	Excursion Inlet entrance, Icy Strait, Alaska	NOS	9452437	58.4167	-135.447	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66403	00:16:00	\N	1.05	00:15:00	\N	1.38	\N	\N	Excursion Inlet Entrance	AK
68686	Long Bay entrance, Culross Passage, Prince William Sound, Alaska	NOS	9454825	60.6917	-148.263	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	66406	00:09:00	-0.1	\N	00:03:00	-0.9	\N	\N	\N	Long Bay Entrance, Culross Passage	AK
69449	Broad River entrance, Point Royal Sound (Depth 15ft), South Carolina Current	NOS	ACT7196_1	32.23167	-80.64	:America/New_York	USA	knots	138	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:25:00	\N	0.9	00:21:00	\N	1	00:36:00	00:32:00	Broad River Entrance, Point Royal Sound	SC
69451	Beaufort River entrance (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7206_1	32.28833	-80.65167	:America/New_York	USA	knots	195	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:03:00	\N	0.7	01:11:00	\N	0.7	00:19:00	00:20:00	Beaufort River Entrance	SC
69465	Byrd Creek entrance, SE of, Broad River (Depth 12ft), South Carolina Current	NOS	ACT7276_1	32.45667	-80.81833	:America/New_York	USA	knots	174	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.5	00:51:00	\N	0.6	01:27:00	01:32:00	Byrd Creek Entrance, SE of, Broad River	SC
69497	Lazaretto Creek entrance, N of, Bull River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7456_1	32	-80.92833	:America/New_York	USA	knots	207	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:04:00	\N	0.7	00:00:00	\N	0.5	-00:37:00	-00:33:00	Lazaretto Creek Entrance, N of, Bull River	GA
69517	Little Ogeechee River entrance (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7556_1	31.88833	-81.09833	:America/New_York	USA	knots	71	259	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:06:00	\N	1	-00:59:00	\N	0.7	-00:15:00	-00:03:00	Little Ogeechee River Entrance	GA
69518	Little Ogeechee River entrance (Depth 20ft), Wassaw Sound, Georgia Current	NOS	ACT7556_2	31.88833	-81.09833	:America/New_York	USA	knots	73	244	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:57:00	\N	0.9	-00:50:00	\N	0.6	-00:30:00	00:05:00	Little Ogeechee River Entrance	GA
69520	Odingsell River entrance (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7566_1	31.86833	-81	:America/New_York	USA	knots	212	32	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:14:00	\N	0.9	00:44:00	\N	0.7	-00:54:00	-00:48:00	Odingsell River Entrance	GA
69521	Odingsell River entrance (Depth 20ft), Wassaw Sound, Georgia Current	NOS	ACT7566_2	31.86833	-81	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:12:00	\N	0.8	00:42:00	\N	0.6	-01:19:00	-00:42:00	Odingsell River Entrance	GA
69528	Little Ogeechee River entrance, north of (Depth 6ft), Ossabaw Sound, Georgia Current	NOS	ACT7596_1	31.89667	-81.095	:America/New_York	USA	knots	156	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:03:00	\N	0.8	00:29:00	\N	0.6	-00:41:00	-00:30:00	Little Ogeechee River Entrance, north of	GA
69533	North of Big Tom Creek entrance (Depth 10ft), Bear River, Georgia Current	NOS	ACT7621_1	31.78333	-81.16033	:America/New_York	USA	knots	179	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:25:00	\N	0.7	-00:13:00	\N	0.6	-00:24:00	-00:19:00	North of Big Tom Creek Entrance	GA
69534	South of Kilkenny Creek entrance, Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7626_1	31.75833	-81.17333	:America/New_York	USA	knots	190	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	1	01:25:00	\N	0.6	00:26:00	-00:02:00	South of Kilkenny Creek Entrance	GA
69535	Northwest of Newell Creek entrance (Depth 10ft), Bear River, Georgia Current	NOS	ACT7631_1	31.74883	-81.1655	:America/New_York	USA	knots	149	349	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.9	00:12:00	\N	0.6	-00:11:00	-00:16:00	Northwest of Newell Creek Entrance	GA
69537	St. Catherines Sound entrance (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7641_1	31.715	-81.1405	:America/New_York	USA	knots	126	291	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.8	-00:31:00	\N	0.9	-00:39:00	00:13:00	St. Catherines Sound Entrance	GA
69549	Sapelo River entrance (Depth 11ft), Sapelo Sound, Georgia Current	NOS	ACT7696_1	31.535	-81.27167	:America/New_York	USA	knots	58	234	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:43:00	\N	0.6	-01:05:00	\N	0.6	-00:23:00	-00:13:00	Sapelo River Entrance	GA
69558	Old Teakettle Creek entrance, south of (Depth 15ft), Doboy Sound, Georgia Current	NOS	ACT7736_1	31.42	-81.315	:America/New_York	USA	knots	159	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.5	-00:59:00	\N	0.5	-00:45:00	00:00:00	Old Teakettle Creek Entrance, south of	GA
69762	Drayton Harbor entrance, Georgia Strait, Washington Current	NOS	PCT2301_1	48.99082946777344	-122.76782989501953	:America/Los_Angeles	USA	knots	313	133	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65281	-01:08:00	\N	0.79	-01:29:00	\N	0.63	-01:01:00	-01:11:00	Drayton Harbor Entrance	WA
69934	Carson Creek entrance, 1.4 nmi. ESE of (Depth 15ft), Icy Bay, Alaska Current	NOS	PCT4416_1	59.98333	-141.47	:America/Anchorage	USA	knots	164	71	IGNORE VELOCITIES	Velocities for this station should be disregarded--use times only.\n	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:09:00	\N	0.001	-00:36:00	\N	0.2	-04:48:00	-00:20:00	Carson Creek Entrance, 1.4 nmi. ESE of	AK
69935	Carson Creek entrance, 3.3 nmi. SE of (Depth 78ft), Icy Bay, Alaska Current	NOS	PCT4421_1	59.97	-141.41333	:America/Anchorage	USA	knots	232	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:03:00	\N	0.2	-01:45:00	\N	0.3	-02:49:00	-01:03:00	Carson Creek Entrance, 3.3 nmi. SE of	AK
69936	Carson Creek entrance, 2.4 nmi. ESE of (Depth 50ft), Icy Bay, Alaska Current	NOS	PCT4426_1	59.98667	-141.43667	:America/Anchorage	USA	knots	244	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-27	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:06:00	\N	0.3	-01:38:00	\N	0.2	-03:00:00	-02:24:00	Carson Creek Entrance, 2.4 nmi. ESE of	AK
66159	Galveston Bay entrance, north jetty, Texas	NOS	8771341	29.3572998046875	-94.72480010986328	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance, North Jetty	TX
67692	St. Marys entrance, north jetty, Georgia	NOS	8679997	30.72	-81.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65890	-00:03:00	\N	0.96	-00:36:00	\N	0.96	\N	\N	St. Marys Entrance, North Jetty	GA
68860	Winyah Bay entrance (south jetty), South Carolina	NOS	TEC2929	33.18333333333299	-79.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2019-12-22	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	65860	-00:24:00	\N	0.89	-00:21:00	\N	0.87	\N	\N	Winyah Bay Entrance (South Jetty)	SC
66173	Matagorda Bay entrance channel, Texas	NOS	8773767	28.42690086364746	-96.3301010131836	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda Bay Entrance Channel	TX
66527	Kavalghak Bay, St. Lawrence Island, Alaska	NOS	9468261	63.682861	-171.750194	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM HST\n	CO-OPS Metadata API	Public domain	2019-12-21	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kavalghak Bay, AK	AK
\.



COPY public.data_sets_old (index, name, station_id_context, station_id, lat, lng, timezone, country, units, min_dir, max_dir, legalese, notes, comments, source, restriction, date_imported, xfields, meridian, datumkind, datum, months_on_station, last_date_on_station, ref_index, min_time_add, min_level_add, min_level_multiply, max_time_add, max_level_add, max_level_multiply, flood_begins, ebb_begins, original_name, state) FROM stdin;
16159	San Diego Bay Entrance, California Current	NOS	PCT0031_1	32.681667	-117.23	:America/Los_Angeles	USA	knots	175	355	\N	\N	1      San Diego Bay Entr., California     T.M. 120 W.\n-00090 1 3 1 0 0 0 355 175	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego Bay Entr., California     T.M. 120 W.	CA
16144	Baltimore Harbor Approach (off Sandy Point), Maryland Current	NOS	ACT4996_1	39.013	-76.368333	:America/New_York	USA	knots	190	25	\N	\N	1      Baltimore Harbor, Maryland    T.M. 75 W.\n000000 1 3 1 0 0 0 025 190	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore Harbor, Maryland    T.M. 75 W.	MD
16145	Bergen Point Reach (Bayonne Bridge), Kill van Kull, New York Current (16d)	NOS	ACT3951_1	40.641667	-74.143333	:America/New_York	USA	knots	76	259	\N	\N	1      Bayonne Bridge, Kill van Kull, New York      T.M. 75 W\n000000 1 3 1 0 0 0 259 076	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayonne Bridge, Kill van Kull, New York      T.M. 75 W	NY
16162	Savannah River Entrance (between jetties), Georgia Current (11d)	NOS	ACT7351_1	32.035667	-80.890333	:America/New_York	USA	knots	110	286	\N	\N	1      Savannah River Entrance, Georgia    T.M. 75 W.  *** Used 1999 ->\n000000 1 3 1 0 0 0 286 110 0 0 0   0   0   0	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savannah River Entrance, Georgia    T.M. 75 W.  *** Used 1999 ->	GA
16157	Pollock Rip Channel (Butler Hole), Massachusetts Current	NOS	ACT1616_1	41.55	-69.983333	:America/New_York	USA	knots	225	35	\N	\N	1      Pollock Rip Channel, Massachusetts    T.M. 75 W.\n  0150 1 3 1 0 0 0 035 225	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pollock Rip Channel, Massachusetts    T.M. 75 W.	MA
16151	Hell Gate (off Mill Rock), New York Current	NOS	ACT3401_1	40.778333	-73.938333	:America/New_York	USA	knots^2	230	50	\N	\N	1      Hell Gate, New York     T.M. 75 W.\n-00600 1 3 1 1 0 0 050 230	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hell Gate, New York     T.M. 75 W.	NY
16148	Charleston Harbor (off Fort Sumter), South Carolina Current	NOS	ACT6651_1	32.756	-79.870333	:America/New_York	USA	knots	127	313	\N	\N	1      Charleston Harbor, South Carolina    T.M. 75 W. ** Used 1997 -> **\n  -217 1 3 1 0 0 0 313 127 0                       Used 1997 ->	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston Harbor, South Carolina    T.M. 75 W. ** Used 1997 -> **	SC
16146	Bolivar Roads, Texas Current (14d)	NOS	ACT8856_2	29.343333	-94.781333	:America/Chicago	USA	knots	123	296	\N	\N	1      Bolivar Roads, Texas   T.M. 90 W.           Used 2000 ->\n-00135 1 3 1 0 0 0 306 116\nHarmonized directions with 2009 predictions	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-06:00:00	\N	-0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolivar Roads, Texas   T.M. 90 W.           Used 2000 ->	TX
16143	Aransas Pass, Texas Current (35d)	NOS	ACT8896_2	27.833833	-97.044167	:America/Chicago	USA	knots	120	300	\N	\N	1      Aransas Pass, Texas     T.M. 90 W           ** USED 1995 -> **\n+00032 1 3 1 0 0 0 300 120                    major axis only	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-06:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas Pass, Texas     T.M. 90 W           ** USED 1995 -> **	TX
16150	Grays Harbor Entrance, Washington Current	NOS	PCT1291_1	46.9225	-124.133	:America/Los_Angeles	USA	knots	240	60	\N	\N	1      Grays Harbor Entrance, Washington    T.M. 120 W.\n-00300 1 3 1 0 0 0 060 240	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grays Harbor Entrance, Washington    T.M. 120 W.	WA
16171	Vieques Passage, Puerto Rico Current	NOS	ACT8926_1	18.188333	-65.618333	:America/Puerto_Rico	USA	knots	55	250	\N	\N	1      Vieques Passage, Puerto Rico     T.M. 60 W.\n-00030 1 3 1 0 0 0 250 055	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-04:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vieques Passage, Puerto Rico     T.M. 60 W.	PR
16163	St. Johns River Entrance (between jetties), Florida Current (16d)	NOS	SJR9801_8	30.400333	-81.385833	:America/New_York	USA	knots	82	262	\N	\N	1      St. Johns River Entrance, Fla.  T.M. 75 W.       ** Use 1999->\n-00128 1 3 1 0 0 0 262 082	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns River Entrance, Fla.  T.M. 75 W.       ** Use 1999->	FL
25446	Wrangell Narrows (off Petersburg), Alaska Current (6d)	NOS	SEA0103_8	56.8163	-132.964	:America/Anchorage	USA	knots	62	246	\N	\N	1      Wrangell Narrows (off Petersburg), Alaska  T.M. 135 W\n   290 1 3 1 0 0 0 246 062         Used 2004 ->	NOS data via Mitch Cline and Dean Pentcheff, 2011-02-07	Public domain	2011-04-07	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	0.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell Narrows (off Petersburg), Alaska  T.M. 135 W	AK
16165	Tampa Bay Entrance (Egmont Channel), Florida Current (15d)	NOS	ACT8411_1	27.604333	-82.760333	:America/New_York	USA	knots	297	118	\N	\N	1       Tampa Bay Entrance (Egmont Channel), Florida  T.M. 75 W.\n000037 1 3 1 0 0 0 118 297             major axis only, k'	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	 Tampa Bay Entrance (Egmont Channel), Florida  T.M. 75 W.	FL
16154	Kvichak Bay (off Naknek River entrance), Alaska Current	NOS	PCT5776_1	58.7	-157.25	:America/Anchorage	USA	knots	240	55	\N	\N	1      Kvichak Bay (off Naknek River Entr.), Alaska        T.M. 135 W\n-00300 1 3 1 0 0 0 055 240	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kvichak Bay (off Naknek River Entr.), Alaska        T.M. 135 W	AK
60157	Pettegrove Point, Dochet Island, Maine	NOS	8410834	45.12844444444445	-67.14466666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pettegrove Point, Dochet Island	ME
16152	Isanotski Strait (False Pass Cannery), Alaska Current	NOS	PCT5446_1	54.866667	-163.4	:America/Anchorage	USA	knots^2	185	0	\N	\N	1      Isanotski Strait (False Pass Cannery), Alaska    T.M. 135 W\n000400 1 3 1 1 0 0 000 185	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	0.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isanotski Strait (False Pass Cannery), Alaska    T.M. 135 W	AK
60135	Port Allen, Hanapepe Bay, Kauai Island, Hawaii	NOS	1611347	21.9033	-159.592	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ALLEN, HANAPEPE BAY, KAUAI ISLAND	HI
60136	Nawiliwili, Nawiliwili Harbor, Kauai Island, Hawaii	NOS	1611400	21.9544	-159.3561	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nawiliwili	HI
60137	Honolulu, Honolulu Harbor, Oahu Island, Hawaii	NOS	1612340	21.30669444444445	-157.867	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Honolulu	HI
60138	Fort Kamehameha, Bishop Point, Pearl Harbor, Oahu Island, Hawaii	NOS	1612366	21.33	-157.967	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT KAMEHAMEHA, BISHOP POINT, PEARL HBR	HI
60139	Pearl Harbor, Ford Island Ferry Dock, Oahu Island, Hawaii	NOS	1612404	21.3683	-157.94	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORD ISLAND, FERRY DOCK, PEARL HARBOR	HI
60140	Moku o Loe, Kaneohe Bay, Oahu Island, Hawaii	NOS	1612480	21.43305555555556	-157.79	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mokuoloe	HI
60141	Kaunakakai Harbor, Molokai Island, Hawaii	NOS	1613198	21.085	-157.032	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaunakakai Harbor	HI
60142	Kahului, Kahului Harbor, Hawaii	NOS	1615680	20.895	-156.4766944444444	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahului, Kahului Harbor	HI
60143	Kawaihae, Hawaii Island, Hawaii	NOS	1617433	20.0366	-155.8294	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kawaihae	HI
60144	Hilo, Hilo Bay, Kuhio Bay, Hawaii Island, Hawaii	NOS	1617760	19.73027801513672	-155.05555725097656	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hilo, Hilo Bay, Kuhio Bay	HI
60145	Johnston Atoll, Pacific Ocean	NOS	1619000	16.7383	-169.53	:Pacific/Johnston	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnston Atoll	\N
60146	Sand Island, Midway Islands	NOS	1619910	28.2117	-177.36	:Pacific/Midway	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6499999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Island, Midway Islands	\N
60147	Apra Harbor, Guam	NOS	1630000	13.44338888888889	144.6563611111111	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apra Harbor, Guam	GU
60148	Pago Bay, Guam	NOS	1631428	13.4283333	144.7969444	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Bay, Guam	GU
60149	Tanapag Harbor, Saipan Island, Marianas	NOS	1633227	15.2267	145.737	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saipan	MP
60150	Pago Pago, American Samoa	NOS	1770000	-14.2766667	-170.6894444	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Pago, American Samoa	AS
60151	Kwajalein, Marshall Islands	NOS	1820000	8.731666564941406	167.73611450195312	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kwajalein, Marshall Islands	MH
60152	Chuuk, Moen Island, E. Caroline Islands, FSM	NOS	1840000	7.44667	151.847	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHUUK, MOEN ISLAND, E. CAROLINE ISLANDS	FM
60153	Wake Island, Pacific Ocean	NOS	1890000	19.29066666666667	166.6175833333333	:Pacific/Wake	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wake Island, Pacific Ocean	MH
60154	Eastport, Passamaquoddy Bay, Maine	NOS	8410140	44.90330555555556	-66.985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastport	ME
60155	Coffin Point, Coffin Neck, Maine	NOS	8410714	44.87	-67.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COFFIN POINT, COFFIN NECK	ME
60156	Garnet Point, Hersey Neck, Pennamquan River, Cobscook Bay, Maine	NOS	8410715	44.9233	-67.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARNET POINT, HERSEY NECK	ME
60158	Gravelly Point, Whiting Bay, Maine	NOS	8410864	44.82333333333333	-67.15166666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gravelly Point, Whiting Bay	ME
60159	Cutler (Farris Wharf), Little River, Maine	NOS	8411060	44.65702819824219	-67.20466613769531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.1899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Farris Wharf	ME
60160	Cutler Naval Base, Machias Bay, Maine	NOS	8411250	44.6417	-67.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Naval Base	ME
60161	Milbridge, Narraguagus River, Maine	NOS	8412581	44.54	-67.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Milbridge	ME
60162	Bar Harbor, Frenchman Bay, Maine	NOS	8413320	44.39219444444444	-68.20427777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Harbor	ME
60163	Ellsworth, Union River, Blue Hill Bay, Maine	NOS	8413801	44.535	-68.4217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ellsworth	ME
60164	Mackerel Cove, Swans Island, Blue Hill Bay, Maine	NOS	8413825	44.17	-68.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MACKEREL COVE, SWANS ISLAND	ME
60165	Oceanville, Deer Isle, Penobscot Bay, Maine	NOS	8414249	44.19230555555556	-68.62093055555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.289999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oceanville, Deer Isle	ME
60166	Bangor, Penobscot River, Maine	NOS	8414612	44.785	-68.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	ME
60167	Fort Point, Penobscot River, Maine	NOS	8414721	44.4717	-68.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
60168	Pulpit Harbor, North Haven Island, Penobscot Bay, Maine	NOS	8414888	44.1567	-68.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PULPIT HARBOR, PENOBSCOT BAY	ME
60169	Rockland, Penobscot River, Maine	NOS	8415490	44.105	-69.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.329999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockland	ME
60170	Thomaston, St. George River, Maine	NOS	8415709	44.0717	-69.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thomaston	ME
60171	Walpole, Damariscotta River, Maine	NOS	8416731	43.9333	-69.58	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WALPOLE, DAMARISCOTTA RIVER	ME
60172	Wiscasset, Sheepscot River, Maine	NOS	8416921	44	-69.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.059999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wiscasset	ME
60173	Phipps Point, Back River, Maine	NOS	8417087	43.8983	-69.7433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Phipps Pt.	ME
60174	Gardiner, Kennebec River, Maine	NOS	8417134	44.2333	-69.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gardiner	ME
60176	Fort Popham, Hunniwell Point, Kennebec River, Maine	NOS	8417177	43.755	-69.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hunniwell Point	ME
60177	Richmond, Kennebec River, Maine	NOS	8417208	44.0883	-69.7983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9700000000000024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	ME
60178	Bath, Kennebec River, Maine	NOS	8417227	43.925	-69.815	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath	ME
60179	Portland, Casco Bay, Maine	NOS	8418150	43.6567	-70.2467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland	ME
60180	Pine Point, Maine	NOS	8418445	43.545	-70.3333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.759999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pine Point	ME
60181	Camp Ellis, Saco River Entrance, Maine	NOS	8418606	43.4617	-70.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.820000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP ELLIS, SACO RIVER	ME
60182	Biddeford, Saco River, Maine	NOS	8418828	43.4917	-70.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDDEFORD, SACO RIVER	ME
60183	Kennebunkport, Kennebunk River, Maine	NOS	8418911	43.3583	-70.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KENNEBUNKPORT, KENNEBUNK RIVER	ME
60184	Wells, Webhannet River, Maine	NOS	8419317	43.32	-70.56330555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.77	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wells	ME
60185	Seavey Island, Portsmouth Harbor, New Hampshire	NOS	8419870	43.08	-70.7417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seavey Island	NH
60186	Dover, Cocheco River, Piscataqua River, New Hampshire	NOS	8420411	43.1983	-70.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9099999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOVER, COCHECO RIVER	NH
60187	Atlantic Terminals T14A, New Hampshire	NOS	8423005	43.1167	-70.8117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATLANTIC TERMINALS  T14A	NH
60188	Fort Point, Portsmouth Harbor, New Hampshire	NOS	8423898	43.071388244628906	-70.71055603027344	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	NH
60189	Salisbury Point, Merrimack River, Massachusetts	NOS	8440273	42.8383	-70.9083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY POINT, MERRIMACK RIVER	MA
60190	Merrimacport, Merrimack River, Massachusetts	NOS	8440369	42.825	-70.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MERRIMACPORT, MERRIMACK RIVER	MA
60191	Plum Island, Merrimack River Entrance, Merrimack River, Massachusetts	NOS	8440452	42.8167	-70.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND, MERRIMACK  RIVER ENTRANCE	MA
60192	Newburyport, Merrimack River, Massachusetts	NOS	8440466	42.815	-70.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWBURYPORT, MERRIMACK RIVER	MA
60193	Riverside, Merrimack River, Massachusetts	NOS	8440889	42.7633	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERSIDE, MERRIMACK RIVER	MA
60194	Plum Island Sound (south end), Massachusetts	NOS	8441241	42.71013888888889	-70.78861111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island South	MA
60195	Rockport Harbor, Massachusetts	NOS	8441551	42.6583	-70.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.709999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROCKPORT HARBOR	MA
60196	Essex, Essex River, Massachusetts	NOS	8441771	42.6317	-70.7767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.080000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESSEX, ESSEX RIVER	MA
60197	Salem, Salem Harbor, Massachusetts	NOS	8442645	42.5233	-70.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALEM, SALEM HARBOR	MA
60198	Lynn, Lynn Harbor, Massachusetts	NOS	8443187	42.4583	-70.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LYNN, LYNN HARBOR	MA
60199	Amelia Earhart Dam, Mystic River, Boston Harbor, Massachusetts	NOS	8443662	42.395	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.239999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AMELIA EARHART DAM, MYSTIC RIVER	MA
60200	Chelsea St. Bridge, Chelsea River, Boston Harbor, Massachusetts	NOS	8443725	42.3867	-71.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chelsea	MA
60201	Boston, Boston Harbor, Massachusetts	NOS	8443970	42.35391666666666	-71.05033333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston	MA
60202	Boston Light, Boston Harbor, Massachusetts	NOS	8444162	42.3283	-70.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.910000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Light	MA
60203	Nut Island, Quincy Bay, Massachusetts	NOS	8444525	42.28	-70.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.170000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nut Island	MA
60204	Shipyard Point, Weymouth Fore River, Massachusetts	NOS	8444788	42.2483	-70.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Fore River	MA
60205	Scituate, Scituate Harbor, Massachusetts	NOS	8445138	42.2017	-70.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SCITUATE, SCITUATE HARBOR	MA
60206	Brant Rock, Green Harbor River, Massachusetts	NOS	8446009	42.0833	-70.6467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRANT ROCK, GREEN HARBOR RIVER	MA
60207	Provincetown, Cape Cod, Massachusetts	NOS	8446121	42.04959166666666	-70.18215833333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.030000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provincetown	MA
60208	Duxbury, Duxbury Harbor, Cape Cod Bay, Massachusetts	NOS	8446166	42.0383	-70.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.489999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUXBURY, DUXBURY HARBOR	MA
60209	Plymouth Harbor, Plymouth, Cape Cod Bay, Massachusetts	NOS	8446493	41.96	-70.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLYMOUTH, PLYMOUTH HARBOR	MA
60210	Cape Cod Canal (Sta. 115), Sagamore, Cape Cod Bay, Massachusetts	NOS	8447173	41.775	-70.535	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.41	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore, Cape Cod Canal (Sta. 115)	MA
60211	Cape Cod Canal, Sandwich, Cape Cod Bay, Massachusetts	NOS	8447180	41.7717	-70.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandwich	MA
60212	Cape Cod Canal (Sta. 200), Bournedale, Cape Cod Bay, Massachusetts	NOS	8447191	41.77	-70.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale, Cape Cod Canal (Sta. 200)	MA
60213	Sesuit Harbor, East Dennis, Cape Cod Bay, Massachusetts	NOS	8447241	41.7517	-70.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.220000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SESUIT HARBOR, EAST DENNIS	MA
60214	Cape Cod Canal (Sta. 320), Bourne Bridge, Cape Cod Bay, Massachusetts	NOS	8447259	41.745	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bourne Bridge, Cape Cod Canal (Sta. 320)	MA
60215	Cape Cod Canal, RR. bridge, Buzzards Bay, Massachusetts	NOS	8447270	41.7417	-70.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buzzards Bay	MA
60216	Gray Gables, Buzzards Bay, Massachusetts	NOS	8447295	41.735	-70.6233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7700000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gray Gables	MA
60217	Great Hill, Buzzards Bay, Massachusetts	NOS	8447368	41.7117	-70.715	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Hill	MA
60218	Fall River, Narragansett Bay, Massachusetts	NOS	8447386	41.70430555555556	-71.16411111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River	MA
60219	Piney Point, Buzzards Bay, Massachusetts	NOS	8447416	41.695	-70.72	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point	MA
60220	Chatham, Cape Cod, Massachusetts	NOS	8447435	41.68847222222222	-69.95108333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.76	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chatham, Lydia Cove	MA
60221	Saquatucket Harbor, Nantucket Sound, Massachusetts	NOS	8447495	41.6683	-70.0567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAQUATUCKET HARBOR	MA
60222	Chatham, Stage Harbor, Cape Cod, Massachusetts	NOS	8447505	41.6667	-69.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHATHAM, STAGE HARBOR	MA
60223	Hyannis Port, Nantucket Sound, Massachusetts	NOS	8447605	41.6317	-70.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HYANNISPORT	MA
60224	Chapoquoit Point, West Falmouth Harbor, Buzzards Bay, Massachusetts	NOS	8447685	41.605	-70.6517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chappaquoit Point	MA
60225	Clarks Point, New Bedford, Buzzards Bay, Massachusetts	NOS	8447712	41.5933	-70.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BEDFORD, CLARKS POINT	MA
60226	Round Hill Point, Buzzards Bay, Massachusetts	NOS	8447842	41.5383	-70.9283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6700000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROUND HILL POINT	MA
60227	Woods Hole, Buzzards Bay, Massachusetts	NOS	8447930	41.52361297607422	-70.67111206054688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole	MA
60228	Vineyard Haven Harbor, Vineyard Haven, Massachusetts	NOS	8448157	41.4583	-70.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VINEYARD HAVEN, VINEYARD HVN HBR	MA
60229	Penikese Island, Buzzards Bay, Massachusetts	NOS	8448248	41.45	-70.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PENIKESE ISLAND	MA
60230	Edgartown, Martha's Vineyard, Massachusetts	NOS	8448558	41.3883	-70.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgartown	MA
60231	Menemsha Harbor, Massachusetts	NOS	8448725	41.35444444444445	-70.76783333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Menemsha Harbor, MA	MA
60232	Martha's Vineyard GPS buoy, Martha's Vineyard, Massachusetts	NOS	8448875	41.32622222222222	-70.59033333333333	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martha's Vineyard GPS Buoy	MA
60233	Nantucket, Nantucket Island, Nantucket Island, Massachusetts	NOS	8449130	41.2852783203125	-70.09638977050781	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nantucket Island	MA
60234	Sakonnet, Sakonnet River, Rhode Island	NOS	8450768	41.465	-71.1933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6100000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAKONNET	RI
60235	Bristol Ferry, Narragansett Bay, Rhode Island	NOS	8451552	41.6367	-71.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRISTOL FERRY	RI
60236	Bristol Highlands, Narragansett Bay, Rhode Island	NOS	8452154	41.69670104980469	-71.29329681396484	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bristol Highlands	RI
60237	Newport, Narragansett Bay, Rhode Island	NOS	8452660	41.505	-71.3267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport	RI
60238	Conimicut Light, Narragansett Bay, Rhode Island	NOS	8452944	41.71666666666667	-71.34333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Conimicut Light	RI
60239	West Jamestown, Dutch Island Harbor, Conanicut Island, Rhode Island	NOS	8453742	41.4967	-71.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST JAMESTOWN	RI
60240	Providence, State Pier no.1, Narragansett Bay, Rhode Island	NOS	8454000	41.8066667	-71.4005556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Providence	RI
60241	Quonset Point, Rhode Island	NOS	8454049	41.5868	-71.411	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quonset Point	RI
60242	Wickford, Narragansett Bay, Rhode Island	NOS	8454538	41.5717	-71.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WICKFORD, NARRAGANSETT BAY	RI
60243	East Greenwich, Narragansett Bay, Rhode Island	NOS	8454578	41.665000915527344	-71.44499969482422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Greenwich	RI
60244	Point Judith, Harbor of Refuge, Rhode Island	NOS	8455083	41.3633	-71.49	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT JUDITH, HARBOR OF REFUGE	RI
60245	Kickamuit River, Narragansett Bay, Rhode Island	NOS	8455137	41.707801818847656	-71.24169921875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1900000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kickamuit River	RI
60246	Westerly, Pawcatuck River, Rhode Island	NOS	8455189	41.3817	-71.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westerly Pawcatuck	RI
60247	Weekapaug Point, Block Island Sound, Rhode Island	NOS	8458022	41.3283	-71.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEEKAPAUG POINT, BLOCK ISLAND SOUND	RI
60248	Block Island (Old Harbor), Rhode Island	NOS	8459338	41.1733	-71.5567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
60340	Atlantic City, New Jersey	NOS	8534720	39.355	-74.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic City	NJ
60250	Block Island (SW end), Block Island Sound, Rhode Island	NOS	8459681	41.1633	-71.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
60251	West Mystic, Mystic River, Long Island Sound, Connecticut	NOS	8460751	41.343299865722656	-71.9749984741211	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Mystic River	CT
60252	New London, Thames River, Connecticut	NOS	8461490	41.355	-72.0867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5399999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London, Thames River	CT
60253	Clinton Harbor, Connecticut	NOS	8463701	41.2683	-72.5317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.469999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Harbor	CT
60254	New Haven Harbor, New Haven Reach, Connecticut	NOS	8465705	41.2833	-72.9083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven	CT
60255	Bridgeport Harbor, Bridgeport, Connecticut	NOS	8467150	41.17575	-73.18402777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport	CT
60256	Black Rock Harbor, Cedar Creek, Connecticut	NOS	8467373	41.1567	-73.2133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.630000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Rock Harbor	CT
60257	Southport, Southport Harbor, Connecticut	NOS	8467726	41.1333	-73.2833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport, Southport Harbor	CT
60258	Saugatuck, Saugatuck River, Long Island Sound, Connecticut	NOS	8468191	41.119998931884766	-73.36830139160156	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saugatuck River	CT
60259	South Norwalk, Norwalk River, Connecticut	NOS	8468448	41.0967	-73.415	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Norwalk	CT
60260	Long Neck Point, Long Island Sound, Connecticut	NOS	8468799	41.0383	-73.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.82	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG NECK POINT, LONG ISLAND SOUND	CT
60261	Mianus, Connecticut	NOS	8469057	41.039194	-73.592028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mianus	CT
60262	Stamford Harbor, Stamford, Connecticut	NOS	8469198	41.0383	-73.5467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stamford Harbor	CT
60264	Lake Montauk, Long Island, New York	NOS	8510448	41.0733	-71.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Montauk	NY
60265	Montauk, Fort Pond Bay, Long Island Sound, New York	NOS	8510560	41.0483333	-71.9594444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montauk	NY
60266	Silver Eel Pond, Fishers Island, New York	NOS	8510719	41.2567	-72.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4200000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Eel Pond	NY
60268	Plum Gut Harbor, Plum Island, Long Island, New York	NOS	8511236	41.1717	-72.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND  PLUM GUT HARBOR	NY
60269	Sag Harbor, Shelter Island Sound, New York	NOS	8511629	41.0033	-72.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sag Harbor	NY
60270	Orient Harbor, Orient, Shelter Island Sound, New York	NOS	8511671	41.1367	-72.3067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orient Harbor	NY
60271	Greenport, Shelter Island Sound, New York	NOS	8511907	41.101	-72.36116666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenport	NY
60272	Shinnecock Inlet (ocean), Long Island, New York	NOS	8512354	40.8367	-72.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.610000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK INLET OPEN COAST	NY
60273	Ponquoque Point, Shinnecock Bay, New York	NOS	8512451	40.85	-72.5033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PONQUOGUE POINT	NY
60274	Mattituck Inlet, Long Island Sound, New York	NOS	8512668	41.015	-72.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mattituck Inlet, Long Island	NY
60275	South Jamesport, Great Peconic Bay, New York	NOS	8512735	40.935	-72.5817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jamesport	NY
60326	Bergen Point West Reach, Kill Van Kull, New York	NOS	8519483	40.63669444444444	-74.14169444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bergen Point West Reach	NY
60276	Shinnecock Yacht Club, Penniman Creek, Shinnecock Bay, New York	NOS	8512769	40.81855555555556	-72.58661111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK YACHT CLUB, PENNIMAN CREEK	NY
60277	Northville, Long Island, New York	NOS	8512987	40.9817	-72.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northville	NY
60278	Moriches Coast Guard Station, Long Island, New York	NOS	8513388	40.7867	-72.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches CGS, Moriches Bay	NY
60279	Moriches Inlet, Long Island, New York	NOS	8513398	40.76441666666667	-72.75597222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches Inlet	NY
60280	Smith Point Bridge, Narrow Bay, Long Island, New York	NOS	8513825	40.7383	-72.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SMITH POINT BRIDGE, NARROW BAY	NY
60281	Patchogue, Patchogue River, Great South Bay, New York	NOS	8514322	40.75	-73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PATCHOGUE, PATCHOGUE RIVER	NY
60282	Cedar Beach, Long Island, New York	NOS	8514422	40.965	-73.0433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR BEACH	NY
60283	Seaview Ferry Dock, Great South Bay, New York	NOS	8514779	40.64925	-73.15061111111112	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seaview Ferry Dock	NY
60284	Fire Island Coast Guard Station, Great South Bay, New York	NOS	8515186	40.6267	-73.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island	NY
60285	Northport, Northport Bay, Long Island, New York	NOS	8515586	40.9	-73.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTHPORT, NORTHPORT BAY	NY
60286	Eatons Neck Point, Long Island, New York	NOS	8515786	40.9533	-73.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck	NY
60287	Huntington Harbor Lighthouse, Huntington Bay, Long Island, New York	NOS	8515921	40.91	-73.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LLOYD HARBOR LIGHTHOUSE	NY
60288	Cold Spring Harbor, Oyster Bay, New York	NOS	8516061	40.8733	-73.47	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLD SPRINGS HARBOR	NY
60289	Green Island, Hempstead Bay, New York	NOS	8516155	40.6233	-73.5017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.759999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREEN ISLAND	NY
60290	Bayville Bridge, Oyster Bay, New York	NOS	8516299	40.9033	-73.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYVILLE BRIDGE, OYSTER BAY	NY
60291	Point Lookout, Long Island, New York	NOS	8516402	40.59388888888889	-73.58397222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lookout	NY
60292	Parsonnage Cove, Long Island, New York	NOS	8516501	40.6333	-73.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.419999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parsonnage Cove	NY
60293	Harry Tappen Marina, Hempstead Harbor, Long Island, New York	NOS	8516607	40.83461111111111	-73.65241666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harry Tappen Marina	NY
60294	Glen Cove Yacht Club, Hempstead Harbor, Long Island, New York	NOS	8516614	40.8633	-73.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GLEN COVE YACHT CLUB, LONG ISLAND	NY
60295	Bay Park, East Rockaway, Hewlett Bay, New York	NOS	8516661	40.63	-73.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5600000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Park, NY	NY
60296	Long Beach (Bridgeview Yacht Club), New York	NOS	8516663	40.59633333333333	-73.65508333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4400000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, NEW YORK	NY
60297	Port Washington, Manhasset Bay, Long Island, New York	NOS	8516761	40.8317	-73.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT WASHINGTON, MANHASSSET BAY	NY
60298	Atlantic Beach, East Rockaway Inlet, Long Island, New York	NOS	8516881	40.595	-73.7433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach	NY
60299	Norton Point, Head of Bay, Jamaica Bay, New York	NOS	8516891	40.635	-73.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTON POINT, HOOK CREEK, NEW YORK	NY
60300	Kings Point, Long Island Sound, New York	NOS	8516945	40.81030555555556	-73.765	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.889999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Point	NY
60301	Willets Point, Little Bay, East River, New York	NOS	8516990	40.7933	-73.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Willets Point	NY
60302	Beach Channel (bridge), Jamaica Bay, New York	NOS	8517137	40.5883	-73.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beach Channel	NY
60303	North Channel Bridge, Grassy Bay, Jamaica Bay, New York	NOS	8517201	40.645	-73.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0299999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Channel	NY
60304	Worlds Fair Marina, Flushing Bay, New York	NOS	8517251	40.761	-73.85036111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Worlds Fair Marina	NY
60306	Kingsborough Community College, Sheepshead Bay, Long Island, New York	NOS	8517756	40.581199645996094	-73.93379974365234	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6499999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsborough CC	NY
60307	Brooklyn Bridge, East River, New York	NOS	8517847	40.7033	-73.995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
60308	Rye Beach (Amusement Park), New York	NOS	8518091	40.9617	-73.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RYE BEACH, AMUSEMENT PARK	NY
60309	Throgs Neck, New York	NOS	8518526	40.805	-73.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck	NY
60310	Port Morris (Stony Point), East River, New York	NOS	8518639	40.8017	-73.9067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Morris	NY
60311	Harlem River, Randalls Island, East River, New York	NOS	8518643	40.8	-73.9283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Randalls Island	NY
60312	Horns Hook, East 90th Street, East River, New York, New York	NOS	8518668	40.7767	-73.9417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5299999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horns Hook	NY
60313	Queensboro Bridge, East River, New York	NOS	8518687	40.7583	-73.9583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Queensboro Bridge	NY
60314	Williamsburg Bridge, East River, New York	NOS	8518699	40.7117	-73.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Williamsburg Bridge	NY
60315	The Battery, New York Harbor, New York	NOS	8518750	40.7005556	-74.0141667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Battery	NY
60316	Ferry Slip, Dyckman Street, Hudson River, New York	NOS	8518902	40.8683	-73.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dyckman Street	NY
60319	Haverstraw Bay, Hudson River, New York	NOS	8518924	41.2183	-73.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAVERSTRAW BAY	NY
60320	Beacon, Flushkill, Hudson River, New York	NOS	8518934	41.5	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon, Hudson River	NY
60321	Hyde Park, Hudson River, New York	NOS	8518951	41.7833	-73.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.009999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hyde Park	NY
60322	Turkey Point Hudson River NERRS, Hudson River, New York	NOS	8518962	42.01390075683594	-73.93920135498047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turkey Point Hudson River NERRS	NY
60323	Albany, Hudson River, New York	NOS	8518995	42.65	-73.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALBANY, HUDSON RIVER	NY
60324	USCG Station, The Narrows, New York	NOS	8519050	40.612	-74.0598611111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station NY	NY
60325	Great Kills Harbor, New Jersey	NOS	8519436	40.5433	-74.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.729999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Kills Harbor	NJ
60327	Port Reading, Arthur Kill, New York	NOS	8531142	40.55500030517578	-74.24500274658203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Reading	NY
60328	Cheesequake Creek, Garden State Parkway, New Jersey	NOS	8531223	40.4533	-74.2733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHEESEQUAKE CREEK	NJ
60329	Keasbey, Raritan River, New Jersey	NOS	8531262	40.50830078125	-74.31169891357422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.86	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEASBEY, RARITAN RIVER	NJ
60330	Old Bridge, South River, Raritan River, New Jersey	NOS	8531369	40.41669845581055	-74.36329650878906	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH OLD BRIDGE, SOUTH RIVER	NJ
60331	Sayreville, Raritan River, New Jersey	NOS	8531390	40.47829818725586	-74.35669708251953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAYREVILLE, RARITAN RIVER	NJ
60332	New Brunswick, Raritan River, New Jersey	NOS	8531463	40.48830032348633	-74.43499755859375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BRUNSWICK  RARITAN RIVER	NJ
60333	Sandy Hook, New Jersey	NOS	8531680	40.4669444	-74.0094444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook	NJ
60334	Sea Bright, Shrewsbury River, New Jersey	NOS	8531804	40.365	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Bright	NJ
60335	Toms River (town), Toms River, Barnegat Bay, New Jersey	NOS	8533051	39.95000076293945	-74.19830322265625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toms River	NJ
60336	Stouts Creek, Barnegat Bay, New Jersey	NOS	8533365	39.845	-74.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.44000000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Creek	NJ
60337	Barnegat Inlet, USCG Station, Barnegat Bay, New Jersey	NOS	8533615	39.7617	-74.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BARNEGAT INLET (INSIDE)	NJ
60338	Shooting Thorofare, Little Egg Inlet, Great Bay, New Jersey	NOS	8534319	39.50830078125	-74.32499694824219	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01409335.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREAT BAY, SHOOTING THOROFARE	NJ
60339	Mays Landing, Great Egg Harbor River, New Jersey	NOS	8534468	39.4483	-74.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYS LANDING, GREAT EGG HARBOR RIVER	NJ
60341	Ventnor City, ocean pier, New Jersey	NOS	8534770	39.335	-74.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENTNOR CITY, FISHING PIER	NJ
60342	Longport, Risely Channel, New Jersey	NOS	8534836	39.3083	-74.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONGPORT, RISELY CHANNEL	NJ
60343	Tuckahoe, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8534883	39.295	-74.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKAHOE,TUCKAHOE RIVER	NJ
60344	Bivalve, Maurice River, Delaware Bay, New Jersey	NOS	8535055	39.23249816894531	-75.03279876708984	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01412150.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1300000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bivalve, Maurice River	NJ
60345	Ocean Drive bridge, Townsends Inlet, New Jersey	NOS	8535375	39.1217	-74.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Townsend Inlet	NJ
60346	Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535419	39.11	-74.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ingram Thorofare	NJ
60368	Inlet (Coast Guard Station), Indian River, Delaware	NOS	8558690	38.61	-75.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	INDIAN RIVER INLET	DE
60369	Ocean City (fishing pier), Maryland	NOS	8570280	38.3267	-75.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN CITY, FISHING PIER	MD
60370	Ocean City Inlet, Maryland	NOS	8570283	38.32833	-75.09166666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean City Inlet	MD
60347	Stone Harbor, Great Channel, Hereford Inlet, New Jersey	NOS	8535581	39.05670166015625	-74.76499938964844	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01411360.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STONE HARBOR, GREAT CHANNEL	NJ
60348	Wildwood Crest, ocean pier, New Jersey	NOS	8535835	38.975	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILDWOOD CREST	NJ
60349	Cape May Canal, Cape May, Delaware Bay, New Jersey	NOS	8536110	38.96777777777778	-74.95972222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May	NJ
60350	Bidwell Creek entrance, Delaware Bay, New Jersey	NOS	8536581	39.1283	-74.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDWELL CREEK ENTRANCE, DELAWARE BAY	NJ
60351	Fortescue Creek, New Jersey	NOS	8536931	39.2383	-75.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORTESCUE CREEK	NJ
60352	Ship John Shoal, Delaware River, New Jersey	NOS	8537121	39.305	-75.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0599999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship John Shoal	NJ
60353	Paulsboro, Mantua Creek, New Jersey	NOS	8538512	39.835	-75.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAULSBORO, MANTUA CREEK	NJ
60354	Tacony-Palmyra Bridge, New Jersey	NOS	8538886	40.01194	-75.04299999978807	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacony-Palmyra Bridge	NJ
60355	Burlington, Delaware River, New Jersey	NOS	8539094	40.08	-74.87333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burlington, Delaware River	NJ
60356	Fieldsboro, Delaware River, New Jersey	NOS	8539487	40.1367	-74.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDSBORO, DELAWARE RIVER	NJ
60357	Trenton Marine Terminal, Trenton, New Jersey	NOS	8539993	40.1883	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.470000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TRENTON MARINE TERMINAL	NJ
60358	Marcus Hook, Pennsylvania	NOS	8540433	39.8116667	-75.4094444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook	PA
60359	Philadelphia (USCG Station), Delaware River, Pennsylvania	NOS	8545240	39.93333333333333	-75.14166666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4899999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Philadelphia	PA
60360	Philadelphia, Municipal Pier 11, Pennsylvania	NOS	8545530	39.9533	-75.1383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHILADELPHIA (PIER 11 NORTH), DEL. RIVER	PA
60361	Bridesburg, Philadelphia, Pennsylvania	NOS	8546252	39.98333333333333	-75.075	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridesburg	PA
60362	Newbold, Delaware River, Pennsylvania	NOS	8548989	40.13730555555556	-74.75188888888889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.329999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold	PA
60363	Delaware City, Delaware River, Delaware	NOS	8551762	39.5817	-75.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.960000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware City	DE
60364	Reedy Point, C&D Canal, Delaware	NOS	8551910	39.5583	-75.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9199999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
60365	Mahon River entrance, Delaware Bay, Delaware	NOS	8554399	39.185	-75.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mahon River Entrance	DE
60366	Brandywine Shoal Light, Delaware Bay, New Jersey	NOS	8555889	38.98667	-75.11333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.610000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light	NJ
60367	Lewes, Fort Miles, Delaware	NOS	8557380	38.782779693603516	-75.1191635131836	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewes	DE
60371	South Point, Sinepuxent Neck, Chincoteague Bay, Maryland	NOS	8570536	38.215	-75.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH POINT, SINEPUXENT NECK, CHINC. BAY	MD
60372	Public Landing, Chincoteague Bay, Maryland	NOS	8570649	38.1483	-75.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUBLIC LANDING, CHINCOTEAGUE BAY	MD
60373	Buntings Bridge, Chincoteague Bay, Maryland	NOS	8570691	38.13894444444445	-75.18352777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buntings Bridge	MD
60374	Crisfield, Little Annemessex River, Chesapeake Bay, Maryland	NOS	8571091	37.9767	-75.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISFIELD	MD
60375	Ewell, Smith Island, Chesapeake Bay, Maryland	NOS	8571117	37.995	-76.0317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ewell, Smith Island	MD
60376	Snow Hill, city park, Pocomoke River, Maryland	NOS	8571359	38.17833	-75.39666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Hill	MD
60377	Bishops Head, Hooper Strait, Maryland	NOS	8571421	38.22038888888889	-76.03866666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishops Head	MD
60378	McCready's Creek, Fishing Bay, Chesapeake Bay, Maryland	NOS	8571559	38.3	-76.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	McCready's Creek	MD
60379	Barren Island, Chesapeake Bay, Maryland	NOS	8571579	38.3417	-76.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barren Island	MD
60380	Salisbury, Wicomico River, Maryland	NOS	8571616	38.3650016784668	-75.60669708251953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY, WICOMICO RIVER	MD
60381	Smithville Road Bridge, Beaverdam Creek, Little Choptank River, Maryland	NOS	8571702	38.42833	-76.23666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaverdam Creek	MD
60382	Vienna, Nanticoke River, Maryland	NOS	8571773	38.48333	-75.81833333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vienna	MD
60383	Cambridge, Choptank River, Maryland	NOS	8571892	38.5741667	-76.0722222	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cambridge	MD
60384	Poplar Island, Chesapeake Bay, Maryland	NOS	8572271	38.75833333333333	-76.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.78	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Poplar Island	MD
60386	Kent Point Marina, Chesapeake Bay, Maryland	NOS	8572467	38.8367	-76.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kent Point	MD
60387	Hillsboro, Tuckahoe Creek, Maryland	NOS	8572669	38.9167	-75.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4600000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hillsboro	MD
60388	Matapeake, Kent Island, Chesapeake Bay, Maryland	NOS	8572770	38.9567	-76.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matapeake	MD
60389	Love Point, Chester River, Maryland	NOS	8572955	39.0317	-76.3017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Love Point Pier	MD
60390	Crumpton, Chester River, Maryland	NOS	8573349	39.245	-75.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crumpton	MD
60391	Tolchester Beach, Chesapeake Bay, Maryland	NOS	8573364	39.21333	-76.245	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tolchester Beach	MD
60392	Sassafras River, Betterton, Chesapeake Bay, Maryland	NOS	8573704	39.3717	-76.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Betterton	MD
60393	Town Point Wharf, Elk River, Maryland	NOS	8573903	39.5033	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TOWN POINT WHARF	MD
60394	Chesapeake City, Chesapeake and Delaware Canal, Maryland	NOS	8573927	39.5267	-75.81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake City	MD
60395	Havre de Grace, Susquehanna River, Maryland	NOS	8574070	39.5367	-76.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Havre De Grace	MD
60396	Pond Point (Aberdeen P.G.), Bush River, Chesapeake Bay, Maryland	NOS	8574459	39.3883	-76.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POND POINT (ABERDEEN P.G.), BUSH RIVER	MD
60397	Baltimore (Fort McHenry), Maryland	NOS	8574680	39.26667	-76.57833333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore, Fort McHenry, Patapsco River	MD
60398	Fort McHenry Marsh, Patapsco River, Maryland	NOS	8574683	39.2617	-76.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort McHenry Marsh	MD
60399	Annapolis (US Naval Academy), Severn River, Maryland	NOS	8575512	38.98328	-76.4815555551317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Annapolis	MD
60400	Long Beach, Chesapeake Bay, Maryland	NOS	8577004	38.465	-76.4733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Beach	MD
60401	Cove Point, Chesapeake Bay, Maryland	NOS	8577188	38.3917	-76.3983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COVE POINT	MD
60402	Solomons Island, Patuxent River, Maryland	NOS	8577330	38.3172222	-76.4508333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Solomons Island	MD
60403	Lower Marlboro, Patuxent River, Maryland	NOS	8579542	38.655	-76.68333333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1099999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Marlboro	MD
60404	Bladensburg, Anacostia River, Maryland	NOS	8579997	38.9333	-76.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLADENSBURG, ANACOSTIA RIVER	MD
60405	Washington, Potomac River, DC	NOS	8594900	38.87333	-77.02166666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Washington	DC
60406	Jesters Island, Virginia	NOS	8630111	37.9817008972168	-75.30169677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JESTERS ISLAND, CHINCOTEAGUE BAY	VA
60540	Black Creek, S.C.L. RR. bridge, Florida	NOS	8720434	30.08	-81.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACK CREEK	FL
60407	Chincoteague Island, USCG station, Virginia	NOS	8630249	37.93170166015625	-75.38330078125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE, USCG STATION	VA
60408	Chincoteague Channel (south end), Chincoteague Bay, Virginia	NOS	8630308	37.9067	-75.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1700000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE CHANNEL, SOUTH END	VA
60409	Wachapreague, Wachapreague Channel, Virginia	NOS	8631044	37.60777777777778	-75.68583333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2899999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wachapreague	VA
60410	Kiptopeke Beach, Chesapeake Bay, Virginia	NOS	8632200	37.16519	-75.98844444433848	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kiptopeke	VA
60412	Rappahannock Light, Virginia	NOS	8632837	37.5383	-76.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Light	VA
60413	Gaskins Point, Occohannock Creek, Chesapeake Bay, Virginia	NOS	8632869	37.5567	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GASKINS PT., OCCOHANNOCK CREEK	VA
60414	Tangier Island, Chesapeake Bay, Virginia	NOS	8633532	37.8283	-75.9933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tangier Island	VA
60415	Saxis, Starling Creek, Virginia	NOS	8633777	37.92169952392578	-75.72830200195312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAXIS, STARLING CREEK	VA
60416	Dahlgren, Upper Machodoc Creek, Potomac River, Virginia	NOS	8635027	38.31975	-77.03661111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dahlgren	VA
60417	Colonial Beach, Potomac River, Virginia	NOS	8635150	38.2517	-76.96	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Colonial Beach, Potomac River	VA
60418	Rappahannock Bend, Virginia	NOS	8635257	38.2133	-77.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Bend	VA
60419	Lewisetta, Potomac River, Virginia	NOS	8635750	37.99538888888889	-76.46461111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewisetta	VA
60420	Wares Wharf, Rappahannock River, Virginia	NOS	8635985	37.8733	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wares Wharf	VA
60421	Windmill Point, Rappahannock River, Virginia	NOS	8636580	37.61611111111111	-76.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Windmill Point	VA
60422	Lester Manor, Pamunkey River, Virginia	NOS	8636653	37.5833	-76.99	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lester Manor	VA
60423	Richmond Deepwater Terminal, James River, Virginia	NOS	8636941	37.45955555555555	-77.42077777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond Deepwater Terminal, James River	VA
60426	Gloucester Point, York River, Virginia	NOS	8637624	37.2467	-76.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2900000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	VA
60427	Yorktown USCG Training Center, York River, Virginia	NOS	8637689	37.2265	-76.4788	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yorktown USCG Training Center	VA
60428	Jamestown Wharf, Jamestown, Virginia	NOS	8637712	37.22011111111111	-76.79141666666666	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=02042770.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jamestown Wharf	VA
60429	Fort Eustis (MARAD), James River, Virginia	NOS	8638017	37.13822222222223	-76.62275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2799999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT EUSTIS (MARAD), JAMES RIVER	VA
60430	Western Branch, Elizabeth River, Virginia	NOS	8638339	36.82322222222222	-76.39911111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Branch	VA
60432	Kingsmill, James River, Virginia	NOS	8638424	37.22	-76.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2799999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsmill	VA
60433	Scotland, James River, Virginia	NOS	8638433	37.185	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotland	VA
60434	Lanexa, Chickahominy River, Virginia	NOS	8638445	37.4033	-76.9117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lanexa, Chickahominy River	VA
60435	Tettington, James River, Virginia	NOS	8638450	37.24	-76.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tettington, James River	VA
60436	Willcox Wharf, Charles City, James River, Virginia	NOS	8638464	37.315	-77.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3099999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilcox Wharf	VA
60437	Hopewell, City Point, James River, Virginia	NOS	8638481	37.3133	-77.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hopewell	VA
60438	Puddledock Sand & Gravel, Appomattox River, Virginia	NOS	8638489	37.2667	-77.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puddledock	VA
60439	Richmond River Locks, James River, Virginia	NOS	8638495	37.525	-77.42	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond River Locks, James River	VA
60440	Sewells Point, Hampton Roads, Virginia	NOS	8638610	36.94666666666667	-76.33	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point	VA
60441	Portsmouth, Naval Shipyard, Elizabeth River, Virginia	NOS	8638660	36.8217	-76.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5299999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORTSMOUTH, NORFOLK NAVAL SHIPYARD	VA
60442	Lafayette River, Virginia	NOS	8638671	36.88422222222222	-76.27585833333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lafayette River	VA
60443	Chesapeake Bay Bridge-Tunnel, Virginia	NOS	8638863	36.9667	-76.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge Tunnel	VA
60466	Zekes Island, Cape Fear River, North Carolina	NOS	8658741	33.95	-77.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZEKES ISLAND, CAPE FEAR RIVER	NC
60444	Chesapeake Bay Bridge-Tunnel, Chesapeake Bay, Virginia	NOS	8638901	37.032901763916016	-76.08329772949219	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CBBT, Chesapeake Channel	VA
60445	Inside channel, Rudee Inlet, Virginia	NOS	8639207	36.8317	-75.9733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rudee Inlet	VA
60446	Money Point, South Bridge, Elizabeth River, Virginia	NOS	8639348	36.77830555555556	-76.30169444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Money Point	VA
60447	FRF Pier, Duck, North Carolina	NOS	8651370	36.18330555555556	-75.74669444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7700000000000031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Duck	NC
60448	Manns Harbor, outer coast, North Carolina	NOS	8652247	35.9033	-75.77	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.21999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manns Harbor	NC
60449	Oyster Creek, Croatan Sound, North Carolina	NOS	8652437	35.845	-75.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.31000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Creek	NC
60450	Roanoke Marshes Light, outer coast, North Carolina	NOS	8652547	35.8117	-75.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Marshes Light	NC
60451	Oregon Inlet Marina, Pamlico Sound, North Carolina	NOS	8652587	35.795	-75.5480556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5800000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oregon Inlet Marina	NC
60452	Oregon Inlet (USCG Station), North Carolina	NOS	8652678	35.7683	-75.5267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG LIFEBOAT STATION, OREGON INLET	NC
60453	Avon Seafood dock, Peter's Ditch, Avon, North Carolina	NOS	8653951	35.35013888888889	-75.51202777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peter's Ditch	NC
60454	Cape Hatteras (fishing pier), North Carolina	NOS	8654400	35.2233	-75.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hatteras Fishing Pier	NC
60455	Hatteras (USCG Station), North Carolina	NOS	8654467	35.20863888888889	-75.70416666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station Hatteras	NC
60456	Ocracoke, Ocracoke Island, North Carolina	NOS	8654792	35.115	-75.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCRACOKE ISLAND	NC
60457	Sea Level, Core Sound, North Carolina	NOS	8655875	34.875	-76.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Level	NC
60458	Davis, Core Sound, North Carolina	NOS	8656201	34.79675	-76.45547222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Core Sound	NC
60459	Spooner Creek, North Carolina	NOS	8656467	34.725	-76.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spooners Creek	NC
60460	Duke Marine Lab, Beaufort, North Carolina	NOS	8656483	34.72	-76.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaufort, Duke Marine Lab	NC
60461	Triple S Pier, Atlantic Beach, North Carolina	NOS	8656590	34.6933	-76.7117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach Triple S Pier	NC
60462	Cape Lookout Bight, North Carolina	NOS	8656841	34.6133	-76.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE LOOKOUT, LOOKOUT BIGHT	NC
60463	Wilmington, North Carolina	NOS	8658120	34.2275	-77.9536111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington	NC
60464	Wrightsville Beach, North Carolina	NOS	8658163	34.21330555555556	-77.78669444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.150000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrightsville Beach	NC
60465	Wharf 3, MOTSU, Cape Fear River, North Carolina	NOS	8658579	34.0233	-77.9467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUNNY POINT, MOTSU NORTH WHARF	NC
60467	Southport, Cape Fear River, North Carolina	NOS	8659084	33.915	-78.0183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
60468	Oak Island, Yaupon Beach, North Carolina	NOS	8659182	33.9017	-78.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5400000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oak Island, Atlantic Ocean	NC
60469	Sunset Beach Pier, North Carolina	NOS	8659897	33.865	-78.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunset Beach	NC
60470	Springmaid Pier, South Carolina	NOS	8661070	33.655	-78.91830555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Springmaid Pier	SC
60471	Bucksport, Waccamaw River, South Carolina	NOS	8661139	33.6467	-79.095	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUCKSPORT, WACCAMAW RIVER	SC
60472	Garden City Bridge, Main Creek, Murrells Inlet, South Carolina	NOS	8661419	33.5783	-79.0033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY BRIDGE, MURRELLS INLET	SC
60473	Garden City Pier (ocean), South Carolina	NOS	8661437	33.575	-78.9967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7100000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY PIER, MURRELLS INLET	SC
60474	Oaks Creek, upper end, Murrells Inlet, South Carolina	NOS	8661684	33.5117	-79.0683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OAKS CREEK, UPPER END, MURRELLS INLET	SC
60475	Thoroughfare Creek entrance, Waccamaw River, South Carolina	NOS	8661703	33.5067	-79.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY ISLAND, THOROUGHFARE CREEK	SC
60476	Bennet's Dock, Pawleys Island Creek, South Carolina	NOS	8661989	33.435	-79.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNETT'S DOCK	SC
60477	Pawleys Island Pier (ocean), South Carolina	NOS	8662006	33.4317	-79.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS ISLAND PIER, ATLANTIC OCEAN	SC
60478	Ward's Dock, Pawleys Inlet, South Carolina	NOS	8662071	33.4117	-79.135	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS INLET, WARDS DOCK	SC
60479	Crab Haul Creek north inlet estuary, Oyster Landing, South Carolina	NOS	8662245	33.3517	-79.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Landing (N Inlet Estuary)	SC
60480	Clambank Creek Dock, Goat Island, North Inlet, South Carolina	NOS	8662299	33.3333	-79.1933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7100000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAMBANK CREEK DOCK, GOAT ISLAND	SC
60481	South Island Plantation (C.G. Station), Winyah Bay, South Carolina	NOS	8662746	33.235	-79.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINYAH BAY, SOUTH ISLAND PLANTATION	SC
60482	Waccamaw River entrance, Winyah Bay, South Carolina	NOS	8662931	33.36669921875	-79.25499725341797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.990000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WACCAMAW RIVER ENTRANCE	SC
60483	Windsor Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8662953	33.415	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9599999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINDSOR PLANTATION, BLACK RIVER	SC
60484	General Dynamics Pier, Cooper River, South Carolina	NOS	8664022	33.0083	-79.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GEN. DYNAMICS PIER, COOPER R.	SC
60485	Cainhoy, Wando River, South Carolina	NOS	8664545	32.9267	-79.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5400000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cainhoy, Wando River	SC
60486	Army Depot, Cooper River, South Carolina	NOS	8664662	32.91	-79.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Army Depot	SC
60487	Capers Creek, South Capers Island, South Carolina	NOS	8664941	32.8567	-79.7067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5799999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Capers Island	SC
60488	I-526 bridge, Ashley River, South Carolina	NOS	8665099	32.8367	-80.0217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.289999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-526 BRIDGE, ASHLEY RIVER	SC
60489	Charleston, Cooper River Entrance, South Carolina	NOS	8665530	32.7808333	-79.9236111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston, Cooper River Entrance	SC
60490	Clarendon Plantation, South Carolina	NOS	8667633	32.5025	-80.7841	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clarendon Plantation	SC
60491	Beaufort, Beaufort River, South Carolina	NOS	8667999	32.43	-80.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BEAUFORT	SC
60492	Fripp Inlet, Hunting Island Bridge, St. Helena Sound, South Carolina	NOS	8668498	32.34	-80.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fripps Inlet	SC
60493	Skull Creek, Ribaut Island, South Carolina	NOS	8668918	32.2667	-80.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIBAUT ISLAND, SKULL CREEK	SC
60494	Port Wentworth, Savannah River, Georgia	NOS	8670424	32.1433	-81.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Wentworth	GA
60496	Fort Pulaski, Savannah River Entrance, Georgia	NOS	8670870	32.0367	-80.9017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pulaski	GA
60498	Skidaway Institute, Skidaway River, Georgia	NOS	8671086	31.99	-81.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.2700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SKIDAWAY INSTITUTE, SKIDAWAY RIVER	GA
60499	Halfmoon Reef, Halfmoon River, Georgia	NOS	8671314	31.9633	-80.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALFMOON REEF, HALFMOON RIVER	GA
60500	Priest Landing, Wilmington River, Georgia	NOS	8671315	31.9633	-81.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRIEST LANDING, WILMINGTON RIVER	GA
60501	Bear River, (Range 'A' Light), Georgia	NOS	8672667	31.7933	-81.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A Light, Bear River	GA
60502	Sunbury, Sunbury Channel, Georgia	NOS	8672875	31.7667	-81.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunbury, Sunbury Channel	GA
60503	South Ossabaw Island, Bear River, Georgia	NOS	8673171	31.72302777777778	-81.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ossabaw Island, Bear River	GA
60504	South Newport River (Daymark 135), Georgia	NOS	8674301	31.575	-81.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7900000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #135, South Newport River	GA
60505	Mud River, head of (Daymark 156), Georgia	NOS	8674975	31.4867	-81.32	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #156, Head of Mud River	GA
60506	Rockdedundy River (Daymark 185), Georgia	NOS	8675761	31.37386111111111	-81.33394444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #185, Rockdedundy River Entrance	GA
60507	Crispen Island, Turtle River, Georgia	NOS	8676808	31.2133	-81.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISPEN ISLAND,TURTLE RIVER	GA
60508	St. Simons Lighthouse, St. Simons Island, Georgia	NOS	8677344	31.1317	-81.3967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5699999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St.Simons Island	GA
60509	Howe Street Pier, Brunswick, Georgia	NOS	8677406	31.14455555555556	-81.49680555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.009999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Howe Street Pier, Brunswick	GA
60510	Raccoon Key Spit, St. Andrew Sound, Georgia	NOS	8678124	31.01480555555555	-81.45597222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5599999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Key Spit	GA
60511	Bailey Cut, 0.8 mile west of, Satilla River, Georgia	NOS	8678322	30.985	-81.5917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bailey Cut, Satilla River	GA
60512	Kings Bay, Navy Base, Georgia	NOS	8679511	30.7967	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KINGS BAY	GA
60513	Dungeness, Seacamp Dock, Georgia	NOS	8679758	30.7633	-81.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUNGENESS, SEACAMP DOCK	GA
60514	St. Marys, St. Marys River, Georgia	NOS	8679964	30.72	-81.5483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARYS, ST. MARYS RIVER	GA
60515	Crandall, St. Marys River, Florida	NOS	8720004	30.7217	-81.6217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRANDALL, ST. MARYS RIVER	FL
60516	Cut 1N front range, St. Marys River, Florida	NOS	8720011	30.7083	-81.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 1N FRONT RANGE, ST MARYS RIVER ENTR	FL
60518	Chester, Bells River, Florida	NOS	8720023	30.6833	-81.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHESTER, BELLS RIVER	FL
60519	Fernandina Beach, Amelia River, Florida	NOS	8720030	30.6713889	-81.4658333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach	FL
60520	Lofton, Lanceford Creek, Florida	NOS	8720051	30.6433	-81.5233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANCEFORD CREEK, LOFTON	FL
60521	Vaughns Landing, Florida	NOS	8720059	30.63	-81.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaughns Landing	FL
60522	Nassauville, Nassau River East, Florida	NOS	8720098	30.5683	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NASSAUVILLE, NASSAU RIVER EAST	FL
60523	Edwards Creek, Nassau River, Florida	NOS	8720145	30.5017	-81.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edwards Creek	FL
60524	Cedar Heights, Broward River, Florida	NOS	8720189	30.4367	-81.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR HEIGHTS	FL
60525	Sisters Creek, Florida	NOS	8720196	30.4167	-81.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3800000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SISTERS CREEK	FL
60526	Clapboard Creek, Pelotes Island, Florida	NOS	8720198	30.4067	-81.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAPBOARD CREEK	FL
60527	Water Treatment Dock, Mayport Naval Station, St Johns River, Florida	NOS	8720211	30.4	-81.4133	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Naval Sta., St Johns River	FL
60528	Sherwood Forest, Trout River, Florida	NOS	8720213	30.42	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TROUT R., SHERWOOD FOREST	FL
60529	Degaussing structure, Mayport Naval Station, Florida	NOS	8720214	30.3967	-81.395	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Degaussing Structure	FL
60530	Bar Pilot Dock, St. Johns River, Florida	NOS	8720218	30.39816666666667	-81.42788888888889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.469999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Bar Pilots Dock)	FL
60531	Dame Point, St. Johns River, Florida	NOS	8720219	30.3867	-81.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8500000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point	FL
60532	Mayport (Ferry Depot), Florida	NOS	8720220	30.3933	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Ferry Depot)	FL
60533	Mayport, St. Johns River, Florida	NOS	8720224	30.395	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYPORT, ST JOHNS RIVER	FL
60534	Phoenix Park, Florida	NOS	8720225	30.3833	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHOENIX PARK	FL
60535	Main Street Bridge, St. Johns River, Florida	NOS	8720226	30.32	-81.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southbank Riverwalk, St Johns River	FL
60536	Jacksonville, Long Branch, Florida	NOS	8720242	30.36	-81.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Longbranch	FL
60537	Jacksonville Beach, Florida	NOS	8720291	30.2833	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacksonville Beach	FL
60538	I-295 Bridge (west end), St. Johns River, Florida	NOS	8720357	30.1917	-81.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.53	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-295 Bridge, St Johns River	FL
60539	Peoria Point, Doctors Lake, Florida	NOS	8720406	30.12	-81.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOCTORS LAKE, PEORIA POINT	FL
60541	Red Bay Point, St. Johns River, Florida	NOS	8720503	29.98166666666667	-81.63416666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Point, St Johns River	FL
60542	Vilano Beach ICWW, Tolomato River, Florida	NOS	8720554	29.9167	-81.3	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vilano Beach ICWW	FL
60543	State Road 312, Matanzas River, ICWW, Florida	NOS	8720582	29.8667	-81.3067	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road 312, Matanzas River	FL
60544	St. Augustine Beach, Florida	NOS	8720587	29.8567	-81.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4300000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Augustine Beach	FL
60545	Racy Point, St. Johns River, Florida	NOS	8720625	29.8017	-81.5483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Racy Point, St Johns River	FL
60546	Crescent Beach, Matanzas River, ICWW, Florida	NOS	8720651	29.7683	-81.2583	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent Beach, Matanzas River	FL
60547	State Road A1A Bridge, Florida	NOS	8720692	29.70453055555556	-81.22785555555555	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road A1A Bridge	FL
60548	Bings Landing, Matanzas River, ICWW, Florida	NOS	8720757	29.615	-81.205	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bings Landing, Matanzas River	FL
60570	Ocean Ridge, ICWW, Florida	NOS	8722718	26.52669906616211	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN RIDGE	FL
60571	South Delray Beach, ICWW, Florida	NOS	8722761	26.4467	-80.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH DELRAY BEACH	FL
60572	Lake Wyman, ICWW, Florida	NOS	8722802	26.37	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKE WYMAN	FL
60549	Buffalo Bluff, St. Johns River, Florida	NOS	8720767	29.595	-81.6817	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5800000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buffalo Bluff, St Johns River	FL
60550	Palatka, St. Johns River, Florida	NOS	8720774	29.6433	-81.6317	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.72	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Palatka, St Johns River	FL
60573	Boca Raton, Lake Boca Raton, Florida	NOS	8722816	26.343299865722656	-80.07669830322266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA RATON	FL
60551	Welaka, St. Johns River, Florida	NOS	8720832	29.4767	-81.675	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Welaka	FL
60553	Daytona Beach Shores, Sunglow Pier, Florida	NOS	8721120	29.1467	-80.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH SHORES	FL
60554	Ponce De Leon Inlet South, Florida	NOS	8721147	29.0633	-80.915	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ponce De Leon Inlet South	FL
60555	Mosquito Lagoon, New Smyrna Beach, Florida	NOS	8721164	29.0233	-80.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Smyrna Beach	FL
60556	Packwood Place, Florida	NOS	8721222	28.94	-80.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PACKWOOD PLACE	FL
60557	Turtle Mound, Florida	NOS	8721223	28.9267	-80.825	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE MOUND	FL
60558	Trident Pier, Port Canaveral, Florida	NOS	8721604	28.4158333	-80.5930556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Pier, Port Canaveral	FL
60560	Cocoa Beach, Florida	NOS	8721649	28.3683	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCOA BEACH, ATLANTIC OCEAN	FL
60561	Vero Beach, Indian River, Florida	NOS	8722125	27.6317	-80.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.43000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vero Beach	FL
60562	North Beach Causeway, Indian River, Florida	NOS	8722208	27.4717	-80.325	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Beach Causeway	FL
60563	Fort Pierce Inlet, Binney Dock, Florida	NOS	8722213	27.4683	-80.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Binney Dock	FL
60564	South Beach Causeway, Indian River, Florida	NOS	8722219	27.4567	-80.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach Causeway	FL
60565	PGA Boulevard Bridge, Palm Beach, Florida	NOS	8722548	26.8433	-80.0667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PGA Boulevard Bridge, Palm Beach	FL
60566	Port of West Palm Beach, Florida	NOS	8722588	26.77	-80.0517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of West Palm Beach	FL
60567	Lake Worth ICW, Florida	NOS	8722669	26.6133	-80.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth ICW	FL
60568	Lake Worth Pier, Florida	NOS	8722670	26.6127778	-80.0341667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Pier, Atlantic Ocean	FL
60574	Hillsboro Inlet Marina, Florida	NOS	8722859	26.260000228881836	-80.08499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HILLSBORO	FL
60575	Lauderdale-by-the-Sea, Anglin Fishing Pier, Florida	NOS	8722899	26.18829917907715	-80.09329986572266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4599999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAUDERDALE-BY-THE-SEA	FL
60576	South Port Everglades, ICWW, Florida	NOS	8722956	26.08169937133789	-80.11669921875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port Everglades	FL
60577	Haulover Pier, N. Miami Beach, Florida	NOS	8723080	25.9033	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAULOVER PIER, N. MIAMI BEACH	FL
60578	Miami, Miamarina, Biscayne Bay, Florida	NOS	8723165	25.7783	-80.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI, BISCAYNE BAY	FL
60579	Miami Beach (city pier), Florida	NOS	8723170	25.7683	-80.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Beach	FL
60580	Government Cut, Miami Harbor Entrance, Florida	NOS	8723178	25.7633	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI BEACH, GOVERNMENT CUT	FL
60581	Virginia Key, Bear Cut, Biscayne Bay, Florida	NOS	8723214	25.7314	-80.1618	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1099999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Virginia Key, Biscayne Bay	FL
60582	Cutler, Biscayne Bay, Florida	NOS	8723289	25.615	-80.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTLER, BISCAYNE BAY	FL
60583	Ragged Key No. 5, Biscayne Bay, Florida	NOS	8723355	25.5233	-80.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RAGGED KEY NO. 5, BISCAYNE BAY	FL
60584	Elliott Key Harbor, Elliott Key, Biscayne Bay, Florida	NOS	8723409	25.4533	-80.1967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELLIOTT KEY HARBOR, ELLIOTT KEY	FL
60585	Turkey Point, Biscayne Bay, Florida	NOS	8723423	25.4367	-80.33	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT, BISCAYNE BAY	FL
60586	East Arsenicker, Card Sound, Florida	NOS	8723465	25.3733	-80.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST ARSENICKER, CARD SOUND	FL
60587	Pumpkin Key, south end, Card Sound, Florida	NOS	8723506	25.325	-80.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUMPKIN KEY, CARD SOUND	FL
60588	Little Card Sound bridge, Florida	NOS	8723534	25.2883	-80.37	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARD SOUND BRIDGE	FL
60589	Key Colony Beach, Florida	NOS	8723962	24.7183	-81.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key Colony Beach	FL
60590	Vaca Key, Florida Bay, Florida	NOS	8723970	24.711	-81.1065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5099999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaca Key, Florida Bay	FL
60591	Boca Chica Marina, Florida	NOS	8724493	24.575	-81.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6499999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA CHICA MARINA	FL
60592	Fleming Key, north end, Florida	NOS	8724571	24.5917	-81.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7100000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key	FL
60593	Key West, Florida	NOS	8724580	24.55583333333333	-81.80777777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West	FL
60594	Sand Key Lighthouse, Sand Key Channel, Florida	NOS	8724635	24.4533	-81.8783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAND KEY LIGHTHOUSE	FL
60595	Smith Shoal Light, Florida	NOS	8724671	24.71827777777778	-81.92152777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Shoal Light	FL
60596	Loggerhead Key, Dry Tortugas, Florida	NOS	8724698	24.6317	-82.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Loggerhead Key	FL
60597	Dismal Key, Pumpkin Bay, Florida	NOS	8724963	25.895	-81.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DISMAL KEY, PUMPKIN BAY	FL
60598	Coon Key Pass, Gullivan Bay, Florida	NOS	8724964	25.8967	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COON KEY PASS, GULLIVAN BAY	FL
60599	Marco Island, Caxambas Pass, Florida	NOS	8724967	25.9083	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.68	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO ISLAND, CAXAMBAS PASS	FL
60600	Marco, Big Marco River, Florida	NOS	8724991	25.9717	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO, BIG MARCO RIVER	FL
60601	McIlvaine Bay, Florida	NOS	8724996	25.985	-81.7017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.44	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MCILVAINE BAY	FL
60602	Keewaydin Island (inside), Florida	NOS	8725019	26.025	-81.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEEWAYDIN ISLAND, INSIDE	FL
60603	Naples, Gulf Of Mexico, Florida	NOS	8725110	26.13166666666667	-81.80747222222222	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naples, Gulf of Mexico	FL
60604	Coconut Point, Estero Bay, Florida	NOS	8725319	26.4	-81.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCONUT POINT, ESTERO BAY	FL
60605	Estero Island, Estero Bay, Florida	NOS	8725351	26.4383	-81.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTERO ISLAND, ESTERO BAY	FL
60606	Tarpon Bay, Sanibel Island, Florida	NOS	8725362	26.4433	-82.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TARPON BAY	FL
60607	Hendry Creek, Estero Bay, Florida	NOS	8725377	26.47	-81.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HENDRY CREEK, ESTERO BAY	FL
60608	Punta Rassa, San Carlos Bay, Florida	NOS	8725391	26.4883	-82.0133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA RASSA, SAN CARLOS BAY	FL
60609	North Captiva Island, Florida	NOS	8725488	26.605	-82.2183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH CAPTIVA ISLAND	FL
60610	Fort Myers, Caloosahatchee River, Florida	NOS	8725520	26.6477	-81.8712	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Myers, Caloosahatchee River	FL
60611	Bokellia, Charlotte Harbor, Florida	NOS	8725541	26.70669937133789	-82.16329956054688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOKEELIA, CHARLOTTE HARBOR	FL
60612	Port Boca Grande, Charlotte Harbor, Florida	NOS	8725577	26.72	-82.2583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT BOCA GRANDE, CHARLOTTE HBR.	FL
60613	Turtle Bay, Charlotte Harbor, Florida	NOS	8725649	26.7967	-82.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE BAY	FL
60614	Don Pedro Island State Park, cutoff (south), Florida	NOS	8725685	26.855	-82.3033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTOFF SOUTH	FL
60615	Locust Point, Hog Island, Charlotte Harbor, Florida	NOS	8725745	26.93	-82.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOCUST POINT, HOG ISLAND	FL
60616	Harbour Heights, Peace River, Charlotte Harbor, Florida	NOS	8725791	26.9883	-81.9933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HARBOUR HEIGHTS, PEACE RIVER	FL
60617	Manasota, Lemon Bay, Florida	NOS	8725809	27.0117	-82.41	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MANASOTA	FL
60618	Myakka River, US 41 bridge, Charlotte Harbor, Florida	NOS	8725837	27.045	-82.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MYAKKA RIVER, US 41	FL
60619	Venice Municipal Airport, Florida	NOS	8725858	27.0717	-82.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GULF OF MEXICO	FL
60620	Egmont Key, Egmont Channel, Tampa Bay, Florida	NOS	8726347	27.6017	-82.76	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EGMONT KEY, TAMPA BAY	FL
60621	Mullet Key Channel (Skyway), Tampa Bay, Florida	NOS	8726364	27.615	-82.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1099999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MULLET KEY, TAMPA BAY	FL
60622	Port Manatee, Tampa Bay, Florida	NOS	8726384	27.6383333	-82.5625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee	FL
60623	Little Manatee River, Florida	NOS	8726436	27.705	-82.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LITTLE MANATEE RIVER	FL
60624	St. Petersburg, Tampa Bay, Florida	NOS	8726520	27.7606	-82.6269	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Petersburg, Tampa Bay	FL
60625	Newman Branch, Tampa Bay, Florida	NOS	8726539	27.7833	-82.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWMAN BRANCH	FL
60626	Port Tampa, Old Tampa Bay, Florida	NOS	8726607	27.8577778	-82.5527778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Port Tampa	FL
60627	Ballast Point, Tampa, Florida	NOS	8726639	27.89	-82.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TAMPA, BALLAST POINT	FL
60628	CSX Rockport, Mckay Bay Entrance, Florida	NOS	8726667	27.91333333333333	-82.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mckay Bay Entrance	FL
60629	Clearwater Beach, Gulf Of Mexico, Florida	NOS	8726724	27.9783	-82.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clearwater Beach	FL
60630	Safety Harbor, Old Tampa Bay, Florida	NOS	8726738	27.9883	-82.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAFETY HARBOR, OLD TAMPA BAY	FL
60631	Anclote Lighthouse, Anclote Key, Florida	NOS	8726917	28.165	-82.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANCLOTE LIGHTHOUSE, ANCLOTE KEY	FL
60632	Bayport, Florida	NOS	8727151	28.5333	-82.65	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYPORT	FL
60633	Johns Island, Chassahowitzka Bay, Florida	NOS	8727235	28.6917	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JOHNS ISLAND, CHASSAHOWITZKA BAY	FL
60634	Chassahowitzka, Chassahowitzka River, Florida	NOS	8727246	28.715	-82.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHASSAHOWITZKA RIVER	FL
60635	Mason Creek, Homosassa Bay, Florida	NOS	8727274	28.7617	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MASON CREEK, HOMOSASSA BAY	FL
60636	Tuckers Island, Homosassa River, Florida	NOS	8727277	28.7717	-82.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKERS ISLAND, HOMOSASSA RIVER	FL
60637	Halls River bridge, Homosassa River, Florida	NOS	8727293	28.8	-82.6033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.32999999999999985	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALLS RIVER BRIDGE, HALLS RIVER	FL
60638	Ozello, St. Martin's River, Florida	NOS	8727306	28.825	-82.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.34999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO	FL
60639	Ozello North, Crystal Bay, Florida	NOS	8727328	28.8633	-82.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO NORTH	FL
60640	Mangrove Pt., Crystal Bay, Florida	NOS	8727333	28.87	-82.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mangrove Point	FL
60641	Dixie Bay, Salt River, Crystal Bay, Florida	NOS	8727336	28.8817	-82.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DIXIE BAY	FL
60642	Crystal River, Kings Bay, Florida	NOS	8727343	28.8983	-82.5983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRYSTAL RIVER, KINGS BAY	FL
60643	Twin Rivers Marina, Crystal River, Florida	NOS	8727348	28.905	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Twin Rivers Marina	FL
60644	Shell Island, north end, Crystal River, Florida	NOS	8727359	28.9233	-82.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5099999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL ISLAND, CRYSTAL RIVER	FL
60645	Cedar Key, Gulf Of Mexico, Florida	NOS	8727520	29.13361111111111	-83.0308888888889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cedar Key	FL
60646	Horseshoe Point, Florida	NOS	8727648	29.4367	-83.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HORSESHOE POINT	FL
60647	Spring Warrior Creek, Florida	NOS	8727843	29.92	-83.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPRING WARRIOR CREEK	FL
60648	St. Marks lighthouse, Apalachee Bay, Florida	NOS	8728130	30.0783	-84.1783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARKS LHTSE., APALACHEE BAY	FL
60649	Shell Point, Walker Creek, Apalachee Bay, Florida	NOS	8728229	30.06	-84.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.95	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL POINT, WALKER CREEK	FL
60650	Turkey Point, Apalachee Bay, St. James Island, Florida	NOS	8728360	29.915	-84.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT	FL
60651	Dog Island, east end, St. George Sound, Florida	NOS	8728408	29.81	-84.585	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOG ISLAND, EAST END	FL
60652	Lanark, St. George Sound, Florida	NOS	8728412	29.878299713134766	-84.59500122070312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANARK, ST. GEORGES SOUND	FL
60653	Carrabelle, Carrabelle River, St. George Sound, Florida	NOS	8728464	29.85	-84.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARRABELLE RIVER, ST. GEORGE SOUND	FL
60654	St. George Island, NE end, St. George Sound, Florida	NOS	8728486	29.766700744628906	-84.69999694824219	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE END, ST. GEORGE ISLAND	FL
60655	South Carrabelle Beach, Florida	NOS	8728488	29.801700592041016	-84.73670196533203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH CARRABELLE BEACH	FL
60656	Cat Point, Apalachicola Bay, Florida	NOS	8728619	29.7233	-84.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAT POINT, APALACHICOLA BAY	FL
60657	St. George Island, 12th St. W (bayside), St. George Sound, Florida	NOS	8728626	29.6533	-84.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. GEORGE ISLAND, BAYSIDE	FL
60658	St. George Island, Sikes Cut, St. George Sound, Florida	NOS	8728669	29.613300323486328	-84.95829772949219	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SIKES CUT, ST. GEORGE ISLAND	FL
60659	Apalachicola, Apalachicola Bay, Florida	NOS	8728690	29.7267	-84.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apalachicola	FL
60660	White Beach, East Bay, Florida	NOS	8728694	29.785	-84.8983	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITE BEACH, EAST BAY	FL
60661	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida	NOS	8728711	29.7633	-85.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	APALACHICOLA RIVER	FL
60662	Huckleberry Landing, Jackson River, Florida	NOS	8728757	29.770000457763672	-85.08499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUCKLEBERRY LANDING, JACKSON RIVER	FL
60663	Eleven Mile, St. Vincent Sound, Florida	NOS	8728786	29.70669937133789	-85.1532974243164	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELEVEN MILE, ST. VINCENT SOUND	FL
60664	White City, ICWW, Florida	NOS	8728853	29.88069444444444	-85.22144444444444	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White City, ICWW	FL
60665	Port Saint Joe, St. Joseph Bay, Florida	NOS	8728912	29.815	-85.3133	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port St. Joe	FL
60667	Overstreet, St. Andrew Bay, Florida	NOS	8728957	29.996700286865234	-85.37000274658203	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OVERSTREET	FL
60668	St. Joseph Point, St. Joseph Bay, Florida	NOS	8728958	29.873300552368164	-85.38999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.76	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. JOSEPH POINT, ST. JOSEPH BAY	FL
60669	Panama City, St. Andrew Bay, Florida	NOS	8729108	30.15227777777778	-85.66694444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City	FL
60670	Panama City Beach (outside), St. Andrew Bay, Florida	NOS	8729210	30.213300704956055	-85.87830352783203	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City Beach	FL
60671	Valparaiso, Florida	NOS	8729501	30.5033	-86.4933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valparaiso	FL
60672	Navarre Beach, Florida	NOS	8729678	30.3767	-86.865	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAVARRE BEACH	FL
60673	East Bay, Pensacola Bay, Florida	NOS	8729702	30.45	-86.9183	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST BAY, HOLLEY	FL
60674	Woodlawn Beach, Florida	NOS	8729736	30.3867	-86.9917	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WOODLAWN BEACH	FL
60676	Shield Point, Blackwater River, Florida	NOS	8729747	30.5817	-87.015	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHIELD POINT, BLACKWATER RIVER	FL
60678	Hernandez Point North, Florida	NOS	8729791	30.455	-87.1	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERNANDEZ POINT NORTH	FL
60679	Fishing Bend, Santa Rosa Sound, Florida	NOS	8729806	30.3367	-87.14	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FISHING BEND, SANTA ROSA SOUND	FL
60680	Lora Point, Escambia Bay, Pensacola Bay, Florida	NOS	8729816	30.515	-87.1617	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LORA POINT, ESCAMBIA BAY	FL
60681	Floridatown, Escambia Bay, Florida	NOS	8729824	30.5817	-87.18	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FLORIDATOWN, ESCAMBIA BAY	FL
60682	Pensacola, Florida	NOS	8729840	30.40438888888889	-87.21119444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pensacola	FL
60683	Millview, Perdido Bay, Florida	NOS	8729905	30.4183	-87.3567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Millview, Perdido Bay	FL
60684	Big Lagoon, Florida	NOS	8729909	30.3267	-87.3567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIG LAGOON	FL
60685	Blue Angels Park, Perdido Bay, Florida	NOS	8729941	30.38694444444445	-87.42880555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blue Angels Park	FL
60686	Alabama Point, Perdido Pass, Alabama	NOS	8730667	30.27861111111111	-87.55500030517578	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alabama Point	AL
60687	Gulf Shores, ICWW, Alabama	NOS	8731439	30.27988888888889	-87.68427777777778	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulf Shores, ICWW	AL
60688	Weeks Bay, Vermilion Bay, Louisiana	NOS	8732828	30.41688888888889	-87.8253888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay, Mobile Bay	LA
60689	Point Clear, Mobile Bay, Alabama	NOS	8733821	30.48663888888889	-87.93452777777777	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Clear, Mobile Bay	AL
60690	Meaher State Park, Mobile Bay, Alabama	NOS	8733839	30.66716666666667	-87.93644444444445	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Meaher State Park, Mobile Bay	AL
60691	Dauphin Island, Mobile Bay, Alabama	NOS	8735180	30.25	-88.075	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island	AL
60692	Dauphin Island Hydro, Alabama	NOS	8735181	30.25131944444444	-88.07948611111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island Hydro	AL
60693	Dog River Bridge, Alabama	NOS	8735391	30.56516666666667	-88.088	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog River Bridge	AL
60694	East Fowl River Bridge, Alabama	NOS	8735523	30.4436111	-88.1138889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Fowl River Bridge	AL
60695	Coast Guard sector, Mobile, Alabama	NOS	8736897	30.64830555555556	-88.05830555555555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coast Guard Sector Mobile	AL
60696	Mobile (Mobile State Docks), Alabama	NOS	8737048	30.7083	-88.0433	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile State Docks	AL
60697	Chickasaw Creek, Alabama	NOS	8737138	30.78188888888889	-88.0736111111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chickasaw Creek	AL
60698	Lower Bryant Landing, Tensay River, Alabama	NOS	8737373	30.9783	-87.8733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9300000000000033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Bryant Landing	AL
60699	West Fowl River Bridge, Alabama	NOS	8738043	30.37663888888889	-88.15855555555555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Fowl River Bridge	AL
60700	Bayou La Batre Bridge, Alabama	NOS	8739803	30.40566666666667	-88.24769444444445	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7799999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayou La Batre Bridge	AL
60701	Grand Bay NERR, Mississippi Sound, Mississippi	NOS	8740166	30.41319444444444	-88.4028888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Bay NERR, Mississippi Sound	MS
60702	Petit Bois Island, Mississippi Sound, Mississippi	NOS	8740405	30.2033	-88.4417	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETIT BOIS ISLAND, MISS. SOUND	MS
60703	Dock E, Port of Pascagoula, Mississippi	NOS	8741041	30.3477778	-88.5058333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dock E, Port of Pascagoula	MS
60704	Pascagoula Point, Mississippi Sound, Mississippi	NOS	8741196	30.34	-88.5333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula Point	MS
60705	Pascagoula NOAA Lab, Pascagoula River, Mississippi	NOS	8741533	30.36777777777778	-88.56305555555555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula NOAA Lab	MS
60706	Gautier, Mississippi	NOS	8741798	30.3833	-88.61	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gautier	MS
60707	Graveline Bayou entrance, Mississippi	NOS	8742205	30.3617	-88.6633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAVELINE BAYOU ENTRANCE	MS
60708	Horn Island, Mississippi Sound, Mississippi	NOS	8742221	30.2383	-88.6667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island	MS
60709	North Shore, Mississippi	NOS	8742523	30.3733	-88.705	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Shore	MS
60710	Hollingsworth Point, Davis Bayou, Mississippi	NOS	8743081	30.3867	-88.7733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HOLLINGSWORTH POINT, DAVIS BAYOU	MS
60711	Ocean Springs Marina, Old Fort Bayou, Mississippi	NOS	8743181	30.4217	-88.7883	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fort Bayou, Ocean Springs Marina	MS
60712	Ocean Springs, Mississippi	NOS	8743281	30.3917	-88.7983	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean Springs	MS
60713	Bayou Talla, Back Bay, Biloxi, Mississippi	NOS	8743301	30.43	-88.8	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU TALLA, BACK BAY OF BILOXI	MS
60714	Ocean Springs, Old Fort Bayou, Mississippi	NOS	8743495	30.42	-88.8283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN SPRINGS, OLD FORT BAYOU	MS
60715	Bayou Poito, Back Bay, Biloxi, Mississippi	NOS	8743639	30.4383	-88.845	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU POITO, BACK BAY OF BILOXI	MS
60716	Biloxi (Cadet Point), Biloxi Bay, Mississippi	NOS	8743735	30.39	-88.8567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi (Cadet Point)	MS
60717	Deer Island, Mississippi	NOS	8743812	30.3833	-88.8667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island	MS
60718	Langley Point, Mississippi	NOS	8743838	30.425	-88.87	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Langley Point	MS
60719	Biloxi, Biloxi Bay, Mississippi	NOS	8744117	30.4117	-88.9033	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi	MS
60722	Popps Ferry, Back Bay, Biloxi, Mississippi	NOS	8744671	30.4133	-88.975	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POPPS FERRY, BACK BAY OF BILOXI	MS
60723	Ship Island, Mississippi Sound, Mississippi	NOS	8744756	30.2133	-88.9717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, Mississippi Sound	MS
60724	Biloxi River, lower end, Mississippi	NOS	8744934	30.435	-89.0083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BILOXI RIVER, LOWER END	MS
60725	Handsboro Bridge, Bernard Bayou, Mississippi	NOS	8745101	30.4067	-89.0267	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANDSBORO BRIDGE, BERNARD BAYOU	MS
60726	Landon, Mississippi	NOS	8745555	30.4317	-89.0817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Landon	MS
60727	Gulfport, Gulfport Harbor, Mississippi	NOS	8745557	30.36	-89.0817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulfport Harbor	MS
60728	Pass Christian Yacht Club, Mississippi Sound, Mississippi	NOS	8746819	30.31	-89.245	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PASS CHRISTIAN YACHT CLUB, MISS. SOUND	MS
60729	Bay Waveland Yacht Club, Bay St. Louis, Mississippi	NOS	8747437	30.325	-89.325	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Waveland Yacht Club	MS
60730	Waveland, Mississipi Sound, Mississippi	NOS	8747766	30.2817	-89.3667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waveland	MS
60731	Devon Energy Facility, Louisiana	NOS	8760417	29.20075	-89.04446666666666	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devon Energy Facility	LA
60732	South Pass, Louisiana	NOS	8760551	28.99	-89.14	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Pass	LA
60733	Grand Pass, Louisiana	NOS	8760668	30.126699447631836	-89.2217025756836	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND PASS	LA
60734	Pilottown, Louisiana	NOS	8760721	29.17830555555556	-89.25830555555555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilottown	LA
60736	Olga Compressor Station, Grand Bay, Louisiana	NOS	8760889	29.38655555555556	-89.3801388888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olga Compressor Station, Grand Bay	LA
60737	Pilots Station (east), Southwest Pass, Louisiana	NOS	8760922	28.9322	-89.4075	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilots Station East, S.W. Pass	LA
60738	Pilot Station, Southwest Pass, Louisiana	NOS	8760943	28.925	-89.4183	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Pass	LA
60739	Shell Beach, Lake Borgne, Louisiana	NOS	8761305	29.86811111111111	-89.67325	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shell Beach	LA
60740	University of New Orleans vicinity, Chef Menteur Pass, Louisiana	NOS	8761385	30.06875	-89.802083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VICINITY OF UNO CHEF MENTEUR	LA
60741	The Rigolets, U.S. Highway 90, Louisiana	NOS	8761402	30.1667	-89.7367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Rigolets	LA
60742	Martello Castle, Lake Borgne, Louisiana	NOS	8761529	29.945	-89.835	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARTELLO CASTLE, LAKE BORGNE	LA
60744	Grand Isle, Mississippi River Delta, Louisiana (2)	NOS	8761724	29.26333333333333	-89.95666666666666	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Isle	LA
60745	Mendicant Island, Barataria Bay, Louisiana	NOS	8761742	29.318300247192383	-89.9800033569336	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MENDICANT ISLAND, BARATARIA BAY	LA
60746	Texaco Dock, Hackberry Bay, Louisiana	NOS	8761819	29.4017	-90.0383	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEXACO DOCK, HACKBERRY BAY	LA
60747	Caminada Pass (bridge), Louisiana	NOS	8761826	29.209999084472656	-90.04000091552734	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHENIERE CAMINADA, CAMINADA PASS	LA
60748	Lafitte, Barataria Waterway, Louisiana	NOS	8761899	29.6667	-90.1117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.17000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAFITTE, BARATARIA WATERWAY	LA
60749	New Canal USCG station, Lake Pontchartrain, Louisiana	NOS	8761927	30.02722222222222	-90.11333333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Canal Station	LA
60750	Port Fourchon, Belle Pass, Louisiana	NOS	8762075	29.11425	-90.19925	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Fourchon, Belle Pass	LA
60751	Leeville, Bayou Lafourche, Louisiana	NOS	8762084	29.2483	-90.2117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LEEVILLE, BAYOU LAFOURCHE	LA
60752	Golden Meadow, Plaisance Canal, Louisiana	NOS	8762184	29.3733	-90.265	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GOLDEN MEADOW, PLAISANCE CANAL	LA
60753	East Timbalier Island, Timbalier Bay, Louisiana	NOS	8762223	29.0767	-90.285	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST TIMBALIER ISLAND, TIMBALIER BAY	LA
60754	East Bank 1, Norco, Bayou LaBranche, Louisiana	NOS	8762372	30.05033333333333	-90.368	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bank 1, Norco, B. LaBranche	LA
60755	I-10 Bonnet Carre Floodway, Louisiana	NOS	8762483	30.06786111111111	-90.38997222222223	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-10 Bonnet Carre Floodway	LA
60756	East Isle Dernire, Lake Pelto, Louisiana	NOS	8762888	29.0717	-90.64	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	E. ISLE DERNIERES, LAKE PELTO	LA
60757	Cocodrie, Terrebonne Bay, Louisiana	NOS	8762928	29.245	-90.6617	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cocodrie	LA
60758	Texas Gas Platform, Caillou Bay, Louisiana	NOS	8763535	29.17477777777778	-90.97644444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Gas Platform, Caillou Bay	LA
60759	Stouts Pass At Six Mile Lake, Louisiana	NOS	8764025	29.7433	-91.23	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Pass at Six Mile Lake	LA
60760	Tesoro Marine Term., Atchafalaya River, Louisiana	NOS	8764044	29.6675	-91.23761111111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.29999999999999716	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Berwick, Atchafalaya River	LA
60761	Lawma, Amerada Pass, Louisiana	NOS	8764227	29.44961111111111	-91.33811111111112	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAWMA, Amerada Pass	LA
60763	Eugene Island, north of, Louisiana	NOS	8764314	29.3675	-91.38388888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0200000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island, North of , Gulf of Mexico	LA
60764	Weeks Bay, Louisiana	NOS	8765148	29.83722222222222	-91.8375	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay	LA
60765	Cypremort Point, Louisiana	NOS	8765251	29.71336111111111	-91.88	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cypremort Point	LA
60766	Freshwater Canal Locks, Louisiana	NOS	8766072	29.55169444444444	-92.30519444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freshwater Canal Locks	LA
60767	Lake Charles, Calcasieu River, Louisiana	NOS	8767816	30.22363888888889	-93.22166666666666	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Charles	LA
60768	Bulk Terminal, Louisiana	NOS	8767961	30.19019444444444	-93.30080555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bulk Terminal	LA
60769	Calcasieu Pass, East Jetty, Louisiana	NOS	8768094	29.76816666666667	-93.3428888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calcasieu Pass	LA
60770	Sabine Naches Canal, Port Arthur, Texas	NOS	8770475	29.86708333333333	-93.931	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Arthur	TX
60771	Rainbow Bridge, Neches River, Texas	NOS	8770520	29.979999542236328	-93.88169860839844	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge (TCOON)	TX
60772	Mesquite Point, Sabine Pass, Texas	NOS	8770539	29.7667	-93.895	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mesquite Point	TX
60773	Round Point, Trinity Bay, Galveston Bay, Texas	NOS	8770559	29.7133	-94.69	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.76	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Point	TX
60774	Sabine Pass (north), Texas	NOS	8770570	29.7284	-93.8701	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass North	TX
60775	Orange (Old Navy Base), Texas	NOS	8770597	30.0983	-93.7217	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orange	TX
60776	Barbours Cut, Morgans Point, Galveston Bay, Texas	NOS	8770613	29.68169444444445	-94.985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Morgans Point, Barbours Cut	TX
60777	Umbrella Point, Trinity Bay, Texas	NOS	8770625	29.68	-94.8683	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UMBRELLA POINT, TRINITY BAY	TX
60778	Lynchburg Landing, San Jacinto River, Galveston Bay, Texas	NOS	8770733	29.76486111111111	-95.07886111111111	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lynchburg Landing	TX
60779	San Jacinto Battleground State Historic Site, Texas	NOS	8770743	29.7567	-95.09	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battleship Texas State Park	TX
60794	USCG Freeport, Texas	NOS	8772447	28.94330555555555	-95.3025	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
60835	Port San Luis, California	NOS	9412110	35.16880555555556	-120.7541944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port San Luis	CA
60780	Houston Ship Channel, Galveston Bay, Manchester, Texas	NOS	8770777	29.72622222222222	-95.26577777777777	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manchester	TX
60781	High Island (TCOON), Texas	NOS	8770808	29.59469985961914	-94.39029693603516	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7799999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	High Island (TCOON)	TX
60782	Texas Point, Sabine Pass, Texas	NOS	8770822	29.68938888888889	-93.84191666666666	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Point, Sabine Pass	TX
60783	Clear Lake, Galveston Bay, Texas	NOS	8770933	29.5633	-95.0667	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clear Lake	TX
60784	Rollover Pass, Texas	NOS	8770971	29.5155556	-94.5105556	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rollover Pass	TX
60785	Eagle Point, Galveston Bay, Texas	NOS	8771013	29.48	-94.91830555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point, Galveston Bay	TX
60787	Port Bolivar, Galveston Bay, Texas	NOS	8771328	29.365	-94.78	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8400000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Bolivar	TX
60788	Galveston Bay Entrance, North Jetty, Texas	NOS	8771341	29.35733333333333	-94.72483333333334	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance, North Jetty	TX
60789	Galveston Pier 21, Galveston Channel, Texas	NOS	8771450	29.31	-94.79330555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pier 21	TX
60790	Galveston Railroad Bridge, Texas	NOS	8771486	29.302600860595703	-94.89710235595703	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.740000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Railroad Bridge	TX
60791	Galveston Pleasure Pier, Gulf Of Mexico, Texas	NOS	8771510	29.2853	-94.7894	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1100000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pleasure Pier	TX
60792	San Luis Pass (TCOON), Texas	NOS	8771972	29.08097222222222	-95.13133333333333	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Luis Pass	TX
60793	Freeport, DOW Barge Canal, Texas	NOS	8772440	28.9483	-95.3083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
60795	Freeport SPIP, Freeport Harbor, Texas	NOS	8772471	28.935699462890625	-95.29419708251953	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport SPIP, Freeport Harbor	TX
60796	Sargent (TCOON), Texas	NOS	8772985	28.77141666666667	-95.61716666666666	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sargent	TX
60797	Seadrift, San Antonio Bay, Texas	NOS	8773037	28.40690040588379	-96.71240234375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.19999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seadrift	TX
60798	Matagorda City (TCOON), Texas	NOS	8773146	28.71005555555556	-95.914	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda City	TX
60799	Port Lavaca, Lavaca Causeway, Matagorda Bay, Texas	NOS	8773259	28.640600204467773	-96.60980224609375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5099999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lavaca	TX
60825	Mission Bay, California	NOS	9410196	32.79372	-117.2238	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8100000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mission Bay	CA
60826	La Jolla (Scripps Institution Wharf), California	NOS	9410230	32.86688888888889	-117.2571388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Jolla	CA
60800	Port O'Connor, Matagorda Bay, Texas	NOS	8773701	28.44586111111111	-96.39555555555556	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port O'Connor	TX
60801	Matagorda Bay Entrance Channel, Texas	NOS	8773767	28.42690086364746	-96.3301010131836	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda Bay Entrance Channel, TX	TX
60802	Aransas Wildlife Refuge (TCOON), Texas	NOS	8774230	28.228300094604492	-96.79499816894531	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.14999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas Wildlife Refuge (TCOON)	TX
60832	Santa Barbara, California	NOS	9411340	34.40311111111111	-119.6928055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Barbara	CA
60833	Gaviota State Park, California	NOS	9411399	34.46938888888889	-120.2283055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gaviota State Park, Pacific Ocean	CA
60834	Oil Platform Harvest (Topex Project), California	NOS	9411406	34.46916666666667	-120.6819444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.719999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oil Platform Harvest	CA
60803	Copano Bay State Fishing Pier, Texas	NOS	8774513	28.11440086364746	-97.02439880371094	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Copano Bay	TX
60804	Rockport, Aransas Bay, Texas	NOS	8774770	28.0216667	-97.0466667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.1899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockport	TX
60805	White Point Bay, Texas	NOS	8775188	27.8583	-97.475	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White Point	TX
60806	Port Aransas, Texas	NOS	8775237	27.83970069885254	-97.07250213623047	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Aransas	TX
60807	Aransas, Aransas Pass, Texas	NOS	8775241	27.836599349975586	-97.03910064697266	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas, Aransas Pass	TX
60808	Nueces Bay (TCOON), Texas	NOS	8775244	27.83275	-97.48594444444444	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nueces Bay	TX
60809	Port Aransas (H. Caldwell Pier), Texas	NOS	8775270	27.82670021057129	-97.05000305175781	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ARANSAS, H. CALDWELL PIER	TX
60810	Port Ingleside, Corpus Christi Bay, Texas	NOS	8775283	27.8217	-97.2033	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Ingleside	TX
61047	Whittier, Prince William Sound, Alaska	NOS	9454949	60.7783	-148.665	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whittier	AK
60811	Texas State Aquarium, Corpus Christi, Texas	NOS	8775296	27.814899444580078	-97.38919830322266	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USS Lexington, Corpus Christi Bay	TX
60812	Corpus Christi Naval Air Station, Texas	NOS	8775421	27.705	-97.28	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naval Air Station	TX
60882	Green Cove, California	NOS	9416409	38.70433333333333	-123.4493888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Cove	CA
60813	Packery Channel, Texas	NOS	8775792	27.63330555555556	-97.23669444444444	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Packery Channel	TX
60814	Corpus Christi, Gulf Of Mexico, Texas	NOS	8775870	27.58	-97.2167	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bob Hall Pier, Corpus Christi	TX
60815	Realitos Peninsula, Texas	NOS	8779280	26.262444	-97.285333	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Realitos Peninsula	TX
60816	Coast Guard Station, South Padre Island, Texas	NOS	8779748	26.07309913635254	-97.1675033569336	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island CG Station	TX
60817	South Padre Island, Brazos Santiago Pass, Texas	NOS	8779749	26.06738888888889	-97.15477777777778	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPI Brazos Santiago	TX
60818	Padre Island, Brazos Santiago Pass, Texas	NOS	8779750	26.0683	-97.1567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island, Brazos Santiago Pass	TX
60819	Port Isabel, Laguna Madre, Texas	NOS	8779770	26.06116666666667	-97.21552777777778	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Isabel	TX
60820	Wilson Cove, San Clemente Island, California	NOS	9410032	33.005001068115234	-118.55699920654297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILSON COVE, SAN CLEMENTE IS.	CA
60821	Avalon, Santa Catalina Island, California	NOS	9410079	33.345	-118.325	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.719999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AVALON, SANTA CATALINA ISLAND	CA
60822	South San Diego Bay, California	NOS	9410135	32.629139	-117.108	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South San Diego Bay	CA
60823	Ballast Point, California	NOS	9410155	32.6867	-117.233	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballast Point	CA
60824	San Diego, San Diego Bay, California	NOS	9410170	32.71419444444445	-117.1735833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego, San Diego Bay	CA
60827	Newport Beach, Newport Bay Entrance, Corona del Mar, California	NOS	9410580	33.6033	-117.883	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWPORT BEACH, NEWPORT BAY ENTRANCE	CA
60828	Los Angeles (outer harbor), California	NOS	9410660	33.71994444444444	-118.2728611111111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Los Angeles	CA
60829	Long Beach, Terminal Island, California	NOS	9410680	33.7517	-118.227	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, TERMINAL ISLAND	CA
60830	Santa Monica, Municipal Pier, San Pedro Channel, California	NOS	9410840	34.0083	-118.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7900000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Monica	CA
60831	Rincon Island, Mussel Shoals, Santa Barbara Channel, California	NOS	9411270	34.3483	-119.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RINCON ISLAND, PACIFIC OCEAN	CA
60836	Mansfield Cone, California	NOS	9412802	35.94952777777777	-121.4819444444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7399999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mansfield Cone	CA
60837	Monterey, Monterey Harbor, California	NOS	9413450	36.60499954223633	-121.88805389404297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monterey	CA
60838	Elkhorn Slough at Elkhorn, Monterey Bay, California	NOS	9413631	36.81829833984375	-121.74700164794922	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough at Elkhorn	CA
60839	Tidal Creek, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413643	36.83330154418945	-121.74500274658203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tidal Creek, Elkhorn Slough	CA
60840	Kirby Park, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413651	36.84130096435547	-121.74530029296875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.950000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kirby Park, Elkhorn Slough	CA
60841	Elkhorn Slough railroad bridge, Monterey Bay, California	NOS	9413663	36.85667	-121.755	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9300000000000033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough Railroad Bridge	CA
60842	Pillar Point Harbor, Half Moon Bay, California	NOS	9414131	37.5025	-122.4821666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9899999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point Harbor	CA
60843	San Francisco, San Francisco Bay, California	NOS	9414290	37.80630555555555	-122.4658888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.119999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco	CA
60845	Rincon Point, Pier 22, San Francisco Bay, California	NOS	9414317	37.79	-122.387	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PIER 22 1/2, SAN FRANCISCO	CA
60846	Hunters Point, San Francisco Bay, California	NOS	9414358	37.73	-122.357	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUNTERS POINT, S.F. BAY	CA
60847	Oyster Point Marina, San Francisco Bay, California	NOS	9414392	37.665	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OYSTER POINT MARINA, SAN FRANCISCO BAY	CA
60848	San Mateo Bridge (west end), San Francisco Bay, California	NOS	9414458	37.58	-122.253	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.109999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
60850	Dumbarton Highway Bridge, San Francisco Bay, California	NOS	9414509	37.5067	-122.115	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.68	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Bridge	CA
60851	Redwood City, Wharf 5, San Francisco Bay, California	NOS	9414523	37.50677777777778	-122.2115277777778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood City	CA
60852	Coyote Creek, Alviso Slough, San Francisco Bay, California	NOS	9414575	37.465	-122.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.869999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Creek	CA
60853	San Leandro Marina, San Francisco Bay, California	NOS	9414688	37.695	-122.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.920000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Leandro Marina	CA
60854	Oakland Harbor, Park Street Bridge, San Francisco Bay, California	NOS	9414746	37.7717	-122.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3800000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PARK STREET BRIDGE	CA
60855	Alameda, San Francisco Bay, California	NOS	9414750	37.7717	-122.3	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alameda	CA
60856	Oakland Inner Harbor, San Francisco Bay, California	NOS	9414764	37.795	-122.282	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor	CA
60857	Alameda Naval Air Station fuel pier, San Francisco Bay, California	NOS	9414767	37.7933	-122.315	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALAMEDA NAS, NAVY FUEL PIER	CA
60858	Sausalito, San Francisco Bay, California	NOS	9414806	37.8467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, SAN FRANCISCO BAY	CA
60859	Nurse Slough, Bradmoor Island, Suisun Bay, California	NOS	9414811	38.1833	-121.923	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradmoor Island	CA
60860	Berkeley, San Francisco Bay, California	NOS	9414816	37.8650016784668	-122.30699920654297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BERKELEY,S.F.BAY	CA
60861	Sausalito, Corps of Engineers Dock, San Francisco Bay, California	NOS	9414819	37.865	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, COE DOCK, S.F. BAY	CA
60862	Chevron Oil Company Pier, Richmond, San Francisco Bay, California	NOS	9414863	37.923	-122.4095833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	CA
60863	Bolinas, Bolinas Lagoon, California	NOS	9414958	37.907779693603516	-122.6786117553711	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolinas, Bolinas Lagoon	CA
60864	Drakes Bay, Point Reyes, California	NOS	9415020	37.99611282348633	-122.97666931152344	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Reyes	CA
60865	Blackslough Landing, San Joaquin River, California	NOS	9415021	37.99469444444444	-121.4190444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8400000000000318	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACKSLOUGH LANDING, SAN JOAQUIN RIVER	CA
60866	Pinole Point, San Pablo Bay, California	NOS	9415056	38.015	-122.363	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, San Pablo Bay	CA
60867	Antioch, San Joaquin River, California	NOS	9415064	38.02	-121.815	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANTIOCH, SAN JOAQUIN RIVER	CA
60868	Martinez-Amorco Pier, California	NOS	9415102	38.03463888888889	-122.1251944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martinez-Amorco Pier	CA
60869	Wards Island, Little Connection Slough, San Joaquin River, California	NOS	9415105	38.05002527777778	-121.4968555555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WARDS ISLAND, SAN JOAQUIN RIVER	CA
60870	Mallard Island Ferry Wharf, Suisun Bay, California	NOS	9415112	38.0433	-121.918	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MALLARD ISLAND, SUISUN BAY	CA
60871	Crockett, Carquinez Strait, California	NOS	9415143	38.0583	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROCKETT, CARQUINEZ STRAIT	CA
60872	Port Chicago, Suisun Bay, California	NOS	9415144	38.056	-122.0395	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chicago	CA
60873	Threemile Slough entrance, San Joaquin River, California	NOS	9415193	38.0867	-121.685	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREE MILE SLOUGH,SAN JOAQUIN R.	CA
60874	Mare Island Naval Shipyard, Carquinez Strait, California	NOS	9415218	38.07	-122.25	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island	CA
60875	Korths Harbor, San Joaquin River, California	NOS	9415229	38.09761	-121.568383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KORTHS HBR, SAN JOAQUIN RIVER	CA
60876	Petaluma River entrance, San Pablo Bay, California	NOS	9415252	38.11530555555556	-122.5056666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETALUMA RIVER ENTRANCE	CA
60877	Suisun Slough entrance, Suisun Bay, California	NOS	9415265	38.1283	-122.073	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.61	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUISUN SLOUGH ENTRANCE	CA
60878	Rio Vista, Sacramento River, California	NOS	9415316	38.145	-121.692	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rio Vista	CA
60879	Sonoma Creek, San Pablo Bay, California	NOS	9415338	38.1567	-122.407	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sonoma Creek Entrance	CA
60880	Lakeville, Petaluma River, California	NOS	9415423	38.1983	-122.547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKEVILLE, PETALUMA RIVER	CA
60881	Upper drawbridge, Petaluma River, San Pablo Bay, California	NOS	9415584	38.2283	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petaluma River, Upper Drawbridge	CA
60883	Arena Cove, California	NOS	9416841	38.91455555555556	-123.7110833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.139999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arena Cove	CA
60884	Noyo Harbor, Fort Bragg, California	NOS	9417426	39.42577777777778	-123.8051111111111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NOYO HARBOR	CA
60885	Shelter Cove, California	NOS	9418024	40.025001525878906	-124.05799865722656	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELTER COVE	CA
60886	Cockrobin Island Bridge, Eel River, San Francisco, California	NOS	9418637	40.63719940185547	-124.2822036743164	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cockrobin Island Bridge	CA
60887	Fields Landing, Humboldt Bay, California	NOS	9418723	40.7233	-124.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.72	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDS LANDING, HUMBOLDT BAY	CA
60888	North Spit, Humboldt Bay, California	NOS	9418767	40.7663	-124.2172	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Spit	CA
60889	Samoa, Humboldt Bay, California	NOS	9418817	40.8267	-124.18	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Samoa, Humboldt Bay	CA
60891	Crescent City, California	NOS	9419750	41.745	-124.183	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent City	CA
60892	Pyramid Point, Smith River, California	NOS	9419945	41.94525	-124.2009166666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.419999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pyramid Point	CA
60893	Gold Beach, Rogue River, Oregon	NOS	9431011	42.42163888888889	-124.4187222222222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9099999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gold Beach	OR
60894	Port Orford, Oregon	NOS	9431647	42.73897	-124.49827777756585	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Orford	OR
60895	Rink Creek Entrance, Coquille River, Oregon	NOS	9432436	43.157901763916016	-124.18180084228516	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.490000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coquille River	OR
60896	Charleston, Coos Bay, Oregon	NOS	9432780	43.345	-124.322	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston	OR
60897	Halfmoon Bay, Umpqua River, Oregon	NOS	9433445	43.675	-124.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Half Moon Bay	OR
60898	Reedsport, Umpqua River, Oregon	NOS	9433501	43.70830154418945	-124.0979995727539	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.950000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEDSPORT	OR
60900	Florence USCG Pier, Suislaw River, Oregon	NOS	9434098	44.00211111111111	-124.123	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence USCG Pier, Suislaw River	OR
60901	Waldport, Alsea Bay, Oregon	NOS	9434939	44.43436111111111	-124.0580833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldport	OR
60902	Weiser Point, Yaquina River, Oregon	NOS	9435308	44.5933	-124.008	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEISER POINT, YAQUINA RIVER	OR
60903	South Beach, Yaquina Bay and River, Oregon	NOS	9435380	44.625	-124.043	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.449999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach	OR
60904	Depoe Bay, Oregon	NOS	9435827	44.81	-124.058	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DEPOE BAY	OR
60905	Chinook Bend, Siletz River, Oregon	NOS	9435992	44.880001068115234	-123.9636001586914	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chinook Bend	OR
60906	Cascade Head, Salmon River, Oregon	NOS	9436381	45.04794444444445	-124.0073055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cascade Head, Salmon River	OR
60907	Dick Point, Tillamook Bay, Oregon	NOS	9437381	45.4817	-123.902	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dick Point	OR
60908	Garibaldi, Tillamook Bay, Oregon	NOS	9437540	45.55453	-123.91894444439146	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Garibaldi	OR
60909	North Jetty, Tillamook Bay, Oregon	NOS	9437585	45.56999969482422	-123.96499633789062	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.270000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH JETTY, TILLAMOOK BAY	OR
60910	North Fork, Nehalem River, Oregon	NOS	9437954	45.73379898071289	-123.87640380859375	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.440000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Fork	OR
60911	Cathcart Landing, Youngs River, Oregon	NOS	9438772	46.12425	-123.8043333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.659999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cathcart Landing	OR
60912	Hammond, Oregon	NOS	9439011	46.2017	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hammond	OR
60913	Tongue Point, Astoria, Columbia River, Oregon	NOS	9439040	46.20731	-123.76830555558205	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Astoria	OR
60914	Wauna, Columbia River, Oregon	NOS	9439099	46.16166687011719	-123.40888977050781	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	OR
60915	Rocky Point, Multnomah Channel, Oregon	NOS	9439189	45.6967	-122.868	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rocky Point	OR
60916	Saint Helens, Columbia River, Oregon	NOS	9439201	45.8633	-122.7962	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Helens	OR
60917	Portland, Morrison Street Bridge, Oregon	NOS	9439221	45.51	-122.673	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Morrison Street Bridge	OR
60918	Washougal, Columbia River, Washington	NOS	9440047	45.57830047607422	-122.38200378417969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WASHOUGAL, COLUMBIA RIVER	WA
60919	Beacon Rock State Park, Columbia River, Washington	NOS	9440079	45.62030029296875	-122.02030181884766	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon Rock State Park	WA
60920	Vancouver, Columbia River, Washington	NOS	9440083	45.63169444444444	-122.697	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3499999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vancouver	WA
60921	Knapp Landing, Columbia River, Washington	NOS	9440171	45.74169921875	-122.75499725341797	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KNAPP(THORNES)LNDG, WILLOW BAR	WA
60922	Temco Kalama Terminal, Columbia River, Washington	NOS	9440357	45.986698150634766	-122.83670043945312	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEMCO Kalama Terminal	WA
60943	Bangor Wharf, Washington	NOS	9445133	47.7483	-122.727	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	WA
60944	Union, Hood Canal, Washington	NOS	9445478	47.3583	-123.098	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UNION, HOOD CANAL	WA
60945	Bremerton, Sinclair Inlet, Port Orchard, Puget Sound, Washington	NOS	9445958	47.56169891357422	-122.62300109863281	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.82	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BREMERTON	WA
60946	Wauna, Carr Inlet, Puget Sound, Washington	NOS	9446291	47.378299713134766	-122.63400268554688	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	WA
60947	Tacoma, Commencement Bay, Sitcum Waterway, Puget Sound, Washington	NOS	9446484	47.26667	-122.41333333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacoma	WA
60923	Longview, Columbia River, Washington	NOS	9440422	46.10613888888889	-122.9541944444444	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Longview	WA
60924	Cape Horn, Columbia River, Washington	NOS	9440482	46.15169906616211	-123.29000091552734	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9899999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE HORN, COLUMBIA RIVER	WA
60925	Barlow Point, Columbia River, Washington	NOS	9440483	46.152198791503906	-123.03919982910156	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barlow Point	WA
60926	Skamokawa, Steamboat Slough, Columbia River, Washington	NOS	9440569	46.2667	-123.452	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skamokawa	WA
60927	Cape Disappointment, Washington	NOS	9440581	46.29999923706055	-124	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.039999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Disappointment	WA
60928	Greenhead Slough, Washington	NOS	9440650	46.37220001220703	-123.95030212402344	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.890000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenhead Slough	WA
60929	Nahcotta, Willapa Bay, Washington	NOS	9440747	46.5017	-124.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAHCOTTA, WILLAPA BAY	WA
60930	South Bend, Willapa River, Willapa Bay, Washington	NOS	9440875	46.6633	-123.798	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH BEND	WA
60931	Toke Point, Willapa Bay, Washington	NOS	9440910	46.70747	-123.96691666666004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.780000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toke Point	WA
60932	Westport, Point Chehalis, Grays Harbor, Washington	NOS	9441102	46.90431	-124.1050833331214	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westport	WA
60933	Aberdeen, Grays Harbor, Washington	NOS	9441187	46.9683	-123.853	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.6000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aberdeen	WA
60935	La Push, Quillayute River, Washington	NOS	9442396	47.91333333333333	-124.6369444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Push, Quillayute River	WA
60936	Tskawahyah Island, Cape Alava, Washington	NOS	9442705	48.17110061645508	-124.73690032958984	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tskawahyah Island, Cape Alava	WA
60937	Neah Bay, Strait Of Juan De Fuca, Washington	NOS	9443090	48.3702778	-124.6019444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Neah Bay	WA
60938	Sekiu, Clallam Bay, Strait of Juan de Fuca, Washington	NOS	9443361	48.2633	-124.297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEKIU, CLALLAM BAY	WA
60939	Jim Creek, Washington	NOS	9443551	48.187198638916016	-124.0625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.059999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jim Creek	WA
60940	Port Angeles, Strait Of Juan De Fuca, Washington	NOS	9444090	48.12472222222223	-123.4411388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Angeles	WA
60941	Port Townsend (Point Hudson), Admiralty Inlet, Washington	NOS	9444900	48.1129	-122.7595	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend	WA
60942	Foulweather Bluff, Washington	NOS	9445016	47.9267	-122.617	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.869999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff	WA
60948	Yoman Point, Anderson Island, Balch Passage, Puget Sound, Washington	NOS	9446705	47.18	-122.675	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOMAN POINT, ANDERSON ISLAND	WA
60949	Sandy Point, Anderson Island, Puget Sound, Washington	NOS	9446804	47.15299987792969	-122.67510223388672	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.619999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT ANDERSON ISLAND, PUGET SOUND	WA
60950	Budd Inlet, south of Gull Harbor, Washington	NOS	9446807	47.0983	-122.895	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.329999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUDD INLET, SOUTH OF GULL HARBOR	WA
60951	Seattle, Puget Sound, Washington	NOS	9447130	47.60264	-122.3393055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seattle	WA
60952	Everett, Washington	NOS	9447659	47.98	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EVERETT	WA
60953	Priest Point, Washington	NOS	9447717	48.03494444444444	-122.2271944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Point	WA
60954	Tulalip, Tulalip Bay, Washington	NOS	9447773	48.065	-122.288	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulalip, Tulalip Bay	WA
60955	Greenbank, Whidbey Island, Washington	NOS	9447883	48.105	-122.57	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bank	WA
60956	Naval Air Station Whidbey Island, Washington	NOS	9447973	48.34280014038086	-122.68579864501953	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.439999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAS Whidbey Island	WA
60957	Spee-Bi-Dah, Washington	NOS	9448009	48.08825	-122.3223333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spee-Bi-Dah	WA
60958	Tulare Beach, Port Susan, Washington	NOS	9448043	48.10680555555555	-122.3472777777778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.459999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulare Beach, Port Susan	WA
60959	Sneeoosh Point, Washington	NOS	9448576	48.4	-122.548	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sneeoosh Point	WA
60961	Deception Pass St. Park, Bowman Bay, Fidalgo I., Washington	NOS	9448614	48.415000915527344	-122.6520004272461	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.630000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOWMAN BAY, FIDALGO ISLAND	WA
60962	Turner Bay, Similk Bay, Washington	NOS	9448657	48.445	-122.555	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turner Bay	WA
60963	Swinomish Channel entrance, Padilla Bay, Washington	NOS	9448682	48.45830154418945	-122.51300048828125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.040000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swinomish	WA
60964	Village Point, Lummi Island, Washington	NOS	9449161	48.7167	-122.708	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.010000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VILLAGE POINT, LUMMI ISLAND	WA
60965	Cherry Point, Strait of Georgia, Washington	NOS	9449424	48.8633	-122.758	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.279999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point	WA
60966	Point Roberts, Strait of Georgia, Washington	NOS	9449639	48.974998474121094	-123.08300018310547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Roberts	WA
60967	Drayton Harbor, Blaine, Strait of Georgia, Washington	NOS	9449679	48.9917	-122.765	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blaine, Drayton Harbor	WA
60968	Waldron Island, Haro Strait, Washington	NOS	9449746	48.686798095703125	-123.03759765625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island	WA
60969	Rosario, East Sound, Orcas Island, Washington	NOS	9449771	48.64670181274414	-122.87000274658203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario, Orcas Island	WA
60970	Hanbury Point, Mosquito Pass, San Juan I., Haro Strait, Washington	NOS	9449828	48.5817	-123.17	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANBURY POINT, SAN JUAN ISLAND	WA
60971	Kanaka Bay, San Juan Island, Haro Strait, Washington	NOS	9449856	48.48500061035156	-123.08300018310547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanaka Bay, San Juan Island	WA
61040	Montague Island, Alaska	NOS	9454616	60.025	-147.592	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Island	AK
60972	Friday Harbor, San Juan Island, San Juan Channel, Washington	NOS	9449880	48.54530555555556	-123.0128888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.550000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Friday Harbor	WA
60973	Upright Head, Lopez Island, Washington	NOS	9449911	48.57170104980469	-122.88500213623047	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Head	WA
60974	Armitage Island, Thatcher Pass, Washington	NOS	9449932	48.535	-122.797	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.660000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Armitage Island	WA
60975	Richardson, Lopez Island, San Juan Channel, Washington	NOS	9449982	48.4467	-122.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richardson	WA
60976	Telegraph Bay, Washington	NOS	9449988	48.44329833984375	-122.80500030517578	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Telegraph Bay	WA
60977	Windy Cove entrance, Alaska	NOS	9450251	55.0354	-133.0238	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance to Windy Cove	AK
60998	Bushy Island, Snow Passage, Alaska	NOS	9451074	56.2767	-132.985	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUSHY ISLAND, SNOW PASSAGE	AK
61048	Seward, Resurrection Bay, Alaska	NOS	9455090	60.12	-149.4266667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seward	AK
60978	Dunbar Inlet GPS Tide Buoy, Alaska	NOS	9450286	55.0879	-132.81583	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.859999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dunbar Inlet GPS Tide Buoy	AK
60979	Custom House Cove, Mary Island, Alaska	NOS	9450296	55.1	-131.217	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Custom House Cove, Mary Island	AK
60980	Metlakatla, Port Chester, Alaska	NOS	9450314	55.1283	-131.567	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Metlakatla, Port Chester, AK	AK
60981	Hydaburg, Sukkwan Strait, Alaska	NOS	9450364	55.201698303222656	-132.822998046875	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hydaburg, Sukkwan Strait	AK
60982	Ketchikan, Tongass Narrows, Alaska	NOS	9450460	55.33183	-131.6261944442325	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketchikan	AK
60983	Trocadero Bay, Alaska	NOS	9450463	55.35166666666667	-132.9380555555556	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trocadero Bay	AK
60984	Craig, Klawock Inlet, Bucareli Bay, Alaska	NOS	9450551	55.4883	-133.142	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRAIG	AK
60986	Lindeman Cove, Kasaan Bay, Alaska	NOS	9450625	55.6017	-132.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.209999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lindeman Cove	AK
60987	Northern Carroll Inlet GPS Tide Buoy, Alaska	NOS	9450642	55.629	-131.362694	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.149999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northern Carroll Inlet GPS Tide Buoy	AK
60988	Nossuk Bay, Tonowek Bay, Gulf of Esquibel, Alaska	NOS	9450711	55.72166666666666	-133.35	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nossuk Bay	AK
60989	Magnetic Point, Union Bay, Earnest Sound, Alaska	NOS	9450753	55.78828333333333	-132.1908833333334	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magnetic Point, Union Bay, Earnest Sound	AK
60990	Burrough Bay, Behm Canal, Alaska	NOS	9450914	56.0383	-131.095	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrough Bay, Behm Canal	AK
60991	Thoms Point, Zimovia Strait, Alaska	NOS	9450970	56.1183	-132.078	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thoms Point	AK
60992	El Capitan Passage, Alaska	NOS	9450997	56.1633	-133.33	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.86	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EL Capitan Passage	AK
60993	Dry Pass, El Capitan Passage, Alaska	NOS	9450998	56.1633	-133.413	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dry Pass, EL Capitan Passage	AK
60994	Point Harrington, Clarence Strait, Alaska	NOS	9451005	56.1783	-132.697	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT HARRINGTON, CLARENCE STRAIT	AK
60995	Bradfield Canal, Alaska	NOS	9451012	56.1833	-131.572	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradfield Canal	AK
60996	Village Rock, Zimovia Strait, Alaska	NOS	9451037	56.22	-132.297	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Rock	AK
60997	Port Alexander, Baranof Island, Alaska	NOS	9451054	56.2467	-134.647	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Alexander	AK
60999	Reef Point, Stikine Strait, Alaska	NOS	9451124	56.3533	-132.553	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEF POINT, STIKINE STRAIT	AK
61000	Madan Bay, Clarence Strait, Alaska	NOS	9451152	56.3922	-132.169	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Madan Bay	AK
61001	Wrangell, Wrangell Island, Alaska	NOS	9451204	56.47	-132.387	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell	AK
61002	Monte Carlo Island, Keku Strait, Alaska	NOS	9451247	56.535	-133.767	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monte Carlo Island	AK
61003	Point Lockwood, Woewodski Island, Wrangell Narrows, Alaska	NOS	9451263	56.5583	-132.963	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.729999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lockwood	AK
61004	Beecher Pass, Wrangell Narrows, Alaska	NOS	9451287	56.595	-132.987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beecher Pass	AK
61005	Anchor Point, Wrangell Narrows, Alaska	NOS	9451317	56.6383	-132.927	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point	AK
61006	Papke's Landing, Wrangell Narrows, Alaska	NOS	9451346	56.6767	-132.933	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.540000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Papke's Landing	AK
61007	The Summit, Keku Strait, Alaska	NOS	9451349	56.68242222222222	-133.7369083333333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Summit	AK
61008	Golf Island, Necker Islands, Alaska	NOS	9451421	56.7867	-135.393	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golf Island	AK
61009	Leconte Bay, Frederick Sound, Alaska	NOS	9451422	56.7883	-132.502	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LECONTE BAY	AK
61010	Turn Point, Alaska	NOS	9451434	56.8	-132.98	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point	AK
61011	Entrance Island, Keku Strait, Alaska	NOS	9451438	56.8117	-133.787	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance Island	AK
61012	Red Bluff Bay, Baranof Island, Alaska	NOS	9451467	56.8567	-134.723	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.789999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bluff Bay, Baranof Island	AK
61013	Saginaw Bay, Kuiu Island, Frederick Sound, Alaska	NOS	9451497	56.90333333333334	-134.3030555555556	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Bay, Kuiu Island	AK
61014	Kake Harbor, Keku Strait, Alaska	NOS	9451528	56.94830555555556	-133.8947222222222	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.509999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor, Keku Strait	AK
61015	Sitka, Baronof Island, Sitka Sound, Alaska	NOS	9451600	57.05169444444444	-135.342	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.290000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitka	AK
61016	Baranof, Warm Spring Bay, Alaska	NOS	9451625	57.08833333333333	-134.825	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baranof,  Warm Spring Bay	AK
61017	Whitestone Narrows, Neva Strait, Alaska	NOS	9451741	57.25	-135.567	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.319999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITESTONE NARROWS, Neva Strait	AK
61018	The Brothers, Stephens Passage, Alaska	NOS	9451785	57.295	-133.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THE BROTHERS, STEPHENS PASSAGE	AK
61019	Scraggy Island, Alaska	NOS	9451805	57.34	-135.707	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scraggy Island	AK
61020	Sergius Narrows, Alaska	NOS	9451853	57.41	-135.627	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.97	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
61021	Provorotni Island, Alaska	NOS	9451936	57.515	-135.555	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.930000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provorotni Island	AK
61022	Target Island, Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	9451953	57.5333	-134.417	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Target Island, Mitchell Bay	AK
61023	Juneau, Gastineau Channel, Stephens Pass, Alaska	NOS	9452210	58.2983	-134.412	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau	AK
61024	Hawk Inlet Entrance, Alaska	NOS	9452294	58.085	-134.777	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet	AK
61025	False Bay, Chatham Strait, Alaska	NOS	9452328	57.9667	-134.935	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Bay, Chatham Strait	AK
61026	Skagway, Taiya Inlet, Lynn Canal, Alaska	NOS	9452400	59.45	-135.327	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagway, Taiya Inlet	AK
61027	Chilkat Inlet, Lynn Canal, Alaska	NOS	9452421	59.17	-135.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHILKAT INLET	AK
61028	Hoonah, Port Fredrick, Alaska	NOS	9452438	58.10755555555556	-135.4441944444444	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.910000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hoonah, Port Fredrick	AK
61030	Pelican Harbor, Lisianski Inlet, Alaska	NOS	9452611	57.95777777777778	-136.2267777777778	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pelican Harbor, Lisianski Inlet, AK	AK
61031	Elfin Cove, Port Althorp, Cross Sound, Alaska	NOS	9452634	58.19472	-136.34694444444443	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elfin Cove	AK
61032	Tarr Inlet, Glacier Bay, Alaska	NOS	9452749	58.96477777777778	-136.8775833333333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.780000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tarr Inlet, Glacier Bay	AK
61033	Yakutat, Yakutat Bay, Alaska	NOS	9453220	59.5485	-139.7334	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakutat, Yakutat Bay	AK
61034	Cordova, Orca Inlet, Prince William Sd, Alaska	NOS	9454050	60.5583	-145.755	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.739999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cordova	AK
61035	Valdez, Prince William Sound, Alaska	NOS	9454240	61.125	-146.362	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez	AK
61036	Perch Point, Montague Island, Alaska	NOS	9454561	60.1267	-147.395	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Perch Point	AK
61037	Wooded Islands, Montague Island, Alaska	NOS	9454562	59.875	-147.403	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
61038	Seal Island, Alaska	NOS	9454564	60.425	-147.41	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEAL ISLAND	AK
61041	South Arm, Knight Island, Bay of Isles, Alaska	NOS	9454652	60.3667	-147.7	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH ARM, KNIGHT ISLAND, BAY OF ISLES	AK
61042	Snug Harbor, Knight Island, Alaska	NOS	9454662	60.25	-147.717	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
61043	Herring Point, Knight Island, Prince William Sound, Alaska	NOS	9454691	60.475	-147.792	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERRING POINT, KNIGHT ISLAND, PR WIL SND	AK
61044	South Bay, Perry Island, Alaska	NOS	9454721	60.6717	-147.932	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PERRY ISLAND (SOUTH BAY)	AK
61045	Guguak, Alaska	NOS	9454751	60.1	-148.038	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guguak	AK
61046	Point Elrington, Elrington Island, Prince William Sound, Alaska	NOS	9454814	59.9383	-148.227	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.680000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Erlington, Erlington Island	AK
61049	Agnes Cove, Aialik Peninsula, Alaska	NOS	9455120	59.7733	-149.588	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGNES COVE	AK
61050	Aialik Bay, north end, Alaska	NOS	9455145	59.9533	-149.715	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.530000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK BAY, NORTH END	AK
61051	Aialik Sill, Aialik Bay, Alaska	NOS	9455146	59.885	-149.718	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.559999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK SILL, AIALIK BAY	AK
61052	Camp Cove, Harris Peninsula, Alaska	NOS	9455151	59.6933	-149.748	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP COVE, HARRIS PENNINSULA	AK
61053	Crater Bay, Harris Bay, Alaska	NOS	9455159	59.7133	-149.787	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRATER BAY, HARRIS BAY	AK
61054	Upper Northwestern Fiord, Harris Bay, Alaska	NOS	9455204	59.79	-150.032	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER NORTHWESTERN FIORD	AK
61055	Seldovia, Cook Inlet, Alaska	NOS	9455500	59.44052777777778	-151.7199444444445	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.559999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
61056	Kasitsna Bay, Kachemak Bay, Alaska	NOS	9455517	59.46830555555555	-151.565	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kasitsna Bay, Kachemak Bay	AK
61057	Bear Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455595	59.725	-151.023	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Cove, Kachemak Bay	AK
61058	Anchor Point, Cook Inlet, Alaska	NOS	9455606	59.77197222222223	-151.8670277777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.709999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, Cook Inlet	AK
61059	Ninilchik, Cook Inlet, Alaska	NOS	9455653	60.055	-151.682	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ninilchik, Cook Inlet	AK
61060	Cape Kasilof, Cook Inlet, Alaska	NOS	9455711	60.3367	-151.38	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kasilof	AK
61061	Kaligan Island (north end), Cook Inlet, Alaska	NOS	9455732	60.51169967651367	-151.95199584960938	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KALIGAN ISLAND (NORTH END),  COOK INLET	AK
61062	Chinulna Point, Cook Inlet, Alaska	NOS	9455735	60.5033	-151.283	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINULNA POINT, COOK INLET	AK
61063	Nikiski, Cook Inlet, Alaska	NOS	9455760	60.68330555555556	-151.398	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.290000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski	AK
61064	Point Possession, Alaska	NOS	9455866	61.0367	-150.413	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.260000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession	AK
61065	North Foreland, Alaska	NOS	9455869	61.04330555555556	-151.163	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Foreland	AK
61066	Fire Island, Cook Inlet, Alaska	NOS	9455912	61.1733	-150.213	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, Cook Inlet	AK
61067	Anchorage, Knik Arm, Cook Inlet, Alaska	NOS	9455920	61.2375	-149.8904	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchorage	AK
61068	Port Mackenzie, Cook Inlet, Alaska	NOS	9455934	61.2682991027832	-149.91700744628906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie	AK
61069	Goose Creek, Knik Arm, Cook Inlet, Alaska	NOS	9455963	61.3933	-149.847	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	17.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Creek, Cook Inlet	AK
61070	Nukshak Island, Shelikof Strait, Alaska	NOS	9456717	58.3917	-153.958	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NUKSHAK ISLAND, SHELIKOF STRAIT	AK
61071	Aguchik Island, Kukak Bay, Alaska	NOS	9456901	58.29	-154.27	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.22	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGUCHIK ISLAND, KUKAK BAY	AK
61072	Ouzinkie, Spruce Island, Alaska	NOS	9457287	57.9217	-152.498	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ouzinkie, Spruce Island	AK
61073	Kodiak, Women's Bay, Alaska	NOS	9457292	57.73027777777778	-152.5138888888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Island	AK
61074	Uzkosti Point, Kupreanof Strait, Alaska	NOS	9457376	57.9283	-152.812	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uzkosti Point	AK
61075	Port Lions, Kodiak Island, Alaska	NOS	9457391	57.87347222222222	-152.8671111111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.789999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lions, AK	AK
61077	Nachalni Island, Kupreanof Strait, Alaska	NOS	9457407	57.9783	-152.925	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nachalni Island	AK
61078	Terror Bay (southwest), Kodiak Island, Alaska	NOS	9457493	57.74402777777778	-153.1954722222222	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Terror Bay	AK
61079	Sitkalidak Island GPS Tide Buoy, Alaska	NOS	9457512	56.96572	-153.252194	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.340000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkalidak Island GPS Tide Buoy	AK
61080	Old Harbor, Kodiak Island, Alaska	NOS	9457527	57.20277777777778	-153.3038888888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.430000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OLD HARBOR, KODIAK ISLAND	AK
61081	West Raspberry Island, Alaska	NOS	9457535	58.10716666666666	-153.3401111111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.3500000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Raspberry Island	AK
61082	Japanese Bay, Kodiak Island, Alaska	NOS	9457634	56.96	-153.687	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Japanese Bay, Kodiak Island	AK
61083	Larsen Bay, Kodiak Island, Alaska	NOS	9457724	57.5333	-153.99	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.140000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Kodiak Island, AK	AK
61084	Geese Island GPS Tide Buoy, Alaska	NOS	9457726	56.594694	-153.996028	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island GPS Tide Buoy	AK
61086	Alitak, Lazy Bay, Alaska	NOS	9457804	56.8974	-154.248	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alitak	AK
61087	Puale Bay, Alaska	NOS	9458209	57.7067	-155.393	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puale Bay	AK
61088	Chirikof Island, Alaska	NOS	9458293	55.8083	-155.74	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chirikof Island	AK
61089	Chowiet Island, Semidi Island, Alaska	NOS	9458519	56.0517	-156.698	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chowiet island	AK
61091	Castle Bay, Northwest Arm, Alaska	NOS	9458907	56.2317	-158.347	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castle Bay	AK
61092	Hump Island, Kuiukta Bay, Alaska	NOS	9458964	56.1133	-158.598	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hump Island, Kuiukta Bay	AK
61093	Mitrofania Island, Alaska	NOS	9459016	55.89	-158.82	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mitrofania Island	AK
61094	Herendeen Island, Shumagin Islands, Alaska	NOS	9459163	55.06555555555556	-159.4186666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Herendeen Island, Shumagin Islands	AK
61095	Bird Island, Shumagin Bank, Shumagin Islands, Alaska	NOS	9459251	54.83522222222222	-159.7595555555556	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bird Island, Shumagin Bank	AK
61096	Sand Point, Popof Island, Alaska	NOS	9459450	55.33669444444445	-160.502	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Point	AK
61097	Zachary Bay, Unga Island, Shumagin Islands, Alaska	NOS	9459465	55.334999084472656	-160.61700439453125	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.969999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZACHARY BAY, UNGA IS (N. SIDE)	AK
61098	Dolgoi Harbor, Dolgoi Island, Alaska	NOS	9459758	55.121700286865234	-161.79200744628906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolgoi Harbor, Dolgoi Island	AK
61099	King Cove, Deer Passage, Alaska	NOS	9459881	55.05988888888889	-162.3261111111111	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6900000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	King Cove	AK
61100	Cold Bay, Alaska	NOS	9459949	55.2083	-162.698	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cold Bay	AK
61101	Attu, Massacre Bay, Alaska	NOS	9460150	52.84	173.195	:America/Adak	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Station 9460150 Massacre Bay, Attu Island is a historic station with tidal\nharmonic constants and tidal datums based upon a 06/1943 - 06/1944\ninstallation. Due to the remote nature of this area, there are no plans to\ncollect updated water level values in the vicinity of Attu Island, AK.  During\nthe 1943-1944 installation of this station NOAA was able to obtain and compute\na full suite of harmonic constants.  Therefore, this station is used as a\ncontrol station for predictions at other subordinate harmonic stations in the\nfar western Aleutian Islands.In order to provide tidal predictions\n(http://tidesandcurrents.noaa.gov/tide_predictions.shtml) for this station and\nits subordinate stations, it is necessary to provide the separation between\nMean Sea Level (MSL) and Mean Lower Low Water (MLLW) only.Therefore, MSL has\nbeen held fixed as station datum and MLLW referenced to MSL in order to remove\nany reference to the terrestrial system.  The removal of a terrestrial\nreference frame enables the relationship between MSL and MLLW to remain\nconsistent over time and not require a periodic National Tidal Datum Epoch\n(NTDE) update to accountant for sea level rise.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.94	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATTU, MASSACRE BAY	AK
61102	Sweeper Cove, Adak Island, Alaska	NOS	9461380	51.86330555555556	-176.632	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Adak Island	AK
61103	Atka, Nazan Bay, Atka Island, Alaska	NOS	9461710	52.232	-174.1726	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9699999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atka	AK
61104	Nikolski, Umnak Island, Alaska	NOS	9462450	52.94061	-168.8713055557675	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikolski	AK
61105	Unalaska, Dutch Harbor, Alaska	NOS	9462620	53.87919444444444	-166.5403055555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0799999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalaska	AK
61106	Biorka Village, Biverly Inlet, Alaska	NOS	9462645	53.82891666666667	-166.21625	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biorka Village, Biverly Inlet	AK
61107	Reef Bight, Alaska	NOS	9462662	54.13072222222223	-166.0993333333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.009999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reef Bight	AK
61108	Broad Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462676	54.06458333333333	-165.9370555555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Broad Bight	AK
61109	Akutan, Aleutian Islands, Alaska	NOS	9462694	54.13327777777778	-165.7773055555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1599999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan, Alaska	AK
61110	Green Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462705	54.11027777777778	-165.6613888888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8700000000000045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bight	AK
61111	Surf Bay, Akutan Bay, Alaska	NOS	9462711	54.15083333333333	-165.615	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surf Bay, Akutan Bay	AK
61112	Akun Cove, Akun Island, Aleutian Islands, Alaska	NOS	9462719	54.2333	-165.533	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Cove, Akun Island	AK
61113	Trident Bay, Akun Island, Aleutian Islands, Alaska	NOS	9462721	54.14	-165.527	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Bay, Akun Island	AK
61114	Rootok Island, Rootok Strait, Alaska	NOS	9462723	54.05222222222222	-165.5141666666667	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.830000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rootok Island	AK
61115	Tigalda Bay, Tigalda Island, Alaska	NOS	9462782	54.12	-164.977	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6199999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tigalda Bay, Tigalda Island	AK
61116	SE Tigalda Island, Aleutian Islands, Alaska	NOS	9462786	54.10180555555556	-164.9415833333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.960000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SE Tigalda Island, Pacific Ocean	AK
61117	Cape Sarichef, Unimak Island, Alaska	NOS	9462787	54.6	-164.928	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sarichef, Unimak Island	AK
61118	Scotch Cap, Unimak Island, Alaska	NOS	9462808	54.39363888888889	-164.7457222222222	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotch Cap, Unimak Island, AK	AK
61119	Cape Chunak, Unimak Island, Alaska	NOS	9462941	55.06427777777778	-163.5341666666667	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.289999999999992	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chunak, AK	AK
61120	Neumans Cove, Bechevin Bay, Aleutian Islands, Alaska	NOS	9462948	54.9667	-163.44	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEUMANS COVE	AK
61121	False Pass, Isanotski Strait, Unimak Island, Alaska	NOS	9462955	54.8583	-163.407	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Pass, Unimak Island	AK
61122	Isanotski Strait Entrance, Aleutian Islands, Alaska	NOS	9462961	54.77844444444445	-163.3642777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ISANOTSKI STRAIT ENTRANCE	AK
61123	Port Moller, Bristol Bay, Alaska	NOS	9463502	55.98569444444445	-160.5738888888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.830000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Moller	AK
61125	Village Cove, St. Paul Island, Bering Sea, Alaska	NOS	9464212	57.12530555555556	-170.2851666666667	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Cove, St Paul Island	AK
61127	Protection Point, Nushagak Bay, Alaska	NOS	9465056	58.5	-158.712	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PROTECTION POINT, NUSHAGAK BAY	AK
61170	Point Hope, Alaska	NOS	9491873	68.3417	-166.808	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3299999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hope	AK
61133	Clarks Point, Nushagak Bay, Alaska	NOS	9465261	58.8483	-158.552	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.97	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLARKS POINT, NUSHAGAK BAY	AK
61136	Snag Point, Dillingham, Alaska	NOS	9465374	59.04	-158.447	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.839999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snag Point, Dillingham	AK
61137	Platinum, Alaska	NOS	9465396	59.0467	-161.818	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Platinum, AK	AK
61138	Carter Bay, Kuskokwim Bay, Alaska	NOS	9465601	59.37801666666667	-162.0293333333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carter Bay, Kuskokwim Bay	AK
61139	Quinhagak (Kwinak), Kushkokwin River, Alaska	NOS	9465831	59.75055277777778	-161.9154361111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.449999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quinhagak (Kwinak), Kushkokwin River	AK
61140	Kinak Bay, Alaska	NOS	9465953	59.947528	-164.2107	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.760000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kinak Bay	AK
61141	Eastern Nunivak Island, Alaska	NOS	9466012	60.04294	-165.680583	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7700000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastern Nunivak Island	AK
61142	Popokamute (Kokokamute), Kuskokwim River, Alaska	NOS	9466057	60.12327777777778	-162.5003611111111	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Popokamute (Kokokamute), Kuskokwim River	AK
61143	Helmick Point (SE of), Kuskokwim River, Alaska	NOS	9466153	60.270301818847656	-162.4102020263672	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.760000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helmick Point	AK
61144	Mekoryuk, Mekoryuk River Entrance, Alaska	NOS	9466217	60.4167	-166.167	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mekoryuk, Mekoryuk River Entrance	AK
61145	Tooksook Bay, Nelson Island, Alaska	NOS	9466298	60.5167	-165.133	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.169999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nelson Island, Tooksook Bay	AK
61146	Lomavik, Alaska	NOS	9466328	60.554298400878906	-162.29710388183594	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lomavik	AK
61147	Bethel, Kuskokwim River, Alaska	NOS	9466477	60.8	-161.75	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bethel, Kuskokwim River, AK	AK
61148	Dall Point, Hooper Bay, Alaska	NOS	9466931	61.5317	-166.148	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dall Point	AK
61149	Nunam Iqua (Sheldon Point), Alaska	NOS	9467551	62.53294444444445	-164.8452777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nunam Iqua (Sheldon Point)	AK
61150	Northeast Cape, St. Lawrence Island, Alaska	NOS	9468039	63.3167	-168.967	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Cape, St. Lawrence Island	AK
61131	Hagemeister Island (north end), Alaska	NOS	9465234	58.7767	-160.777	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH END, HAGEMEISTER ISLAND	AK
61152	Savoonga, St. Lawrence Island, Alaska	NOS	9468258	63.67908333333333	-170.5371111111111	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savoonga	AK
61154	Unalakleet, Alaska	NOS	9468333	63.875	-160.788	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalakleet	AK
61155	Shaktoolik, Alaska	NOS	9468691	64.38022222222222	-161.2351388888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6699999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shaktoolik	AK
61156	Nome, Norton Sound, Alaska	NOS	9468756	64.49461111111111	-165.4396388888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nome, Norton Sound	AK
61157	Point Spencer, Port Clarence, Norton Sound, Alaska	NOS	9469237	65.2567	-166.847	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Spencer, Port Clarence	AK
61158	Teller, Port Clarence, Alaska	NOS	9469239	65.2667	-166.353	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TELLER, PORT CLARENCE	AK
61159	Lost River, Seward Peninsula, Alaska	NOS	9469338	65.39	-167.145	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOST RIVER, SEWARD PENINSULA	AK
61160	Tin City, Bering Sea, Alaska	NOS	9469439	65.55833333333334	-167.975	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.46999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tin City, Bering Sea	AK
61161	Outside Lopp Lagoon, Alaska	NOS	9469515	65.728806	-168.032139	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.480000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outside Lopp Lagoon	AK
61162	Deering, Kotzebue Sound, Alaska	NOS	9469751	66.09716666666667	-162.7404722222222	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deering	AK
61163	Goodhope Bay, Kotzebue Sound, Alaska	NOS	9469833	66.23030090332031	-163.9040985107422	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8800000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goodhope Bay	AK
61164	Shishmaref Inlet 2, Alaska	NOS	9469854	66.2633	-166.02	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shishmaref Inlet 2	AK
61165	Cape Espenberg, Kotzebue Sound, Alaska	NOS	9490096	66.58569444444444	-164.2508333333333	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5300000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Espenberg, Kotzebue Sound	AK
61166	Kotzebue, Kotzebue Sound, Alaska	NOS	9490424	66.9017	-162.582	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kotzebue	AK
61167	Cape Krusenstern, Kotzebue Sound, Alaska	NOS	9490571	67.05419444444445	-163.3212777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.23000000000000398	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Krusenstern	AK
61168	Red Dog Dock, Alaska	NOS	9491094	67.57580555555556	-164.0643888888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Dog Dock	AK
61169	Kivalina, Alaska	NOS	9491253	67.7267	-164.592	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kivalina	AK
61171	Barrow (offshore), Alaska	NOS	9494935	71.36011111111111	-156.7298611111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barrow Offshore	AK
61172	Prudhoe Bay, Alaska	NOS	9497645	70.41141666666667	-148.5317777777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prudhoe Bay	AK
61175	Barter Island, Alaska	NOS	9499176	70.12855555555555	-143.6110277777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.28000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barter Island	AK
61176	Leinster Point, Leinster Bay, St. John, Virgin Islands	NOS	9751309	18.36761111111111	-64.72072222222222	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Leinster Point, Leinster Bay, St. John's	VI
61177	Christiansted Harbor, St. Croix, Virgin Islands	NOS	9751364	17.75	-64.705	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Christiansted Harbor, St Croix	VI
61178	Coral Harbor, St. John, Virgin Islands	NOS	9751373	18.3483	-64.7167	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST JOHN'S ISLAND, CORAL HARBOR	VI
63368	Kizhuyak Bay, Alaska	NOS	9457401	57.82	-152.9	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:11:00	0	\N	00:06:00	0.8	\N	\N	\N	Kizhuyak Bay	AK
61179	Lameshur Bay, St. John, Virgin Islands	NOS	9751381	18.31824999994702	-64.72422222243415	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lameshur Bay, St John	VI
61180	Lime Tree Bay, St. Croix, Virgin Islands	NOS	9751401	17.69472222222222	-64.75380555555556	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.37000000000000455	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lime Tree Bay. St. Croix	VI
61181	Lovango Cay, St. John, Virgin Islands	NOS	9751467	18.36066666666667	-64.80352777777777	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovango Cay, St. John	VI
61182	Dog Island, St. Thomas, Virgin Islands	NOS	9751494	18.29713888888889	-64.81775	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog Island, St. Thomas	VI
61184	Water Bay, St. Thomas, Virgin Islands	NOS	9751583	18.34894444444445	-64.86416666666666	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5599999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Water Bay	VI
61185	Fredericksted, St. Croix, Virgin Islands	NOS	9751584	17.7133	-64.8833	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fredericksted, St. Croix	VI
61186	Charlotte Amalie, St. Thomas, Virgin Islands	NOS	9751639	18.33583333333333	-64.92	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlotte Amalie	VI
61187	Dorothea Bay, St. Thomas, Virgin Islands	NOS	9751768	18.37125	-64.96347222222222	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dorothea Bay, Saint Thomas	VI
61188	Botany Bay, St. Thomas, Virgin Islands	NOS	9751774	18.3633	-65.035	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Botany Bay, St. Thomas	VI
61189	Culebra, Puerto Rico	NOS	9752235	18.30086111111111	-65.30247222222222	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Culebra	PR
61190	Isabel Segunda, Vieques Island, Puerto Rico	NOS	9752619	18.15252777777778	-65.44380555555556	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isabel Segunda, Vieques Island	PR
61217	Waianae, Oahu Island, Hawaii	NOS	1612482	21.445	-158.192	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:18:00	\N	1	00:20:00	\N	0.93	\N	\N	Waianae	HI
61218	Haleiwa, Waialua Bay, Oahu Island, Hawaii	NOS	1612668	21.5983	-158.108	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-02:05:00	\N	0.8	-01:02:00	\N	0.8	\N	\N	Haleiwa, Waialua Bay	HI
61219	Kamalo Harbor, Molokai Island, Hawaii	NOS	1613077	21.0483	-156.877	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:16:00	0	\N	-00:37:00	0.1	\N	\N	\N	Kamalo Harbor	HI
61220	Pukoo Harbor, Molokai Island, Hawaii	NOS	1613155	21.0717	-156.8	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:48:00	0	\N	-01:03:00	0.1	\N	\N	\N	Pukoo Harbor	HI
61191	Esperanza, Vieques Island, Puerto Rico	NOS	9752695	18.09386111111111	-65.47136111111111	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Esperanza, Vieques Island	PR
61192	Isla Palominos, Puerto Rico	NOS	9752962	18.34497222222222	-65.5695	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7099999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isla Palominos	PR
61193	Fajardo, Puerto Rico	NOS	9753216	18.33522222222222	-65.63111111111111	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fajardo	PR
61194	Naguabo, Puerto Rico	NOS	9753641	18.18705555555556	-65.71138888888889	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naguabo	PR
60263	Montauk Point Light, Long Island Sound, New York	NOS	8510321	41.0717	-71.8567	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MONTAUK POINT LIGHT	NY
61195	Yabucoa Harbor, Puerto Rico	NOS	9754228	18.05508333333333	-65.833	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.34999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yabucoa Harbor	PR
61196	San Juan, La Puntilla, San Juan Bay, Puerto Rico	NOS	9755371	18.45916666666667	-66.11638888888889	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan, La Puntilla, San Juan Bay	PR
61197	Las Mareas, Puerto Rico	NOS	9755679	17.9283	-66.1583	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Las Mareas	PR
61198	Santa Isabel, Puerto Rico	NOS	9756639	17.955	-66.4067	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Isabel	PR
61199	Arecibo, Puerto Rico	NOS	9757809	18.48052777777778	-66.70236111111112	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arecibo	PR
61200	Peuelas (Punta Guayanilla), Puerto Rico	NOS	9758053	17.97252777777778	-66.76177777777778	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penuelas (Punta Guayanilla)	PR
61201	Magueyes Island, Caribbean Sea, Puerto Rico	NOS	9759110	17.97	-67.0463889	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magueyes Island	PR
61202	Puerto Real, Puerto Rico	NOS	9759189	18.07480555555556	-67.18877777777777	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puerto Real	PR
61203	Baha Salinas, Puerto Rico	NOS	9759197	17.95144444444444	-67.19658333333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bahia Salinas	PR
61204	Mayagez, Puerto Rico	NOS	9759394	18.21888888888889	-67.1625	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayaguez	PR
61205	Aguadilla, Crashboat Beach, Puerto Rico	NOS	9759412	18.45663888888889	-67.16458333333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aguadilla, Crashboat Beach	PR
61206	Punta Guanajibo, Mayagez, Puerto Rico	NOS	9759421	18.165	-67.1817	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA GUANAJABO, MAYAGUES	PR
61207	Mona Island, Puerto Rico	NOS	9759938	18.08991666687859	-67.93850000010596	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mona Island	PR
60677	Hawkins Recreational Park, Blackwater River, Florida	NOS	8729753	30.6367	-87.0283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAWKINS REC. PARK, BLACKWATER RIVER	FL
60899	Cushman, Suislaw River, Oregon	NOS	9434068	43.98500061035156	-124.04499816894531	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cushman	OR
60175	Augusta, MCRR Bridge, Kennebec River, Maine	NOS	8417144	44.32	-69.77028	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augusta, MCRR Bridge, Kennebec River	ME
60249	Sandy Point, Block Island Sound, Rhode Island	NOS	8459479	41.2283	-71.58	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT, BLOCK IS, SOUND	RI
60267	Threemile Harbor entrance, Gardiners Bay, Long Island, New York	NOS	8511171	41.035	-72.19	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREEMILE HARBOR ENTRANCE	NY
60305	College Pt, Ft. of 110th Street, Long Island, New York	NOS	8517276	40.7833	-73.8567	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLLEGE PT, FT. OF 110TH ST, LI	NY
60317	Spuyten Duyvil Creek Entrance, Hudson River, New York	NOS	8518903	40.8783	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPUYTEN DUYVIL CK, ENT., HUDSON R,	NY
60318	Riverdale, Hudson River, New York	NOS	8518905	40.9033	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERDALE, HUDSON RIVER	NY
60385	St. Michaels, Miles River, Chesapeake Bay, Maryland	NOS	8572342	38.7867	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAELS, MILES RIVER	MD
60411	Cape Charles Harbor (USCG Wharf), Chesapeake Bay, Virginia	NOS	8632366	37.2633	-76.02	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CHARLES HBR (U.S. G. WHARF)	VA
60424	New Point, Virginia	NOS	8637289	37.3467	-76.2733	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT	VA
60425	New Point (Comfort Shoal), Virginia	NOS	8637590	37.2567	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT, COMFORT SHOAL	VA
60431	Burwell Bay, James River, Virginia	NOS	8638421	37.0567	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BURWELL BAY, JAMES RIVER	VA
60495	Savannah (Bull Street), Georgia	NOS	8670681	32.0817	-81.0917	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BULL STREET, SAVANNAH RIVER	GA
60517	Cut 2N front range, St. Marys River, Florida	NOS	8720012	30.7167	-81.3017	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 2N FRONT RANGE, ST MARYS RIVER ENTR	FL
60552	Daytona Beach (ocean), Florida	NOS	8721020	29.2283	-81.005	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH (OCEAN)	FL
60559	Canaveral Harbor Entrance, Florida	NOS	8721608	28.4083	-80.6017	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CANAVERAL HARBOR ENTRANCE	FL
60569	Boynton Beach, Lake Worth, Florida	NOS	8722706	26.54829978942871	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOYNTON BEACH	FL
60666	Richardson Hammock, St. Joseph Bay, Florida	NOS	8728949	29.69	-85.3633	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RICHARDSON HAMMOCK, ST. JOSEPH BAY	FL
60675	Upper Blackwater River, Florida	NOS	8729738	30.6583	-86.9883	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER BLACKWATER RIVER	FL
60720	Keesler AFB, Back Bay, Biloxi, Mississippi	NOS	8744284	30.4183	-88.925	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEESLER AFB, BACK BAY OF BILOXI	MS
60721	Tchoutacabouffa River Entrance, Mississippi	NOS	8744663	30.4417	-88.9733	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tchoutacabouffa River Entrance	MS
60735	Venice, Grand Pass, Louisiana	NOS	8760849	29.2733	-89.3517	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GRAND PASS	LA
60743	Grand Isle, Mississippi River Delta, Louisiana	NOS	8761720	29.255	-89.9683	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND ISLE	LA
60762	Eugene Island, Atchafalaya Bay, Louisiana	NOS	8764311	29.3717	-91.385	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island	LA
60786	Sabine (offshore), Texas	NOS	8771081	29.4983	-93.64	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Offshore	TX
60844	North Point, Pier 41, San Francisco, San Francisco Bay, California	NOS	9414305	37.81	-122.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.22	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH POINT [PIER 41] S.F.BAY	CA
60849	Redwood Creek Marker 8, San Francisco Bay, California	NOS	9414501	37.5333	-122.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REDWOOD CREEK,C.M. NO. 8,S.F.BAY	CA
60890	Requa Dock, California	NOS	9419551	41.545	-124.07	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Requa Dock	CA
60934	Taholah, Washington	NOS	9441644	47.34817	-124.28475	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Taholah	WA
60960	Yokeko Point, Deception Pass, Washington	NOS	9448601	48.4133	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.95	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOKEKO POINT	WA
60985	Big Salt Lake, Alaska	NOS	9450623	55.6	-132.95	:America/Juneau	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Salt Lake	AK
61029	Muir Inlet, Glacier Bay, Alaska	NOS	9452584	58.9133	-136.108	:America/Juneau	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	8.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Muir Inlet, Glacier Bay	AK
63392	Beaver Bay, Alaska	NOS	9459522	55.4733	-160.84	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:02:00	\N	1.05	00:03:00	\N	1.01	\N	\N	Beaver Bay	AK
61230	Napoopoo, Kealakekua Bay, Hawaii Island, Hawaii	NOS	1618021	19.4767	-155.922	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60144	00:47:00	\N	0.67	00:48:00	\N	0.8	\N	\N	Napoopoo, Kealakekua Bay	HI
61039	Storey Island (north side), Alaska	NOS	9454571	60.7317	-147.437	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	6.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STOREY ISLAND NORTH SIDE	AK
61076	Dovolno Point, Kizhuyak Bay, Alaska	NOS	9457393	57.7394	-152.87472	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dovolno Point, Kizhuyak Bay	AK
61085	Uyak, Uyak Bay, Alaska	NOS	9457728	57.635	-154.007	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	7.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak	AK
61090	Sutwik Island, West End, Alaska	NOS	9458665	56.54	-157.327	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.91	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST END, SUTWIK ISLAND	AK
61124	Zapadni Bay, St. George Island, Alaska	NOS	9463885	56.57	-169.7	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZAPADNI BAY, ST. GEORGE ISLAND	AK
61126	Cape Constantine, Nushagak Peninsula, Alaska	NOS	9464961	58.521694	-159.152	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CONSTANTINE, NUSHAGAK PENINSULA	AK
61128	Pyrite Point, Bristol Bay, Alaska	NOS	9465123	58.62	-161.542	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PYRITE POINT, BRISTOL BAY	AK
61129	High Island, Bristol Bay, Alaska	NOS	9465173	58.721694	-160.427	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HIGH ISLAND, BRISTOL BAY	AK
61130	Black Rock, Walrus Islands, Nushagak Bay, Alaska	NOS	9465182	58.7083	-160.188	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACK ROCK, WALRUS IS BRISTOL B	AK
61132	Estus Point, Hagemeister Strait, Alaska	NOS	9465249	58.8083	-161.1	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.95	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTUS POINT, HAGEMEISTER STRAIT	AK
61134	Kulukak Point, Alaska	NOS	9465265	58.84	-159.647	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.53	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KULUKAK POINT	AK
61151	St. Michael, Norton Sound, Alaska	NOS	9468132	63.475	-162.027	:America/Nome	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAEL, NORTON SOUND	AK
61153	Akeftapak, St. Lawrence Island, Alaska	NOS	9468283	63.7185	-171.6447	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM HST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akeftapak, St. Lawrence Island	AK
61173	Prudhoe Bay #2, Alaska	NOS	9497649	70.3883	-148.51	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRUDHOE BAY #2	AK
61229	Kailua Kona, Hawaii Island, Hawaii	NOS	1617846	19.6433	-156	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60144	00:37:00	\N	0.67	00:38:00	\N	0.8	\N	\N	Kailua Kona	HI
61174	Cross Island (Dinkum Sands), Alaska	NOS	9497778	70.4917	-147.95	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROSS ISLAND, (DINKUM SANDS)	AK
61183	Benner Bay, St. Thomas, Virgin Islands	NOS	9751567	18.32	-64.87	:America/St_Thomas	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AST to 2002-01-01 12:00 AM AST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNER BAY	VI
60497	Palmer Johnson Shipyard, Wilmington River, Georgia	NOS	8670893	32.0233	-81.0467	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PALMER JOHNSON SHIPYARD, WILMINGTON R.	GA
61135	Summit Island, NE side, Togiak Bay, Alaska	NOS	9465283	58.8467	-160.21	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE SIDE SUMMIT ISLAND, TOGIAK BAY A	AK
61208	Nonopapa, Niihau Island, Hawaii	NOS	1610367	21.87	-160.235	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:11:00	\N	0.77	-00:16:00	\N	0.77	\N	\N	Nonopapa, Niihau Island	HI
61209	Port Allen, Hanapepe Bay, Kauai Island, Hawaii (sub)	NOS	1611347	21.9033	-159.592	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60136	-00:10:00	\N	1	-00:15:00	\N	1.01	\N	\N	Port Allen, Hanapepe Bay	HI
61210	Waimea Bay, Kauai Island, Hawaii	NOS	1611401	21.9567	-159.673	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60136	00:18:00	\N	0.91	00:07:00	\N	0.86	\N	\N	Waimea Bay	HI
61211	Hanamaulu Bay, Kauai Island, Hawaii	NOS	1611443	21.995	-159.335	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60136	00:04:00	\N	0.91	00:10:00	\N	1	\N	\N	Hanamaulu Bay	HI
61212	Hanalei Bay, Kauai Island, Hawaii	NOS	1611683	22.215	-159.502	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60136	-01:22:00	\N	0.91	-01:01:00	\N	1.07	\N	\N	Hanalei Bay	HI
61213	Hanauma Bay, Oahu Island, Hawaii	NOS	1612301	21.275	-157.697	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:45:00	\N	1	-00:59:00	\N	1	\N	\N	Hanauma Bay	HI
61214	Fort Kamehameha, Bishop Point, Pearl Harbor, Oahu Island, Hawaii (sub)	NOS	1612366	21.33	-157.967	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:06:00	\N	0.88	00:15:00	\N	1	\N	\N	Pearl Harbor Entrance, Bishop Point	HI
61215	Waimanalo, Oahu Island, Hawaii	NOS	1612376	21.335	-157.693	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60140	00:05:00	\N	0.75	00:11:00	\N	0.88	\N	\N	Waimanalo	HI
61216	Pearl Harbor, Ford Island Ferry Dock, Oahu Island, Hawaii (sub)	NOS	1612404	21.3683	-157.94	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:08:00	\N	0.88	00:16:00	\N	1.03	\N	\N	Pearl Harbor, Ford Island Ferry	HI
61221	Kaunakakai Harbor, Molokai Island, Hawaii (sub)	NOS	1613198	21.085	-157.032	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:14:00	\N	1.25	-00:10:00	\N	1.13	\N	\N	Kaunakakai	HI
61222	Kolo, Molokai Island, Hawaii	NOS	1613226	21.0933	-157.197	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:01:00	0	\N	00:05:00	0	\N	\N	\N	Kolo	HI
61223	Kaumalapau, Lanai Island, Hawaii	NOS	1614465	20.79	-156.995	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:03:00	0	\N	00:02:00	0.2	\N	\N	\N	Kaumalapau, Lanai Island	HI
61224	Makena, Maui Island, Hawaii	NOS	1615202	20.6567	-156.445	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60142	01:09:00	\N	0.54	01:21:00	\N	0.73	\N	\N	Makena	HI
61225	Hana, Maui Island, Hawaii	NOS	1615395	20.7617	-155.987	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60142	00:18:00	\N	0.54	00:40:00	\N	1.05	\N	\N	Hana	HI
61226	Kuheia Bay, Kahoolawe Island, Hawaii	NOS	1616696	20.595	-156.607	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:09:00	0	\N	-00:09:00	0.2	\N	\N	\N	Kuheia Bay	HI
61227	Mahukona, Hawaii Island, Hawaii	NOS	1617277	20.1867	-155.903	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60144	00:42:00	\N	0.67	00:38:00	\N	0.8	\N	\N	Mahukona	HI
61228	Kawaihae, Hawaii Island, Hawaii (sub)	NOS	1617433	20.0366	-155.8294	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60144	00:57:00	\N	0.6	01:01:00	\N	0.83	\N	\N	Kawaihae	HI
61231	Honuapo, Hawaii Island, Hawaii	NOS	1618578	19.0883	-155.553	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60144	00:33:00	\N	1	00:38:00	\N	1.01	\N	\N	Honuapo	HI
61232	East Island, French Frigate Shoals, Hawaii	NOS	1619222	23.7833	-166.208	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:08:00	\N	0.73	00:03:00	\N	0.73	\N	\N	East Island, French Frigate Shoals	HI
61233	Laysan Island, Hawaii	NOS	1619645	25.7667	-171.75	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	01:12:00	\N	0.5	01:02:00	\N	0.53	\N	\N	Laysan Island	HI
61234	Coffin Point, Coffin Neck, Maine (sub)	NOS	8410714	44.87	-67.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	00:33:00	\N	0.77	00:31:00	\N	0.94	\N	\N	Coffins Point	ME
61235	Garnet Point, Hersey Neck, Pennamquan River, Cobscook Bay, Maine (sub)	NOS	8410715	44.9233	-67.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	00:14:00	\N	1	00:11:00	\N	1.04	\N	\N	Garnet Point, Pennamquan River	ME
61236	Birch Islands, Cobscook Bay, Maine	NOS	8410875	44.875	-67.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	01:13:00	\N	0.75	00:59:00	\N	0.94	\N	\N	Birch Islands	ME
61237	Cutler (Farris Wharf), Little River, Maine (sub)	NOS	8411060	44.65702819824219	-67.20466613769531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	-00:19:00	\N	0.74	-00:10:00	\N	0.74	\N	\N	Cutler, Little River	ME
61238	Cutler Naval Base, Machias Bay, Maine (sub)	NOS	8411250	44.6417	-67.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	-00:15:00	\N	0.7	-00:06:00	\N	0.7	\N	\N	Cutler, Naval Radio Station	ME
61239	Stone Island, Machias Bay, Maine	NOS	8411411	44.6033	-67.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	-00:28:00	\N	0.68	-00:11:00	\N	0.68	\N	\N	Stone Island, Machias Bay	ME
61240	Machiasport, Machias River, Maine	NOS	8411467	44.6983	-67.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	-00:09:00	\N	0.69	00:01:00	\N	0.69	\N	\N	Machiasport, Machias River	ME
61241	Shoppee Point, Englishman Bay, Maine	NOS	8411696	44.615	-67.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	-00:13:00	\N	0.66	-00:05:00	\N	0.66	\N	\N	Shoppee Point, Englishman Bay	ME
61242	Steele Harbor Island, Maine	NOS	8411801	44.4933	-67.5433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:20:00	\N	1.27	-00:28:00	\N	1.27	\N	\N	Steele Harbor Island	ME
61243	Green Island, Petit Manan Bar, Maine	NOS	8412568	44.3717	-67.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:24:00	\N	1.16	-00:28:00	\N	1.16	\N	\N	Green Island, Petit Manan Bar	ME
61244	Milbridge, Narraguagus River, Maine (sub)	NOS	8412581	44.54	-67.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:05:00	\N	1.09	-00:15:00	\N	1.23	\N	\N	Millbridge, Narraguagus River, Maine	ME
61245	Prospect Harbor, Maine	NOS	8412932	44.4	-68.0217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:15:00	\N	1.15	-00:24:00	\N	1.15	\N	\N	Prospect Harbor	ME
61246	Winter Harbor, Frenchman Bay, Maine	NOS	8413079	44.3883	-68.0867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:10:00	\N	0.95	-00:01:00	\N	0.95	\N	\N	Winter Harbor, Frenchman Bay	ME
61247	Southwest Harbor, Mount Desert Island, Maine	NOS	8413564	44.275	-68.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	-00:27:00	\N	0.95	00:00:00	\N	0.96	\N	\N	Southwest Harbor	ME
61248	Bass Harbor, Mount Desert Island, Maine	NOS	8413651	44.2417	-68.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	-00:27:00	\N	0.93	00:04:00	\N	0.93	\N	\N	Bass Harbor	ME
61249	Ellsworth, Union River, Blue Hill Bay, Maine (sub)	NOS	8413801	44.535	-68.4217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:16:00	\N	0.97	00:15:00	\N	1	\N	\N	Ellsworth, Union River	ME
61250	Mackerel Cove, Swans Island, Blue Hill Bay, Maine (sub)	NOS	8413825	44.17	-68.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	-00:27:00	\N	0.93	00:02:00	\N	0.94	\N	\N	Mackerel Cove	ME
61251	Burnt Coat Harbor, Swans Island, Maine	NOS	8413857	44.145	-68.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:06:00	\N	0.88	-00:01:00	\N	0.89	\N	\N	Burnt Coat Harbor, Swans Island	ME
61252	Blue Hill Harbor, Blue Hill Bay, Maine	NOS	8414112	44.4083	-68.5633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:11:00	\N	0.95	00:09:00	\N	0.95	\N	\N	Blue Hill Harbor	ME
61253	Center Harbor, Eggemoggin Reach, Maine	NOS	8414168	44.2633	-68.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:12:00	\N	0.95	00:09:00	\N	0.95	\N	\N	Center Harbor	ME
61254	Isle Au Haut, Penobscot Bay, Maine	NOS	8414288	44.0733	-68.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	-00:27:00	\N	0.88	-00:01:00	\N	0.87	\N	\N	Isle Au Haut	ME
61255	Stonington, Deer Isle, Penobscot Bay, Maine	NOS	8414348	44.1533	-68.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:06:00	\N	0.9	00:08:00	\N	0.91	\N	\N	Stonington, Deer Isle	ME
61256	Little Deer Isle, Eggemoggin Reach, Maine	NOS	8414424	44.2917	-68.6933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:14:00	\N	0.93	00:16:00	\N	0.94	\N	\N	Little Deer Isle	ME
61257	Gross Point, Eastern Channel, Penobscot River, Maine	NOS	8414581	44.5367	-68.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:10:00	\N	0.98	-00:06:00	\N	0.99	\N	\N	Gross Point, Eastern Channel	ME
61258	Bangor, Penobscot River, Maine (sub)	NOS	8414612	44.785	-68.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:18:00	\N	0.87	-00:06:00	\N	1.25	\N	\N	Bangor	ME
61259	Castine, Penobscot Bay, Maine	NOS	8414672	44.3867	-68.7967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:11:00	\N	1	00:15:00	\N	0.95	\N	\N	Castine	ME
61260	Bucksport, Penobscot River, Maine	NOS	8414684	44.5717	-68.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:11:00	\N	1	-00:04:00	\N	1.01	\N	\N	Bucksport	ME
61261	Sandy Point, Penobscot River, Maine	NOS	8414692	44.505	-68.805	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:08:00	\N	0.98	00:06:00	\N	0.99	\N	\N	Sandy Point	ME
61262	Vinalhaven, Vinalhaven Island, Penobscot Bay, Maine	NOS	8414776	44.0433	-68.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:10:00	\N	0.88	00:09:00	\N	0.87	\N	\N	Vinalhaven, Vinalhaven Island	ME
61263	Winterport, Penobscot River, Maine	NOS	8414781	44.6367	-68.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:04:00	\N	0.92	-00:09:00	\N	1.11	\N	\N	Winterport	ME
61264	North Haven, Penobscot Bay, Maine	NOS	8414856	44.1267	-68.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:10:00	\N	0.9	00:13:00	\N	0.91	\N	\N	North Haven	ME
61265	Matinicus Harbor, Wheaton Island, Penobscot Bay, Maine	NOS	8414876	43.8617	-68.8817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	-00:27:00	\N	0.85	00:05:00	\N	0.85	\N	\N	Matinicus Harbor, Wheaton Island	ME
61266	Belfast, Penobscot Bay, Maine	NOS	8415191	44.4267	-69.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:04:00	\N	1.03	00:09:00	\N	0.97	\N	\N	Belfast	ME
61267	Rockland, Penobscot River, Maine (sub)	NOS	8415490	44.105	-69.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:06:00	\N	1.03	00:09:00	\N	0.93	\N	\N	Rockland	ME
61268	Thomaston, St. George River, Maine (sub)	NOS	8415709	44.0717	-69.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:03:00	\N	1.03	-00:04:00	\N	1.03	\N	\N	Thomaston	ME
61269	Tenants Harbor, Maine	NOS	8415809	43.965	-69.2167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:11:00	\N	1.02	-00:11:00	\N	1.02	\N	\N	Tenants Harbor	ME
61270	Otis Cove, St. George River, Maine	NOS	8415867	43.9867	-69.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:14:00	\N	1	-00:15:00	\N	1	\N	\N	Otis Cove	ME
61271	Port Clyde, St. George River, Maine	NOS	8415933	43.925	-69.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:07:00	\N	0.98	-00:11:00	\N	0.98	\N	\N	Port Clyde	ME
61272	Burnt Island, Georges Islands, Maine	NOS	8416028	43.8717	-69.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:12:00	\N	0.98	-00:13:00	\N	0.98	\N	\N	Burnt Island, Georges Islands	ME
61273	Monhegan Island, Maine	NOS	8416092	43.765	-69.3217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:09:00	\N	0.97	-00:13:00	\N	0.97	\N	\N	Monhegan Island	ME
61274	Friendship Harbor, Maine	NOS	8416141	43.97	-69.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:11:00	\N	0.99	-00:18:00	\N	0.99	\N	\N	Friendship Harbor	ME
61275	Waldoboro, Medomak River, Maine	NOS	8416224	44.0933	-69.3767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:04:00	\N	1.04	-00:16:00	\N	1.04	\N	\N	Waldoboro	ME
61276	Jones Neck, Medomak River, Maine	NOS	8416232	44.015	-69.38	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:05:00	\N	1	-00:10:00	\N	1	\N	\N	Jones Neck	ME
61277	Muscongus Harbor, Muscongus Sound, Maine	NOS	8416381	43.9667	-69.4417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:03:00	\N	0.99	-00:09:00	\N	0.99	\N	\N	Muscongus Harbor, Muscongus Sound	ME
61278	New Harbor, Muscongus Bay, Maine	NOS	8416501	43.875	-69.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:08:00	\N	0.97	-00:10:00	\N	0.97	\N	\N	New Harbor, Muscongus Bay	ME
61279	Pemaquid Harbor, Johns Bay, Maine	NOS	8416581	43.8767	-69.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:04:00	\N	0.97	-00:05:00	\N	0.97	\N	\N	Pemaquid Harbor, Johns Bay	ME
61280	Newcastle, Damariscotta River, Maine	NOS	8416608	44.0333	-69.5367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:25:00	\N	1.02	00:16:00	\N	1.02	\N	\N	Newcastle	ME
61281	East Boothbay, Damariscotta River, Maine	NOS	8416721	43.865	-69.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	East Boothbay	ME
61282	Damariscove Harbor, Damariscove Island, Maine	NOS	8416796	43.7583	-69.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:10:00	\N	0.97	-00:09:00	\N	0.97	\N	\N	Damariscove Harbor, Damariscove Island	ME
61283	Sheepscot (below rapids), Sheepscot River, Maine	NOS	8416804	44.05	-69.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:20:00	\N	1.05	00:20:00	\N	1.05	\N	\N	Sheepscot (below rapids)	ME
61284	Boothbay Harbor, Maine	NOS	8416828	43.85	-69.6283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:08:00	\N	0.97	-00:06:00	\N	0.97	\N	\N	Boothbay Harbor	ME
61285	Southport, Townsend Gut, Maine	NOS	8416908	43.8467	-69.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.98	00:01:00	\N	0.98	\N	\N	Southport, Townsend Gut	ME
61286	Wiscasset, Sheepscot River, Maine (sub)	NOS	8416921	44	-69.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:04:00	\N	1.03	00:16:00	\N	1.03	\N	\N	Wiscasset	ME
61287	Cross River entrance, Sheepscot River, Maine	NOS	8416928	43.925	-69.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:04:00	\N	1	00:07:00	\N	1	\N	\N	Cross River entrance	ME
61288	Back River, Sheepscot River, Maine	NOS	8416961	43.9583	-69.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:31:00	\N	1	00:34:00	\N	1	\N	\N	Back River	ME
61289	Isle of Springs, Sheepscot River, Maine	NOS	8416968	43.86	-69.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:04:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	Isle of Springs	ME
61313	Cow Island, Casco Bay, Maine	NOS	8418009	43.69	-70.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:00:00	\N	1	-00:01:00	\N	1	\N	\N	Cow Island	ME
61290	Robinhood, Sasanoa River, Sheepscot River, Maine	NOS	8417067	43.8533	-69.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:14:00	\N	0.97	00:14:00	\N	0.97	\N	\N	Robinhood, Sasanoa River	ME
61291	Mill Point, Sasanoa River, Sheepscot River, Maine	NOS	8417127	43.8867	-69.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:43:00	\N	0.97	00:35:00	\N	0.97	\N	\N	Mill Point, Sasanoa River	ME
61292	Fort Popham, Hunniwell Point, Kennebec River, Maine (sub)	NOS	8417177	43.755	-69.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:04:00	\N	0.92	00:09:00	\N	0.92	\N	\N	Fort Popham, Hunniwell Point	ME
61293	Phippsburg, Kennebec River, Maine	NOS	8417221	43.8183	-69.81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:28:00	\N	0.88	00:26:00	\N	0.88	\N	\N	Phippsburg	ME
61294	Bath, Kennebec River, Maine (sub)	NOS	8417227	43.925	-69.815	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:17:00	\N	0.7	01:01:00	\N	0.7	\N	\N	Bath	ME
61295	Sturgeon Island, Merrymeeting Bay, Kennebec River, Maine	NOS	8417271	43.9817	-69.835	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	02:04:00	\N	0.58	02:00:00	\N	0.58	\N	\N	Sturgeon Island, Merrymeeting Bay	ME
61296	Howard Point, New Meadows River, Casco Bay, Maine	NOS	8417367	43.89	-69.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.99	-00:05:00	\N	0.99	\N	\N	Howard Point, New Meadows River	ME
61297	Androscoggin River entrance, Kennebec River, Maine	NOS	8417377	43.95	-69.8883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	03:26:00	\N	0.52	02:24:00	\N	0.52	\N	\N	Androscoggin River entrance	ME
61298	Cundy Harbor, New Meadows River, Casco Bay, Maine	NOS	8417387	43.7883	-69.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:02:00	\N	0.98	-00:01:00	\N	0.98	\N	\N	Cundy Harbor, New Meadows River	ME
61299	Bowdoinham, Cathance River, Kennebec River, Maine	NOS	8417391	44.0083	-69.895	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	02:42:00	\N	0.63	02:34:00	\N	0.63	\N	\N	Bowdoinham, Cathance River	ME
61300	Brunswick, Androscoggin River, Kennebec River, Maine	NOS	8417527	43.9217	-69.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	04:36:00	\N	0.42	02:35:00	\N	0.42	\N	\N	Brunswick, Androscoggin River	ME
61301	Wilson Cove, Middle Bay, Casco Bay, Maine	NOS	8417553	43.825	-69.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:02:00	\N	1	00:02:00	\N	1	\N	\N	Wilson Cove, Middle Bay	ME
61302	South Harpswell, Potts Harbor, Casco Bay, Maine	NOS	8417647	43.7383	-70.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.98	00:02:00	\N	0.98	\N	\N	South Harpswell, Potts Harbor	ME
61303	South Freeport, Casco Bay, Maine	NOS	8417801	43.82	-70.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:10:00	\N	0.99	00:12:00	\N	0.99	\N	\N	South Freeport	ME
61304	Cliff Island, Luckse Sound, Casco Bay, Maine	NOS	8417821	43.695	-70.11	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:02:00	\N	1	-00:02:00	\N	1	\N	\N	Cliff Island, Luckse Sound	ME
61305	Doyle Point, Casco Bay, Maine	NOS	8417874	43.7517	-70.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:03:00	\N	0.88	-00:02:00	\N	1	\N	\N	Doyle Point	ME
61306	Great Chebeague Island, Casco Bay, Maine	NOS	8417881	43.7217	-70.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:02:00	\N	1.03	00:02:00	\N	1	\N	\N	Great Chebeague Island	ME
61307	Vaill Island, Casco Bay, Maine	NOS	8417911	43.6767	-70.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	1.03	00:05:00	\N	0.98	\N	\N	Vaill Island	ME
61308	Long Island, Casco Bay, Maine	NOS	8417941	43.69	-70.17	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Long Island	ME
61309	Prince Point, Casco Bay, Maine	NOS	8417948	43.7617	-70.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.99	00:00:00	\N	1	\N	\N	Prince Point	ME
61310	Great Diamond Island, Casco Bay, Maine	NOS	8417988	43.67	-70.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:00:00	\N	1.03	00:00:00	\N	1	\N	\N	Great Diamond Island	ME
61311	Cushing Island, Casco Bay, Maine	NOS	8417997	43.645	-70.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	1.03	00:01:00	\N	0.99	\N	\N	Cushing Island	ME
61312	Peak Island, Casco Bay, Maine	NOS	8418001	43.655	-70.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:08:00	\N	0.99	-00:04:00	\N	0.99	\N	\N	Peak Island	ME
61314	Falmouth Foreside, Casco Bay, Maine	NOS	8418015	43.7317	-70.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.97	00:01:00	\N	1	\N	\N	Falmouth Foreside	ME
61315	Portland Head Light, Casco Bay, Maine	NOS	8418031	43.6233	-70.2067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:01:00	\N	1	-00:02:00	\N	0.97	\N	\N	Portland Head Light	ME
61316	Presumpscot River Bridge, Casco Bay, Maine	NOS	8418137	43.6867	-70.2467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:04:00	\N	1.06	00:01:00	\N	1.01	\N	\N	Presumpscot River Bridge	ME
61317	Back Cove, Casco Bay, Maine	NOS	8418175	43.6767	-70.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:06:00	\N	0.97	00:02:00	\N	0.97	\N	\N	Back Cove	ME
61318	Fore River, Casco Bay, Maine	NOS	8418268	43.6417	-70.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:02:00	\N	1.03	00:02:00	\N	1	\N	\N	Fore River	ME
61319	Old Orchard Beach, Maine	NOS	8418557	43.5167	-70.3667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:06:00	\N	0.97	00:00:00	\N	0.97	\N	\N	Old Orchard Beach	ME
61320	Camp Ellis, Saco River Entrance, Maine (sub)	NOS	8418606	43.4617	-70.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:10:00	\N	1	00:03:00	\N	0.97	\N	\N	Camp Ellis, Saco River Entrance	ME
61321	Cape Porpoise, Maine	NOS	8418772	43.3667	-70.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:14:00	\N	0.95	00:12:00	\N	0.95	\N	\N	Cape Porpoise	ME
61322	Biddeford, Saco River, Maine (sub)	NOS	8418828	43.4917	-70.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:26:00	\N	0.97	00:12:00	\N	0.99	\N	\N	Biddeford, Saco River	ME
61323	Kennebunkport, Kennebunk River, Maine (sub)	NOS	8418911	43.3583	-70.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:05:00	\N	1	00:07:00	\N	0.97	\N	\N	Kennebunkport	ME
61730	Salem, Salem River, New Jersey	NOS	8537979	39.5767	-75.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:41:00	\N	0.76	00:49:00	\N	0.76	\N	\N	Salem	NJ
61324	Wells, Webhannet River, Maine (sub)	NOS	8419317	43.32	-70.56330555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:02:00	\N	0.97	00:06:00	\N	0.96	\N	\N	Wells, Webhannet River	ME
61325	Cape Neddick, Maine	NOS	8419399	43.1667	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:08:00	\N	1	00:02:00	\N	0.95	\N	\N	Cape Neddick	ME
61326	York Harbor, Maine	NOS	8419518	43.1317	-70.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:13:00	\N	0.95	00:03:00	\N	0.95	\N	\N	York Harbor	ME
61327	Fort Point, York Harbor, Maine	NOS	8419528	43.13	-70.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:10:00	\N	0.94	-00:04:00	\N	0.95	\N	\N	Fort Point, York Harbor	ME
61328	Seapoint, Cutts Island, Maine	NOS	8419590	43.085	-70.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:04:00	\N	0.96	00:01:00	\N	0.96	\N	\N	Seapoint, Cutts Island	ME
61329	Gerrish Island, Portsmouth Harbor, New Hampshire	NOS	8419688	43.0667	-70.6967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:03:00	\N	0.95	-00:02:00	\N	0.95	\N	\N	Gerrish Island	NH
61330	Kittery Point, Portsmouth Harbor, New Hampshire	NOS	8419807	43.0817	-70.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.96	-00:07:00	\N	0.96	\N	\N	Kittery Point	NH
61331	Seavey Island, Portsmouth Harbor, New Hampshire (sub)	NOS	8419870	43.08	-70.7417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:18:00	\N	0.89	00:20:00	\N	0.89	\N	\N	Seavey Island	NH
61332	Salmon Falls River, Piscataqua River, New Hampshire	NOS	8419997	43.1917	-70.825	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:52:00	\N	0.75	01:35:00	\N	0.75	\N	\N	Salmon Falls River	NH
61333	Dover, Cocheco River, Piscataqua River, New Hampshire (sub)	NOS	8420411	43.1983	-70.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:39:00	\N	0.76	01:45:00	\N	0.77	\N	\N	Dover, Cocheco River	NH
61334	Dover Point, Piscataqua River, New Hampshire	NOS	8421897	43.1217	-70.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:27:00	\N	0.7	01:33:00	\N	0.7	\N	\N	Dover Point	NH
61335	Squamscott River RR. Bridge, Piscataqua River, New Hampshire	NOS	8422687	43.0533	-70.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	02:41:00	\N	0.75	02:19:00	\N	0.75	\N	\N	Squamscott River RR. Bridge	NH
61336	Atlantic Heights, Piscataqua River, New Hampshire	NOS	8423635	43.09	-70.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:28:00	\N	0.82	00:37:00	\N	0.82	\N	\N	Atlantic Heights	NH
61337	Portsmouth, Portsmouth Harbor, New Hampshire	NOS	8423745	43.0783	-70.7517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:17:00	\N	0.86	00:22:00	\N	0.86	\N	\N	Portsmouth	NH
61338	Fort Point, Portsmouth Harbor, New Hampshire (sub)	NOS	8423898	43.071388244628906	-70.71055603027344	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:07:00	\N	0.94	00:03:00	\N	0.94	\N	\N	Fort Point	NH
61339	Jaffrey Point, Portsmouth Harbor, New Hampshire	NOS	8424601	43.0567	-70.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:05:00	\N	0.95	-00:03:00	\N	0.95	\N	\N	Jaffrey Point	NH
61340	Gosport Harbor, Isles of Shoals, New Hampshire	NOS	8427031	42.9783	-70.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:02:00	\N	0.93	00:02:00	\N	0.93	\N	\N	Gosport Harbor, Isles of Shoals	NH
61341	Hampton Harbor, New Hampshire	NOS	8429489	42.895	-70.8167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:32:00	\N	0.91	00:14:00	\N	0.91	\N	\N	Hampton Harbor	NH
61342	Salisbury Point, Merrimack River, Massachusetts (sub)	NOS	8440273	42.8383	-70.9083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:18:00	\N	0.56	00:55:00	\N	0.83	\N	\N	Salisbury Point	MA
61343	Merrimacport, Merrimack River, Massachusetts (sub)	NOS	8440369	42.825	-70.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	02:08:00	\N	0.5	01:26:00	\N	0.76	\N	\N	Merrimacport	MA
61344	Plum Island, Merrimack River Entrance, Merrimack River, Massachusetts (sub)	NOS	8440452	42.8167	-70.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:29:00	\N	0.88	00:06:00	\N	0.88	\N	\N	Plum Island, Merrimack River Entrance	MA
61345	Newburyport, Merrimack River, Massachusetts (sub)	NOS	8440466	42.815	-70.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:11:00	\N	0.86	00:31:00	\N	0.86	\N	\N	Newburyport	MA
61346	Riverside, Merrimack River, Massachusetts (sub)	NOS	8440889	42.7633	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	03:30:00	\N	0.35	01:56:00	\N	0.62	\N	\N	Riverside	MA
61347	Plum Island Sound (south end), Massachusetts (sub)	NOS	8441241	42.71013888888889	-70.78861111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:37:00	\N	0.94	00:12:00	\N	0.94	\N	\N	Plum Island Sound (south end)	MA
61348	Rockport Harbor, Massachusetts (sub)	NOS	8441551	42.6583	-70.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:06:00	\N	0.97	00:06:00	\N	0.95	\N	\N	Rockport	MA
61349	Annisquam, Lobster Cove, Massachusetts	NOS	8441571	42.655	-70.6767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:03:00	\N	0.97	00:11:00	\N	0.97	\N	\N	Annisquam, Lobster Cove	MA
61350	Essex, Essex River, Massachusetts (sub)	NOS	8441771	42.6317	-70.7767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:31:00	\N	0.94	00:22:00	\N	1	\N	\N	Essex	MA
61351	Gloucester Harbor, Massachusetts	NOS	8441841	42.61	-70.66	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:04:00	\N	0.97	00:00:00	\N	0.93	\N	\N	Gloucester Harbor	MA
61352	Salem, Salem Harbor, Massachusetts (sub)	NOS	8442645	42.5233	-70.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:05:00	\N	0.97	-00:02:00	\N	0.94	\N	\N	Salem, Salem Harbor	MA
61353	Lynn, Lynn Harbor, Massachusetts (sub)	NOS	8443187	42.4583	-70.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:03:00	\N	1	00:01:00	\N	0.97	\N	\N	Lynn, Lynn Harbor	MA
61354	Amelia Earhart Dam, Mystic River, Boston Harbor, Massachusetts (sub)	NOS	8443662	42.395	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:02:00	\N	0.97	00:01:00	\N	1.01	\N	\N	Amelia Earhart Dam, Mystic River	MA
61355	Chelsea St. Bridge, Chelsea River, Boston Harbor, Massachusetts (sub)	NOS	8443725	42.3867	-71.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:06:00	\N	1.01	00:01:00	\N	1.01	\N	\N	Chelsea St. Bridge, Chelsea River	MA
61356	Charlestown, Charles River entrance, Boston Harbor, Massachusetts	NOS	8443838	42.3717	-71.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:01:00	\N	1	00:00:00	\N	1	\N	\N	Charlestown, Charles River entrance	MA
61357	Deer Island (south end), Boston Harbor, Massachusetts	NOS	8444012	42.3483	-70.96	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:00:00	\N	0.97	00:01:00	\N	0.97	\N	\N	Deer Island (south end)	MA
61358	Boston Light, Boston Harbor, Massachusetts (sub)	NOS	8444162	42.3283	-70.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:02:00	\N	0.97	-00:01:00	\N	0.95	\N	\N	Boston Light	MA
61359	Moon Head, Boston Harbor, Massachusetts	NOS	8444312	42.3083	-70.9917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:04:00	\N	0.99	00:01:00	\N	0.99	\N	\N	Moon Head	MA
61360	Hull, Massachusetts	NOS	8444351	42.3033	-70.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:07:00	\N	0.97	00:05:00	\N	0.97	\N	\N	Hull	MA
61361	Neponset, Neponset River, Boston Harbor, Massachusetts	NOS	8444488	42.285	-71.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:03:00	\N	1	-00:02:00	\N	1	\N	\N	Neponset, Neponset River	MA
61362	Nut Island, Quincy Bay, Massachusetts (sub)	NOS	8444525	42.28	-70.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:01:00	\N	1	00:01:00	\N	0.99	\N	\N	Nut Island, Quincy Bay	MA
61363	Nantasket Beach, Weir River, Massachusetts	NOS	8444601	42.27	-70.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:07:00	\N	0.99	00:06:00	\N	0.99	\N	\N	Nantasket Beach, Weir River	MA
61364	Crow Point, Hingham Harbor entrance, Massachusetts	NOS	8444662	42.2617	-70.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:05:00	\N	0.99	00:02:00	\N	0.99	\N	\N	Crow Point, Hingham Harbor entrance	MA
61365	Cohasset Harbor (White Head), Massachusetts	NOS	8444762	42.2483	-70.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:02:00	\N	0.92	00:04:00	\N	0.92	\N	\N	Cohasset Harbor (White Head)	MA
61366	Hingham, Massachusetts	NOS	8444775	42.2467	-70.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:08:00	\N	1	00:09:00	\N	1	\N	\N	Hingham	MA
61367	Shipyard Point, Weymouth Fore River, Massachusetts (sub)	NOS	8444788	42.2483	-70.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:06:00	\N	1	00:09:00	\N	1	\N	\N	Weymouth Fore River Bridge	MA
61368	Scituate, Scituate Harbor, Massachusetts (sub)	NOS	8445138	42.2017	-70.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:01:00	\N	1.03	00:03:00	\N	0.95	\N	\N	Scituate, Scituate Harbor	MA
61369	Damons Point, North River, Massachusetts	NOS	8445425	42.16	-70.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:36:00	\N	0.89	00:20:00	\N	0.89	\N	\N	Damons Point, North River	MA
61370	Brant Rock, Green Harbor River, Massachusetts (sub)	NOS	8446009	42.0833	-70.6467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:03:00	\N	1.03	00:05:00	\N	0.96	\N	\N	Brant Rock, Green Harbor River	MA
61371	Provincetown, Cape Cod, Massachusetts (sub)	NOS	8446121	42.04959166666666	-70.18215833333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:18:00	\N	0.95	00:16:00	\N	0.95	\N	\N	Provincetown	MA
61372	Duxbury, Duxbury Harbor, Cape Cod Bay, Massachusetts (sub)	NOS	8446166	42.0383	-70.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:33:00	\N	1.03	00:06:00	\N	1.04	\N	\N	Duxbury, Duxbury Harbor	MA
61373	Plymouth Harbor, Plymouth, Cape Cod Bay, Massachusetts (sub)	NOS	8446493	41.96	-70.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:18:00	\N	1	00:04:00	\N	1.03	\N	\N	Plymouth	MA
61374	Wellfleet, Cape Cod Bay, Massachusetts	NOS	8446613	41.93	-70.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:30:00	\N	1.05	00:14:00	\N	1.05	\N	\N	Wellfleet	MA
61375	Cape Cod Canal (Sta. 115), Sagamore, Cape Cod Bay, Massachusetts (sub)	NOS	8447173	41.775	-70.535	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:06:00	\N	0.88	-00:15:00	\N	0.83	\N	\N	Cape Cod Canal, Sagamore	MA
61376	Cape Cod Canal, Sandwich, Cape Cod Bay, Massachusetts (sub)	NOS	8447180	41.7717	-70.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:03:00	\N	0.68	-00:01:00	\N	0.91	\N	\N	Sandwich Marina, Cape Cod Canal, east entrance	MA
61377	Cape Cod Canal (Sta. 200), Bournedale, Cape Cod Bay, Massachusetts (sub)	NOS	8447191	41.77	-70.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:21:00	\N	0.79	-00:29:00	\N	0.66	\N	\N	Cape Cod Canal, Bournedale	MA
61378	Sesuit Harbor, East Dennis, Cape Cod Bay, Massachusetts (sub)	NOS	8447241	41.7517	-70.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:01:00	\N	0.82	00:02:00	\N	1.02	\N	\N	Sesuit Harbor, East Dennis	MA
61379	Cape Cod Canal (Sta. 320), Bourne Bridge, Cape Cod Bay, Massachusetts (sub)	NOS	8447259	41.745	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:24:00	\N	0.79	-01:13:00	\N	0.46	\N	\N	Cape Cod Canal, Bourne Bridge	MA
61380	Cape Cod Canal, RR. bridge, Buzzards Bay, Massachusetts (sub)	NOS	8447270	41.7417	-70.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	02:50:00	\N	1.01	01:17:00	\N	1.01	\N	\N	Cape Cod Canal, RR. bridge	MA
61381	Onset Beach, Onset Bay, Buzzards Bay, Massachusetts	NOS	8447277	41.7417	-70.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:25:00	\N	1.03	00:41:00	\N	1.03	\N	\N	Onset Beach, Onset Bay	MA
61382	Steep Brook, Taunton River, Narragansett Bay, Rhode Island	NOS	8447281	41.74	-71.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:05:00	\N	1.29	00:26:00	\N	1.3	\N	\N	Steep Brook, Taunton River	RI
61383	Pleasant Bay, Cape Cod, Massachusetts	NOS	8447291	41.7367	-69.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	03:27:00	\N	0.34	02:28:00	\N	0.34	\N	\N	Pleasant Bay	MA
61384	Gray Gables, Buzzards Bay, Massachusetts (sub)	NOS	8447295	41.735	-70.6233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:16:00	\N	1.21	00:37:00	\N	1.05	\N	\N	Gray Gables	MA
61385	Barnstable Harbor, Beach Point, Cape Cod Bay, Massachusetts	NOS	8447335	41.7217	-70.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:30:00	\N	1	00:11:00	\N	1	\N	\N	Barnstable Harbor, Beach Point	MA
61386	Monument Beach, Buzzards Bay, Massachusetts	NOS	8447355	41.715	-70.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:30:00	\N	1.15	00:16:00	\N	1.15	\N	\N	Monument Beach	MA
61387	Great Hill, Buzzards Bay, Massachusetts (sub)	NOS	8447368	41.7117	-70.715	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:12:00	\N	1.21	00:12:00	\N	1.14	\N	\N	Great Hill	MA
61388	Marion, Sippican Harbor, Buzzards Bay, Massachusetts	NOS	8447385	41.705	-70.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:12:00	\N	1.29	00:10:00	\N	1.13	\N	\N	Marion, Sippican Harbor	MA
61389	Fall River, Narragansett Bay, Massachusetts (sub)	NOS	8447386	41.70430555555556	-71.16411111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:03:00	\N	1.21	00:18:00	\N	1.25	\N	\N	Fall River, Massachusetts	MA
61390	Piney Point, Buzzards Bay, Massachusetts (sub)	NOS	8447416	41.695	-70.72	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:10:00	\N	1.21	00:10:00	\N	1.13	\N	\N	Piney Point	MA
61391	Chatham, Cape Cod, Massachusetts (sub)	NOS	8447435	41.68847222222222	-69.95108333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	01:57:00	\N	0.35	01:08:00	\N	0.48	\N	\N	Chatham Harbor, Aunt Lydias Cove	MA
61392	Texas Tower, Georges Shoal	NOS	8447436	41.6883	-67.76	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:43:00	\N	0.44	-00:47:00	\N	0.44	\N	\N	Georges Shoal, Texas Tower	\N
61393	Saquatucket Harbor, Nantucket Sound, Massachusetts (sub)	NOS	8447495	41.6683	-70.0567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:16:00	\N	0.41	00:46:00	\N	0.41	\N	\N	Saquatucket Harbor	MA
61394	South Yarmouth, Bass River, Nantucket Sound, Massachusetts	NOS	8447504	41.665	-70.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	01:46:00	\N	0.29	01:48:00	\N	0.29	\N	\N	South Yarmouth, Bass River	MA
61395	Chatham, Stage Harbor, Cape Cod, Massachusetts (sub)	NOS	8447505	41.6667	-69.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:19:00	\N	0.43	00:46:00	\N	0.43	\N	\N	Chatham, Stage Harbor	MA
61396	Wychmere Harbor, Nantucket Sound, Massachusetts	NOS	8447506	41.665	-70.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:25:00	\N	0.39	00:52:00	\N	0.39	\N	\N	Wychmere Harbor	MA
61397	Dennisport, Nantucket Sound, Massachusetts	NOS	8447525	41.6583	-70.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:38:00	\N	0.36	01:03:00	\N	0.36	\N	\N	Dennisport	MA
61398	Mattapoisett, Mattapoisett Harbor, Buzzards Bay, Massachusetts	NOS	8447531	41.6567	-70.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:20:00	\N	1	00:11:00	\N	1.09	\N	\N	Mattapoisett, Mattapoisett Harbor	MA
61399	New Bedford, Buzzards Bay, Massachusetts	NOS	8447584	41.64	-70.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:07:00	\N	1.05	00:07:00	\N	1.05	\N	\N	New Bedford	MA
61400	Cotuit Highlands, Nantucket Sound, Massachusetts	NOS	8447675	41.6083	-70.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:47:00	\N	0.26	01:17:00	\N	0.26	\N	\N	Cotuit Highlands	MA
61401	Clarks Point, New Bedford, Buzzards Bay, Massachusetts (sub)	NOS	8447712	41.5933	-70.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:23:00	\N	1.07	00:14:00	\N	1.03	\N	\N	Clarks Point	MA
61402	Poponesset Island, Poponesset Bay, Nantucket Sound, Massachusetts	NOS	8447742	41.5867	-70.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	01:52:00	\N	0.24	02:03:00	\N	0.24	\N	\N	Poponesset Island, Poponesset Bay	MA
61403	Hix Bridge, East Branch, Westport River, Massachusetts	NOS	8447791	41.57	-71.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	02:30:00	\N	0.77	01:40:00	\N	0.77	\N	\N	Hix Bridge, East Branch	MA
61404	Round Hill Point, Buzzards Bay, Massachusetts (sub)	NOS	8447842	41.5383	-70.9283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:22:00	\N	1	00:14:00	\N	0.99	\N	\N	Round Hill Point	MA
61405	Falmouth Heights, Nantucket Sound, Massachusetts	NOS	8447865	41.545	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:09:00	\N	0.14	-00:16:00	\N	0.14	\N	\N	Falmouth Heights	MA
61406	Little Harbor, Woods Hole, Massachusetts	NOS	8447939	41.52	-70.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	02:21:00	\N	0.4	00:32:00	\N	0.4	\N	\N	Little Harbor	MA
61407	Uncatena Island (south side), Woods Hole, Massachusetts	NOS	8447941	41.52	-70.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:22:00	\N	1.02	00:12:00	\N	1.02	\N	\N	Uncatena Island (south side)	MA
61408	Westport Harbor, Westport River, Massachusetts	NOS	8447975	41.5083	-71.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:33:00	\N	0.85	00:09:00	\N	0.85	\N	\N	Westport Harbor	MA
61409	Oak Bluffs, Martha's Vineyard, Massachusetts	NOS	8448208	41.4583	-70.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	03:47:00	\N	0.71	03:59:00	\N	0.5	\N	\N	Oak Bluffs	MA
61410	Penikese Island, Buzzards Bay, Massachusetts (sub)	NOS	8448248	41.45	-70.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:16:00	\N	0.97	-00:17:00	\N	0.97	\N	\N	Penikese Island	MA
61411	Quicks Hole, North side, Massachusetts	NOS	8448251	41.4483	-70.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:08:00	\N	0.99	-00:08:00	\N	0.99	\N	\N	Quicks Hole, North side	MA
61412	Cedar Tree Neck, Martha's Vineyard, Massachusetts	NOS	8448325	41.435	-70.6967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:32:00	\N	0.62	00:10:00	\N	0.62	\N	\N	Cedar Tree Neck	MA
61413	Cuttyhunk, Massachusetts	NOS	8448376	41.425	-70.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:15:00	\N	0.93	01:20:00	\N	0.97	\N	\N	Cuttyhunk	MA
61414	Edgartown, Martha's Vineyard, Massachusetts (sub)	NOS	8448558	41.3883	-70.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:18:00	\N	0.2	00:57:00	\N	0.2	\N	\N	Edgartown	MA
61415	Great Point, Nantucket Island, Massachusetts	NOS	8448566	41.3867	-70.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:28:00	\N	0.32	00:43:00	\N	0.32	\N	\N	Great Point	MA
61416	Wasque Point, Chappaquiddick Island, Martha's Vineyard, Massachusetts	NOS	8448683	41.3633	-70.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	03:20:00	\N	0.31	02:02:00	\N	0.31	\N	\N	Wasque Point, Chappaquiddick Island	MA
61417	Gay Head, Martha's Vineyard, Massachusetts	NOS	8448733	41.3533	-70.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:45:00	\N	0.82	-00:06:00	\N	0.82	\N	\N	Gay Head	MA
61418	Muskeget Island, north side, Nantucket Island, Massachusetts	NOS	8448817	41.3367	-70.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:15:00	\N	0.21	00:25:00	\N	0.21	\N	\N	Muskeget Island, north side	MA
61419	Squibnocket Point, Martha's Vineyard, Massachusetts	NOS	8448942	41.3117	-70.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:02:00	\N	0.82	-00:45:00	\N	0.82	\N	\N	Squibnocket Point	MA
61420	Eel Point, Nantucket Island, Massachusetts	NOS	8449062	41.2917	-70.2083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:07:00	\N	0.24	00:39:00	\N	0.24	\N	\N	Eel Point	MA
61421	Nomans Land, Martha's Vineyard, Massachusetts	NOS	8449287	41.2617	-70.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:18:00	\N	0.85	-00:19:00	\N	0.85	\N	\N	Nomans Land	MA
61422	North End, Bay Oil pier, Sakonnet River, Rhode Island	NOS	8450898	41.6517	-71.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:01:00	\N	1.07	00:20:00	\N	1.2	\N	\N	North End, Bay Oil pier	RI
61423	Anthony Point, Sakonnet River, Rhode Island	NOS	8450948	41.6383	-71.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:01:00	\N	1.09	00:00:00	\N	1.09	\N	\N	Anthony Point	RI
61424	Nannaquaket Neck, Sakonnet River, Rhode Island	NOS	8450954	41.6183	-71.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:13:00	\N	1.01	-00:12:00	\N	1.01	\N	\N	Nannaquaket Neck	RI
61425	The Glen, Sakonnet River, Rhode Island	NOS	8451301	41.5583	-71.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:03:00	\N	1	-00:13:00	\N	0.98	\N	\N	The Glen	RI
61426	Sachuest, Flint Point, Sakonnet River, Rhode Island	NOS	8451351	41.4867	-71.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:15:00	\N	0.93	-00:05:00	\N	0.9	\N	\N	Sachuest, Flint Point	RI
61427	Bristol Ferry, Narragansett Bay, Rhode Island (sub)	NOS	8451552	41.6367	-71.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:00:00	\N	1.14	00:15:00	\N	1.17	\N	\N	Bristol Ferry	RI
61428	Bristol, Bristol Harbor, Narragansett Bay, Rhode Island	NOS	8451929	41.6683	-71.28	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:00:00	\N	1.14	00:13:00	\N	1.16	\N	\N	Bristol, Bristol Harbor	RI
61429	Prudence Island, (south end), Narragansett Bay, Rhode Island	NOS	8452555	41.58	-71.3217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:03:00	\N	1.14	00:08:00	\N	1.08	\N	\N	Prudence Island, (south end)	RI
61430	Bay Spring, Bullock Cove, Narragansett Bay, Rhode Island	NOS	8453033	41.7517	-71.3517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:01:00	\N	1.21	00:12:00	\N	1.22	\N	\N	Bay Spring, Bullock Cove	RI
61431	Castle Hill, Narragansett Bay, Rhode Island	NOS	8453201	41.4633	-71.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:13:00	\N	1	-00:05:00	\N	0.94	\N	\N	Castle Hill	RI
61432	Rumford, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453433	41.84	-71.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:06:00	\N	1.29	00:12:00	\N	1.34	\N	\N	Rumford, Seekonk River	RI
61433	Conanicut Point, Conanicut Island, Rhode Island	NOS	8453465	41.5733	-71.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:06:00	\N	1.07	00:07:00	\N	1.07	\N	\N	Conanicut Point	RI
61434	Pawtucket, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453611	41.8683	-71.38	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:09:00	\N	1.29	00:18:00	\N	1.31	\N	\N	Pawtucket, Seekonk River	RI
61435	West Jamestown, Dutch Island Harbor, Conanicut Island, Rhode Island (sub)	NOS	8453742	41.4967	-71.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:04:00	\N	1	00:05:00	\N	1	\N	\N	West Jamestown, Dutch Island Harbor	RI
61436	Pawtuxet, Pawtuxet Cove, Narragansett Bay, Rhode Island	NOS	8453767	41.7617	-71.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:11:00	\N	1.29	00:06:00	\N	1.25	\N	\N	Pawtuxet, Pawtuxet Cove	RI
61437	Beavertail Point, Conanicut Island, Rhode Island	NOS	8453999	41.4517	-71.4017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:04:00	\N	0.98	-00:05:00	\N	0.98	\N	\N	Beavertail Point	RI
61438	Providence, State Pier no.1, Narragansett Bay, Rhode Island (sub)	NOS	8454000	41.8066667	-71.4005556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:00:00	\N	1.29	00:13:00	\N	1.27	\N	\N	Providence, State Pier no.1	RI
61439	Watson Pier, Boston Neck, Narragansett Bay, Rhode Island	NOS	8454341	41.46	-71.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:16:00	\N	0.93	-00:03:00	\N	0.96	\N	\N	Watson Pier, Boston Neck	RI
61440	Wickford, Narragansett Bay, Rhode Island (sub)	NOS	8454538	41.5717	-71.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:06:00	\N	1.07	00:03:00	\N	1.07	\N	\N	Wickford	RI
61441	Narragansett Pier, Narragansett Bay, Rhode Island	NOS	8454658	41.4217	-71.455	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:11:00	\N	0.93	-00:11:00	\N	0.91	\N	\N	Narragansett Pier	RI
61442	Point Judith, Harbor of Refuge, Rhode Island (sub)	NOS	8455083	41.3633	-71.49	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:33:00	\N	0.93	00:00:00	\N	0.87	\N	\N	Point Judith, Harbor of Refuge	RI
61443	Westerly, Pawcatuck River, Rhode Island (sub)	NOS	8455189	41.3817	-71.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:03:00	\N	1	-00:21:00	\N	1.02	\N	\N	Westerly, Pawcatuck River	RI
61444	Weekapaug Point, Block Island Sound, Rhode Island (sub)	NOS	8458022	41.3283	-71.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:06:00	\N	0.93	00:41:00	\N	0.74	\N	\N	Weekapaug Point, Block Island Sound	RI
61445	Watch Hill Point, Rhode Island	NOS	8458694	41.305	-71.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:16:00	\N	0.71	00:41:00	\N	0.74	\N	\N	Watch Hill Point	RI
61446	Block Island (Old Harbor), Rhode Island (sub)	NOS	8459338	41.1733	-71.5567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:15:00	\N	0.86	-00:13:00	\N	0.82	\N	\N	Block Island (Old Harbor)	RI
61447	Block Island (SW end), Block Island Sound, Rhode Island (sub)	NOS	8459681	41.1633	-71.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:42:00	\N	0.79	00:05:00	\N	0.75	\N	\N	Southwest Point, Block Island	RI
61448	Norwich, Thames River, Connecticut	NOS	8461392	41.5233	-72.0783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:19:00	\N	1.21	00:24:00	\N	1.18	\N	\N	Norwich	CT
61449	Yale boathouse, Thames River, Connecticut	NOS	8461467	41.43	-72.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:10:00	\N	1.11	00:14:00	\N	1.07	\N	\N	Yale boathouse	CT
61450	Niantic, Niantic River, Connecticut	NOS	8461925	41.325	-72.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:57:00	\N	0.84	00:52:00	\N	0.99	\N	\N	Niantic, Niantic River	CT
61451	Saybrook Jetty, Connecticut River, Connecticut	NOS	8462723	41.2633	-72.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:45:00	\N	1.35	01:11:00	\N	1.36	\N	\N	Saybrook Jetty	CT
61452	Saybrook Point, Connecticut River, Connecticut	NOS	8462752	41.2833	-72.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:53:00	\N	1.25	01:11:00	\N	1.24	\N	\N	Saybrook Point	CT
61453	Lyme, highway bridge, Connecticut River, Connecticut	NOS	8462764	41.3217	-72.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	01:09:00	\N	0.95	01:36:00	\N	1.26	\N	\N	Lyme, highway bridge	CT
61454	Essex, Connecticut River, Connecticut	NOS	8462925	41.3483	-72.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	01:38:00	\N	1.15	01:39:00	\N	1.16	\N	\N	Essex	CT
61455	Hadlyme, Connecticut River, Connecticut	NOS	8463155	41.42	-72.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	02:23:00	\N	1.05	02:19:00	\N	1.05	\N	\N	Hadlyme	CT
61456	Tylerville, Connecticut River, Connecticut	NOS	8463348	41.4517	-72.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	02:51:00	\N	1.02	02:38:00	\N	1.02	\N	\N	Tylerville	CT
61457	Westbrook, Duck Island Roads, Connecticut	NOS	8463409	41.2733	-72.475	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:32:00	\N	0.6	-00:24:00	\N	0.61	\N	\N	Westbrook, Duck Island Roads	CT
61458	Haddam, Connecticut River, Connecticut	NOS	8463582	41.4817	-72.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	03:08:00	\N	0.95	02:48:00	\N	0.97	\N	\N	Haddam	CT
61459	Maromas, Connecticut River, Connecticut	NOS	8463827	41.5417	-72.5517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	04:01:00	\N	0.91	03:25:00	\N	0.91	\N	\N	Maromas	CT
61460	Higganum Creek, Connecticut River, Connecticut	NOS	8463836	41.5033	-72.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	03:40:00	\N	0.91	03:08:00	\N	0.91	\N	\N	Higganum Creek	CT
61461	Madison, Connecticut	NOS	8464041	41.27	-72.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:30:00	\N	0.72	-00:21:00	\N	0.73	\N	\N	Madison	CT
61462	Rocky Hill, Connecticut River, Connecticut	NOS	8464255	41.6633	-72.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	05:36:00	\N	0.63	04:30:00	\N	0.72	\N	\N	Rocky Hill	CT
61463	Middletown, Connecticut River, Connecticut	NOS	8464336	41.56	-72.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	04:39:00	\N	0.83	03:54:00	\N	0.83	\N	\N	Middletown	CT
61464	South Hartford, Connecticut River, Connecticut	NOS	8464418	41.755	-72.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	06:54:00	\N	0.58	05:24:00	\N	0.74	\N	\N	South Hartford	CT
61465	Guilford Harbor, Connecticut	NOS	8464445	41.2717	-72.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:21:00	\N	0.96	-00:11:00	\N	0.77	\N	\N	Guilford Harbor	CT
61466	Hartford, Connecticut River, Connecticut	NOS	8464464	41.77	-72.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	06:52:00	\N	0.75	05:30:00	\N	0.74	\N	\N	Hartford	CT
61467	Sachem Head, Connecticut	NOS	8464687	41.245	-72.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:15:00	\N	0.8	-00:11:00	\N	0.8	\N	\N	Sachem Head	CT
61468	Branford, Branford River, Connecticut	NOS	8465233	41.2617	-72.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:13:00	\N	0.96	-00:05:00	\N	0.87	\N	\N	Branford, Branford River	CT
61469	Lighthouse Point, New Haven Harbor, Connecticut	NOS	8465692	41.2517	-72.905	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:07:00	\N	0.96	-00:04:00	\N	0.91	\N	\N	Lighthouse Point, New Haven Harbor	CT
61470	New Haven Harbor, New Haven Reach, Connecticut (sub)	NOS	8465705	41.2833	-72.9083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:06:00	\N	1	-00:01:00	\N	0.92	\N	\N	New Haven Harbor, New Haven Reach	CT
61471	Gulf Beach, Connecticut	NOS	8466375	41.205	-73.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:08:00	\N	1.04	-00:05:00	\N	0.94	\N	\N	Gulf Beach	CT
61472	Milford Harbor, Connecticut	NOS	8466442	41.2183	-73.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:03:00	\N	1.04	-00:02:00	\N	0.94	\N	\N	Milford Harbor	CT
61473	Shelton, Housatonic River, Connecticut	NOS	8466573	41.3017	-73.0717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	01:19:00	\N	0.96	00:46:00	\N	1.04	\N	\N	Shelton	CT
61474	Long Hill, Housatonic River, Connecticut	NOS	8466664	41.275	-73.0883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	01:13:00	\N	1.04	00:43:00	\N	1.02	\N	\N	Long Hill	CT
61475	Sniffens Point, Housatonic River, Connecticut	NOS	8466791	41.1867	-73.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:09:00	\N	1	00:10:00	\N	0.96	\N	\N	Sniffens Point	CT
61476	Stratford, I-95 bridge, Housatonic River, Connecticut	NOS	8466797	41.2033	-73.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:23:00	\N	1	00:23:00	\N	0.98	\N	\N	Stratford, I-95 bridge	CT
61477	South Norwalk, Norwalk River, Connecticut (sub)	NOS	8468448	41.0967	-73.415	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:15:00	\N	1.04	00:09:00	\N	1.05	\N	\N	South Norwalk	CT
61478	Rowayton, Fivemile River, Connecticut	NOS	8468609	41.065	-73.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:05:00	\N	1.08	00:00:00	\N	1.05	\N	\N	Rowayton, Fivemile River	CT
61479	Long Neck Point, Long Island Sound, Connecticut (sub)	NOS	8468799	41.0383	-73.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:01:00	\N	0.96	-00:09:00	\N	1.06	\N	\N	Long Neck Point	CT
61480	Cos Cob Harbor, Connecticut	NOS	8469549	41.0167	-73.5967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:11:00	\N	1.08	00:05:00	\N	1.07	\N	\N	Cos Cob Harbor	CT
61481	Lake Montauk, Long Island, New York (sub)	NOS	8510448	41.0733	-71.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	-00:22:00	\N	0.89	-00:26:00	\N	0.77	\N	\N	Lake Montauk	NY
61482	Montauk Harbor entrance, Long Island, New York	NOS	8510502	41.075	-71.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	-00:16:00	\N	0.75	-00:24:00	\N	0.74	\N	\N	Montauk Harbor entrance	NY
61483	Silver Eel Pond, Fishers Island, New York (sub)	NOS	8510719	41.2567	-72.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	-00:04:00	\N	1	-00:04:00	\N	0.91	\N	\N	Silver Eel Pond, Fishers Island, N.Y.	NY
61484	Little Gull Island, Long Island, New York	NOS	8510884	41.2067	-72.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	-00:22:00	\N	0.85	00:13:00	\N	0.85	\N	\N	Little Gull Island	NY
61485	Threemile Harbor entrance, Gardiners Bay, Long Island, New York (sub)	NOS	8511171	41.035	-72.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:19:00	\N	1	00:39:00	\N	0.96	\N	\N	Threemile Harbor entrance, Gardiners Bay	NY
61486	Plum Gut Harbor, Plum Island, Long Island, New York (sub)	NOS	8511236	41.1717	-72.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:16:00	\N	1.01	00:28:00	\N	1.01	\N	\N	Plum Gut Harbor, Plum Island	NY
61487	Orient Harbor, Orient, Shelter Island Sound, New York (sub)	NOS	8511671	41.1367	-72.3067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:36:00	\N	0.97	00:37:00	\N	0.97	\N	\N	Orient	NY
61488	Noyack Bay, Shelter Island Sound, New York	NOS	8511779	40.995	-72.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	01:44:00	\N	0.89	02:06:00	\N	0.89	\N	\N	Noyack Bay	NY
61489	Hashamomuck Beach, Long Island, New York	NOS	8512053	41.095	-72.3983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:13:00	\N	0.64	00:03:00	\N	0.64	\N	\N	Hashamomuck Beach	NY
61490	Southold, Shelter Island Sound, New York	NOS	8512114	41.06	-72.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	01:33:00	\N	0.89	01:44:00	\N	0.89	\N	\N	Southold	NY
61491	New Suffolk, Peconic Bays, New York	NOS	8512328	40.9917	-72.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	02:11:00	\N	1	02:27:00	\N	1.01	\N	\N	New Suffolk	NY
61492	Shinnecock Bay entrance, Shinnecock Bay, New York	NOS	8512671	40.82	-72.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:51:00	\N	0.37	01:12:00	\N	0.51	\N	\N	Shinnecock Bay entrance	NY
61493	South Jamesport, Great Peconic Bay, New York (sub)	NOS	8512735	40.935	-72.5817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	02:43:00	\N	0.95	02:34:00	\N	1.07	\N	\N	South Jamesport	NY
61494	Shinnecock Yacht Club, Penniman Creek, Shinnecock Bay, New York (sub)	NOS	8512769	40.81855555555556	-72.58661111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:45:00	\N	0.55	01:01:00	\N	0.55	\N	\N	Shinnecock Yacht Club, Penniman Creek	NY
61495	Northville, Long Island, New York (sub)	NOS	8512987	40.9817	-72.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:03:00	\N	0.92	00:05:00	\N	0.8	\N	\N	Northville	NY
61496	Smith Point Bridge, Narrow Bay, Long Island, New York (sub)	NOS	8513825	40.7383	-72.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:34:00	\N	0.6	01:58:00	\N	0.27	\N	\N	Smith Point Bridge, Narrow Bay	NY
61497	Patchogue, Patchogue River, Great South Bay, New York (sub)	NOS	8514322	40.75	-73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:33:00	\N	0.53	03:14:00	\N	0.25	\N	\N	Patchogue	NY
61498	Mount Sinai Harbor, Long Island, New York	NOS	8514421	40.9633	-73.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:18:00	\N	0.88	00:04:00	\N	0.89	\N	\N	Mount Sinai Harbor	NY
61499	Cedar Beach, Long Island, New York (sub)	NOS	8514422	40.965	-73.0433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:05:00	\N	1	00:07:00	\N	0.96	\N	\N	Cedar Beach	NY
61500	Port Jefferson, Long Island, New York	NOS	8514560	40.95	-73.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:05:00	\N	0.92	00:04:00	\N	0.98	\N	\N	Port Jefferson	NY
61501	Port Jefferson Harbor entrance, Long Island, New York	NOS	8514594	40.9717	-73.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:01:00	\N	0.98	00:02:00	\N	0.98	\N	\N	Port Jefferson Harbor entrance	NY
61502	Great River, Connetquot River, Great South Bay, New York	NOS	8514783	40.7233	-73.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:32:00	\N	0.15	03:19:00	\N	0.15	\N	\N	Great River, Connetquot River	NY
61503	West Fire Island, Great South Bay, New York	NOS	8514961	40.6567	-73.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:18:00	\N	0.13	02:10:00	\N	0.13	\N	\N	West Fire Island	NY
61504	Fire Island Light, Great South Bay, New York	NOS	8515014	40.635	-73.22	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:22:00	\N	0.15	00:46:00	\N	0.15	\N	\N	Fire Island Light	NY
61505	Bay Shore, Watchogue Creek Entrance, Great South Bay, New York	NOS	8515102	40.7167	-73.24	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:27:00	\N	0.37	02:15:00	\N	0.22	\N	\N	Bay Shore, Watchogue Creek Entrance	NY
61506	Democrat Point, Fire Island Inlet, Long Island, New York	NOS	8515228	40.6333	-73.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:27:00	\N	0.55	-00:39:00	\N	0.56	\N	\N	Democrat Point, Fire Island Inlet	NY
61507	Oak Beach, Great South Bay, New York	NOS	8515336	40.64	-73.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:58:00	\N	0.15	02:23:00	\N	0.15	\N	\N	Oak Beach	NY
61508	Babylon, Great South Bay, New York	NOS	8515421	40.685	-73.315	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:41:00	\N	0.15	02:11:00	\N	0.13	\N	\N	Babylon	NY
61509	Northport, Northport Bay, Long Island, New York (sub)	NOS	8515586	40.9	-73.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:04:00	\N	0.92	-00:05:00	\N	1.07	\N	\N	Northport, Northport Bay	NY
61510	Gilgo Heading, Great South Bay, New York	NOS	8515764	40.62	-73.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:58:00	\N	0.25	02:22:00	\N	0.24	\N	\N	Gilgo Heading	NY
61511	Eatons Neck Point, Long Island, New York (sub)	NOS	8515786	40.9533	-73.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:08:00	\N	1.04	00:02:00	\N	1.05	\N	\N	Eatons Neck Point	NY
61512	Amityville, Great South Bay, New York	NOS	8515864	40.655	-73.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:05:00	\N	0.25	02:20:00	\N	0.26	\N	\N	Amityville	NY
61513	Huntington Harbor Lighthouse, Huntington Bay, Long Island, New York (sub)	NOS	8515921	40.91	-73.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:07:00	\N	0.88	-00:01:00	\N	1.04	\N	\N	Lloyd Harbor, Huntington Bay	NY
61514	Biltmore Shores, South Oyster Bay, Long Island, New York	NOS	8516055	40.6667	-73.4683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:32:00	\N	0.3	02:04:00	\N	0.3	\N	\N	Biltmore Shores, South Oyster Bay	NY
61515	Cold Spring Harbor, Oyster Bay, New York (sub)	NOS	8516061	40.8733	-73.47	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:02:00	\N	0.92	-00:07:00	\N	1.07	\N	\N	Cold Spring Harbor	NY
61516	Green Island, Hempstead Bay, New York (sub)	NOS	8516155	40.6233	-73.5017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:31:00	\N	0.4	01:21:00	\N	0.41	\N	\N	Green Island	NY
61517	Oyster Bay Harbor, Oyster Bay, New York	NOS	8516201	40.8667	-73.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:13:00	\N	1.08	00:07:00	\N	1.08	\N	\N	Oyster Bay Harbor	NY
61518	Bellmore, Bellmore Creek, Hempstead Bay, New York	NOS	8516211	40.6633	-73.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:58:00	\N	0.45	01:28:00	\N	0.43	\N	\N	Bellmore, Bellmore Creek	NY
61519	Cuba Island, Hempstead Bay, New York	NOS	8516221	40.62	-73.5233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:22:00	\N	0.5	01:07:00	\N	0.49	\N	\N	Cuba Island	NY
61520	Deep Creek Meadow, Hempstead Bay, New York	NOS	8516225	40.6033	-73.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:11:00	\N	0.5	01:01:00	\N	0.51	\N	\N	Deep Creek Meadow	NY
61521	Bayville Bridge, Oyster Bay, New York (sub)	NOS	8516299	40.9033	-73.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:04:00	\N	1.04	-00:06:00	\N	1.09	\N	\N	Bayville Bridge	NY
61522	Neds Creek, Hempstead Bay, New York	NOS	8516315	40.6233	-73.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:54:00	\N	0.6	00:49:00	\N	0.58	\N	\N	Neds Creek	NY
61523	Jones Inlet (Point Lookout), Long Island, New York	NOS	8516385	40.5867	-73.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:25:00	\N	0.75	-00:20:00	\N	0.77	\N	\N	Jones Inlet (Point Lookout)	NY
61524	Freeport, Baldwin Bay, Hempstead Bay, New York	NOS	8516411	40.6333	-73.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:55:00	\N	0.65	00:37:00	\N	0.64	\N	\N	Freeport, Baldwin Bay	NY
61525	Long Beach (Inside), Hempstead Bay, New York	NOS	8516601	40.6	-73.65	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:02:00	\N	0.85	00:18:00	\N	0.84	\N	\N	Long Beach (Inside)	NY
61526	Glen Cove Yacht Club, Hempstead Harbor, Long Island, New York (sub)	NOS	8516614	40.8633	-73.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	-00:26:00	\N	0.82	-00:22:00	\N	1.01	\N	\N	Glen Cove, Hempstead Harbor	NY
61527	Woodmere, Brosewere Bay, Hempstead Bay, New York	NOS	8516745	40.62	-73.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:50:00	\N	0.85	00:34:00	\N	0.84	\N	\N	Woodmere, Brosewere Bay	NY
61528	Port Washington, Manhasset Bay, Long Island, New York (sub)	NOS	8516761	40.8317	-73.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	-00:12:00	\N	0.96	-00:12:00	\N	1.02	\N	\N	Port Washington, Manhasset Bay	NY
61529	Motts Basin, Jamaica Bay, New York	NOS	8516925	40.6167	-73.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:48:00	\N	1.15	00:39:00	\N	1.16	\N	\N	Motts Basin	NY
61530	Willets Point, Little Bay, East River, New York (sub)	NOS	8516990	40.7933	-73.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:00:00	\N	1.04	-00:01:00	\N	1	\N	\N	Willets Point	NY
61531	J.F.K. International Airport, Jamaica Bay, New York	NOS	8516999	40.6233	-73.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:45:00	\N	1.15	00:25:00	\N	1.14	\N	\N	J.F.K. International Airport	NY
61532	Whitestone, East River, New York	NOS	8517125	40.7983	-73.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:09:00	\N	1.04	00:07:00	\N	1	\N	\N	Whitestone	NY
61533	Beach Channel (bridge), Jamaica Bay, New York (sub)	NOS	8517137	40.5883	-73.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:24:00	\N	1.1	00:37:00	\N	1.09	\N	\N	Beach Channel (bridge)	NY
61534	College Pt, Ft. of 110th Street, Long Island, New York (sub)	NOS	8517276	40.7833	-73.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:16:00	\N	1.04	00:17:00	\N	0.95	\N	\N	College Point, Flushing Bay	NY
61535	Canarsie, Jamaica Bay, New York	NOS	8517381	40.63	-73.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:08:00	\N	1.1	00:27:00	\N	1.12	\N	\N	Canarsie	NY
61536	Barren Island, Rockaway Inlet, Jamaica Bay, New York	NOS	8517394	40.5783	-73.8883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:04:00	\N	1.05	-00:01:00	\N	1.07	\N	\N	Barren Island, Rockaway Inlet	NY
61537	Hell Gate, Wards Island, East River, New York	NOS	8517401	40.7867	-73.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	03:45:00	\N	1.59	02:58:00	\N	1.33	\N	\N	Hell Gate, Wards Island	NY
61538	Mill Basin, Jamaica Bay, New York	NOS	8517519	40.6083	-73.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:04:00	\N	1.1	00:28:00	\N	1.12	\N	\N	Mill Basin	NY
61539	Plumb Beach Channel, Jamaica Bay, New York	NOS	8517531	40.585	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:03:00	\N	1.05	00:02:00	\N	1.05	\N	\N	Plumb Beach Channel	NY
61540	Hunters Point, Newtown Creek, East River, New York	NOS	8517673	40.74	-73.9617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:56:00	\N	0.9	01:22:00	\N	0.89	\N	\N	Hunters Point, Newtown Creek	NY
61541	Wallabout Bay, Brooklyn Navy Yard, East River, New York	NOS	8517732	40.7067	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:22:00	\N	1.05	00:32:00	\N	0.94	\N	\N	Wallabout Bay, Brooklyn Navy Yard	NY
61542	Coney Island, New York	NOS	8517741	40.57	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:17:00	\N	1	-00:04:00	\N	1.01	\N	\N	Coney Island	NY
61543	Norton Point, Gravesend Bay, New York	NOS	8517811	40.59	-73.9983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:03:00	\N	1.15	-00:01:00	\N	1.02	\N	\N	Norton Point, Gravesend Bay	NY
61544	Brooklyn Bridge, East River, New York (sub)	NOS	8517847	40.7033	-73.995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	-00:04:00	\N	1	00:24:00	\N	0.99	\N	\N	Brooklyn Bridge	NY
61545	Gowanus Bay, New York	NOS	8517921	40.665	-74.0133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	-00:12:00	\N	0.95	-00:18:00	\N	1.03	\N	\N	Gowanus Bay	NY
61546	Fort Hamilton, The Narrows, New York	NOS	8517942	40.6083	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:07:00	\N	1	00:02:00	\N	1.01	\N	\N	Fort Hamilton, The Narrows	NY
61547	Rye Beach (Amusement Park), New York (sub)	NOS	8518091	40.9617	-73.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	-00:27:00	\N	0.86	-00:20:00	\N	1	\N	\N	Rye Beach	NY
61548	New Rochelle, New York	NOS	8518490	40.8933	-73.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	-00:18:00	\N	0.93	-00:16:00	\N	1.01	\N	\N	New Rochelle	NY
61549	Hunts Point, East River, New York	NOS	8518621	40.8	-73.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:10:00	\N	1.07	00:12:00	\N	0.97	\N	\N	Hunts Point	NY
61550	North Brother Island, East River, New York	NOS	8518635	40.7983	-73.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:18:00	\N	1.11	00:18:00	\N	0.93	\N	\N	North Brother Island	NY
61551	Port Morris (Stony Point), East River, New York (sub)	NOS	8518639	40.8017	-73.9067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:10:00	\N	0.96	00:07:00	\N	0.87	\N	\N	Port Morris (Stony Point)	NY
61552	Horns Hook, East 90th Street, East River, New York, New York (sub)	NOS	8518668	40.7767	-73.9417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:34:00	\N	0.9	01:54:00	\N	1.03	\N	\N	Horns Hook, East 90th Street	NY
61553	Queensboro Bridge, East River, New York (sub)	NOS	8518687	40.7583	-73.9583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:57:00	\N	1	01:23:00	\N	0.96	\N	\N	Queensboro Bridge	NY
61554	East 41st Street, New York City, East River, New York	NOS	8518695	40.7467	-73.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:46:00	\N	1.09	01:03:00	\N	0.95	\N	\N	East 41st Street, New York City	NY
61555	Williamsburg Bridge, East River, New York (sub)	NOS	8518699	40.7117	-73.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:28:00	\N	0.95	00:45:00	\N	0.93	\N	\N	Williamsburg Bridge	NY
61556	Spuyten Duyvil Creek Entrance, Hudson River, New York (sub)	NOS	8518903	40.8783	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:48:00	\N	0.84	00:52:00	\N	0.84	\N	\N	Spuyten Duyvil Creek ent., N.Y.	NY
61557	Riverdale, Hudson River, New York (sub)	NOS	8518905	40.9033	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:49:00	\N	0.85	00:48:00	\N	0.85	\N	\N	Riverdale, N.Y.	NY
61558	Tarrytown, Hudson River, New York	NOS	8518919	41.0783	-73.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:57:00	\N	0.7	01:49:00	\N	0.7	\N	\N	Tarrytown	NY
61559	Haverstraw Bay, Hudson River, New York (sub)	NOS	8518924	41.2183	-73.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	02:42:00	\N	0.81	02:15:00	\N	0.72	\N	\N	Haverstraw	NY
61560	Newburgh, Hudson River, New York	NOS	8518935	41.5	-74.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	04:03:00	\N	0.64	03:46:00	\N	0.62	\N	\N	Newburgh	NY
61561	New Hamburg, Hudson River, New York	NOS	8518939	41.5833	-73.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	04:28:00	\N	0.64	04:04:00	\N	0.64	\N	\N	New Hamburg	NY
61562	Poughkeepsie, Hudson River, New York	NOS	8518945	41.7	-73.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	04:46:00	\N	0.68	04:34:00	\N	0.68	\N	\N	Poughkeepsie	NY
61563	Peekskill, Hudson River, New York	NOS	8518949	41.2883	-73.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	03:03:00	\N	0.64	02:28:00	\N	0.64	\N	\N	Peekskill	NY
61564	Tivoli, Hudson River, New York	NOS	8518964	42.0583	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	06:04:00	\N	0.86	05:50:00	\N	0.86	\N	\N	Tivoli	NY
61565	Hudson, Hudson River, New York	NOS	8518974	42.25	-73.8	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	07:12:00	\N	0.86	06:58:00	\N	0.88	\N	\N	Hudson	NY
61566	Castleton, Hudson River, New York	NOS	8518989	42.5333	-73.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60323	-00:29:00	0.1	\N	-00:17:00	-0.2	\N	\N	\N	Castleton	NY
61567	Kingston, Hudson River, New York	NOS	8518993	41.9183	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	05:34:00	\N	0.82	05:20:00	\N	0.81	\N	\N	Kingston	NY
61568	Fort Wadsworth, The Narrows, Staten Island, New York	NOS	8519024	40.6067	-74.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:06:00	\N	1.05	00:06:00	\N	0.98	\N	\N	Fort Wadsworth, The Narrows	NY
61569	St. George, Staten Island, New York	NOS	8519112	40.6433	-74.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	-00:15:00	\N	0.99	-00:17:00	\N	0.99	\N	\N	St. George, Staten Island	NY
61570	Port Ivory, Howland Hook, Arthur Kill, New York	NOS	8519200	40.645	-74.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:39:00	\N	1.09	00:27:00	\N	1.09	\N	\N	Port Ivory, Howland Hook, N.Y.	NY
61571	Princes Bay, New Jersey	NOS	8519726	40.5117	-74.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:06:00	\N	1.05	00:00:00	\N	1.05	\N	\N	Princes Bay	NJ
61572	Rossville, Arthur Kill, New York	NOS	8519789	40.5567	-74.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:29:00	\N	1.12	00:20:00	\N	1.12	\N	\N	Rossville, N.Y.	NY
61573	Alpine, Hudson River, New Jersey	NOS	8530095	40.945	-73.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:02:00	\N	0.9	01:05:00	\N	0.83	\N	\N	Alpine, N.J.	NJ
61574	New Millford, Hackensack River, New Jersey	NOS	8530186	40.935	-74.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	02:49:00	\N	1.02	01:17:00	\N	1.02	\N	\N	New Millford	NJ
61575	Hackensack, Hackensack River, New Jersey	NOS	8530278	40.88	-74.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:00:00	\N	1.38	01:06:00	\N	1.33	\N	\N	Hackensack	NJ
61576	Ridgefield Park, Hackensack River, New Jersey	NOS	8530398	40.85	-74.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:00:00	\N	1.26	01:00:00	\N	1.26	\N	\N	Ridgefield Park	NJ
61577	East Rutherford, Passaic River, New Jersey	NOS	8530403	40.8467	-74.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:06:00	\N	1.29	00:09:00	\N	1.29	\N	\N	East Rutherford	NJ
61578	Edgewater, Hudson River, New Jersey	NOS	8530505	40.8133	-73.9783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:28:00	\N	0.93	00:31:00	\N	0.93	\N	\N	Edgewater, N.J.	NJ
61579	Carlstadt, Garretts Reach, Hackensack River, New Jersey	NOS	8530528	40.8067	-74.06	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:45:00	\N	1.29	00:59:00	\N	1.26	\N	\N	Carlstadt, Garretts Reach	NJ
61580	North Secaucus, Garretts Reach, Hackensack River, New York	NOS	8530531	40.805	-74.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:57:00	\N	1.23	00:57:00	\N	1.23	\N	\N	North Secaucus, Garretts Reach	NY
61581	Fish Creek, Berrys Creek, Hackensack River, New Jersey	NOS	8530586	40.7933	-74.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:00:00	\N	1	01:02:00	\N	1.16	\N	\N	Fish Creek, Berrys Creek	NJ
61582	Belleville, Passaic River, New Jersey	NOS	8530591	40.7867	-74.1467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:49:00	\N	1.19	00:09:00	\N	1.23	\N	\N	Belleville	NJ
61583	Weehawken, Union City, Hudson River, New Jersey	NOS	8530645	40.765	-74.0183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:15:00	\N	0.96	00:13:00	\N	0.96	\N	\N	Weehawken, Union City, N.J.	NJ
61584	Amtrak RR. swing bridge, Hackensack River, New Jersey	NOS	8530696	40.7517	-74.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:39:00	\N	1.1	00:33:00	\N	1.16	\N	\N	Amtrak RR. swing bridge	NJ
61585	Point No Point, Passaic River, New Jersey	NOS	8530743	40.7317	-74.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:22:00	\N	1.04	00:00:00	\N	1.15	\N	\N	Point No Point	NJ
61586	Kearny Point, Hackensack River, New Jersey	NOS	8530772	40.7283	-74.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:22:00	\N	1.14	00:11:00	\N	1.15	\N	\N	Kearny Point	NJ
61587	Port Elizabeth, New Jersey	NOS	8530882	40.6733	-74.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:13:00	\N	0.95	-00:02:00	\N	1.11	\N	\N	Port Elizabeth	NJ
61588	Port Newark Terminal, New Jersey	NOS	8530884	40.69	-74.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:21:00	\N	1.12	00:03:00	\N	1.12	\N	\N	Port Newark Terminal	NJ
61589	Constable Hook, Kill Van Kull, New York	NOS	8530985	40.655	-74.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	-00:08:00	\N	1.02	-00:18:00	\N	1.02	\N	\N	Constable Hook	NY
61590	Rahway River, RR. Bridge, Arthur Kill, New Jersey	NOS	8531077	40.5983	-74.2317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:30:00	\N	1.16	00:17:00	\N	1.14	\N	\N	Rahway River, RR. Bridge	NJ
61591	Carteret, Arthur Kill, New Jersey	NOS	8531095	40.5867	-74.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:33:00	\N	1.09	00:22:00	\N	1.09	\N	\N	Carteret	NJ
61592	Woodbridge Creek, 0.8 n.mi. above entrance, Arthur Kill, New Jersey	NOS	8531156	40.545	-74.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:21:00	\N	1	00:09:00	\N	1.1	\N	\N	Woodbridge Creek, 0.8 n.mi. above entrance	NJ
61593	South Amboy, Raritan River, New Jersey	NOS	8531232	40.4917	-74.2817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:08:00	\N	1.09	-00:04:00	\N	1.09	\N	\N	South Amboy	NJ
61594	Matawan Creek, Route 35 bridge, New Jersey	NOS	8531526	40.4333	-74.2183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:07:00	\N	1.08	-00:01:00	\N	1.08	\N	\N	Matawan Creek, Route 35 bridge	NJ
61595	Keyport, New Jersey	NOS	8531545	40.44	-74.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:06:00	\N	1.1	-00:04:00	\N	1.08	\N	\N	Keyport	NJ
61596	Waackaack Creek, New Jersey	NOS	8531592	40.4483	-74.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:21:00	\N	0.99	-00:06:00	\N	0.99	\N	\N	Waackaack Creek	NJ
61597	Atlantic Highlands, Sandy Hook Bay, New Jersey	NOS	8531662	40.4183	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:10:00	\N	1.01	-00:10:00	\N	1.01	\N	\N	Atlantic Highlands	NJ
61598	Highlands, Route 36 bridge, Shrewsbury River, New Jersey	NOS	8531712	40.3967	-73.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:14:00	\N	0.9	00:17:00	\N	0.9	\N	\N	Highlands, Route 36 bridge	NJ
61599	Oceanic Bridge, Navesink River, Shrewsbury River, New Jersey	NOS	8531753	40.3767	-74.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:45:00	\N	0.63	01:13:00	\N	0.72	\N	\N	Oceanic Bridge, Navesink River	NJ
61600	Sea Bright, Shrewsbury River, New Jersey (sub)	NOS	8531804	40.365	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:07:00	\N	0.68	01:15:00	\N	0.68	\N	\N	Sea Bright	NJ
61601	Red Bank, Navesink River, Shrewsbury River, New Jersey	NOS	8531833	40.355	-74.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:57:00	\N	0.63	01:17:00	\N	0.74	\N	\N	Red Bank, Navesink River	NJ
61602	Gooseneck Point, bridge, Shrewsbury River, New Jersey	NOS	8531925	40.3267	-74.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:41:00	\N	0.55	02:18:00	\N	0.55	\N	\N	Gooseneck Point, bridge	NJ
61603	Long Branch Reach, Shrewsbury River, New Jersey	NOS	8531942	40.325	-73.9967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:41:00	\N	0.63	02:18:00	\N	0.56	\N	\N	Long Branch Reach	NJ
61604	Long Branch (fishing pier), New Jersey	NOS	8531991	40.3033	-73.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:36:00	\N	1	-00:26:00	\N	0.94	\N	\N	Long Branch (fishing pier)	NJ
61605	Shark River Hills, Shark River, New Jersey	NOS	8532322	40.1917	-74.0383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:09:00	\N	0.94	-00:13:00	\N	0.94	\N	\N	Shark River Hills	NJ
61606	Belmar (ocean), New Jersey	NOS	8532337	40.185	-74.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:45:00	\N	0.95	-00:35:00	\N	0.95	\N	\N	Belmar, Atlantic Ocean	NJ
61607	Shark River Island, fixed RR. bridge, Shark River, New Jersey	NOS	8532339	40.1867	-74.0267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:08:00	\N	0.93	-00:13:00	\N	0.93	\N	\N	Shark River Island, fixed RR. bridge	NJ
61608	New Bedford, Shark River, New Jersey	NOS	8532371	40.1783	-74.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:07:00	\N	0.95	-00:13:00	\N	0.95	\N	\N	New Bedford	NJ
61609	Brielle, Route 35 bridge, Manasquan River, New Jersey	NOS	8532585	40.105	-74.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:20:00	\N	0.83	-00:06:00	\N	0.83	\N	\N	Brielle, Route 35 bridge	NJ
61610	Manasquan Inlet, USCG Station, New Jersey	NOS	8532591	40.1017	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:24:00	\N	0.95	-00:12:00	\N	0.86	\N	\N	Manasquan Inlet, USCG Station	NJ
61611	Riviera Beach, Manasquan River, New Jersey	NOS	8532611	40.0967	-74.0867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:38:00	\N	0.73	00:08:00	\N	0.73	\N	\N	Riviera Beach	NJ
61612	Forge Pond, Metedeconk River, New Jersey	NOS	8532703	40.065	-74.135	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:07:00	\N	0.07	02:17:00	\N	0.07	\N	\N	Forge Pond	NJ
61613	Beaverdam Creek entrance, Metedeconk River, New Jersey	NOS	8532715	40.0617	-74.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:40:00	\N	0.37	02:41:00	\N	0.07	\N	\N	Beaverdam Creek entrance	NJ
61614	Beaverdam Creek, inside, Metedeconk River, New Jersey	NOS	8532716	40.0617	-74.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:47:00	\N	0.06	02:49:00	\N	0.06	\N	\N	Beaverdam Creek, inside	NJ
61615	Tall Pines Camp, Metedeconk River, New Jersey	NOS	8532721	40.0583	-74.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:24:00	\N	0.06	02:23:00	\N	0.06	\N	\N	Tall Pines Camp	NJ
61616	Mantoloking, Barnegat Bay, New Jersey	NOS	8532786	40.0367	-74.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:39:00	\N	0.07	04:28:00	\N	0.07	\N	\N	Mantoloking	NJ
61617	Kettle Creek, Green Island, Barnegat Bay, New Jersey	NOS	8532835	40.0133	-74.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:41:00	\N	0.08	04:23:00	\N	0.08	\N	\N	Kettle Creek, Green Island	NJ
61618	Ocean Beach, Barnegat Bay, New Jersey	NOS	8532885	39.9883	-74.0683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:36:00	\N	0.08	04:17:00	\N	0.08	\N	\N	Ocean Beach	NJ
61619	Silver Bay, Silver Bay Marina, Barnegat Bay, New Jersey	NOS	8532921	39.9967	-74.1483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:39:00	\N	0.08	04:26:00	\N	0.08	\N	\N	Silver Bay, Silver Bay Marina	NJ
61620	Goose Creek entrance, Barnegat Bay, New Jersey	NOS	8533005	39.9633	-74.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:29:00	\N	0.08	04:06:00	\N	0.08	\N	\N	Goose Creek entrance	NJ
61621	Coates Point, Barnegat Bay, New Jersey	NOS	8533055	39.9483	-74.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:21:00	\N	0.08	04:00:00	\N	0.08	\N	\N	Coates Point	NJ
61622	Seaside Heights, ocean, New Jersey	NOS	8533071	39.9433	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:32:00	\N	0.92	-00:30:00	\N	0.92	\N	\N	Seaside Heights, ocean	NJ
61623	Seaside Park, Barnegat Bay, New Jersey	NOS	8533135	39.9217	-74.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:05:00	\N	0.08	03:40:00	\N	0.08	\N	\N	Seaside Park	NJ
61624	Barnegat Pier, Barnegat Bay, New Jersey	NOS	8533141	39.9183	-74.11	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:55:00	\N	0.08	03:35:00	\N	0.08	\N	\N	Barnegat Pier	NJ
61625	Sloop Creek, Barnegat Bay, New Jersey	NOS	8533185	39.905	-74.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:01:00	\N	0.08	03:38:00	\N	0.08	\N	\N	Sloop Creek	NJ
61626	Cedar Creek, Barnegat Bay, New Jersey	NOS	8533295	39.87	-74.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:45:00	\N	0.08	03:23:00	\N	0.08	\N	\N	Cedar Creek	NJ
61627	Island Beach, Barnegat Bay, New Jersey	NOS	8533345	39.8517	-74.0883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:28:00	\N	0.08	03:04:00	\N	0.08	\N	\N	Island Beach	NJ
61628	Stouts Creek, Barnegat Bay, New Jersey (sub)	NOS	8533365	39.845	-74.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:33:00	\N	0.06	03:16:00	\N	0.06	\N	\N	Stouts Creek	NJ
61629	Forked River, Barnegat Bay, New Jersey	NOS	8533391	39.825	-74.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:20:00	\N	0.07	03:08:00	\N	0.07	\N	\N	Forked River	NJ
61630	Oyster Creek, Barnegat Bay, New Jersey	NOS	8533465	39.8083	-74.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:36:00	\N	0.06	03:30:00	\N	0.06	\N	\N	Oyster Creek	NJ
61631	Island Beach, Sedge Islands, Barnegat Bay, New Jersey	NOS	8533535	39.7883	-74.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:56:00	\N	0.07	03:00:00	\N	0.07	\N	\N	Island Beach, Sedge Islands	NJ
61632	Waretown, Barnegat Bay, New Jersey	NOS	8533541	39.7917	-74.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:00:00	\N	0.07	02:43:00	\N	0.07	\N	\N	Waretown	NJ
61633	High Bar, Barnegat Bay, New Jersey	NOS	8533631	39.7567	-74.1283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:55:00	\N	0.12	01:04:00	\N	0.12	\N	\N	High Bar	NJ
61634	Double Creek, Barnegat Bay, New Jersey	NOS	8533665	39.745	-74.2017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:33:00	\N	0.07	03:03:00	\N	0.07	\N	\N	Double Creek	NJ
61635	Loveladies Harbor, Barnegat Bay, New Jersey	NOS	8533738	39.725	-74.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:39:00	\N	0.1	03:02:00	\N	0.1	\N	\N	Loveladies Harbor	NJ
61636	Flat Creek, Manahawkin Bay, New Jersey	NOS	8533780	39.7067	-74.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:35:00	\N	0.18	03:33:00	\N	0.18	\N	\N	Flat Creek	NJ
61637	North Beach, Manahawkin Bay, New Jersey	NOS	8533862	39.675	-74.16	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:07:00	\N	0.22	03:02:00	\N	0.22	\N	\N	North Beach	NJ
61638	Mill Creek, 1 n.mi. above entrance, Little Egg Harbor, New Jersey	NOS	8533905	39.665	-74.2317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:33:00	\N	0.35	02:32:00	\N	0.35	\N	\N	Mill Creek, 1 n.mi. above entrance	NJ
61639	Manahawkin Creek, Manahawkin Bay, New Jersey	NOS	8533909	39.6667	-74.215	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:51:00	\N	0.27	02:50:00	\N	0.27	\N	\N	Manahawkin Creek	NJ
61640	Manahawkin Drawbridge, Manahawkin Bay, New Jersey	NOS	8533935	39.6533	-74.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:39:00	\N	0.27	02:47:00	\N	0.27	\N	\N	Manahawkin Drawbridge	NJ
61641	Cedar Run, Little Egg Harbor, New Jersey	NOS	8533941	39.6533	-74.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:56:00	\N	0.4	02:10:00	\N	0.4	\N	\N	Cedar Run	NJ
61642	Dinner Point Creek, upper end, Little Egg Harbor, New Jersey	NOS	8533982	39.6567	-74.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:17:00	\N	0.4	02:41:00	\N	0.4	\N	\N	Dinner Point Creek, upper end	NJ
61643	West Creek, Westecunk Creek, Little Egg Harbor, New Jersey	NOS	8533987	39.6317	-74.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:40:00	\N	0.47	02:10:00	\N	0.44	\N	\N	West Creek, Westecunk Creek	NJ
61644	Sweetwater, Mullica River Marina, Mullica River, New Jersey	NOS	8534002	39.625	-74.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:21:00	\N	0.56	03:23:00	\N	0.56	\N	\N	Sweetwater, Mullica River Marina	NJ
61645	Wading River (town), Wading River, Mullica River, New Jersey	NOS	8534043	39.6183	-74.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:44:00	\N	0.79	02:48:00	\N	0.64	\N	\N	Wading River (town), Wading River	NJ
61646	Westecunk Creek entrance, Little Egg Harbor, New Jersey	NOS	8534044	39.6133	-74.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:40:00	\N	0.47	02:00:00	\N	0.42	\N	\N	Westecunk Creek entrance	NJ
61647	Beach Haven Crest, Little Egg Harbor, New Jersey	NOS	8534048	39.6133	-74.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:59:00	\N	0.32	02:13:00	\N	0.38	\N	\N	Beach Haven Crest	NJ
61648	Parker Run, upper end, Little Egg Harbor, New Jersey	NOS	8534049	39.6167	-74.31	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:39:00	\N	0.47	02:05:00	\N	0.45	\N	\N	Parker Run, upper end	NJ
61649	Tuckerton, Tuckerton Creek, Little Egg Harbor, New Jersey	NOS	8534080	39.6017	-74.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:15:00	\N	0.47	01:45:00	\N	0.45	\N	\N	Tuckerton, Tuckerton Creek	NJ
61650	New Gretna, Bass River, Mullica River, New Jersey	NOS	8534104	39.5917	-74.4417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:06:00	\N	0.74	01:52:00	\N	0.66	\N	\N	New Gretna, Bass River	NJ
61651	Green Bank, Mullica River, New Jersey	NOS	8534117	39.6117	-74.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:16:00	\N	0.66	02:59:00	\N	0.66	\N	\N	Green Bank	NJ
61652	Tuckerton Creek entrance, Little Egg Harbor, New Jersey	NOS	8534139	39.5767	-74.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:59:00	\N	0.45	01:32:00	\N	0.45	\N	\N	Tuckerton Creek entrance	NJ
61653	Beach Haven Coast Guard Station, Little Egg Harbor, New Jersey	NOS	8534208	39.5483	-74.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:23:00	\N	0.58	01:18:00	\N	0.46	\N	\N	Beach Haven Coast Guard Station	NJ
61654	Cramers Boatyard, Mullica River, New Jersey	NOS	8534212	39.5483	-74.4617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:01:00	\N	0.79	01:27:00	\N	0.63	\N	\N	Chestnut Neck Boat Yard	NJ
61655	Graveling Point, Great Bay, New Jersey	NOS	8534244	39.54	-74.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:14:00	\N	0.68	00:44:00	\N	0.68	\N	\N	Graveling Point	NJ
61656	Nacote Creek, U.S. Highway 9 bridge, Mullica River, New Jersey	NOS	8534256	39.535	-74.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:55:00	\N	0.68	01:34:00	\N	0.66	\N	\N	Nacote Creek, U.S. Highway 9 bridge	NJ
61657	Little Sheepshead Creek, Great Bay, New Jersey	NOS	8534287	39.5217	-74.32	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:44:00	\N	0.68	00:35:00	\N	0.66	\N	\N	Little Sheepshead Creek	NJ
61658	Seven Island, Newmans Thorofare, Great Bay, New Jersey	NOS	8534296	39.5167	-74.3367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:28:00	\N	0.73	00:32:00	\N	0.73	\N	\N	Seven Island, Newmans Thorofare	NJ
61659	Main Marsh Thorofare, New Jersey	NOS	8534393	39.4783	-74.3833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:52:00	\N	0.76	01:10:00	\N	0.8	\N	\N	Main Marsh Thorofare	NJ
61660	Mays Landing, Great Egg Harbor River, New Jersey (sub)	NOS	8534468	39.4483	-74.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	03:10:00	\N	1.12	02:50:00	\N	1.01	\N	\N	Mays Landing, Great Egg Harbor River	NJ
61661	Brigantine Channel @ Hoffman Thorofare, New Jersey	NOS	8534496	39.435	-74.3633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:58:00	\N	0.88	00:59:00	\N	0.9	\N	\N	Brigantine Channel @ Hoffman Thorofare	NJ
61662	Absecon, Absecon Creek, U.S. Hwy. 30 bridge, New Jersey	NOS	8534540	39.4233	-74.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:37:00	\N	0.94	01:28:00	\N	0.96	\N	\N	Absecon, Absecon Creek, U.S. Hwy. 30 bridge	NJ
61663	Absecon Channel, State Route 87 bridge, New Jersey	NOS	8534638	39.385	-74.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:26:00	\N	1.13	00:38:00	\N	0.96	\N	\N	Absecon Channel, State Route 87 bridge	NJ
61664	Pleasantville, Lakes Bay, Great Egg Harbor Inlet, New Jersey	NOS	8534657	39.3817	-74.5183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:37:00	\N	0.82	01:00:00	\N	0.98	\N	\N	Pleasantville, Lakes Bay, Great Egg Harbor Inlet	NJ
61665	River Bend Marina, Great Egg Harbor River, New Jersey	NOS	8534691	39.3683	-74.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	02:25:00	\N	1	02:12:00	\N	0.87	\N	\N	River Bend Marina, Great Egg Harbor River	NJ
61666	Dock Thorofare, Risley Channel, New Jersey	NOS	8534739	39.3517	-74.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:00:00	\N	0.94	00:55:00	\N	0.98	\N	\N	Dock Thorofare, Risley Channel	NJ
61667	Ventnor City, ocean pier, New Jersey (sub)	NOS	8534770	39.335	-74.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	-00:02:00	\N	1	-00:02:00	\N	1	\N	\N	Ventnor City, ocean pier	NJ
61668	Steelmanville, Patcong Ck., 2.5 n.mi. above ent, Great Egg Harbor Bay, New Jersey	NOS	8534778	39.335	-74.5967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:50:00	\N	0.94	01:28:00	\N	0.92	\N	\N	Steelmanville, Patcong Ck., 2.5 nm above ent.	NJ
61669	Longport, Risely Channel, New Jersey (sub)	NOS	8534836	39.3083	-74.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:32:00	\N	0.88	00:26:00	\N	0.94	\N	\N	Longport (inside), Great Egg Harbor Inlet	NJ
61670	Tuckahoe, Tuckahoe River, Great Egg Harbor Bay, New Jersey (sub)	NOS	8534883	39.295	-74.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	02:40:00	\N	1.25	02:12:00	\N	0.86	\N	\N	Tuckahoe, Tuckahoe River	NJ
61671	Beesleys Point, Great Egg Harbor Bay, New Jersey	NOS	8534975	39.2883	-74.6283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:32:00	\N	1	00:55:00	\N	0.87	\N	\N	Beesleys Point	NJ
61672	Cedar Swamp Creek, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8535001	39.2467	-74.7183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	03:03:00	\N	1.53	03:14:00	\N	0.78	\N	\N	Cedar Swamp Creek, Tuckahoe River	NJ
61673	Middle Thorofare, Ocean Drive bridge, Corson Inlet, New Jersey	NOS	8535101	39.215	-74.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:30:00	\N	0.94	00:31:00	\N	0.95	\N	\N	Middle Thorofare, Ocean Drive bridge	NJ
61674	Strathmere, Strathmere Bay, Corson Inlet, New Jersey	NOS	8535163	39.2	-74.6567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:38:00	\N	1	00:31:00	\N	0.95	\N	\N	Strathmere, Strathmere Bay	NJ
61675	Ludlam Bay, west side, Corson Inlet, New Jersey	NOS	8535221	39.1767	-74.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:12:00	\N	0.94	00:56:00	\N	0.98	\N	\N	Ludlam Bay, west side	NJ
61676	Townsend Sound, Townsends Inlet, New Jersey	NOS	8535309	39.1467	-74.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:39:00	\N	0.59	01:08:00	\N	0.9	\N	\N	Townsend Sound	NJ
61677	Stites Sound, Townsends Inlet, New Jersey	NOS	8535357	39.12	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:04:00	\N	1	00:49:00	\N	0.97	\N	\N	Stites Sound	NJ
61678	Ingram Thorofare, Townsends Inlet, New Jersey (sub)	NOS	8535419	39.11	-74.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:50:00	\N	1	00:44:00	\N	0.96	\N	\N	Ingram Thorofare	NJ
61679	Long Reach, Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535451	39.1017	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:11:00	\N	1.06	01:06:00	\N	0.98	\N	\N	Long Reach, Ingram Thorofare	NJ
61680	Nummy Island, Grassy Sound Channel, Hereford Inlet, New Jersey	NOS	8535661	39.0283	-74.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:45:00	\N	1	00:32:00	\N	1	\N	\N	Nummy Island, Grassy Sound Channel	NJ
61681	Old Turtle Thorofare, RR. bridge, Hereford Inlet, New Jersey	NOS	8535695	39.0183	-74.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:10:00	\N	1	00:56:00	\N	1.06	\N	\N	Old Turtle Thorofare, RR. bridge	NJ
61682	West Wildwood, Grassy Sound, Hereford Inlet, New Jersey	NOS	8535726	39.005	-74.8267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:11:00	\N	1	00:57:00	\N	1.04	\N	\N	West Wildwood, Grassy Sound	NJ
61683	Swain Channel, Taylor Sound, Cape May Inlet, New Jersey	NOS	8535805	38.98	-74.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:40:00	\N	1.06	00:55:00	\N	1.09	\N	\N	Swain Channel, Taylor Sound	NJ
61684	Wildwood Crest, Sunset Lake, Cape May Inlet, New Jersey	NOS	8535838	38.9783	-74.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:47:00	\N	1.06	00:52:00	\N	1.1	\N	\N	Wildwood Crest, Sunset Lake	NJ
61685	Cape May Harbor, Cape May Inlet, New Jersey	NOS	8535901	38.9483	-74.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:19:00	\N	1.06	00:33:00	\N	1.1	\N	\N	Cape May Harbor	NJ
61686	Cape Island Creek, Cape May, New Jersey	NOS	8535902	38.9467	-74.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:20:00	\N	1.19	00:40:00	\N	1.11	\N	\N	Cape Island Creek, Cape May	NJ
61687	Cape May (ocean), New Jersey	NOS	8535962	38.93	-74.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:21:00	\N	1.06	00:34:00	\N	1.12	\N	\N	Cape May, Atlantic Ocean	NJ
61688	Cape May Point, Sunset Beach, Delaware Bay, New Jersey	NOS	8536021	38.9467	-74.9717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	-00:08:00	\N	1.16	-00:05:00	\N	1.16	\N	\N	Cape May Point, Sunset Beach	NJ
61689	Cape May Canal, Cape May, Delaware Bay, New Jersey (sub)	NOS	8536110	38.96777777777778	-74.95972222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	-00:05:00	\N	1	-00:06:00	\N	1.18	\N	\N	Cape May, ferry terminal	NJ
61690	North Highlands Beach, Delaware Bay, New Jersey	NOS	8536271	39.0183	-74.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	00:14:00	\N	1.26	00:04:00	\N	1.26	\N	\N	North Highlands Beach	NJ
61691	Dias Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536449	39.0833	-74.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	03:18:00	\N	0.46	01:09:00	\N	0.46	\N	\N	Dias Creek, Route 47 bridge	NJ
61692	Bidwell Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536551	39.1183	-74.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	00:48:00	\N	1.36	00:36:00	\N	1.36	\N	\N	Bidwell Creek, Route 47 bridge	NJ
61693	Bidwell Creek entrance, Delaware Bay, New Jersey (sub)	NOS	8536581	39.1283	-74.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	00:46:00	\N	1.19	00:15:00	\N	1.39	\N	\N	Bidwell Creek entrance	NJ
61694	Sluice Creek, Route 47 bridge, Dennis Creek, Delaware Bay, New Jersey	NOS	8536687	39.1617	-74.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:36:00	\N	1.22	01:49:00	\N	1.22	\N	\N	Sluice Creek, Route 47 bridge, Dennis Creek	NJ
61695	Dennis Creek, 2.5 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536736	39.1783	-74.8517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:17:00	\N	1.26	00:55:00	\N	1.26	\N	\N	Dennis Creek, 2.5 n.mi. above entrance	NJ
61696	Dennis Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536752	39.1833	-74.8217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:30:00	\N	1.2	02:01:00	\N	1.2	\N	\N	Dennis Creek, Route 47 bridge	NJ
61697	West Creek, 0.7 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536764	39.1883	-74.915	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:31:00	\N	1.15	00:20:00	\N	1.15	\N	\N	West Creek, 0.7 n.mi. above entrance	NJ
61698	East Point, Maurice River Cove, Delaware Bay, New Jersey	NOS	8536780	39.2	-75.02	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:08:00	\N	1.39	00:40:00	\N	1.39	\N	\N	East Point, Maurice River Cove	NJ
61699	Riggins Ditch, 0.5 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536801	39.2	-74.97	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:29:00	\N	1.24	00:29:00	\N	1.24	\N	\N	Riggins Ditch, 0.5 n.mi. above entrance	NJ
61700	East Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536823	39.2083	-74.9017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	02:24:00	\N	0.94	01:46:00	\N	0.94	\N	\N	East Creek, Route 47 bridge	NJ
61701	Fishing Creek entrance, Delaware Bay, New Jersey	NOS	8536848	39.2167	-75.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-02:10:00	\N	1.02	-01:51:00	\N	1.02	\N	\N	Fishing Creek entrance	NJ
61702	Dividing Creek entrance, Delaware Bay, New Jersey	NOS	8536849	39.2167	-75.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:05:00	\N	1.35	00:29:00	\N	1.35	\N	\N	Dividing Creek entrance	NJ
61703	West Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536851	39.2167	-74.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	03:17:00	\N	0.58	02:20:00	\N	0.58	\N	\N	West Creek, Route 47 bridge	NJ
61704	Riggins Ditch, Heislerville, Delaware Bay, New Jersey	NOS	8536855	39.2183	-74.98	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:40:00	\N	1.12	01:36:00	\N	1.12	\N	\N	Riggins Ditch, Heislerville	NJ
61705	Weir Creek bridge, Dividing Creek, Delaware Bay, New Jersey	NOS	8536935	39.25	-75.1283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	02:33:00	\N	0.71	01:38:00	\N	0.71	\N	\N	Weir Creek bridge, Dividing Creek	NJ
61706	Hollywood Beach, The Glades, Delaware Bay, New Jersey	NOS	8537026	39.275	-75.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:13:00	\N	0.21	01:45:00	\N	0.21	\N	\N	Hollywood Beach, The Glades	NJ
61707	Money Island, Nantuxent Creek entrance, Delaware Bay, New Jersey	NOS	8537052	39.285	-75.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-01:58:00	\N	1.1	-01:43:00	\N	1.1	\N	\N	Money Island, Nantuxent Creek entrance	NJ
61708	Mauricetown, Maurice River, New Jersey	NOS	8537059	39.285	-74.9917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	02:30:00	\N	1.05	02:17:00	\N	1.05	\N	\N	Mauricetown	NJ
61709	Newport Landing, Nantuxent Creek, Delaware Bay, New Jersey	NOS	8537079	39.2917	-75.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:28:00	\N	0.74	-00:03:00	\N	0.74	\N	\N	Newport Landing, Nantuxent Creek	NJ
61710	Cedar Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537101	39.2983	-75.2467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-01:51:00	\N	1.08	-01:37:00	\N	1.08	\N	\N	Cedar Creek entrance, Nantuxent Cove	NJ
61711	Back Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537116	39.305	-75.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-01:34:00	\N	1.07	-01:29:00	\N	1.07	\N	\N	Back Creek entrance, Nantuxent Cove	NJ
61712	Port Elizabeth, Manumuskin River, Maurice River, New Jersey	NOS	8537147	39.3133	-74.985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	02:58:00	\N	1.05	02:52:00	\N	1.05	\N	\N	Port Elizabeth, Manumuskin River	NJ
61713	Menantico Creek entrance, Maurice River, New Jersey	NOS	8537242	39.3433	-75.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	03:09:00	\N	1.1	03:06:00	\N	1.1	\N	\N	Menantico Creek entrance	NJ
61714	Tindalls Wharf, Cohansey River, Delaware Bay, New Jersey	NOS	8537353	39.3783	-75.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:02:00	\N	1.09	01:01:00	\N	1.09	\N	\N	Tindalls Wharf, Cohansey River	NJ
61715	Millville, Maurice River, New Jersey	NOS	8537359	39.3917	-75.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	03:36:00	\N	1.21	03:33:00	\N	1.21	\N	\N	Millville	NJ
61716	Greenwich Pier, Cohansey River, Delaware Bay, New Jersey	NOS	8537374	39.3833	-75.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:54:00	\N	0.99	-00:42:00	\N	0.99	\N	\N	Greenwich Pier, Cohansey River	NJ
61717	Stathems Neck, Stow Creek, Delaware River, New Jersey	NOS	8537416	39.4067	-75.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:37:00	\N	0.88	-00:22:00	\N	0.88	\N	\N	Stathems Neck, Stow Creek, N.J.	NJ
61718	Pine Island, Malapartis Creek, Mad Horse Creek, New Jersey	NOS	8537488	39.4217	-75.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:18:00	\N	0.92	00:21:00	\N	0.92	\N	\N	Pine Island, Malapartis Creek, N.J.	NJ
61719	Raccoon Ditch, Newport Meadows, Stow Creek, Delaware River, New Jersey	NOS	8537489	39.4217	-75.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:33:00	\N	0.76	01:08:00	\N	0.76	\N	\N	Raccoon Ditch, Newport Meadows, Stow Creek, N.J.	NJ
61969	Haxall, James River, Virginia	NOS	8638478	37.3733	-77.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:53:00	\N	1.33	-04:10:00	\N	0.99	\N	\N	Haxall	VA
61720	1 n.mi. above entrance, Mad Horse Creek, New Jersey	NOS	8537535	39.4317	-75.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:47:00	\N	1.07	-00:20:00	\N	1.07	\N	\N	1 n.mi. above entrance, N.J.	NJ
61721	Canton, Stow Creek, Delaware River, New Jersey	NOS	8537562	39.4617	-75.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:45:00	\N	0.8	01:36:00	\N	0.8	\N	\N	Canton, Stow Creek, N.J.	NJ
61722	Artificial Island, Salem Nuclear Plant, Delaware River, New Jersey	NOS	8537614	39.46	-75.5317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:33:00	\N	1.08	-00:35:00	\N	1.08	\N	\N	Artificial Island, Salem Nuclear Plant, N.J.	NJ
61723	Hope Creek, 0.6 n.mi. above entrance, Delaware River, New Jersey	NOS	8537667	39.4583	-75.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:36:00	\N	1.05	-00:25:00	\N	1.05	\N	\N	Hope Creek, 0.6 n.mi. above entrance, N.J.	NJ
61724	0.8 n.mi. above entrance, Alloway Creek, New Jersey	NOS	8537731	39.4967	-75.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:10:00	\N	0.99	00:21:00	\N	0.99	\N	\N	0.8 n.mi. above entrance	NJ
61725	2.5 n.mi. above entrance, Alloway Creek, New Jersey	NOS	8537753	39.505	-75.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:15:00	\N	0.9	00:51:00	\N	0.9	\N	\N	2.5 n.mi. above entrance	NJ
61726	Abbots Meadow, Alloway Creek, New Jersey	NOS	8537774	39.5117	-75.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:12:00	\N	0.94	00:44:00	\N	0.94	\N	\N	Abbots Meadow	NJ
61727	Coopers Creek bridge, Alloway Creek, New Jersey	NOS	8537779	39.5133	-75.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:00:00	\N	0.78	01:51:00	\N	0.78	\N	\N	Coopers Creek bridge	NJ
61728	Quinton, Alloway Creek, New Jersey	NOS	8537889	39.5483	-75.415	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:30:00	\N	0.69	02:24:00	\N	0.69	\N	\N	Quinton	NJ
61729	Sinnickson Landing, Salem River, New Jersey	NOS	8537961	39.57	-75.4983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:19:00	\N	0.97	00:04:00	\N	0.97	\N	\N	Sinnickson Landing	NJ
61731	Salem Canal entrance, Delaware River, New Jersey	NOS	8538231	39.6833	-75.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:52:00	\N	1	00:36:00	\N	1	\N	\N	Salem Canal entrance, N.J.	NJ
61732	Auburn, Oldmans Creek, Delaware River, New Jersey	NOS	8538274	39.715	-75.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	03:30:00	\N	0.55	04:12:00	\N	0.55	\N	\N	Auburn, Oldmans Creek, N.J.	NJ
61733	Pedricktown, Oldmans Creek, Delaware River, New Jersey	NOS	8538369	39.7617	-75.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	02:07:00	\N	0.75	02:11:00	\N	0.75	\N	\N	Pedricktown, Oldmans Creek, N.J.	NJ
61734	Mantua, Mantua Creek, New Jersey	NOS	8538438	39.795	-75.1767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:56:00	\N	0.71	01:28:00	\N	0.71	\N	\N	Mantua, Mantua Creek, N.J.	NJ
61735	Bridgeport, Raccoon Creek, New Jersey	NOS	8538449	39.8067	-75.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:50:00	\N	1	-01:11:00	\N	0.91	\N	\N	Bridgeport, Raccoon Creek, N.J.	NJ
61736	Woodbury Creek, New Jersey	NOS	8538548	39.86	-75.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:14:00	\N	0.95	-00:13:00	\N	0.96	\N	\N	Woodbury Creek, N.J.	NJ
61737	Billingsport, New Jersey	NOS	8538552	39.85	-75.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:28:00	\N	0.95	-00:35:00	\N	0.93	\N	\N	Billingsport, N.J.	NJ
61738	Westville, Rt. 47 bridge, Big Timber Creek, New Jersey	NOS	8538601	39.8733	-75.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:03:00	\N	1	00:02:00	\N	0.97	\N	\N	Westville, Rt. 47 bridge, Big Timber Creek, N.J.	NJ
61739	Pavonia, Cooper River, RR. bridge, New Jersey	NOS	8538752	39.9467	-75.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:23:00	\N	1	00:14:00	\N	1.04	\N	\N	Pavonia, Cooper River, RR. bridge, N.J.	NJ
61740	Hainesport, South Branch, Rancocas Creek, New Jersey	NOS	8538824	39.9783	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	03:05:00	\N	0.62	02:58:00	\N	0.62	\N	\N	Hainesport, South Branch	NJ
61741	North Branch, Rancocas Creek, New Jersey	NOS	8538848	39.9983	-74.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	03:29:00	\N	0.6	02:58:00	\N	0.48	\N	\N	North Branch	NJ
61742	Palmyra, Pennsauken Creek, Route 73 bridge, New Jersey	NOS	8538853	39.9933	-75.0283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:03:00	\N	0.89	00:51:00	\N	0.89	\N	\N	Palmyra, Pennsauken Creek, Route 73 bridge, N.J.	NJ
61743	Pompeston Creek, New Jersey	NOS	8538875	40.0133	-75.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:43:00	\N	1.05	00:21:00	\N	1.05	\N	\N	Pompeston Creek, N.J.	NJ
61744	Bridgeboro, Rancocas Creek, New Jersey	NOS	8538921	40.0283	-74.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:18:00	\N	1	01:15:00	\N	1.06	\N	\N	Bridgeboro	NJ
61745	Assiscunk Creek, Route 130 bridge, New Jersey	NOS	8539058	40.0733	-74.8483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:31:00	\N	0.85	01:04:00	\N	1.12	\N	\N	Assiscunk Creek, Route 130 bridge, N.J.	NJ
61746	Burlington, Delaware River, New Jersey (sub)	NOS	8539094	40.08	-74.87333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:07:00	\N	1	00:53:00	\N	1.2	\N	\N	Burlington, N.J.	NJ
61747	Fieldsboro, Delaware River, New Jersey (sub)	NOS	8539487	40.1367	-74.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:39:00	\N	1.1	01:07:00	\N	1.29	\N	\N	Fieldsboro, N.J.	NJ
61748	Trenton Marine Terminal, Trenton, New Jersey (sub)	NOS	8539993	40.1883	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:54:00	\N	1	01:13:00	\N	1.35	\N	\N	Trenton, N.J.	NJ
61749	Marcus Hook, Pennsylvania (sub)	NOS	8540433	39.8116667	-75.4094444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-01:07:00	\N	0.95	-01:23:00	\N	0.92	\N	\N	Marcus Hook, Pa.	PA
61750	Wanamaker Bridge, Darby Creek, Pennsylvania	NOS	8542425	39.8767	-75.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:34:00	\N	0.95	-00:46:00	\N	0.95	\N	\N	Wanamaker Bridge	PA
61751	Norwood City, Darby Creek, Pennsylvania	NOS	8542699	39.88	-75.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:35:00	\N	1	-00:42:00	\N	0.97	\N	\N	Norwood City	PA
61752	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania	NOS	8542885	39.8783	-75.2767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:08:00	\N	0.9	-00:22:00	\N	0.91	\N	\N	Tinicum National Wildlife Refuge	PA
61797	Bishops Head, Hooper Strait, Maryland (sub)	NOS	8571421	38.22038888888889	-76.03866666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:04:00	\N	1.08	05:32:00	\N	0.7	\N	\N	Bishops Head, Hooper Strait	MD
61753	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania (2)	NOS	8543024	39.8867	-75.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:27:00	\N	0.74	-00:24:00	\N	0.74	\N	\N	Tinicum National Wildlife Refuge	PA
61754	Penrose Avenue Bridge, Schuylkill River, Pennsylvania	NOS	8543925	39.8983	-75.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:11:00	\N	0.85	-00:22:00	\N	0.96	\N	\N	Penrose Avenue Bridge	PA
61755	Market Street Bridge, Schuylkill River, Pennsylvania	NOS	8545120	39.955	-75.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:00:00	\N	0.8	-00:20:00	\N	0.99	\N	\N	Market Street Bridge	PA
61756	Philadelphia, Municipal Pier 11, Pennsylvania (sub)	NOS	8545530	39.9533	-75.1383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:05:00	\N	0.95	00:02:00	\N	1.04	\N	\N	Philadelphia, Municipal Pier 11, Pa.	PA
61757	Bridesburg, Philadelphia, Pennsylvania (sub)	NOS	8546252	39.98333333333333	-75.075	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:15:00	\N	0.9	00:12:00	\N	1.06	\N	\N	Bridesburg, Philadelphia, Pa.	PA
61758	Cornwells Heights, Pennsylvania	NOS	8547333	40.0683	-74.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:58:00	\N	1	00:46:00	\N	1.17	\N	\N	Cornwells Heights, Pa.	PA
61759	Newbold, Delaware River, Pennsylvania (sub)	NOS	8548989	40.13730555555556	-74.75188888888889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:31:00	\N	1	01:10:00	\N	1.3	\N	\N	Newbold, Pa.	PA
61760	Edgely, Pennsylvania	NOS	8549424	40.1283	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:28:00	\N	1.15	01:08:00	\N	1.27	\N	\N	Edgely, Pa.	PA
61761	Edgemoor, Delaware River, Delaware	NOS	8550438	39.75	-75.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:11:00	\N	1.17	00:52:00	\N	1.02	\N	\N	Edgemoor, Del.	DE
61762	Millside, RR. bridge, Christina River, Delaware	NOS	8550658	39.725	-75.56	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:19:00	\N	1.06	01:08:00	\N	0.99	\N	\N	Millside, RR. bridge	DE
61763	Wilmington Marine Terminal, Christina River, Delaware	NOS	8550714	39.7183	-75.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:06:00	\N	1.11	00:50:00	\N	0.99	\N	\N	Wilmington Marine Terminal	DE
61764	New Castle, Delaware River, Delaware	NOS	8551201	39.6567	-75.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:40:00	\N	1	00:29:00	\N	0.98	\N	\N	New Castle, Delaware	DE
61765	Pea Patch Island, Bulkhead Shoal Channel, Delaware River, Delaware	NOS	8551702	39.5833	-75.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:00:00	\N	1	00:03:00	\N	1.05	\N	\N	Pea Patch Island, Bulkhead Shoal Channel, Del.	DE
61766	Delaware City, Delaware River, Delaware (sub)	NOS	8551762	39.5817	-75.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:14:00	\N	1	00:11:00	\N	0.99	\N	\N	Delaware City	DE
61767	Delaware City Branch Channel bridge, Delaware River, Delaware	NOS	8551851	39.57	-75.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:05:00	\N	0.89	00:00:00	\N	1.02	\N	\N	Delaware City Branch Channel bridge	DE
61768	St. Georges, Chesapeake and Delaware Canal, Delaware	NOS	8551973	39.555	-75.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:17:00	\N	1	-00:16:00	\N	0.83	\N	\N	St. Georges, Delaware	DE
61769	Summit Bridge, Chesapeake and Delaware Canal, Delaware	NOS	8552125	39.5333	-75.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:52:00	\N	0.56	-00:28:00	\N	0.65	\N	\N	Summit Bridge, Delaware	DE
61770	Taylors Bridge, Blackbird Creek, Delaware River, Delaware	NOS	8553069	39.405	-75.5983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:57:00	\N	0.56	01:53:00	\N	0.54	\N	\N	Taylors Bridge, Blackbird Creek, Del.	DE
61771	Woodland Beach, Delaware River, Delaware	NOS	8553501	39.3333	-75.4667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-01:10:00	\N	1.11	-01:07:00	\N	1.11	\N	\N	Woodland Beach, Del.	DE
61772	Leipsic, Leipsic River, Delaware Bay, Delaware	NOS	8554038	39.245	-75.5183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	03:49:00	\N	0.63	03:35:00	\N	0.85	\N	\N	Leipsic, Leipsic River	DE
61773	Mahon River entrance, Delaware Bay, Delaware (sub)	NOS	8554399	39.185	-75.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:29:00	\N	1.13	00:58:00	\N	1.3	\N	\N	Mahon River entrance	DE
61774	Murderkill River entrance, Delaware Bay, Delaware	NOS	8555388	39.0583	-75.3967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:11:00	\N	0.94	00:39:00	\N	1.25	\N	\N	Murderkill River entrance	DE
61775	Brandywine Shoal Light, Delaware Bay, New Jersey (sub)	NOS	8555889	38.98667	-75.11333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	00:23:00	\N	1.06	-00:01:00	\N	1.16	\N	\N	Brandywine Shoal Light	NJ
61776	Mispillion River entrance, Delaware Bay, Delaware	NOS	8556198	38.945	-75.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	00:50:00	\N	1	00:22:00	\N	1.13	\N	\N	Mispillion River entrance	DE
61777	Rehoboth Beach, Delaware	NOS	8557863	38.72	-75.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:08:00	\N	1.33	00:15:00	\N	1.13	\N	\N	Rehoboth Beach	DE
61778	Inlet (Coast Guard Station), Indian River, Delaware (sub)	NOS	8558690	38.61	-75.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:45:00	\N	1	01:14:00	\N	0.76	\N	\N	Indian River Inlet (Coast Guard Station)	DE
61779	Keydash, Isle of Wight Bay, Maryland	NOS	8570255	38.3417	-75.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:54:00	\N	0.81	-00:57:00	\N	0.47	\N	\N	Keydash, Isle of Wight Bay	MD
61780	Ocean City (Isle of Wight Bay), Maryland	NOS	8570282	38.3317	-75.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:23:00	\N	0.94	00:25:00	\N	0.67	\N	\N	Ocean City (Isle of Wight Bay)	MD
61781	Ocean City Inlet, Maryland (sub)	NOS	8570283	38.32833	-75.09166666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:14:00	\N	1	00:28:00	\N	0.65	\N	\N	Ocean City Inlet	MD
61782	South Point, Sinepuxent Neck, Chincoteague Bay, Maryland (sub)	NOS	8570536	38.215	-75.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	05:02:00	\N	0.16	05:16:00	\N	0.16	\N	\N	South Point, Sinepuxent Neck	MD
61783	Public Landing, Chincoteague Bay, Maryland (sub)	NOS	8570649	38.1483	-75.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	05:21:00	\N	0.18	04:41:00	\N	0.18	\N	\N	Public Landing	MD
61784	Ape Hole Creek, Pocomoke Sound, Chesapeake Bay, Maryland	NOS	8571072	37.9617	-75.8217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:58:00	\N	0.83	04:27:00	\N	0.9	\N	\N	Ape Hole Creek, Pocomoke Sound	MD
61785	Crisfield, Little Annemessex River, Chesapeake Bay, Maryland (sub)	NOS	8571091	37.9767	-75.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:51:00	\N	1	04:34:00	\N	0.75	\N	\N	Crisfield, Little Annemessex River	MD
61786	Shelltown, Pocomoke River, Maryland	NOS	8571097	37.98	-75.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:16:00	\N	1	04:32:00	\N	0.94	\N	\N	Shelltown	MD
61787	Ewell, Smith Island, Chesapeake Bay, Maryland (sub)	NOS	8571117	37.995	-76.0317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:19:00	\N	1	04:56:00	\N	0.61	\N	\N	Ewell, Smith Island	MD
61788	Colburn Creek, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571181	38.0483	-75.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:30:00	\N	1.17	04:59:00	\N	0.78	\N	\N	Colburn Creek, Big Annemessex River	MD
61789	Long Point, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571201	38.0567	-75.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:47:00	\N	0.83	05:19:00	\N	0.82	\N	\N	Long Point, Big Annemessex River	MD
61790	Holland Island Bar Light, Chesapeake Bay, Maryland	NOS	8571214	38.0683	-76.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:30:00	\N	0.58	05:16:00	\N	0.56	\N	\N	Holland Island Bar Light	MD
61791	Teague Creek, Manokin River, Chesapeake Bay, Maryland	NOS	8571269	38.1083	-75.8383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:05:00	\N	0.83	05:38:00	\N	0.82	\N	\N	Teague Creek, Manokin River	MD
61792	Chance, Chesapeake Bay, Maryland	NOS	8571351	38.1717	-75.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:57:00	\N	1.17	05:29:00	\N	0.78	\N	\N	Chance	MD
61793	Snow Hill, city park, Pocomoke River, Maryland (sub)	NOS	8571359	38.17833	-75.39666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	08:54:00	\N	1.33	08:44:00	\N	0.58	\N	\N	Snowhill, city park	MD
61794	Sharkfin Shoal Light, Chesapeake Bay, Maryland	NOS	8571396	38.2017	-75.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:06:00	\N	0.92	05:46:00	\N	0.86	\N	\N	Sharkfin Shoal Light	MD
61795	Hooper Strait Light, Chesapeake Bay, Maryland	NOS	8571402	38.2267	-76.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:51:00	\N	1.17	05:26:00	\N	0.61	\N	\N	Hooper Strait Light	MD
61796	Great Shoals Light, Monie Bay, Chesapeake Bay, Maryland	NOS	8571416	38.2167	-75.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:22:00	\N	0.92	06:00:00	\N	0.9	\N	\N	Great Shoals Light, Monie Bay	MD
61798	Roaring Point, Nanticoke River, Maryland	NOS	8571476	38.2617	-75.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:35:00	\N	0.92	06:00:00	\N	0.9	\N	\N	Roaring Point	MD
61799	Whitehaven, Wicomico River, Maryland	NOS	8571485	38.2683	-75.7883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:46:00	\N	1	06:26:00	\N	0.94	\N	\N	Whitehaven	MD
61800	Middle Hooper Island, Chesapeake Bay, Maryland	NOS	8571519	38.2967	-76.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:39:00	\N	1.5	-04:40:00	\N	1.32	\N	\N	Middle Hooper Island	MD
61801	McCready's Creek, Fishing Bay, Chesapeake Bay, Maryland (sub)	NOS	8571559	38.3	-76.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:22:00	\N	1.17	05:49:00	\N	0.82	\N	\N	McCreedy's Creek, Fishing Bay	MD
61802	Barren Island, Chesapeake Bay, Maryland (sub)	NOS	8571579	38.3417	-76.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:56:00	\N	0.68	-04:45:00	\N	1.01	\N	\N	Barren Island	MD
61803	Smithville Road Bridge, Beaverdam Creek, Little Choptank River, Maryland (sub)	NOS	8571702	38.42833	-76.23666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:49:00	\N	0.82	-02:26:00	\N	1.01	\N	\N	Smithville Road Bridge, Beaverdam Creek	MD
61804	Taylors Island, Slaughter Creek, Little Choptank River, Maryland	NOS	8571752	38.4667	-76.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-03:00:00	\N	1.18	-03:15:00	\N	1.1	\N	\N	Taylors Island, Slaughter Creek	MD
61805	Vienna, Nanticoke River, Maryland (sub)	NOS	8571773	38.48333	-75.81833333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	08:32:00	\N	1.33	08:25:00	\N	0.79	\N	\N	Vienna	MD
61806	Woolford, Church Creek, Little Choptank River, Maryland	NOS	8571807	38.5067	-76.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:55:00	\N	1.41	-03:11:00	\N	1.25	\N	\N	Woolford, Church Creek	MD
61807	Sharptown, Nanticoke River, Maryland	NOS	8571858	38.545	-75.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	09:28:00	\N	1	09:19:00	\N	0.97	\N	\N	Sharptown	MD
61808	Cherry Island, Beckwiths Creek, Little Choptank River, Maryland	NOS	8571881	38.5617	-76.2083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:57:00	\N	1.27	-03:07:00	\N	1.18	\N	\N	Cherry Island, Beckwiths Creek	MD
61809	Cambridge, Choptank River, Maryland (sub)	NOS	8571892	38.5741667	-76.0722222	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:28:00	\N	0.95	-02:42:00	\N	1.23	\N	\N	Cambridge	MD
61810	Avalon, Dogwood Harbor, Chesapeake Bay, Maryland	NOS	8571901	38.71	-76.335	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:48:00	\N	1.36	-02:54:00	\N	1.18	\N	\N	Avalon, Dogwood Harbor	MD
61811	Dover Bridge, Choptank River, Maryland	NOS	8571944	38.7567	-75.9983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:41:00	\N	1.68	-00:18:00	\N	1.54	\N	\N	Dover Bridge	MD
61812	Ferry Cove, Tilghman Island, Chesapeake Bay, Maryland	NOS	8571979	38.765	-76.3283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:42:00	\N	1	-02:33:00	\N	0.98	\N	\N	Tilghman Island, Ferry Cove, Eastern Bay	MD
61813	Oxford, Tred Avon River, Maryland	NOS	8572108	38.6933	-76.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:45:00	\N	1.41	-02:50:00	\N	1.25	\N	\N	Oxford	MD
61814	Deep Neck Point, Broad Creek, Chesapeake Bay, Maryland	NOS	8572204	38.7317	-76.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:47:00	\N	1.41	-02:57:00	\N	1.25	\N	\N	Deep Neck Point, Broad Creek	MD
61815	Easton Point, Tred Avon River, Maryland	NOS	8572296	38.7683	-76.095	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:35:00	\N	1.59	-02:45:00	\N	1.47	\N	\N	Easton Point	MD
61816	St. Michaels, San Domingo Creek, Chesapeake Bay, Maryland	NOS	8572313	38.775	-76.2333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:52:00	\N	1.41	-02:55:00	\N	1.25	\N	\N	St. Michaels, San Domingo Creek	MD
61817	St. Michaels, Miles River, Chesapeake Bay, Maryland (sub)	NOS	8572342	38.7867	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:02:00	\N	1.18	-02:12:00	\N	1.22	\N	\N	St. Michaels, Miles River	MD
61818	Kent Point Marina, Chesapeake Bay, Maryland (sub)	NOS	8572467	38.8367	-76.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:29:00	\N	0.95	-02:21:00	\N	0.97	\N	\N	Kent Point Marina	MD
61819	Claiborne, Eastern Bay, Chesapeake Bay, Maryland	NOS	8572468	38.8367	-76.28	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:28:00	\N	1.09	-02:26:00	\N	0.96	\N	\N	Claiborne, Eastern Bay	MD
61820	Hillsboro, Tuckahoe Creek, Maryland (sub)	NOS	8572669	38.9167	-75.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	01:18:00	\N	0.86	01:21:00	\N	1.83	\N	\N	Hillsboro, Tuckahoe Creek	MD
61821	Matapeake, Kent Island, Chesapeake Bay, Maryland (sub)	NOS	8572770	38.9567	-76.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-01:49:00	\N	0.95	-01:30:00	\N	0.9	\N	\N	Matapeake, Kent Island	MD
61822	Kent Island Narrows, Chesapeake Bay, Maryland	NOS	8572792	38.9667	-76.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-01:23:00	\N	1.18	-01:30:00	\N	1.1	\N	\N	Kent Island Narrows	MD
61823	Queenstown, Chester River, Maryland	NOS	8572867	38.9967	-76.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:08:00	\N	1.27	00:05:00	\N	1.18	\N	\N	Queenstown	MD
61824	Love Point, Chester River, Maryland (sub)	NOS	8572955	39.0317	-76.3017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:41:00	\N	0.95	-00:25:00	\N	1.03	\N	\N	Love Point	MD
61825	Centreville Landing, Corsica River, Chester River, Maryland	NOS	8573006	39.0533	-76.075	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	00:14:00	\N	1.89	00:20:00	\N	1.47	\N	\N	Centreville Landing, Corsica River	MD
61826	Cliffs Point, Chester River, Maryland	NOS	8573125	39.1067	-76.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:02:00	\N	1.5	00:12:00	\N	1.32	\N	\N	Cliffs Point	MD
61827	Cliffs Wharf, Chester River, Maryland	NOS	8573137	39.11	-76.1383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:08:00	\N	1.27	00:09:00	\N	1.33	\N	\N	Cliffs Wharf	MD
61828	Deep Landing, Swan Creek, Chesapeake Bay, Maryland	NOS	8573211	39.145	-76.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:04:00	\N	1.09	00:02:00	\N	0.96	\N	\N	Deep Landing, Swan Creek	MD
61829	Chestertown, Chester River, Maryland	NOS	8573343	39.2067	-76.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	00:36:00	\N	1.77	01:03:00	\N	1.62	\N	\N	Chestertown	MD
61830	Crumpton, Chester River, Maryland (sub)	NOS	8573349	39.245	-75.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	01:04:00	\N	0.91	01:10:00	\N	1.82	\N	\N	Crumpton	MD
61831	Tolchester Beach, Chesapeake Bay, Maryland (sub)	NOS	8573364	39.21333	-76.245	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	00:11:00	\N	0.95	00:18:00	\N	1.04	\N	\N	Tolchester Beach	MD
61832	Worton Creek entrance, Chesapeake Bay, Maryland	NOS	8573442	39.2967	-76.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	01:19:00	\N	1.27	01:22:00	\N	1.18	\N	\N	Worton Creek entrance	MD
61833	Sassafras River, Betterton, Chesapeake Bay, Maryland (sub)	NOS	8573704	39.3717	-76.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	02:15:00	\N	1	02:35:00	\N	1.34	\N	\N	Sassafras River, Betterton	MD
61834	Saxis, Starling Creek, Pocomoke Sound, Chesapeake Bay, Maryland	NOS	8573777	37.92166666666701	-75.728333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:36:00	\N	1.17	03:52:00	\N	0.89	\N	\N	Saxis, Starling Creek, Pocomoke Sound	MD
61835	Town Point Wharf, Elk River, Maryland (sub)	NOS	8573903	39.5033	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	02:59:00	\N	0.86	03:18:00	\N	1.74	\N	\N	Town Point Wharf	MD
61836	Chesapeake City, Chesapeake and Delaware Canal, Maryland (sub)	NOS	8573927	39.5267	-75.81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-01:12:00	\N	1.28	-00:45:00	\N	0.56	\N	\N	Chesapeake City, Maryland	MD
61837	Charlestown, Northeast River, Chesapeake Bay, Maryland	NOS	8573968	39.5733	-75.97	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	04:03:00	\N	1.86	03:52:00	\N	1.69	\N	\N	Charlestown, Northeast River	MD
61838	Old Frenchtown Wharf, Elk River, Maryland	NOS	8573969	39.575	-75.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	03:00:00	\N	2.27	03:13:00	\N	2.06	\N	\N	Old Frenchtown Wharf	MD
61839	Port Deposit, Susquehanna River, Maryland	NOS	8574008	39.6033	-76.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	03:49:00	\N	1.14	03:24:00	\N	1.51	\N	\N	Port Deposit	MD
61840	Havre de Grace, Susquehanna River, Maryland (sub)	NOS	8574070	39.5367	-76.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	03:27:00	\N	0.95	03:13:00	\N	1.55	\N	\N	Havre de Grace	MD
61841	Pond Point (Aberdeen P.G.), Bush River, Chesapeake Bay, Maryland (sub)	NOS	8574459	39.3883	-76.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	01:31:00	\N	0.86	01:52:00	\N	1.06	\N	\N	Pond Point, Bush River	MD
61842	Fort McHenry Marsh, Patapsco River, Maryland (sub)	NOS	8574683	39.2617	-76.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Fort McHenry Marsh	MD
61843	Hawkins Point, Patapsco River, Maryland	NOS	8574821	39.2083	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	00:06:00	\N	0.95	00:00:00	\N	1.03	\N	\N	Hawkins Point	MD
61844	North Point, Patapsco River, Maryland	NOS	8574857	39.1967	-76.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	00:04:00	\N	1.09	00:12:00	\N	0.93	\N	\N	North Point	MD
61845	Stony Creek, Patapsco River, Maryland	NOS	8574931	39.1633	-76.5267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:05:00	\N	0.91	00:03:00	\N	0.95	\N	\N	Stony Creek	MD
61846	Cornfield Creek, Magothy River, Chesapeake Bay, Maryland	NOS	8575109	39.1	-76.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:38:00	\N	0.95	-00:29:00	\N	0.89	\N	\N	Cornfield Creek, Magothy River	MD
61847	Mountain Point, Magothy River, Chesapeake Bay, Maryland	NOS	8575229	39.0617	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:04:00	\N	0.77	-00:04:00	\N	0.74	\N	\N	Mountain Point, Magothy River	MD
61848	Brewer Point, Severn River, Maryland	NOS	8575331	39.0267	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:54:00	\N	0.91	-00:45:00	\N	0.74	\N	\N	Brewer Point	MD
61849	Annapolis (US Naval Academy), Severn River, Maryland (sub)	NOS	8575512	38.98328	-76.4815555551317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-01:44:00	\N	1	-01:30:00	\N	0.88	\N	\N	Annapolis (US Naval Academy)	MD
61850	Gingerville Creek, South River, Chesapeake Bay, Maryland	NOS	8575550	38.9583	-76.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:06:00	\N	1	-02:01:00	\N	0.92	\N	\N	Gingerville Creek, South River	MD
61851	Edgewater, South River, Chesapeake Bay, Maryland	NOS	8575579	38.95	-76.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:07:00	\N	0.91	-01:51:00	\N	0.81	\N	\N	Edgewater, South River	MD
61852	Thomas Point Shoal Light, Chesapeake Bay, Maryland	NOS	8575737	38.9	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:11:00	\N	0.91	-01:56:00	\N	0.81	\N	\N	Thomas Point Shoal Light	MD
61853	Rhode River (County Wharf), Chesapeake Bay, Maryland	NOS	8575787	38.8867	-76.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:17:00	\N	1	-02:07:00	\N	0.88	\N	\N	Rhode River (County Wharf)	MD
61854	Galesville, West River, Chesapeake Bay, Maryland	NOS	8575923	38.8417	-76.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-01:34:00	\N	0.91	-01:39:00	\N	0.81	\N	\N	Galesville, West River	MD
61855	Rose Haven, Chesapeake Bay, Maryland	NOS	8576256	38.725	-76.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:44:00	\N	0.91	-02:37:00	\N	0.81	\N	\N	Rose Haven	MD
61856	Chesapeake Beach, Chesapeake Bay, Maryland	NOS	8576363	38.7	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-03:05:00	\N	1	-02:47:00	\N	0.88	\N	\N	Chesapeake Beach	MD
61857	Long Beach, Chesapeake Bay, Maryland (sub)	NOS	8577004	38.465	-76.4733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:04:00	\N	0.77	-03:47:00	\N	0.87	\N	\N	Long Beach	MD
61858	Broomes Island, Patuxent River, Maryland	NOS	8577123	38.415	-76.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:19:00	\N	1.36	-04:13:00	\N	1.18	\N	\N	Broomes Island	MD
61859	Cove Point, Chesapeake Bay, Maryland (sub)	NOS	8577188	38.3917	-76.3983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:25:00	\N	0.83	-04:10:00	\N	0.83	\N	\N	Cove Point	MD
61860	Solomons Island, Patuxent River, Maryland (sub)	NOS	8577330	38.3172222	-76.4508333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:46:00	\N	0.73	-04:38:00	\N	0.98	\N	\N	Solomons Island	MD
61861	Cornfield Harbor, Potomac River, Maryland	NOS	8577940	38.06	-76.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-07:35:00	\N	0.53	-06:16:00	\N	0.48	\N	\N	Cornfield Harbor, Md.	MD
61862	Point Lookout, Chesapeake Bay, Maryland	NOS	8578002	38.04	-76.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-05:37:00	\N	0.77	-05:28:00	\N	1.02	\N	\N	Point Lookout	MD
61863	Piney Point, Potomac River, Maryland	NOS	8578240	38.1333	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-07:16:00	\N	0.6	-05:54:00	\N	0.51	\N	\N	Piney Point, Md.	MD
61864	Colton Point, Potomac River, Maryland	NOS	8578465	38.2233	-76.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-06:43:00	\N	0.73	-05:18:00	\N	0.65	\N	\N	Colton Point, Md.	MD
61865	Mills Point (south of), Wicomico River, Maryland	NOS	8578551	38.3267	-76.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-06:05:00	\N	0.73	-05:05:00	\N	0.65	\N	\N	Mills Point (south of), Wicomico Riv., Md.	MD
61866	Lower Cedar Point, Potomac River, Maryland	NOS	8578693	38.3417	-76.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-05:56:00	\N	0.6	-04:48:00	\N	0.54	\N	\N	Lower Cedar Point, Md.	MD
61867	Goose Creek, Port Tobacco River, Potomac River, Maryland	NOS	8578769	38.4533	-77.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-05:07:00	\N	0.6	-04:08:00	\N	0.54	\N	\N	Goose Creek, Port Tobacco River, Md.	MD
61868	Riverside, Potomac River, Maryland	NOS	8578853	38.3867	-77.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:24:00	\N	0.53	-03:23:00	\N	0.48	\N	\N	Riverside, Md.	MD
61869	Clifton Beach, Smith Point, Potomac River, Maryland	NOS	8578931	38.41333333333299	-77.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-02:46:00	\N	0.67	-01:42:00	\N	0.41	\N	\N	Clifton Beach, Smith Point, Md.	MD
61870	Liverpool Point, Potomac River, Maryland	NOS	8578984	38.46	-77.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-01:58:00	\N	0.67	-00:39:00	\N	0.44	\N	\N	Liverpool Point, Md.	MD
61871	Benedict, Patuxent River, Maryland	NOS	8579135	38.5133	-76.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-03:54:00	\N	1.82	-03:54:00	\N	1.47	\N	\N	Benedict	MD
61872	Indian Head, Potomac River, Maryland	NOS	8579381	38.6017	-77.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-01:33:00	\N	0.73	-00:14:00	\N	0.65	\N	\N	Indian Head, Md.	MD
61873	Lower Marlboro, Patuxent River, Maryland (sub)	NOS	8579542	38.655	-76.68333333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:51:00	\N	0.77	-02:44:00	\N	1.44	\N	\N	Lower Marlboro	MD
61874	Marshall Hall, Potomac River, Maryland	NOS	8579629	38.6867	-77.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-00:55:00	\N	0.93	00:10:00	\N	0.82	\N	\N	Marshall Hall, Md.	MD
61875	Bladensburg, Anacostia River, Maryland (sub)	NOS	8579997	38.9333	-76.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	00:25:00	\N	1.13	00:31:00	\N	1.06	\N	\N	Bladensburg, Md.	MD
61876	Bellevue, Potomac River, DC	NOS	8590111	38.8267	-77.0267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-00:11:00	\N	1.33	00:34:00	\N	1.02	\N	\N	Bellevue, D.C.	DC
61877	Washington Naval Yard, Anacostia River, DC	NOS	8593005	38.8717	-76.995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-00:06:00	\N	1.2	00:18:00	\N	1.01	\N	\N	Washington Naval Yard	DC
61878	Kingman Lake, Anacostia River, DC	NOS	8593545	38.895	-76.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	00:04:00	\N	1.2	00:22:00	\N	1.03	\N	\N	Kingman Lake	DC
61879	Kenilworth Aquatic Garden, Anacostia River, DC	NOS	8593909	38.91	-76.955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	00:10:00	\N	1.07	00:29:00	\N	1.05	\N	\N	Kenilworth Aquatic Garden	DC
61880	Franklin City, Virginia	NOS	8630055	38.0067	-75.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	03:00:00	\N	0.63	02:20:00	\N	0.22	\N	\N	Franklin City	VA
61881	Chincoteague Island, Blake Cove, Virginia	NOS	8630194	37.9517	-75.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	02:32:00	\N	0.56	01:51:00	\N	0.28	\N	\N	Chincoteague Island, Blake Cove	VA
61882	Chincoteague Island, Oyster Bay, Virginia	NOS	8630225	37.9417	-75.3467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	02:05:00	\N	0.56	01:44:00	\N	0.46	\N	\N	Chincoteague Island, Oyster Bay	VA
61883	Chincoteague Island, Lewis Creek, Virginia	NOS	8630229	37.9383	-75.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:38:00	\N	0.63	01:17:00	\N	0.4	\N	\N	Chincoteague Island, Lewis Creek	VA
61884	Chincoteague Channel (south end), Chincoteague Bay, Virginia (sub)	NOS	8630308	37.9067	-75.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:47:00	\N	0.69	00:39:00	\N	0.64	\N	\N	Chincoteague Channel (south end)	VA
61885	Harbor of Refuge, Virginia	NOS	8630316	37.9033	-75.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:35:00	\N	0.88	00:31:00	\N	0.73	\N	\N	Harbor of Refuge	VA
61886	Wishart Point, Bogues Bay, Virginia	NOS	8630371	37.8817	-75.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:13:00	\N	0.63	00:52:00	\N	0.77	\N	\N	Wishart Point, Bogues Bay	VA
61887	Assateague Beach, Toms Cove, Virginia	NOS	8630413	37.865	-75.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:48:00	\N	1.25	00:35:00	\N	1.08	\N	\N	Assateague Beach, Toms Cove	VA
61888	Wallops Island, Virginia	NOS	8630440	37.8417	-75.4783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	-00:04:00	\N	0.31	00:04:00	\N	1.06	\N	\N	Wallops Island	VA
61889	Gargathy Neck, Virginia	NOS	8630637	37.7767	-75.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:27:00	\N	0.63	01:31:00	\N	0.88	\N	\N	Gargathy Neck	VA
61890	Folly Creek, Metompkin Inlet, Virginia	NOS	8630839	37.6967	-75.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:12:00	\N	0.63	01:24:00	\N	0.97	\N	\N	Folly Creek, Metompkin Inlet	VA
61891	Metompkin Inlet, Virginia	NOS	8630901	37.6717	-75.595	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:44:00	\N	1.25	01:01:00	\N	1.08	\N	\N	Metompkin Inlet	VA
61892	Wachapreague, Wachapreague Channel, Virginia (sub)	NOS	8631044	37.60777777777778	-75.68583333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:56:00	\N	1.06	01:10:00	\N	1.19	\N	\N	Wachapreague, Wachapreague Channel	VA
61893	Revel Island, Revel Creek, Virginia	NOS	8631234	37.4967	-75.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:27:00	\N	1	00:35:00	\N	1.19	\N	\N	Revel Creek, Revel Island	VA
61894	Upshur Neck, south end, Virginia	NOS	8631287	37.4667	-75.8	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:14:00	\N	1.25	01:09:00	\N	1.31	\N	\N	Upshur Neck, south end	VA
61895	Great Machipongo Inlet (inside), Virginia	NOS	8631411	37.3933	-75.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:56:00	\N	1.25	01:05:00	\N	1.16	\N	\N	Great Machipongo Inlet (inside)	VA
61896	Sand Shoal Inlet (Coast Guard Station), Virginia	NOS	8631542	37.3017	-75.7783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:17:00	\N	1	00:32:00	\N	1.18	\N	\N	Sand Shoal Inlet (Coast Guard Station)	VA
61897	Oyster Harbor, Virginia	NOS	8631591	37.2883	-75.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:36:00	\N	1.13	01:00:00	\N	1.34	\N	\N	Oyster Harbor	VA
61898	Smith Island (Coast Guard Station), Virginia	NOS	8631874	37.1233	-75.9117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:29:00	\N	1.25	00:52:00	\N	1.05	\N	\N	Smith Island (Coast Guard Station)	VA
61899	Fishermans Island, Chesapeake Bay, Virginia	NOS	8632085	37.0967	-75.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	00:11:00	\N	1.25	00:02:00	\N	1.19	\N	\N	Fishermans Island	VA
61900	Kiptopeke Beach, Chesapeake Bay, Virginia (sub)	NOS	8632200	37.16519	-75.98844444433848	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	00:32:00	\N	0.92	00:23:00	\N	1.01	\N	\N	Kiptopeke Beach	VA
61901	Old Plantation Light, Chesapeake Bay, Virginia	NOS	8632314	37.2333	-76.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	00:52:00	\N	0.83	00:33:00	\N	0.92	\N	\N	Old Plantation Light	VA
61902	Cape Charles Harbor (USCG Wharf), Chesapeake Bay, Virginia (sub)	NOS	8632366	37.2633	-76.02	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	01:03:00	\N	0.92	00:45:00	\N	0.9	\N	\N	Cape Charles Harbor	VA
61903	Gaskins Point, Occohannock Creek, Chesapeake Bay, Virginia (sub)	NOS	8632869	37.5567	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	03:13:00	\N	0.83	02:35:00	\N	0.66	\N	\N	Gaskins Point, Occohannock Creek	VA
61904	Harborton, Pungoteague Creek, Chesapeake Bay, Virginia	NOS	8633091	37.6667	-75.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	03:33:00	\N	0.83	03:11:00	\N	0.7	\N	\N	Harborton, Pungoteague Creek	VA
61905	Onancock, Onancock Creek, Chesapeake Bay, Virginia	NOS	8633214	37.7117	-75.7567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:19:00	\N	0.83	03:55:00	\N	0.71	\N	\N	Onancock, Onancock Creek	VA
61906	Chesconessex Creek, Schooner Bay, Chesapeake Bay, Virginia	NOS	8633362	37.7633	-75.7733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	03:59:00	\N	1.25	03:41:00	\N	0.78	\N	\N	Chesconessex Creek, Schooner Bay	VA
61907	Watts Island, Chesapeake Bay, Virginia	NOS	8633451	37.7983	-75.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:12:00	\N	0.83	04:02:00	\N	0.64	\N	\N	Watts Island	VA
61908	Tangier Island, Chesapeake Bay, Virginia (sub)	NOS	8633532	37.8283	-75.9933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:16:00	\N	0.75	03:58:00	\N	0.6	\N	\N	Tangier Island	VA
61909	Guard Shore, Chesapeake Bay, Virginia	NOS	8633596	37.85	-75.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:47:00	\N	0.83	04:06:00	\N	0.9	\N	\N	Guard Shore	VA
61910	Muddy Creek Entrance, Chesapeake Bay, Virginia	NOS	8633604	37.855	-75.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:51:00	\N	0.83	04:14:00	\N	0.86	\N	\N	Muddy Creek Entrance	VA
61911	Alexandria, Potomac River, Virginia	NOS	8634214	38.805	-77.0383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-00:11:00	\N	1.33	00:18:00	\N	0.96	\N	\N	Alexandria, Va.	VA
61912	Quantico, Potomac River, Virginia	NOS	8634689	38.52	-77.2867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-02:04:00	\N	0.67	-00:52:00	\N	0.51	\N	\N	Quantico, Va.	VA
61913	Aquia Creek, Potomac River, Virginia	NOS	8634858	38.4183	-77.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-02:32:00	\N	0.67	-01:28:00	\N	0.48	\N	\N	Aquia Creek, Va.	VA
61914	Mathias Point, Potomac River, Virginia	NOS	8634892	38.3983	-77.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:56:00	\N	0.67	-04:00:00	\N	0.44	\N	\N	Mathias Point, Va.	VA
61915	Massaponax Sand & Gravel, Rappahannock River, Virginia	NOS	8635154	38.255	-77.41	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-00:41:00	\N	1.33	-00:39:00	\N	0.88	\N	\N	Massaponax	VA
61916	Hopyard Landing, Rappahannock River, Virginia	NOS	8635171	38.2433	-77.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-01:57:00	\N	0.67	-01:07:00	\N	0.75	\N	\N	Hopyard Landing	VA
61917	Rappahannock Bend, Virginia (sub)	NOS	8635257	38.2133	-77.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-02:30:00	\N	0.2	-01:35:00	\N	0.73	\N	\N	Park Turn	VA
61918	Port Royal, Rappahannock River, Virginia	NOS	8635299	38.1733	-77.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-03:02:00	\N	0.67	-02:19:00	\N	0.68	\N	\N	Port Royal	VA
61919	Mount Holly, Nomini Creek, Potomac River, Virginia	NOS	8635409	38.0983	-76.735	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-06:14:00	\N	0.67	-04:51:00	\N	0.54	\N	\N	Mount Holly, Nomini Creek, Va.	VA
61920	Ragged Point, Coles Neck, Potomac River, Virginia	NOS	8635485	38.1417	-76.6133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-07:03:00	\N	0.67	-05:35:00	\N	0.54	\N	\N	Ragged Point, Coles Neck, Va.	VA
61921	Saunders Wharf, Rappahannock River, Virginia	NOS	8635554	38.09	-77.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:41:00	\N	0.66	-03:53:00	\N	0.54	\N	\N	Saunders Wharf	VA
61922	Kinsale, Yeocomico River, Virginia	NOS	8635671	38.0317	-76.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-06:53:00	\N	0.67	-05:46:00	\N	0.44	\N	\N	Kinsale, Yeocomico River, Va.	VA
61923	Lewisetta, Potomac River, Virginia (sub)	NOS	8635750	37.99538888888889	-76.46461111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-07:31:00	\N	0.8	-06:19:00	\N	0.46	\N	\N	Lewisetta, Va.	VA
61924	Travis Point, Coan River, Potomac River, Virginia	NOS	8635762	37.9967	-76.4667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-07:05:00	\N	0.67	-06:00:00	\N	0.44	\N	\N	Travis Point, Coan River, Va.	VA
61925	Tappahannock, Rappahannock River, Virginia	NOS	8635881	37.93	-76.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	05:18:00	\N	0.83	04:40:00	\N	0.71	\N	\N	Tappahannock	VA
61926	Sunnybank, Little Wicomico River, Chesapeake Bay, Virginia	NOS	8635959	37.8867	-76.2667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:45:00	\N	0.3	06:41:00	\N	0.3	\N	\N	Sunnybank, Little Wicomico River	VA
61927	Wares Wharf, Rappahannock River, Virginia (sub)	NOS	8635985	37.8733	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	04:34:00	\N	0.33	04:04:00	\N	0.75	\N	\N	Wares Wharf	VA
61928	Glebe Point, Great Wicomico River, Chesapeake Bay, Virginia	NOS	8636046	37.8467	-76.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:37:00	\N	0.83	04:15:00	\N	0.49	\N	\N	Glebe Point, Great Wicomico River	VA
61929	Fleeton Point, Chesapeake Bay, Virginia	NOS	8636128	37.8133	-76.275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:14:00	\N	0.41	03:58:00	\N	0.41	\N	\N	Fleeton Point	VA
61930	Great Wicomico River Light, Chesapeake Bay, Virginia	NOS	8636142	37.805	-76.2683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:11:00	\N	0.41	03:58:00	\N	0.41	\N	\N	Great Wicomico River Light	VA
61931	Bayport, Rappahannock River, Virginia	NOS	8636261	37.755	-76.6733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	03:51:00	\N	0.83	03:22:00	\N	0.67	\N	\N	Bayport	VA
61932	Millenbeck, Corrotoman River, Rappahannock River, Virginia	NOS	8636458	37.6683	-76.4867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	03:05:00	\N	0.83	02:37:00	\N	0.55	\N	\N	Millenbeck, Corrotoman River	VA
61933	Wakema (Fraziers Ferry), Mattaponi River, Virginia	NOS	8636499	37.65	-76.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	03:57:00	\N	1.67	03:34:00	\N	1.41	\N	\N	Wakema (Fraziers Ferry), Mattaponi River	VA
61934	Urbanna, Rappahannock River, Virginia	NOS	8636522	37.65	-76.575	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	03:09:00	\N	0.83	02:50:00	\N	0.59	\N	\N	Urbanna	VA
61935	Northbury, Pamunkey River, Virginia	NOS	8636558	37.625	-77.1217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	06:18:00	\N	1.67	06:03:00	\N	1.37	\N	\N	Northbury	VA
61936	Windmill Point, Rappahannock River, Virginia (sub)	NOS	8636580	37.61611111111111	-76.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:14:00	\N	0.83	01:55:00	\N	0.49	\N	\N	Windmill Point	VA
61937	Windmill Point Light, Chesapeake Bay, Virginia	NOS	8636623	37.5967	-76.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	03:12:00	\N	0.41	02:48:00	\N	0.41	\N	\N	Windmill Point Light	VA
61938	Lester Manor, Pamunkey River, Virginia (sub)	NOS	8636653	37.5833	-76.99	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	05:00:00	\N	0.83	04:45:00	\N	1.05	\N	\N	Lester Manor	VA
61939	Mill Creek (Grey Point), Rappahannock River, Virginia	NOS	8636654	37.5833	-76.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:42:00	\N	0.83	02:28:00	\N	0.55	\N	\N	Mill Creek (Grey Point)	VA
61940	Jackson Creek, Deltaville, Piankatank River, Virginia	NOS	8636735	37.5483	-76.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:04:00	\N	0.83	01:36:00	\N	0.51	\N	\N	Jackson Creek, Deltaville	VA
61941	West Point, York River, Virginia	NOS	8636769	37.535	-76.7933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:38:00	\N	0.83	02:12:00	\N	1.14	\N	\N	West Point	VA
61942	Dixie, Piankatank River, Virginia	NOS	8636831	37.5067	-76.4167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:14:00	\N	0.83	01:34:00	\N	0.55	\N	\N	Dixie	VA
61943	Roane Point, York River, Virginia	NOS	8636969	37.4467	-76.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	01:50:00	\N	0.83	01:47:00	\N	1.14	\N	\N	Roane Point	VA
61944	Belleville, Mobjack Bay, Virginia	NOS	8637072	37.4117	-76.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:00:00	\N	0.83	-00:06:00	\N	1.02	\N	\N	Belleville	VA
61945	Wolf Trap Light, Chesapeake Bay, Virginia	NOS	8637144	37.39	-76.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:32:00	\N	0.83	-00:02:00	\N	0.67	\N	\N	Wolf Trap Light	VA
61946	Mobjack, East River, Mobjack Bay, Virginia	NOS	8637199	37.3733	-76.3467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:02:00	\N	0.83	-00:17:00	\N	0.98	\N	\N	Mobjack, East River	VA
61947	Browns Bay, Mobjack Bay, Virginia	NOS	8637444	37.3	-76.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	-00:03:00	\N	1.58	-00:11:00	\N	0.98	\N	\N	Browns Bay	VA
61948	Cheatham Annex, York River, Virginia	NOS	8637472	37.2917	-76.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:40:00	\N	0.83	00:48:00	\N	1.02	\N	\N	Cheatham Annex	VA
61949	Gloucester Point, York River, Virginia (sub)	NOS	8637624	37.2467	-76.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:11:00	\N	1	00:10:00	\N	0.98	\N	\N	Gloucester Point	VA
61950	Tue Marshes Light, York River, Virginia	NOS	8637663	37.235	-76.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:03:00	\N	0.83	00:03:00	\N	0.9	\N	\N	Tue Marshes Light	VA
61951	Goodwin Neck, Yorktown, York River, Virginia	NOS	8637686	37.23	-76.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:15:00	\N	0.83	00:18:00	\N	0.9	\N	\N	Yorktown, Goodwin Neck	VA
61952	Yorktown USCG Training Center, York River, Virginia (sub)	NOS	8637689	37.2265	-76.4788	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:15:00	\N	1.08	00:10:00	\N	0.95	\N	\N	Yorktown, USCG Training Center	VA
61953	Messick Point, Back River, Chesapeake Bay, Virginia	NOS	8638051	37.1083	-76.3183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:02:00	\N	0.97	-00:07:00	\N	0.97	\N	\N	Messick Point, Back River	VA
61954	Old Point Comfort, Hampton Roads, Virginia	NOS	8638288	37.0033	-76.315	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:09:00	\N	0.83	00:01:00	\N	1.02	\N	\N	Old Point Comfort	VA
61955	Newport News, James River, Virginia	NOS	8638379	36.9733	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:28:00	\N	0.83	00:29:00	\N	1.08	\N	\N	Newport News	VA
61956	Huntington Park, James River, Virginia	NOS	8638401	37.0133	-76.4583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:39:00	\N	0.92	00:38:00	\N	1.07	\N	\N	Huntington Park	VA
61957	Town Point, Nansemond River, Virginia	NOS	8638406	36.8833	-76.5083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:44:00	\N	0.83	00:37:00	\N	1.22	\N	\N	Town Point	VA
61958	Menchville, James River, Virginia	NOS	8638407	37.0817	-76.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	01:19:00	\N	0.83	01:03:00	\N	1.06	\N	\N	Menchville	VA
61959	Hollidays Point (Kings Highway bridge), Nansemond River, Virginia	NOS	8638409	36.8383	-76.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	01:03:00	\N	1.67	00:56:00	\N	1.25	\N	\N	Hollidays Point (Kings Highway bridge)	VA
61960	Smithfield, Pagan River, James River, Virginia	NOS	8638418	36.9833	-76.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	01:38:00	\N	0.83	01:34:00	\N	1.14	\N	\N	Smithfield, Pagan River	VA
61961	Burwell Bay, James River, Virginia (sub)	NOS	8638421	37.0567	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	01:39:00	\N	1.17	01:17:00	\N	1	\N	\N	Burwell Bay	VA
61962	Kingsmill, James River, Virginia (sub)	NOS	8638424	37.22	-76.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:26:00	\N	1.33	02:05:00	\N	0.94	\N	\N	Kingsmill	VA
61963	Scotland, James River, Virginia (sub)	NOS	8638433	37.185	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	03:13:00	\N	1.08	02:44:00	\N	0.78	\N	\N	Scotland	VA
61964	Wright Island Landing, Chickahominy River, Virginia	NOS	8638441	37.345	-76.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	05:03:00	\N	0.83	04:44:00	\N	0.9	\N	\N	Wright Island Landing	VA
61965	Ferry Point (bridge), Chickahominy River, Virginia	NOS	8638442	37.2633	-76.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	04:26:00	\N	0.83	04:01:00	\N	0.78	\N	\N	Ferry Point (bridge)	VA
61966	Claremont, James River, Virginia	NOS	8638449	37.2317	-76.9483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	04:25:00	\N	1.17	03:51:00	\N	0.76	\N	\N	Claremont	VA
61967	Sturgeon Point, James River, Virginia	NOS	8638455	37.3067	-77.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	05:09:00	\N	0.83	04:37:00	\N	0.86	\N	\N	Sturgeon Point	VA
61968	Jordan Point, James River, Virginia	NOS	8638476	37.3133	-77.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	06:39:00	\N	0.83	06:16:00	\N	1.02	\N	\N	Jordan Point	VA
61970	Meadowville, James River, Virginia	NOS	8638486	37.3783	-77.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:17:00	\N	1.33	-03:46:00	\N	1.05	\N	\N	Meadowville	VA
61971	Puddledock Sand & Gravel, Appomattox River, Virginia (sub)	NOS	8638489	37.2667	-77.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:32:00	\N	1.07	-03:49:00	\N	1	\N	\N	Puddledock, Appomattox River	VA
61972	Chester, James River, Virginia	NOS	8638491	37.3833	-77.3783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-03:59:00	\N	0.67	-03:39:00	\N	1.02	\N	\N	Chester	VA
61973	Richmond River Locks, James River, Virginia (sub)	NOS	8638495	37.525	-77.42	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-03:26:00	\N	1.33	-03:16:00	\N	1.16	\N	\N	Richmond (river locks)	VA
61974	Pig Point, Nansemond River, Virginia	NOS	8638514	36.9167	-76.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:40:00	\N	0.83	00:42:00	\N	1.05	\N	\N	Pig Point	VA
61975	Craney Island Light, Elizabeth River, Virginia	NOS	8638596	36.8917	-76.3383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:04:00	\N	0.83	00:18:00	\N	1.06	\N	\N	Craney Island Light	VA
61976	Norfolk, Elizabeth River, Virginia	NOS	8638654	36.8517	-76.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:20:00	\N	0.83	00:23:00	\N	1.14	\N	\N	Norfolk	VA
61977	Portsmouth, Naval Shipyard, Elizabeth River, Virginia (sub)	NOS	8638660	36.8217	-76.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:10:00	\N	1.17	00:08:00	\N	1.13	\N	\N	Portsmouth, Naval Shipyard	VA
61978	Little Creek NAB, Chesapeake Bay, Virginia	NOS	8638776	36.9117	-76.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	00:09:00	\N	1.17	00:08:00	\N	1.01	\N	\N	Little Creek, NAB	VA
61979	Buchanan Creek entrance, Lynnhaven Bay, Virginia	NOS	8638854	36.8617	-76.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	02:56:00	\N	0.83	02:02:00	\N	0.75	\N	\N	Buchanan Creek entrance	VA
61980	Bayville, Lynnhaven Bay, Virginia	NOS	8638867	36.8933	-76.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	02:48:00	\N	0.83	01:52:00	\N	0.67	\N	\N	Bayville	VA
61981	Virginia pilot's dock, Lynnhaven Inlet, Chesapeake Bay, Virginia	NOS	8638888	36.9067	-76.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	00:38:00	\N	1.08	00:40:00	\N	0.88	\N	\N	Lynnhaven Inlet, Virginia Pilots Dock	VA
61982	Long Creek, Lynnhaven Bay, Virginia	NOS	8638916	36.9033	-76.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	01:15:00	\N	1.08	01:15:00	\N	0.68	\N	\N	Long Creek	VA
61983	Brown Cove, Lynnhaven Bay, Virginia	NOS	8638922	36.875	-76.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	02:43:00	\N	0.83	02:05:00	\N	0.65	\N	\N	Brown Cove	VA
61984	Broad Bay Canal, Lynnhaven Bay, Virginia	NOS	8638923	36.9017	-76.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	02:00:00	\N	0.92	02:05:00	\N	0.56	\N	\N	Broad Bay Canal	VA
61985	Cape Henry, Virginia	NOS	8638999	36.93	-76.00669444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:36:00	\N	0.93	00:31:00	\N	0.96	\N	\N	Cape Henry	VA
61986	Virginia Beach, Virginia	NOS	8639168	36.8433	-75.9717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:16:00	\N	1.07	00:15:00	\N	1.07	\N	\N	Virginia Beach	VA
61987	Inside channel, Rudee Inlet, Virginia (sub)	NOS	8639207	36.8317	-75.9733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:16:00	\N	1	00:17:00	\N	1.02	\N	\N	Rudee Inlet, interior channel	VA
61988	Rudee Inlet entrance, Virginia	NOS	8639208	36.8317	-75.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:02:00	\N	0.86	00:02:00	\N	1.01	\N	\N	Rudee Inlet entrance	VA
61989	Rudee Heights, Lake Wesley, Virginia	NOS	8639214	36.825	-75.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:16:00	\N	1	00:18:00	\N	1.03	\N	\N	Rudee Heights, Lake Wesley	VA
61990	Lake Rudee, south end, Virginia	NOS	8639219	36.825	-75.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:19:00	\N	1.07	00:20:00	\N	1.05	\N	\N	Lake Rudee, south end	VA
61991	Money Point, South Bridge, Elizabeth River, Virginia (sub)	NOS	8639348	36.77830555555556	-76.30169444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:12:00	\N	1.17	00:16:00	\N	1.18	\N	\N	Money Point	VA
61992	Deep Creek Entrance, Elizabeth River, Virginia	NOS	8639414	36.755	-76.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:18:00	\N	1.25	00:22:00	\N	1.21	\N	\N	Deep Creek Entrance	VA
61993	Sandbridge, Virginia	NOS	8639428	36.6917	-75.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:07:00	\N	1.04	00:07:00	\N	1.04	\N	\N	Sandbridge	VA
61994	Kitty Hawk (ocean), North Carolina	NOS	8651605	36.1017	-75.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:02:00	\N	1.43	-00:01:00	\N	1.01	\N	\N	Kitty Hawk (ocean)	NC
61995	Jennettes Pier, Nags Head (ocean), North Carolina	NOS	8652226	35.91	-75.5917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:01:00	\N	1.43	-00:05:00	\N	1.04	\N	\N	Jennettes Pier, Nags Head (ocean)	NC
61996	Roanoke Sound Channel, North Carolina	NOS	8652591	35.7983	-75.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	01:17:00	\N	0.14	01:37:00	\N	0.47	\N	\N	Roanoke Sound Channel	NC
61997	Old House Channel, North Carolina	NOS	8652648	35.7767	-75.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	00:28:00	\N	0.21	00:34:00	\N	0.66	\N	\N	Old House Channel	NC
61998	Oregon Inlet Channel, North Carolina	NOS	8652657	35.7733	-75.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	-00:34:00	\N	0.43	-00:09:00	\N	1.23	\N	\N	Oregon Inlet Channel	NC
61999	Oregon Inlet Bridge, North Carolina	NOS	8652659	35.7733	-75.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	-00:55:00	\N	0.64	-00:17:00	\N	1.89	\N	\N	Oregon Inlet Bridge	NC
62000	Davis Slough, North Carolina	NOS	8652737	35.7483	-75.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	-00:01:00	\N	0.29	00:09:00	\N	0.85	\N	\N	Davis Slough	NC
62001	Rodanthe, Pamlico Sound, North Carolina	NOS	8653215	35.595	-75.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	01:36:00	\N	0.69	02:03:00	\N	0.79	\N	\N	Rodanthe, Pamlico Sound	NC
62002	Hatteras (USCG Station), North Carolina (sub)	NOS	8654467	35.20863888888889	-75.70416666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	-00:13:00	\N	1.67	-00:15:00	\N	1.14	\N	\N	Hatteras (ocean)	NC
62003	Ocracoke, Ocracoke Island, North Carolina (sub)	NOS	8654792	35.115	-75.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:47:00	\N	0.5	00:15:00	\N	0.34	\N	\N	Ocracoke, Ocracoke Island	NC
62004	Core Creek Bridge, North Carolina	NOS	8656084	34.825	-76.69	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:46:00	\N	0.83	01:26:00	\N	0.68	\N	\N	Core Creek Bridge	NC
62005	North River Bridge, North Carolina	NOS	8656225	34.7917	-76.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	03:08:00	\N	0.67	02:25:00	\N	0.59	\N	\N	North River Bridge	NC
62006	Newport River (Yacht Club), North Carolina	NOS	8656306	34.7683	-76.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:13:00	\N	1	01:03:00	\N	1.03	\N	\N	Newport River (Yacht Club)	NC
62007	Gallant Channel, North Carolina	NOS	8656451	34.7283	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:44:00	\N	1.25	00:49:00	\N	1.01	\N	\N	Gallant Channel	NC
62008	Duke Marine Lab, Beaufort, North Carolina (sub)	NOS	8656483	34.72	-76.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:36:00	\N	1.17	00:39:00	\N	1.05	\N	\N	Beaufort, Duke Marine Lab	NC
62009	Morehead City, North Carolina	NOS	8656496	34.7183	-76.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:27:00	\N	1.25	00:26:00	\N	1.04	\N	\N	Morehead City	NC
62010	Atlantic Beach Bridge, North Carolina	NOS	8656499	34.7183	-76.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:02:00	\N	0.83	00:48:00	\N	0.79	\N	\N	Atlantic Beach Bridge	NC
62011	Morehead City Harbor, North Carolina	NOS	8656502	34.72	-76.71083333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:37:00	\N	1.17	00:35:00	\N	1.04	\N	\N	Morehead City Harbor	NC
62012	Harkers Island Bridge, North Carolina	NOS	8656503	34.715	-76.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	02:31:00	\N	0.67	02:08:00	\N	0.52	\N	\N	Harkers Island Bridge	NC
62013	Beaufort, Taylor Creek, North Carolina	NOS	8656518	34.7117	-76.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:48:00	\N	1.17	00:52:00	\N	0.95	\N	\N	Beaufort, Taylor Creek	NC
62014	Lenoxville Point, North Carolina	NOS	8656539	34.7083	-76.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:11:00	\N	1	01:18:00	\N	0.8	\N	\N	Lenoxville Point	NC
62015	Channel Marker Lt. 59, North Carolina	NOS	8656554	34.7033	-76.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:27:00	\N	0.83	01:25:00	\N	0.66	\N	\N	Channel Marker Lt. 59	NC
62016	Coral Bay, Atlantic Beach, North Carolina	NOS	8656566	34.7	-76.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	02:14:00	\N	0.83	01:47:00	\N	0.53	\N	\N	Coral Bay, Atlantic Beach	NC
62017	Beaufort Inlet Channel Range, North Carolina	NOS	8656569	34.6983	-76.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:11:00	\N	1.67	00:07:00	\N	1.07	\N	\N	Beaufort Inlet Channel Range	NC
62018	Fort Macon, USCG Station, North Carolina	NOS	8656571	34.6983	-76.6817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:18:00	\N	1.25	00:17:00	\N	1.03	\N	\N	Fort Macon, USCG Station	NC
62019	Triple S Marina, Bogue Sd., North Carolina	NOS	8656583	34.695	-76.7117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:28:00	\N	1.17	00:35:00	\N	0.93	\N	\N	Triple ESS Marina, Bogue Sd.	NC
62020	Triple S Pier, Atlantic Beach, North Carolina (sub)	NOS	8656590	34.6933	-76.7117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:01:00	\N	1.25	-00:02:00	\N	1.23	\N	\N	Atlantic Beach	NC
62021	Cape Lookout (ocean), North Carolina	NOS	8656937	34.6083	-76.5283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	-00:22:00	\N	1.25	-00:22:00	\N	1.15	\N	\N	Cape Lookout (ocean)	NC
62022	New River Inlet, North Carolina	NOS	8657167	34.5333	-77.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:17:00	\N	0.83	00:16:00	\N	0.98	\N	\N	New River Inlet	NC
62023	Ocean City Beach (fishing pier), North Carolina	NOS	8657419	34.4517	-77.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	-00:01:00	\N	1.33	00:03:00	\N	1.4	\N	\N	Ocean City Beach (fishing pier)	NC
62024	Wrightsville Beach, North Carolina (sub)	NOS	8658163	34.21330555555556	-77.78669444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:23:00	\N	1.25	00:18:00	\N	1.27	\N	\N	Wrightsville Beach	NC
62025	Orton Point, Cape Fear River, North Carolina	NOS	8658501	34.0567	-77.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-00:58:00	\N	1	-00:36:00	\N	0.98	\N	\N	Orton Point	NC
62026	Wilmington Beach, North Carolina	NOS	8658559	34.0317	-77.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:10:00	\N	1.25	00:18:00	\N	1.4	\N	\N	Wilmington Beach	NC
62027	Reaves Point, Cape Fear River, North Carolina	NOS	8658622	34.0033	-77.955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-01:18:00	\N	1.07	-00:54:00	\N	0.96	\N	\N	Reaves Point	NC
62028	Sunny Point Army Base, Wharf no.1, Cape Fear River, North Carolina	NOS	8658654	33.99	-77.9567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-01:45:00	\N	0.93	-01:03:00	\N	0.95	\N	\N	Sunny Point Army Base, Wharf no.1	NC
62029	Federal Point, Cape Fear River, North Carolina	NOS	8658715	33.9617	-77.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-01:52:00	\N	0.93	-01:17:00	\N	0.94	\N	\N	Federal Point	NC
62030	Bald Head, Cape Fear River, North Carolina	NOS	8658901	33.88	-78.0017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-02:43:00	\N	1.13	-02:06:00	\N	1.05	\N	\N	Bald Head	NC
62031	Southport, Cape Fear River, North Carolina (sub)	NOS	8659084	33.915	-78.0183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-02:22:00	\N	1	-01:49:00	\N	0.99	\N	\N	Southport	NC
62032	Fort Caswell, Cape Fear River, North Carolina	NOS	8659086	33.8967	-78.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-02:45:00	\N	1.25	-02:02:00	\N	1.03	\N	\N	Fort Caswell	NC
62033	Oak Island, Yaupon Beach, North Carolina (sub)	NOS	8659182	33.9017	-78.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	-00:05:00	\N	0.84	-00:05:00	\N	0.94	\N	\N	Oak Island, Yaupon Beach	NC
62034	Shallotte Inlet (Bowen Point), North Carolina	NOS	8659665	33.915	-78.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:55:00	\N	1	00:43:00	\N	0.91	\N	\N	Shallotte Inlet (Bowen Point)	NC
62035	Sunset Beach Pier, North Carolina (sub)	NOS	8659897	33.865	-78.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	-00:03:00	\N	1.11	00:02:00	\N	0.97	\N	\N	Sunset Beach Pier	NC
62036	Sunset Beach Bridge, North Carolina	NOS	8659899	33.88166666666701	-78.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:56:00	\N	0.84	00:34:00	\N	0.94	\N	\N	Sunset Beach Bridge	NC
62037	Little River Neck, north end, South Carolina	NOS	8660098	33.87	-78.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:46:00	\N	0.84	00:32:00	\N	0.92	\N	\N	Little River Neck, north end	SC
62038	Little River (town), South Carolina	NOS	8660121	33.87	-78.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:39:00	\N	0.79	00:13:00	\N	0.84	\N	\N	Little River (town)	SC
62039	Dunn Sound, north end, South Carolina	NOS	8660147	33.86	-78.58	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:40:00	\N	0.84	00:25:00	\N	0.93	\N	\N	Dunn Sound, north end	SC
62040	Dunn Sound, Little River Inlet, South Carolina	NOS	8660148	33.8583	-78.57	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:41:00	\N	0.8	00:15:00	\N	0.91	\N	\N	Dunn Sound, Little River Inlet	SC
62041	Nixon Crossroads, South Carolina	NOS	8660166	33.855	-78.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:51:00	\N	0.68	00:27:00	\N	0.78	\N	\N	Nixon Crossroads	SC
62042	Dunn Sound, west end, South Carolina	NOS	8660195	33.8517	-78.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:36:00	\N	1	00:29:00	\N	0.96	\N	\N	Dunn Sound, west end	SC
62043	Cherry Grove (inside), South Carolina	NOS	8660265	33.835	-78.6333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:44:00	\N	0.74	00:40:00	\N	0.92	\N	\N	Cherry Grove (inside)	SC
62044	Hog Inlet Pier, South Carolina	NOS	8660266	33.8367	-78.6067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	-00:07:00	\N	0.9	-00:06:00	\N	0.99	\N	\N	Hog Inlet Pier	SC
62045	Conway, RR. bridge, Waccamaw River, South Carolina	NOS	8660275	33.835	-79.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	07:28:00	\N	0.74	07:19:00	\N	0.25	\N	\N	Conway, RR. bridge	SC
62046	Grahamville, Waccamaw River, South Carolina	NOS	8660315	33.83	-78.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	08:32:00	\N	0.58	08:17:00	\N	0.2	\N	\N	Grahamville	SC
62047	Myrtle Beach Airport, South Carolina	NOS	8660401	33.82	-78.7183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:47:00	\N	0.84	01:09:00	\N	0.56	\N	\N	Myrtle Beach Airport	SC
62048	Pitch Landing, Waccamaw River, South Carolina	NOS	8660475	33.8	-79.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	07:30:00	\N	0.74	07:25:00	\N	0.2	\N	\N	Pitch Landing	SC
62049	North Myrtle Beach, South Carolina	NOS	8660642	33.766700744628906	-78.81500244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:12:00	\N	0.84	02:15:00	\N	0.36	\N	\N	North Myrtle Beach, ICWW	SC
62050	Keysfield, Waccamaw River, South Carolina	NOS	8660831	33.745	-79.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	06:20:00	\N	0.89	06:09:00	\N	0.28	\N	\N	Keysfield	SC
62051	Myrtle Beach, Combination Bridge, South Carolina	NOS	8660854	33.7133	-78.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:18:00	\N	0.89	02:56:00	\N	0.35	\N	\N	Myrtle Beach, Combination Bridge	SC
62052	Socastee Bridge, South Carolina	NOS	8660983	33.6867	-79.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:41:00	\N	0.74	03:27:00	\N	0.41	\N	\N	Socastee Bridge	SC
62053	Enterprise Landing, Waccamaw River, South Carolina	NOS	8661067	33.6667	-79.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	05:35:00	\N	0.37	05:01:00	\N	0.38	\N	\N	Enterprise Landing	SC
62054	Yauhannah Bridge, Great Pee Dee River, South Carolina	NOS	8661093	33.66	-79.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	05:24:00	\N	0.68	04:33:00	\N	0.33	\N	\N	Yauhannah Bridge	SC
62055	Little Bull Creek entrance, Bull Creek, Waccamaw River, South Carolina	NOS	8661119	33.6017	-79.1183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:43:00	\N	0.84	03:59:00	\N	0.46	\N	\N	Little Bull Creek entrance, Bull Creek	SC
62056	Lower Topsaw Landing, Great Pee Dee River, South Carolina	NOS	8661299	33.6083	-79.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	05:20:00	\N	0.53	04:48:00	\N	0.2	\N	\N	Lower Topsaw Landing	SC
62057	Bull Creek entrance, Waccamaw River, South Carolina	NOS	8661347	33.5967	-79.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:22:00	\N	0.79	03:36:00	\N	0.48	\N	\N	Bull Creek entrance	SC
62058	Rhems, Black Mingo Creek, Black River, Great Pee Dee River, South Carolina	NOS	8661367	33.6033	-79.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	06:13:00	\N	1.05	06:00:00	\N	0.36	\N	\N	Rhems, Black Mingo Creek, Black River	SC
62059	Wachesaw Landing, Waccamaw River, South Carolina	NOS	8661493	33.56	-79.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:00:00	\N	0.84	03:11:00	\N	0.53	\N	\N	Wachesaw Landing	SC
62060	Captain Alex's Marina, Parsonage Creek, Murrells Inlet, South Carolina	NOS	8661529	33.5517	-79.0367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	01:28:00	\N	0.68	00:57:00	\N	0.85	\N	\N	Captain Alex's Marina, Parsonage Creek	SC
62398	Great Pocket, Florida	NOS	8722381	27.155	-80.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:42:00	\N	1	00:55:00	\N	0.5	\N	\N	Great Pocket	FL
62061	Holly Grove Plantation, Great Pee Dee River, South Carolina	NOS	8661558	33.5517	-79.1767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:12:00	\N	0.68	03:20:00	\N	0.5	\N	\N	Holly Grove Plantation	SC
62062	Smith's Dock, Murrells Inlet, South Carolina	NOS	8661559	33.545	-79.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	01:36:00	\N	0.95	01:01:00	\N	0.86	\N	\N	Smith's Dock	SC
62063	Divine's Dock, Murrells Inlet, South Carolina	NOS	8661582	33.5417	-79.0283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	01:18:00	\N	0.84	00:40:00	\N	0.84	\N	\N	Divine's Dock	SC
62064	Winea Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661593	33.535	-79.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:39:00	\N	0.84	04:23:00	\N	0.47	\N	\N	Winea Plantation, Black River	SC
62065	Allston Creek, Murrells Inlet, South Carolina	NOS	8661608	33.5317	-79.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	01:32:00	\N	0.95	00:52:00	\N	0.84	\N	\N	Allston Creek	SC
62066	Oaks Creek, 0.5 mi. above entrance, Murrells Inlet, South Carolina	NOS	8661609	33.53	-79.0433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	01:03:00	\N	0.95	00:38:00	\N	0.85	\N	\N	Oaks Creek, 0.5 mi. above entrance	SC
62067	Black River (south of Dunbar), Great Pee Dee River, South Carolina	NOS	8661686	33.5117	-79.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:09:00	\N	0.89	03:29:00	\N	0.47	\N	\N	Black River (south of Dunbar)	SC
62068	Mt. Pleasant Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661734	33.495	-79.4617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	06:04:00	\N	1.05	05:38:00	\N	0.37	\N	\N	Mt. Pleasant Plantation, Black River	SC
62069	Arundel Plantation, Great Pee Dee River, South Carolina	NOS	8661741	33.4833	-79.1783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:39:00	\N	0.79	02:38:00	\N	0.53	\N	\N	Arundel Plantation	SC
62070	South of Sam Worth Game Management Area, Great Pee Dee River, South Carolina	NOS	8661866	33.4683	-79.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:06:00	\N	0.68	02:21:00	\N	0.69	\N	\N	South of Sam Worth Game Management Area	SC
62071	Litchfield Beach bridge, South Carolina	NOS	8661867	33.4717	-79.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	03:02:00	\N	0.75	01:10:00	\N	0.58	\N	\N	Litchfield Beach bridge	SC
62072	Carr Creek, 1 mile above entrance, Great Pee Dee River, South Carolina	NOS	8661873	33.465	-79.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:00:00	\N	0.84	02:13:00	\N	0.69	\N	\N	Carr Creek, 1 mile above entrance	SC
62073	Weymouth Plantation, Great Pee Dee River, South Carolina	NOS	8661913	33.455	-79.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:02:00	\N	0.89	02:16:00	\N	0.68	\N	\N	Weymouth Plantation	SC
62074	Midway Inlet North, Pawleys Island, South Carolina	NOS	8661947	33.4483	-79.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:42:00	\N	1	00:16:00	\N	0.87	\N	\N	Midway Inlet North, Pawleys Island	SC
62075	Hagley Landing, Waccamaw River, South Carolina	NOS	8661991	33.435	-79.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:53:00	\N	0.79	01:58:00	\N	0.67	\N	\N	Hagley Landing	SC
62076	Cumberland, Sampit River, South Carolina	NOS	8662216	33.37	-79.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:29:00	\N	0.74	02:42:00	\N	0.77	\N	\N	Cumberland	SC
62077	Jacobs Wharf, Sampit River, South Carolina	NOS	8662237	33.3633	-79.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:22:00	\N	0.74	02:15:00	\N	0.73	\N	\N	Jacobs Wharf	SC
62078	Jamestown Bridge, Santee River, South Carolina	NOS	8662405	33.305	-79.6783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	06:30:00	\N	0.37	04:15:00	\N	0.22	\N	\N	Jamestown Bridge, Santee River	SC
62079	South Island Ferry, Intracoastal Waterway, South Carolina	NOS	8662549	33.2517	-79.2683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:25:00	\N	0.74	00:54:00	\N	0.71	\N	\N	South Island Ferry, Intracoastal Waterway	SC
62080	Pleasant Hill Landing, Santee River, South Carolina	NOS	8662670	33.245	-79.5217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:47:00	\N	0.74	02:28:00	\N	0.45	\N	\N	Pleasant Hill Landing, Santee River	SC
62081	South Island Plantation (C.G. Station), Winyah Bay, South Carolina (sub)	NOS	8662746	33.235	-79.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:36:00	\N	0.84	00:35:00	\N	0.74	\N	\N	South Island Plantation (C.G. Station)	SC
62082	Georgetown Lighthouse, South Carolina	NOS	8662747	33.2233	-79.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:25:00	\N	1.05	00:26:00	\N	0.75	\N	\N	Georgetown Lighthouse	SC
62083	North Santee Bridge, South Carolina	NOS	8662793	33.21	-79.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:54:00	\N	0.74	01:09:00	\N	0.72	\N	\N	North Santee Bridge	SC
62084	Minim Creek ent., ICWW, North Santee Bay, South Carolina	NOS	8662796	33.195	-79.275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:00:00	\N	0.95	00:16:00	\N	0.77	\N	\N	Minim Creek ent., ICWW, North Santee Bay	SC
62085	U.S. Highway 17 bridge, South Santee River, South Carolina	NOS	8662799	33.185	-79.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:43:00	\N	0.95	00:43:00	\N	0.78	\N	\N	U.S. Highway 17 bridge, South Santee River	SC
62086	Georgetown, Sampit River, South Carolina	NOS	8662926	33.3617	-79.28	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:09:00	\N	0.79	01:25:00	\N	0.71	\N	\N	Georgetown	SC
62087	Cape Romain, South Carolina	NOS	8663101	33.025	-79.3483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:17:00	\N	0.89	-00:22:00	\N	0.89	\N	\N	Cape Romain	SC
62088	Cedar Island, North Santee Bay, South Carolina	NOS	8663261	33.14	-79.245	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:17:00	\N	0.95	-00:03:00	\N	0.8	\N	\N	Cedar Island, North Santee Bay	SC
62089	Cedar Island Point, South Santee River, South Carolina	NOS	8663381	33.12	-79.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:08:00	\N	0.79	-00:16:00	\N	0.78	\N	\N	Cedar Island Point, South Santee River	SC
62090	Casino Creek, ICWW, South Carolina	NOS	8663461	33.1083	-79.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:53:00	\N	0.79	00:40:00	\N	0.87	\N	\N	Casino Creek, ICWW	SC
62091	Quinby Creek bridge, East Branch, Cooper River, South Carolina	NOS	8663535	33.095	-79.8083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:12:00	\N	1.42	04:37:00	\N	0.56	\N	\N	Quinby Creek bridge, East Branch	SC
62092	Pimlico, West Branch, Cooper River, South Carolina	NOS	8663539	33.095	-79.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:53:00	\N	0.89	03:19:00	\N	0.34	\N	\N	Pimlico, West Branch	SC
62093	McClellanville, Jeremy Creek, Bulls Bay, South Carolina	NOS	8663618	33.0783	-79.46	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:24:00	\N	0.89	00:31:00	\N	0.93	\N	\N	McClellanville, Jeremy Creek	SC
62094	Old Rice Mill, West Branch, Cooper River, South Carolina	NOS	8663631	33.0783	-79.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:51:00	\N	1.63	02:56:00	\N	0.53	\N	\N	Old Rice Mill, West Branch	SC
62095	Richmond Plantation, East Branch, Cooper River, South Carolina	NOS	8663665	33.0767	-79.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:43:00	\N	1.37	03:43:00	\N	0.54	\N	\N	Richmond Plantation, East Branch	SC
62096	Bonneau Ferry, East Branch, Cooper River, South Carolina	NOS	8663731	33.0717	-79.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:49:00	\N	1.79	03:14:00	\N	0.63	\N	\N	Bonneau Ferry, East Branch	SC
62097	Dupont, Dean Hall, Cooper River, South Carolina	NOS	8663757	33.0583	-79.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:07:00	\N	1.58	02:21:00	\N	0.68	\N	\N	Dupont, Dean Hall	SC
62098	Blessing Plantation, East Branch, Cooper River, South Carolina	NOS	8663781	33.055	-79.88	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:20:00	\N	1.32	03:24:00	\N	0.56	\N	\N	Blessing Plantation, East Branch	SC
62099	Buck Hall, Awendaw Creek, Bulls Bay, South Carolina	NOS	8663858	33.04	-79.56	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:37:00	\N	1	00:22:00	\N	0.95	\N	\N	Buck Hall, Awendaw Creek	SC
62100	Harbor River entrance, Bulls Bay, South Carolina	NOS	8663899	33.0333	-79.535	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:36:00	\N	0.95	00:03:00	\N	0.93	\N	\N	Harbor River entrance	SC
62101	General Dynamics Pier, Cooper River, South Carolina (sub)	NOS	8664022	33.0083	-79.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:24:00	\N	1.11	01:40:00	\N	0.84	\N	\N	General Dynamics Pier	SC
62102	Five Fathom Creek entrance, Bulls Bay, South Carolina	NOS	8664099	33	-79.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:07:00	\N	0.95	-00:06:00	\N	0.93	\N	\N	Five Fathom Creek entrance	SC
62103	Back River Reservoir, West Branch, Cooper River, South Carolina	NOS	8664131	32.995	-79.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	05:57:00	\N	0.79	05:44:00	\N	0.17	\N	\N	Back River Reservoir, West Branch	SC
62104	Moores Landing, ICWW, Sewee Bay, South Carolina	NOS	8664442	32.9367	-79.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:08:00	\N	1	00:11:00	\N	0.96	\N	\N	Moores Landing, ICWW, Sewee Bay	SC
62105	Snow Point, 0.4 mi. North of, Cooper River, South Carolina	NOS	8664515	32.9483	-79.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:45:00	\N	1.05	00:59:00	\N	1.02	\N	\N	Snow Point, 0.4 mi. North of	SC
62106	Bacon Bridge, Ashley River, South Carolina	NOS	8664531	32.9583	-80.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:41:00	\N	0.16	02:45:00	\N	0.39	\N	\N	Bacon Bridge	SC
62107	Greggs Landing, Matceba Gardens, Ashley River, South Carolina	NOS	8664532	32.9317	-80.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:42:00	\N	1.16	02:06:00	\N	1.15	\N	\N	Greggs Landing, Mateeba Gardens	SC
62108	Yeamans Hall, Goose Creek, Cooper River, South Carolina	NOS	8664541	32.925	-79.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:31:00	\N	1.37	02:06:00	\N	1	\N	\N	Yeamans Hall, Goose Creek	SC
62109	Cainhoy, Wando River, South Carolina (sub)	NOS	8664545	32.9267	-79.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:31:00	\N	1	00:49:00	\N	1.15	\N	\N	Cainhoy	SC
62110	Woodville, Wando River, South Carolina	NOS	8664582	32.92	-79.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:22:00	\N	1.19	02:07:00	\N	1.19	\N	\N	Woodville	SC
62111	Hanahan, Turkey Creek, Goose Creek, Cooper River, South Carolina	NOS	8664589	32.9183	-80.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:13:00	\N	0.79	02:51:00	\N	0.9	\N	\N	Hanahan, Turkey Creek, Goose Creek	SC
62112	Big Paradise Island, Wando River, South Carolina	NOS	8664611	32.915	-79.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:52:00	\N	1.11	01:24:00	\N	1.24	\N	\N	Big Paradise Island	SC
62113	Wharf Creek entrance, Bulls Bay, South Carolina	NOS	8664621	32.9133	-79.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:08:00	\N	0.95	00:12:00	\N	0.97	\N	\N	Wharf Creek entrance	SC
62114	Clouter Creek, north entrance, Cooper River, South Carolina	NOS	8664688	32.9067	-79.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:33:00	\N	1	00:45:00	\N	1.04	\N	\N	Clouter Creek, north entrance	SC
62115	Nowell Creek, Wando River, South Carolina	NOS	8664701	32.9	-79.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:23:00	\N	1.05	00:47:00	\N	1.13	\N	\N	Nowell Creek	SC
62116	Parker Island, Horlbeck Creek, Wando River, South Carolina	NOS	8664782	32.885	-79.845	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:27:00	\N	1.11	00:43:00	\N	1.09	\N	\N	Parker Island, Horlbeck Creek	SC
62117	Price Creek, North Capers Island, South Carolina	NOS	8664801	32.8817	-79.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:21:00	\N	0.89	-00:01:00	\N	0.92	\N	\N	Price Creek, North Capers Island	SC
62118	Magnolia Gardens, Ashley River, South Carolina	NOS	8664841	32.8767	-80.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:54:00	\N	1.05	01:02:00	\N	1.1	\N	\N	Magnolia Gardens	SC
62119	Old Capers Landing, Santee Pass, Capers Island, South Carolina	NOS	8664878	32.87	-79.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:09:00	\N	0.84	00:21:00	\N	0.94	\N	\N	Old Capers Landing, Santee Pass, Capers Island	SC
62120	Capers Creek, South Capers Island, South Carolina (sub)	NOS	8664941	32.8567	-79.7067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:15:00	\N	0.95	00:04:00	\N	0.94	\N	\N	Capers Creek, South Capers Island	SC
62121	Clouter Creek, south entrance, Cooper River, South Carolina	NOS	8664945	32.86	-79.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:19:00	\N	1	00:25:00	\N	1.02	\N	\N	Clouter Creek, south entrance	SC
62122	North Dewees Island, Capers Inlet, South Carolina	NOS	8664992	32.85	-79.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:11:00	\N	0.95	-00:02:00	\N	0.91	\N	\N	North Dewees Island, Capers Inlet	SC
62123	Drayton, Bee's Ferry, Ashley River, South Carolina	NOS	8665002	32.8483	-80.0517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:39:00	\N	1.05	00:41:00	\N	1.09	\N	\N	Drayton, Bee's Ferry	SC
62124	I-526 bridge, Ashley River, South Carolina (sub)	NOS	8665099	32.8367	-80.0217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:29:00	\N	1.11	00:30:00	\N	1.08	\N	\N	I-526 bridge	SC
62125	Cosgrove Bridge, Ashley River, South Carolina	NOS	8665101	32.835	-79.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:17:00	\N	1.05	00:25:00	\N	1.07	\N	\N	Cosgrove Bridge	SC
62126	South Dewees Island, Dewees Inlet, South Carolina	NOS	8665111	32.8333	-79.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:17:00	\N	0.89	-00:01:00	\N	0.94	\N	\N	South Dewees Island, Dewees Inlet	SC
62127	Duck Island, Ashley River, South Carolina	NOS	8665145	32.83	-79.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:17:00	\N	1.06	00:23:00	\N	1.06	\N	\N	Duck Island	SC
62128	Hamlin Sound, South Carolina	NOS	8665167	32.8267	-79.7867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:13:00	\N	1	00:13:00	\N	0.99	\N	\N	Hamlin Sound	SC
62129	Hobcaw Point, Wando River, South Carolina	NOS	8665192	32.8217	-79.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:13:00	\N	0.95	00:19:00	\N	1.03	\N	\N	Hobcaw Point	SC
62130	Canaday Landing, south of, Edisto River, South Edisto River, South Carolina	NOS	8665257	32.8133	-80.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	05:34:00	\N	0.32	04:20:00	\N	0.13	\N	\N	Canaday Landing, south of, Edisto River	SC
62131	Hamlin Creek, Isle of Palms, South Carolina	NOS	8665387	32.7867	-79.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:12:00	\N	1	00:06:00	\N	0.97	\N	\N	Hamlin Creek, Isle of Palms	SC
62132	Folly Creek, Hwy. 171 bridge, South Carolina	NOS	8665424	32.675	-79.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:06:00	\N	1	00:25:00	\N	1.04	\N	\N	Folly Creek, Hwy. 171 bridge	SC
62133	Shem Creek, South Carolina	NOS	8665426	32.7933	-79.8817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:03:00	\N	1	-00:02:00	\N	0.99	\N	\N	Shem Creek	SC
62134	Limehouse Bridge, Stono River, South Carolina	NOS	8665475	32.7867	-80.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:34:00	\N	1.08	01:43:00	\N	1.08	\N	\N	Limehouse Bridge	SC
62135	Isle of Palms Pier, South Carolina	NOS	8665494	32.7833	-79.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:28:00	\N	0.89	-00:25:00	\N	0.95	\N	\N	Isle of Palms Pier	SC
62136	South Ashley Bridge, Ashley River, South Carolina	NOS	8665495	32.7833	-79.9567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:07:00	\N	1.05	00:04:00	\N	1.01	\N	\N	South Ashley Bridge	SC
62137	Breach Inlet, Isle of Palms, South Carolina	NOS	8665552	32.7767	-79.8117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:14:00	\N	1.05	-00:05:00	\N	0.95	\N	\N	Breach Inlet, Isle of Palms	SC
62138	Ben Sawyer Bridge, ICWW, South Carolina	NOS	8665567	32.7733	-79.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:12:00	\N	1	00:06:00	\N	0.97	\N	\N	Ben Sawyer Bridge, ICWW	SC
62139	Sandblasters, Pennys Creek, Stono River, South Carolina	NOS	8665589	32.77	-80.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:18:00	\N	1.02	01:30:00	\N	1.02	\N	\N	Sandblasters, Pennys Creek	SC
62140	Pennys Creek, west entrance, Stono River, South Carolina	NOS	8665599	32.7683	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:20:00	\N	1.32	01:23:00	\N	1.03	\N	\N	Pennys Creek, west entrance	SC
62141	Wappoo Creek, highway bridge, Ashley River, South Carolina	NOS	8665613	32.7667	-79.9733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:22:00	\N	0.99	00:22:00	\N	0.99	\N	\N	Wappoo Creek, highway bridge	SC
62142	The Cove, Fort Moultrie, South Carolina	NOS	8665637	32.7633	-79.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:10:00	\N	0.95	-00:01:00	\N	0.97	\N	\N	The Cove, Fort Moultrie	SC
62143	Elliott Cut entrance, Stono River, South Carolina	NOS	8665641	32.7633	-80.0017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:52:00	\N	1.16	00:48:00	\N	0.99	\N	\N	Elliott Cut entrance	SC
62144	Fort Johnson, South Carolina	NOS	8665726	32.7517	-79.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:02:00	\N	1	-00:05:00	\N	0.97	\N	\N	Fort Johnson	SC
62145	Fort Sumter, South Carolina	NOS	8665728	32.7533	-79.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:01:00	\N	0.95	00:02:00	\N	0.97	\N	\N	Fort Sumter	SC
62146	Jacksonboro Camp, South Edisto River, South Carolina	NOS	8665737	32.7533	-80.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:34:00	\N	0.86	02:46:00	\N	0.59	\N	\N	Jacksonboro Camp	SC
62147	Church Flats, Stono River, South Carolina	NOS	8665763	32.7467	-80.165	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:14:00	\N	1.16	01:51:00	\N	1.22	\N	\N	Church Flats	SC
62148	James Island Creek, 1 mi. above ent., Ashley River, South Carolina	NOS	8665775	32.745	-79.9483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:07:00	\N	1.05	00:17:00	\N	1.02	\N	\N	James Island Creek, 1 mi. above ent.	SC
62149	Ashepoo, Ashepoo River, South Carolina	NOS	8665814	32.7433	-80.5567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	04:00:00	\N	1.05	04:18:00	\N	0.34	\N	\N	Ashepoo	SC
62150	Penny Creek, south of, Edisto River, South Edisto River, South Carolina	NOS	8666017	32.715	-80.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:43:00	\N	1.18	02:10:00	\N	0.73	\N	\N	Penny Creek, south of, Edisto River	SC
62151	Church Creek bridge, Wadmalaw River, South Carolina	NOS	8666029	32.715	-80.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:58:00	\N	1	01:58:00	\N	1.3	\N	\N	Church Creek bridge	SC
62152	Johns Island, Church Creek, Wadmalaw River, South Carolina	NOS	8666101	32.7067	-80.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:00:00	\N	1.16	01:43:00	\N	1.3	\N	\N	Johns Island, Church Creek	SC
62153	Lower Toogoodoo Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8666131	32.7033	-80.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:47:00	\N	1.26	01:26:00	\N	1.29	\N	\N	Lower Toogoodoo Creek, 2 mi. above entrance	SC
62154	Cuckolds Creek, Combahee River, South Carolina	NOS	8666166	32.7133	-80.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	04:12:00	\N	1.73	04:45:00	\N	0.51	\N	\N	Cuckolds Creek	SC
62155	Hope Creek, Edisto River, South Edisto River, South Carolina	NOS	8666167	32.7	-80.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:13:00	\N	1.05	01:46:00	\N	0.82	\N	\N	Hope Creek, Edisto River	SC
62156	Yonges Island, Wadmalaw River, South Carolina	NOS	8666217	32.695	-80.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:45:00	\N	1.16	01:22:00	\N	1.24	\N	\N	Yonges Island	SC
62157	Oak Branch, Bohicket Creek, North Edisto River, South Carolina	NOS	8666282	32.6833	-80.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:57:00	\N	1.16	01:39:00	\N	1.26	\N	\N	Oak Branch, Bohicket Creek	SC
62158	Abbapoola Creek entrance, Stono River, South Carolina	NOS	8666283	32.6767	-80.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:02:00	\N	0.95	00:17:00	\N	1.01	\N	\N	Abbapoola Creek entrance	SC
62159	Bluff Plantation, Combahee River, South Carolina	NOS	8666359	32.6833	-80.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:51:00	\N	1.59	04:17:00	\N	0.5	\N	\N	Bluff Plantation	SC
62160	Willtown Bluff, Edisto River, South Edisto River, South Carolina	NOS	8666367	32.6817	-80.4167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:03:00	\N	1	01:34:00	\N	0.83	\N	\N	Willtown Bluff, Edisto River	SC
62161	Toogoodoo Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8666433	32.6683	-80.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:38:00	\N	1.05	01:06:00	\N	1.21	\N	\N	Toogoodoo Creek, 2 mi. above entrance	SC
62162	Folly River, north, Folly Island, South Carolina	NOS	8666467	32.67	-79.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:05:00	\N	0.95	00:24:00	\N	1.03	\N	\N	Folly River, north, Folly Island	SC
62163	Park Island, Tom Point Creek, North Edisto River, South Carolina	NOS	8666552	32.665	-80.3167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:34:00	\N	1.21	01:19:00	\N	1.21	\N	\N	Park Island, Tom Point Creek	SC
62164	Dawho River, South Edisto River, South Carolina	NOS	8666616	32.6567	-80.3917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:31:00	\N	0.95	01:07:00	\N	0.89	\N	\N	Dawho River	SC
62165	Folly River Bridge, Folly Island, South Carolina	NOS	8666652	32.6617	-79.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:03:00	\N	0.95	00:21:00	\N	1.01	\N	\N	Folly River Bridge, Folly Island	SC
62166	U.S. 17 Bridge, Combahee River, South Carolina	NOS	8666659	32.6517	-80.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:29:00	\N	1.14	03:00:00	\N	0.71	\N	\N	U.S. 17 Bridge	SC
62167	Bluff Point, Wadmalaw River, South Carolina	NOS	8666699	32.6467	-80.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:31:00	\N	1.11	00:58:00	\N	1.17	\N	\N	Bluff Point	SC
62168	Airy Hall Plantation, Ashepoo River, South Carolina	NOS	8666749	32.6317	-80.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:59:00	\N	1	01:57:00	\N	0.6	\N	\N	Airy Hall Plantation	SC
62169	Snake Island, Stono River, South Carolina	NOS	8666767	32.64	-80.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:12:00	\N	1	00:01:00	\N	1.01	\N	\N	Snake Island	SC
62170	Leadenwah Creek, 3 mi. above entrance, North Edisto River, South Carolina	NOS	8666775	32.6367	-80.2017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:23:00	\N	1.11	00:54:00	\N	1.15	\N	\N	Leadenwah Creek, 3 mi. above entrance	SC
62171	Dawho Bridge, Dawho River, North Edisto River, South Carolina	NOS	8666799	32.6367	-80.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:47:00	\N	1.11	00:56:00	\N	1.18	\N	\N	Dawho Bridge, Dawho River	SC
62172	Ho-Non-Wah Boy Scout Camp, Bohicket Creek, North Edisto River, South Carolina	NOS	8666918	32.625	-80.1667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:30:00	\N	1.11	00:49:00	\N	1.13	\N	\N	Ho-Non-Wah Boy Scout Camp, Bohicket Creek	SC
62173	Brickyard Ferry, swing bridge, Ashepoo River, South Carolina	NOS	8667017	32.6133	-80.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:34:00	\N	0.86	01:27:00	\N	0.71	\N	\N	Brickyard Ferry, swing bridge	SC
62174	Kiawah River Bridge, South Carolina	NOS	8667062	32.6033	-80.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:06:00	\N	0.89	00:14:00	\N	1.07	\N	\N	Kiawah River Bridge	SC
62175	Pine Landing, South Edisto River, South Carolina	NOS	8667067	32.6033	-80.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:45:00	\N	0.95	00:29:00	\N	0.92	\N	\N	Pine Landing	SC
62176	Wiggins, Chehaw River, Combahee River, South Carolina	NOS	8667074	32.6017	-80.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:20:00	\N	1.18	01:45:00	\N	0.88	\N	\N	Wiggins, Chehaw River	SC
62177	Steamboat Landing, Steamboat Creek, North Edisto River, South Carolina	NOS	8667075	32.6033	-80.2867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:25:00	\N	1.11	00:45:00	\N	1.15	\N	\N	Steamboat Landing, Steamboat Creek	SC
62178	Tulifiny River, I-95 bridge, Broad River, South Carolina	NOS	8667076	32.6017	-80.9033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:31:00	\N	0.73	03:24:00	\N	0.73	\N	\N	Tulifiny River, I-95 bridge	SC
62179	Rockville, Bohicket Creek, North Edisto River, South Carolina	NOS	8667089	32.5983	-80.195	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:07:00	\N	1.11	00:19:00	\N	1.09	\N	\N	Rockville, Bohicket Creek	SC
62180	Windsor Plantation, Russel Creek, North Edisto River, South Carolina	NOS	8667101	32.5983	-80.345	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:35:00	\N	1.11	01:16:00	\N	1.21	\N	\N	Windsor Plantation, Russel Creek	SC
62181	North Dawson Landing, Coosawhatchie River, Broad River, South Carolina	NOS	8667146	32.5617	-80.91	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:10:00	\N	1.14	02:34:00	\N	1.12	\N	\N	North Dawson Landing, Coosawhatchie River	SC
62182	Sheldon, Huspa Creek, Whale Branch, Coosaw River, South Carolina	NOS	8667172	32.5833	-80.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:52:00	\N	0.77	02:11:00	\N	1.16	\N	\N	Sheldon, Huspa Creek, Whale Branch	SC
62183	Point of Pines, North Edisto River, South Carolina	NOS	8667178	32.585	-80.2283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:11:00	\N	1.05	00:15:00	\N	1.08	\N	\N	Point of Pines	SC
62184	Briars Creek ent., Wimbee Creek, Bull River, Coosaw River, South Carolina	NOS	8667199	32.5783	-80.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:24:00	\N	0.95	02:06:00	\N	0.93	\N	\N	Briars Creek ent., Wimbee Creek, Bull River	SC
62185	Bluff Islands, Ashepoo River, South Carolina	NOS	8667201	32.5783	-80.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:04:00	\N	0.91	00:46:00	\N	0.84	\N	\N	Bluff Islands	SC
62186	Musselboro Island, Mosquito Creek, Ashepoo River, South Carolina	NOS	8667209	32.5783	-80.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:57:00	\N	0.91	01:21:00	\N	0.9	\N	\N	Musselboro Island, Mosquito Creek	SC
62187	Fields Point, Combahee River, South Carolina	NOS	8667259	32.5683	-80.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:52:00	\N	0.91	00:42:00	\N	0.91	\N	\N	Fields Point	SC
62188	Bowles Island, New Chehaw River, Combahee River, South Carolina	NOS	8667272	32.565	-80.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:42:00	\N	1	01:02:00	\N	0.96	\N	\N	Bowles Island, New Chehaw River	SC
62189	Ocella Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8667281	32.5617	-80.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:09:00	\N	1.08	00:32:00	\N	1.08	\N	\N	Ocella Creek, 2 mi. above entrance	SC
62190	Fenwick Island, South Edisto River, South Carolina	NOS	8667309	32.56	-80.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:25:00	\N	1.09	00:15:00	\N	0.9	\N	\N	Fenwick Island	SC
62191	Hutchinson Island, Ashepoo River, South Carolina	NOS	8667351	32.5517	-80.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:44:00	\N	0.91	00:31:00	\N	0.87	\N	\N	Hutchinson Island	SC
62192	Lobeco, Whale Branch, Coosaw River, South Carolina	NOS	8667411	32.5733	-80.745	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:28:00	\N	0.95	01:40:00	\N	1.11	\N	\N	Lobeco, Whale Branch	SC
62302	St. Simons Lighthouse, St. Simons Island, Georgia (sub)	NOS	8677344	31.1317	-81.3967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:16:00	\N	0.91	00:14:00	\N	0.95	\N	\N	St. Simons Light	GA
62193	Peters Point, St. Pierre Creek, South Edisto River, South Carolina	NOS	8667425	32.54	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:09:00	\N	0.95	00:22:00	\N	0.88	\N	\N	Peters Point, St. Pierre Creek	SC
62194	Ashepoo-Coosaw Cutoff, ICWW, Ashepoo River, South Carolina	NOS	8667482	32.525	-80.4517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:23:00	\N	0.91	00:15:00	\N	0.9	\N	\N	Ashepoo-Coosaw Cutoff, ICWW	SC
62195	Whale Branch entrance, Coosaw River, South Carolina	NOS	8667491	32.525	-80.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:20:00	\N	0.95	01:27:00	\N	1.06	\N	\N	Whale Branch entrance	SC
62196	Summerhouse Point, Bull River, Coosaw River, South Carolina	NOS	8667493	32.5267	-80.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	0.95	00:55:00	\N	0.96	\N	\N	Summerhouse Point, Bull River	SC
62197	RR. Bridge, Hall Island, Broad River, South Carolina	NOS	8667508	32.5217	-80.8383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:24:00	\N	1.05	01:39:00	\N	1.17	\N	\N	RR. Bridge, Hall Island	SC
62198	Seabrook, Ashepoo River, South Carolina	NOS	8667524	32.5233	-80.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:18:00	\N	0.91	00:11:00	\N	0.9	\N	\N	Seabrook	SC
62199	Pilot Island, West Branch Boyds Creek, Broad River, South Carolina	NOS	8667591	32.505	-80.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:24:00	\N	0.91	01:50:00	\N	1.15	\N	\N	Pilot Island, West Branch Boyds Creek	SC
62220	Hwy. 170 bridge, Broad River, South Carolina	NOS	8668223	32.3867	-80.7767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:45:00	\N	0.91	00:51:00	\N	1.06	\N	\N	Hwy. 170 bridge	SC
62200	Brickyard Point, Brickyard Creek, Coosaw River, South Carolina	NOS	8667624	32.4933	-80.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:19:00	\N	0.95	01:27:00	\N	1.08	\N	\N	Brickyard Point, Brickyard Creek	SC
62201	Edisto Beach, Edisto Island, South Carolina	NOS	8667630	32.5017	-80.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:29:00	\N	0.95	-00:21:00	\N	0.84	\N	\N	Edisto Beach, Edisto Island	SC
62202	Clarendon Plantation, South Carolina (sub)	NOS	8667633	32.5025	-80.7841	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:25:00	\N	0.77	01:37:00	\N	1.15	\N	\N	Corning Landing, Whale Branch	SC
62203	Edisto Marina, Big Bay Creek entrance, South Edisto River, South Carolina	NOS	8667676	32.4933	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:13:00	\N	0.91	-00:06:00	\N	0.86	\N	\N	Edisto Marina, Big Bay Creek entrance	SC
62204	Carters Dock, Big Bay Creek, South Edisto River, South Carolina	NOS	8667679	32.4933	-80.3267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:07:00	\N	0.91	00:08:00	\N	0.87	\N	\N	Carters Dock, Big Bay Creek	SC
62205	Sams Point, Lucy Point Creek, Coosaw River, South Carolina	NOS	8667733	32.4833	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:45:00	\N	0.91	00:55:00	\N	0.97	\N	\N	Sams Point, Lucy Point Creek	SC
62206	Otter Island, St. Helena Sound, South Carolina	NOS	8667783	32.4767	-80.42	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:07:00	\N	0.95	00:04:00	\N	0.87	\N	\N	Otter Island	SC
62207	Marine Corps Air Station, Brickyard Creek, Beaufort River, South Carolina	NOS	8667864	32.465	-80.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:11:00	\N	0.95	01:27:00	\N	1.1	\N	\N	Marine Corps Air Station, Brickyard Creek	SC
62208	Lucy Point Creek entrance, Morgan River, South Carolina	NOS	8667901	32.4517	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:33:00	\N	0.88	00:53:00	\N	0.9	\N	\N	Lucy Point Creek entrance	SC
62209	Albergottie Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8667909	32.45	-80.7317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:02:00	\N	0.45	01:48:00	\N	0.98	\N	\N	Albergottie Creek, Rt. 21 bridge	SC
62210	Village Creek Entrance, Morgan River, South Carolina	NOS	8667927	32.445	-80.5033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:07:00	\N	1	00:17:00	\N	0.93	\N	\N	Village Creek Entrance	SC
62211	Edding Point, Edding Creek, Morgan River, South Carolina	NOS	8667972	32.4467	-80.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:14:00	\N	0.95	00:31:00	\N	0.93	\N	\N	Edding Point, Edding Creek	SC
62212	Jenkins Creek, 1 mi. above entrance, Morgan River, South Carolina	NOS	8667982	32.44	-80.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:17:00	\N	0.95	00:41:00	\N	0.98	\N	\N	Jenkins Creek, 1 mi. above entrance	SC
62213	Village Creek Cemetery, Morgan River, South Carolina	NOS	8668077	32.4167	-80.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:15:00	\N	0.95	00:36:00	\N	0.94	\N	\N	Village Creek Cemetery	SC
62962	Fort Ross, California	NOS	9416024	38.5133	-123.245	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:30:00	\N	0.96	-00:51:00	\N	0.96	\N	\N	Fort Ross	CA
62214	Jenkins Creek, Polawana Island, Morgan River, South Carolina	NOS	8668091	32.42	-80.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:27:00	\N	1.05	00:55:00	\N	1.01	\N	\N	Jenkins Creek, Polawana Island	SC
62215	Battery Creek, 4 mi. above entrance, Beaufort River, South Carolina	NOS	8668092	32.4133	-80.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	0.91	01:14:00	\N	1.1	\N	\N	Battery Creek, 4 mi. above entrance	SC
62216	Broughton Point, Hazzard Creek, Broad River, South Carolina	NOS	8668109	32.41	-80.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:30:00	\N	0.82	01:34:00	\N	1.1	\N	\N	Broughton Point, Hazzard Creek	SC
62217	Harbor River Bridge, St. Helena Sound, South Carolina	NOS	8668146	32.4033	-80.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:06:00	\N	0.95	00:03:00	\N	0.88	\N	\N	Harbor River Bridge	SC
62218	Distant Island Creek, upper end, Cowen Creek, Beaufort River, South Carolina	NOS	8668155	32.4017	-80.6533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:08:00	\N	0.36	01:00:00	\N	0.98	\N	\N	Distant Island Creek, upper end, Cowen Creek	SC
62219	Cowen Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8668173	32.3983	-80.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:58:00	\N	0.55	00:55:00	\N	1	\N	\N	Cowen Creek, Rt. 21 bridge	SC
62764	Breton Islands, Louisiana	NOS	8760595	29.4933	-89.1733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:08:00	\N	1.14	02:07:00	\N	1.14	\N	\N	Breton Islands	LA
62221	Johnson Creek Bridge, Hunting Island, St. Helena Sound, South Carolina	NOS	8668227	32.3917	-80.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:03:00	\N	0.86	00:03:00	\N	0.85	\N	\N	Johnson Creek Bridge, Hunting Island	SC
62264	Fort Jackson, Savannah River, Georgia	NOS	8670678	32.0817	-81.0367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:42:00	\N	1.09	00:29:00	\N	1.09	\N	\N	Fort Jackson	GA
62222	Capers Creek, Cowen Creek, St. Helena Island, Beaufort River, South Carolina	NOS	8668255	32.3717	-80.605	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:34:00	\N	0.95	00:58:00	\N	1.08	\N	\N	Capers Creek, Cowen Creek, St. Helena Island	SC
62223	Distant Island, Cowen Creek, Beaufort River, South Carolina	NOS	8668282	32.3783	-80.6333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:27:00	\N	1.05	00:43:00	\N	1.06	\N	\N	Distant Island, Cowen Creek	SC
62224	Chechessee Bluff, Chechessee River, South Carolina	NOS	8668301	32.3733	-80.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:48:00	\N	1	01:06:00	\N	1.1	\N	\N	Chechessee Bluff, Chechessee River	SC
62225	Parris Island, Marine Corps Recruit Depot, Beaufort River, South Carolina	NOS	8668445	32.35	-80.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:26:00	\N	0.91	00:37:00	\N	1.02	\N	\N	Parris Island, Marine Corps Recruit Depot	SC
62226	Baileys Landing, Okatee River, Colleton River, South Carolina	NOS	8668482	32.3467	-80.89	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:57:00	\N	1.05	01:25:00	\N	1.17	\N	\N	Baileys Landing, Okatee River, Colleton River	SC
62227	Fripp Inlet, Hunting Island Bridge, St. Helena Sound, South Carolina (sub)	NOS	8668498	32.34	-80.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:22:00	\N	0.91	-00:10:00	\N	0.88	\N	\N	Fripps Inlet, Hunting Island Bridge	SC
62228	Callawassie Island Bridge, Colleton River, South Carolina	NOS	8668511	32.3417	-80.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:49:00	\N	1.14	01:12:00	\N	1.13	\N	\N	Callawassie Island Bridge, Colleton River	SC
62229	Club Bridge Creek ent., Trenchards Inlet, South Carolina	NOS	8668529	32.335	-80.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:24:00	\N	1	00:15:00	\N	0.99	\N	\N	Club Bridge Creek ent., Trenchards Inlet	SC
62230	Station Creek, County Landing, South Carolina	NOS	8668601	32.325	-80.6017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:16:00	\N	1	00:27:00	\N	0.99	\N	\N	Station Creek, County Landing	SC
62231	Colleton River Entrance, South Carolina	NOS	8668619	32.3217	-80.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	1.05	00:49:00	\N	1.05	\N	\N	Colleton River Entrance	SC
62232	Callawassie Creek, Colleton River, South Carolina	NOS	8668636	32.3167	-80.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:53:00	\N	1.14	01:15:00	\N	1.13	\N	\N	Callawassie Creek, Colleton River	SC
62233	Callawassie Island, south, Colleton River, South Carolina	NOS	8668655	32.3133	-80.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:40:00	\N	1.11	01:09:00	\N	1.19	\N	\N	Callawassie Island, south, Colleton River	SC
62234	Fort Fremont, Beaufort River, South Carolina	NOS	8668686	32.3067	-80.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:17:00	\N	0.64	00:19:00	\N	0.95	\N	\N	Fort Fremont	SC
62235	Purrysburg Landing, Savannah River, South Carolina	NOS	8668701	32.3033	-81.1217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:38:00	\N	0.41	02:14:00	\N	0.44	\N	\N	Purrysburg Landing, S.C.	SC
62236	Station Creek, west end, South Carolina	NOS	8668836	32.28	-80.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:13:00	\N	0.91	00:16:00	\N	0.96	\N	\N	Station Creek, west end	SC
62237	Capers Island, Trenchards Inlet, South Carolina	NOS	8668837	32.2733	-80.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:18:00	\N	0.95	-00:01:00	\N	0.93	\N	\N	Capers Island, Trenchards Inlet	SC
62238	Skull Creek, Ribaut Island, South Carolina (sub)	NOS	8668918	32.2667	-80.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:16:00	\N	0.91	00:15:00	\N	0.99	\N	\N	Skull Creek, north entrance, Hilton Head Island	SC
62239	Pinckney Island, Mackay Creek, Chechessee River, South Carolina	NOS	8668944	32.26	-80.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:25:00	\N	0.91	00:36:00	\N	1.04	\N	\N	Pinckney Island, Mackay Creek, Chechessee River	SC
62240	Rt. 170 bridge, New River, South Carolina	NOS	8669072	32.2367	-81.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:53:00	\N	0.51	04:12:00	\N	0.51	\N	\N	Rt. 170 bridge	SC
62241	Bluffton, May River, South Carolina	NOS	8669103	32.23	-80.8617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	1.05	01:00:00	\N	1.16	\N	\N	Bluffton	SC
62242	Skull Creek, south entrance, Hilton Head Island, South Carolina	NOS	8669133	32.2233	-80.7717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:23:00	\N	1.05	00:34:00	\N	1.05	\N	\N	Skull Creek, south entrance, Hilton Head Island	SC
62243	Port Royal Plantation, Hilton Head Island, South Carolina	NOS	8669167	32.22	-80.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:11:00	\N	1	00:01:00	\N	0.88	\N	\N	Port Royal Plantation, Hilton Head Island	SC
62244	Bull Island North, May River, South Carolina	NOS	8669262	32.2	-80.815	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:25:00	\N	1.05	00:40:00	\N	1.09	\N	\N	Bull Island North	SC
62245	Cook Landing Cemetery, New River, South Carolina	NOS	8669277	32.195	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:00:00	\N	1.41	03:09:00	\N	0.69	\N	\N	Cook Landing Cemetery	SC
62246	Savage I., Savage Creek, Bull Creek, South Carolina	NOS	8669323	32.185	-80.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:19:00	\N	1	00:46:00	\N	1.1	\N	\N	Savage I., Savage Creek, Bull Creek	SC
62247	Broad Creek, Hilton Head Island, South Carolina	NOS	8669338	32.185	-80.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:17:00	\N	1.05	00:33:00	\N	1.08	\N	\N	Broad Creek, Hilton Head Island	SC
62248	Good Hope Landing, south of, New River, South Carolina	NOS	8669346	32.1767	-80.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:06:00	\N	1.55	02:19:00	\N	0.85	\N	\N	Good Hope Landing, south of	SC
62249	Moreland Cemetery, May River, South Carolina	NOS	8669369	32.175	-80.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:23:00	\N	0.77	00:49:00	\N	1.11	\N	\N	Moreland Cemetery	SC
62250	Bull Creek, Bull Island South, Cooper River, South Carolina	NOS	8669414	32.165	-80.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:12:00	\N	1.05	00:28:00	\N	1.05	\N	\N	Bull Creek, Bull Island South, Cooper River	SC
62251	Little Back River, Hwy. 17, Back River, Savannah River, South Carolina	NOS	8669415	32.165	-81.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:41:00	\N	1.14	01:28:00	\N	1.1	\N	\N	Little Back River, Hwy. 17, Back River, S.C.	SC
62252	Calibogue Cay, Broad Creek, Hilton Head Island, South Carolina	NOS	8669464	32.1533	-80.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:09:00	\N	1	00:20:00	\N	1.04	\N	\N	Calibogue Cay, Broad Creek, Hilton Head Island	SC
62253	Haig Point, Daufuskie Island, Cooper River, South Carolina	NOS	8669493	32.1467	-80.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:10:00	\N	1	00:20:00	\N	1.02	\N	\N	Haig Point, Daufuskie Island, Cooper River	SC
62254	Doughboy Island, New River, South Carolina	NOS	8669531	32.1383	-80.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:06:00	\N	1.05	01:04:00	\N	1.01	\N	\N	Doughboy Island	SC
62255	Turnbridge Landing, Salt Water Creek, South Carolina	NOS	8669575	32.1283	-81.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:59:00	\N	1.09	01:41:00	\N	1.06	\N	\N	Turnbridge Landing, Salt Water Creek	SC
62256	Pine Island, Ramshorn Creek, Cooper River, South Carolina	NOS	8669601	32.1217	-80.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:28:00	\N	0.91	00:34:00	\N	1.03	\N	\N	Pine Island, Ramshorn Creek, Cooper River	SC
62257	Braddock Point, Hilton Head Island, South Carolina	NOS	8669625	32.1133	-80.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:02:00	\N	1	00:05:00	\N	0.98	\N	\N	Braddock Point, Hilton Head Island	SC
62258	Daufuskie Landing, Daufuskie Island, New River, South Carolina	NOS	8669691	32.1033	-80.895	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:33:00	\N	0.95	00:30:00	\N	1.01	\N	\N	Daufuskie Landing, Daufuskie Island	SC
62259	Hargray Pier, Daufuskie Island, New River, South Carolina	NOS	8669722	32.0983	-80.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:27:00	\N	1.05	00:19:00	\N	1.01	\N	\N	Hargray Pier, Daufuskie Island	SC
62260	Bloody Point, Daufuskie Island, New River, South Carolina	NOS	8669801	32.0817	-80.8783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:19:00	\N	0.91	00:01:00	\N	0.98	\N	\N	Bloody Point, Daufuskie Island	SC
62261	Fields Cut, Wright River, South Carolina	NOS	8669815	32.0867	-80.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:29:00	\N	1.05	00:16:00	\N	1.02	\N	\N	Fields Cut, Wright River	SC
62262	S.C.L. RR. bridge, Savannah River, Georgia	NOS	8670073	32.2317	-81.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:08:00	\N	0.91	01:51:00	\N	0.9	\N	\N	S.C.L. RR. bridge	GA
62922	Benicia, California	NOS	9415111	38.0433	-122.13	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	-00:33:00	\N	1.18	-00:24:00	\N	1.09	\N	\N	Benicia	CA
62263	Port Wentworth, Savannah River, Georgia (sub)	NOS	8670424	32.1433	-81.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60495	-00:02:00	\N	0.84	00:11:00	\N	1.03	\N	\N	Port Wentworth	GA
62265	Savannah (Bull Street), Georgia (sub)	NOS	8670681	32.0817	-81.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:33:00	\N	1.14	00:44:00	\N	1.14	\N	\N	SAVANNAH	GA
62266	Tybee Light, Savannah River, Georgia	NOS	8670892	32.0283	-80.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:12:00	\N	0.99	-00:10:00	\N	0.99	\N	\N	Tybee Light	GA
62267	Vernon View, Burnside River, Georgia	NOS	8671642	31.9267	-81.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:31:00	\N	1.09	00:40:00	\N	1.09	\N	\N	Vernon View, Burnside River	GA
62268	Florida Passage, Ogeechee River, Georgia	NOS	8672219	31.8533	-81.1467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:46:00	\N	0.91	00:34:00	\N	1.05	\N	\N	Florida Passage, Ogeechee River	GA
62269	Bradley Point, Bradley River, Georgia	NOS	8672455	31.8217	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:13:00	\N	0.95	00:04:00	\N	1.02	\N	\N	Bradley Point, Bradley River	GA
62270	Belfast, Belfast River, Georgia	NOS	8672462	31.8217	-81.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:10:00	\N	1.14	01:23:00	\N	1.13	\N	\N	Belfast, Belfast River	GA
62271	Bear River, (Range 'A' Light), Georgia (sub)	NOS	8672667	31.7933	-81.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:39:00	\N	0.95	00:43:00	\N	1.09	\N	\N	Bear River, (Range 'A' Light)	GA
62272	Kilkenny Club, Kilkenny Creek, Georgia	NOS	8672696	31.7883	-81.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	0.91	00:48:00	\N	1.09	\N	\N	Kilkenny Club, Kilkenny Creek	GA
62273	Sunbury, Sunbury Channel, Georgia (sub)	NOS	8672875	31.7667	-81.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:52:00	\N	0.73	00:53:00	\N	1.05	\N	\N	Sunbury, Medway River	GA
62274	Halfmoon, Timmons River, Georgia	NOS	8673381	31.695	-81.2717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:09:00	\N	1.05	01:21:00	\N	1.06	\N	\N	Halfmoon, Timmons River	GA
62275	Walburg Creek entrance, Georgia	NOS	8673437	31.69	-81.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:21:00	\N	1	00:16:00	\N	1.03	\N	\N	Walburg Creek entrance	GA
62276	North Newport River (Daymark 119), Georgia	NOS	8673499	31.6817	-81.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:31:00	\N	1	00:35:00	\N	1.05	\N	\N	North Newport River (Daymark 119)	GA
62277	Thomas Landing, S. Newport River, Georgia	NOS	8673812	31.6433	-81.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:46:00	\N	0.95	00:57:00	\N	1.06	\N	\N	Thomas Landing, S. Newport River	GA
62278	Eagle Neck, South Newport River, Georgia	NOS	8673875	31.65	-81.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:06:00	\N	1	01:16:00	\N	1.09	\N	\N	Eagle Neck, South Newport River	GA
62303	8 miles above mouth, Little Satilla River, Georgia	NOS	8677566	31.0983	-81.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:02:00	\N	1.2	00:24:00	\N	1.2	\N	\N	8 miles above mouth	GA
62279	Harris Neck, Barbour Island River, Georgia	NOS	8673962	31.6233	-81.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:32:00	\N	1	00:54:00	\N	1.08	\N	\N	Harris Neck, Barbour Island River	GA
62280	Barbour Island, Barbour Island River, Georgia	NOS	8674251	31.5783	-81.24	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:24:00	\N	1	00:36:00	\N	1.06	\N	\N	Barbour Island, Barbour Island River	GA
62281	South Newport River (Daymark 135), Georgia (sub)	NOS	8674301	31.575	-81.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:20:00	\N	1.05	00:27:00	\N	1.03	\N	\N	South Newport River (Daymark 135)	GA
62282	Pine Harbor, Sapelo River, Georgia	NOS	8674512	31.5483	-81.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:04:00	\N	1.05	01:03:00	\N	1.05	\N	\N	Pine Harbor, Sapelo River	GA
62283	Dog Hammock, Sapelo River, Georgia	NOS	8674623	31.5317	-81.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:22:00	\N	0.91	00:33:00	\N	1.04	\N	\N	Dog Hammock, Sapelo River	GA
62284	Bellville Point, Sapelo River, Georgia	NOS	8674638	31.5317	-81.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:02:00	\N	0.86	01:12:00	\N	1.08	\N	\N	Bellville Point, Sapelo River	GA
62285	Eagle Creek, Mud River, Georgia	NOS	8674801	31.51	-81.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:19:00	\N	1.05	00:21:00	\N	1.05	\N	\N	Eagle Creek, Mud River	GA
62286	Creighton Narrows entrance, Crescent River, Georgia	NOS	8674875	31.4983	-81.325	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	1.09	00:49:00	\N	1.08	\N	\N	Creighton Narrows Entrance, Crescent River	GA
62287	Blackbeard Creek, Blackbeard Island, Georgia	NOS	8674962	31.4883	-81.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:47:00	\N	0.95	00:19:00	\N	0.94	\N	\N	Blackbeard Creek, Blackbeard Island	GA
62288	Hudson Creek entrance, Georgia	NOS	8675245	31.4467	-81.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:31:00	\N	1.05	00:37:00	\N	1.05	\N	\N	Hudson Creek entrance	GA
62289	Old Tea Kettle Creek (Daymark 173), Georgia	NOS	8675365	31.4317	-81.3067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:39:00	\N	0.82	00:39:00	\N	0.96	\N	\N	Old Tea Kettle Creek (Daymark 173)	GA
62290	Old Tower, Sapelo Island, Georgia	NOS	8675622	31.39	-81.2883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:14:00	\N	0.95	00:15:00	\N	0.99	\N	\N	Old Tower, Sapelo Island	GA
62291	Rockdedundy River (Daymark 185), Georgia (sub)	NOS	8675761	31.37386111111111	-81.33394444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:41:00	\N	1.01	00:29:00	\N	1	\N	\N	Rockdedundy River (Daymark 185)	GA
62292	Darien, Darien River, Georgia	NOS	8675779	31.3683	-81.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:15:00	\N	1.05	01:08:00	\N	1.06	\N	\N	Darien, Darien River	GA
62293	Threemile Cut entrance, Darien River, Georgia	NOS	8675843	31.3567	-81.3767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:55:00	\N	1.05	00:44:00	\N	1.03	\N	\N	Threemile Cut entrance, Darien River	GA
62294	Champney Island, South Altamaha River, Georgia	NOS	8676012	31.3317	-81.46	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:33:00	\N	0.77	01:10:00	\N	0.76	\N	\N	Champney Island, South Altamaha River	GA
62295	Mackay River (ICWW), Buttermilk Sound, Georgia	NOS	8676329	31.285	-81.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:23:00	\N	1.09	00:58:00	\N	1	\N	\N	Mackay River (ICWW), Buttermilk Sound	GA
62296	Dillard Creek, Turtle River, Georgia	NOS	8676722	31.225	-81.5717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:02:00	\N	1.18	01:32:00	\N	1.16	\N	\N	Dillard Creek	GA
62297	Frederica River, Georgia	NOS	8676743	31.2217	-81.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:56:00	\N	1.05	00:48:00	\N	1.05	\N	\N	Frederica River	GA
62298	Mackay River (Daymark 239), Georgia	NOS	8676766	31.21	-81.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:56:00	\N	1.09	00:58:00	\N	1.03	\N	\N	Mackay River (Daymark 239)	GA
62299	Buffalo River entrance, Turtle River, Georgia	NOS	8676787	31.215	-81.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:58:00	\N	1.18	01:37:00	\N	1.16	\N	\N	Buffalo River entrance	GA
62300	Crispen Island, Turtle River, Georgia (sub)	NOS	8676808	31.2133	-81.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:55:00	\N	1.05	01:33:00	\N	1.15	\N	\N	Crispen Island	GA
62301	Frederick River Bridge, Georgia	NOS	8677045	31.1683	-81.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:45:00	\N	1.09	00:43:00	\N	1	\N	\N	Frederick River Bridge	GA
62304	Jointer Island, Jointer Creek, Georgia	NOS	8677576	31.095	-81.505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:31:00	\N	1.18	00:11:00	\N	1.18	\N	\N	Jointer Island, Jointer Creek	GA
62305	Jekyll Island Marina, Jekyll Creek, Georgia	NOS	8677832	31.0567	-81.4233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:36:00	\N	1.16	00:03:00	\N	1.13	\N	\N	Jekyll Island Marina, Jekyll Creek	GA
62306	2.5 miles above mouth, Little Satilla River, Georgia	NOS	8677833	31.0583	-81.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:31:00	\N	1.12	-00:04:00	\N	1.12	\N	\N	2.5 miles above mouth	GA
62307	Dover Bluff, Dover Creek, Georgia	NOS	8678111	31.0167	-81.5283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:31:00	\N	1.15	00:06:00	\N	1.15	\N	\N	Dover Bluff, Dover Creek	GA
62308	Todd Creek entrance, Satilla River, Georgia	NOS	8678412	30.9717	-81.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:41:00	\N	1.1	-00:08:00	\N	1.1	\N	\N	Todd Creek entrance	GA
62309	Ceylon, Satilla River, Georgia	NOS	8678466	30.9633	-81.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:35:00	\N	1.09	00:34:00	\N	1.09	\N	\N	Ceylon	GA
62310	Floyd Creek, 2.8 miles above entrance, Georgia	NOS	8678642	30.9367	-81.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:21:00	\N	1.17	00:08:00	\N	1.17	\N	\N	Floyd Creek, 2.8 miles above entrance	GA
62311	Cumberland Wharf, Cumberland River, Georgia	NOS	8678688	30.93	-81.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:26:00	\N	1.12	00:00:00	\N	1.12	\N	\N	Cumberland Wharf, Cumberland River	GA
62312	Harrietts Bluff, Crooked River, Georgia	NOS	8679083	30.87	-81.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:56:00	\N	1.05	01:29:00	\N	1.05	\N	\N	Harrietts Bluff, Crooked River	GA
62313	Crooked River, Cumberland Dividings, Georgia	NOS	8679242	30.8433	-81.4867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:56:00	\N	1.12	00:44:00	\N	1.12	\N	\N	Crooked River, Cumberland Dividings	GA
62314	Kings Bay, Navy Base, Georgia (sub)	NOS	8679511	30.7967	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:10:00	\N	1.05	00:12:00	\N	1.09	\N	\N	Kings Bay, Navy Base	GA
62315	Dungeness, Seacamp Dock, Georgia (sub)	NOS	8679758	30.7633	-81.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:16:00	\N	1.05	00:12:00	\N	1.04	\N	\N	Seacamp Dock, Cumberland Island	GA
62316	Beach Creek ent., Cumberland Island, Georgia	NOS	8679945	30.7267	-81.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:04:00	\N	0.95	00:00:00	\N	0.98	\N	\N	Beach Creek ent., Cumberland Island	GA
62317	St. Marys, St. Marys River, Georgia (sub)	NOS	8679964	30.72	-81.5483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:45:00	\N	1.05	00:38:00	\N	0.98	\N	\N	St. Marys	GA
62318	St. Marys Entrance, North Jetty, Georgia	NOS	8679997	30.72	-81.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:03:00	\N	0.96	-00:36:00	\N	0.96	\N	\N	St. Marys Entrance, North Jetty	GA
62319	Kings Ferry, St. Marys River, Florida	NOS	8720001	30.7867	-81.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	04:09:00	\N	1.16	04:05:00	\N	0.49	\N	\N	Kings Ferry	FL
62320	Little St. Marys River, St. Marys River, Florida	NOS	8720006	30.7317	-81.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	02:36:00	\N	0.79	02:49:00	\N	0.71	\N	\N	Little St. Marys River	FL
62321	Roses Bluff, Bells River, Florida	NOS	8720007	30.7033	-81.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:35:00	\N	0.95	00:35:00	\N	1.03	\N	\N	Roses Bluff, Bells River	FL
62322	Chester, Bells River, Florida (sub)	NOS	8720023	30.6833	-81.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:19:00	\N	1.11	00:27:00	\N	1.04	\N	\N	Chester, Bells River	FL
62323	Lofton, Lanceford Creek, Florida (sub)	NOS	8720051	30.6433	-81.5233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:01:00	\N	1.05	00:18:00	\N	1.05	\N	\N	Lofton, Lanceford Creek	FL
62324	Kingsley Creek, RR. bridge, Florida	NOS	8720058	30.6317	-81.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:25:00	\N	1	00:27:00	\N	0.99	\N	\N	Kingsley Creek, RR. bridge	FL
62325	Boggy Creek, 2 mi. above entrance, Nassau River, Florida	NOS	8720084	30.5883	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	03:50:00	\N	0.89	03:29:00	\N	0.49	\N	\N	Boggy Creek, 2 mi. above entrance	FL
62326	Amelia City, South Amelia River, Florida	NOS	8720086	30.5867	-81.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:42:00	\N	0.89	00:21:00	\N	0.89	\N	\N	Amelia City, South Amelia River	FL
62327	Halfmoon Island, highway bridge, Nassau River, Florida	NOS	8720093	30.5767	-81.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	02:39:00	\N	1.05	02:00:00	\N	0.7	\N	\N	Halfmoon Island, highway bridge	FL
62328	Cuno, Lofton Creek, Nassau River, Florida	NOS	8720097	30.5767	-81.5717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	02:48:00	\N	1.05	02:14:00	\N	0.6	\N	\N	Cuno, Lofton Creek	FL
62329	Nassauville, Nassau River East, Florida (sub)	NOS	8720098	30.5683	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:09:00	\N	1	00:24:00	\N	0.8	\N	\N	Nassauville	FL
62330	Mink Creek entrance, Nassau River, Florida	NOS	8720119	30.5367	-81.5817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	02:05:00	\N	1.05	01:13:00	\N	0.72	\N	\N	Mink Creek entrance	FL
62331	Nassau River entrance, Florida	NOS	8720135	30.5183	-81.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:41:00	\N	1	-00:18:00	\N	0.86	\N	\N	entrance	FL
62332	Sawpit Creek entrance, bridge, Florida	NOS	8720137	30.5133	-81.4567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:21:00	\N	1	-00:14:00	\N	0.84	\N	\N	Sawpit Creek entrance, bridge	FL
62333	Sawpit Creek, 1 mi. above entrance, Florida	NOS	8720143	30.5033	-81.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:31:00	\N	0.74	00:05:00	\N	0.84	\N	\N	Sawpit Creek, 1 mi. above entrance	FL
62334	Edwards Creek, Nassau River, Florida (sub)	NOS	8720145	30.5017	-81.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:51:00	\N	0.85	01:24:00	\N	0.77	\N	\N	Edwards Creek, 1 mi. above entrance	FL
62335	Tiger Point, Pumpkin Hill Creek, Nassau River, Florida	NOS	8720148	30.5017	-81.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:46:00	\N	0.95	01:22:00	\N	0.82	\N	\N	Tiger Point, Pumpkin Hill Creek	FL
62336	Simpson Creek, A1A highway bridge, Florida	NOS	8720168	30.465	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:17:00	\N	0.63	00:04:00	\N	0.84	\N	\N	Simpson Creek, A1A highway bridge	FL
62337	Fort George Island, Fort George River, Florida	NOS	8720186	30.44	-81.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:33:00	\N	0.74	00:10:00	\N	0.79	\N	\N	Fort George Island, Fort George River	FL
62338	Little Talbot Island, ocean, Florida	NOS	8720194	30.43	-81.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:13:00	\N	1	-00:36:00	\N	0.91	\N	\N	Little Talbot Island, ocean	FL
62339	Sisters Creek, Florida (sub)	NOS	8720196	30.4167	-81.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	00:50:00	\N	0.93	00:32:00	\N	0.95	\N	\N	Sisters Creek	FL
62340	Blount Island Bridge, Florida	NOS	8720203	30.4133	-81.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:05:00	\N	0.73	00:42:00	\N	0.77	\N	\N	Blount Island Bridge	FL
62341	Water Treatment Dock, Mayport Naval Station, St Johns River, Florida (sub)	NOS	8720211	30.4	-81.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	-00:06:00	\N	1	-00:12:00	\N	1.03	\N	\N	Mayport Naval Station, Water Treatment Dock	FL
62342	Sherwood Forest, Trout River, Florida (sub)	NOS	8720213	30.42	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	02:13:00	\N	0.67	01:42:00	\N	0.58	\N	\N	Sherwood Forest	FL
62343	Jacksonville, Navy Fuel Depot, Florida	NOS	8720215	30.4	-81.6267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:48:00	\N	0.53	01:14:00	\N	0.56	\N	\N	Jacksonville, Navy Fuel Depot	FL
62344	Lake Forest, Ribault River, Trout River, Florida	NOS	8720216	30.3983	-81.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	02:10:00	\N	0.6	01:13:00	\N	0.58	\N	\N	Lake Forest, Ribault River	FL
62345	Moncrief Creek entrance, Trout River, Florida	NOS	8720217	30.3917	-81.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:53:00	\N	0.53	01:11:00	\N	0.55	\N	\N	Moncrief Creek entrance	FL
62346	Dame Point, St. Johns River, Florida (sub)	NOS	8720219	30.3867	-81.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:12:00	\N	0.67	00:42:00	\N	0.7	\N	\N	Dame Point	FL
62347	Fulton, Florida	NOS	8720221	30.39	-81.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	00:40:00	\N	0.73	00:24:00	\N	0.8	\N	\N	Fulton	FL
62348	Phoenix Park, Florida (sub)	NOS	8720225	30.3833	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:47:00	\N	0.6	01:02:00	\N	0.56	\N	\N	Phoenix Park	FL
62349	Main Street Bridge, St. Johns River, Florida (sub)	NOS	8720226	30.32	-81.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	02:09:00	\N	0.73	01:39:00	\N	0.4	\N	\N	Jacksonville, Main Street Bridge	FL
62350	Pablo Creek entrance, Florida	NOS	8720232	30.3767	-81.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	00:33:00	\N	0.73	00:29:00	\N	0.85	\N	\N	Pablo Creek entrance	FL
62351	Jacksonville, Long Branch, Florida (sub)	NOS	8720242	30.36	-81.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:54:00	\N	0.73	01:15:00	\N	0.55	\N	\N	Jacksonville, Long Branch	FL
62352	Atlantic Beach, Florida	NOS	8720259	30.335	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:23:00	\N	0.86	-00:41:00	\N	0.86	\N	\N	Atlantic Beach	FL
62353	Pablo Creek, ICWW bridge, Florida	NOS	8720267	30.3233	-81.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:20:00	\N	1	01:14:00	\N	0.84	\N	\N	Pablo Creek, ICWW bridge	FL
62354	Little Pottsburg Creek, Florida	NOS	8720274	30.31	-81.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	02:09:00	\N	0.53	01:31:00	\N	0.44	\N	\N	Little Pottsburg Creek	FL
62355	Jacksonville Beach, Florida (sub)	NOS	8720291	30.2833	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:27:00	\N	0.84	-00:50:00	\N	0.84	\N	\N	Jacksonville Beach	FL
62356	Ortega River entrance, Florida	NOS	8720296	30.2783	-81.705	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	02:47:00	\N	0.47	02:09:00	\N	0.25	\N	\N	Ortega River entrance	FL
62357	Oak Landing, ICWW, Florida	NOS	8720305	30.2533	-81.43	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	02:03:00	\N	0.8	02:15:00	\N	0.68	\N	\N	Oak Landing, ICWW	FL
62358	Piney Point, Florida	NOS	8720333	30.2283	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	03:36:00	\N	0.4	02:39:00	\N	0.2	\N	\N	Piney Point	FL
62359	I-295 Bridge (west end), St. Johns River, Florida (sub)	NOS	8720357	30.1917	-81.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	03:43:00	\N	0.6	02:56:00	\N	0.21	\N	\N	I-295 bridge (west end)	FL
62360	Orange Park Landing, Orange Park, Florida	NOS	8720374	30.16830062866211	-81.69499969482422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	04:44:00	\N	0.2	03:24:00	\N	0.2	\N	\N	Orange Park Landing, Orange Park	FL
62361	Palm Valley, ICWW, Florida	NOS	8720398	30.1333	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:49:00	\N	0.75	02:00:00	\N	0.79	\N	\N	Palm Valley, ICWW	FL
62362	Julington Creek, Florida	NOS	8720409	30.135000228881836	-81.62999725341797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	05:13:00	\N	0.2	03:58:00	\N	0.2	\N	\N	Julington Creek	FL
62363	Green Cove Springs, Florida	NOS	8720496	29.99	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	05:55:00	\N	0.27	04:57:00	\N	0.17	\N	\N	Green Cove Springs	FL
62364	Vilano Beach ICWW, Tolomato River, Florida (sub)	NOS	8720554	29.9167	-81.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:05:00	\N	0.9	-00:20:00	\N	0.74	\N	\N	Vilano Beach, Tolomato River	FL
62365	St. Augustine, city dock, Florida	NOS	8720576	29.8917	-81.31	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:01:00	\N	0.89	-00:20:00	\N	0.75	\N	\N	St. Augustine, city dock	FL
62366	St. Augustine Beach, Florida (sub)	NOS	8720587	29.8567	-81.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:32:00	\N	0.84	-00:51:00	\N	0.77	\N	\N	St. Augustine Beach	FL
62367	Tocoi, Florida	NOS	8720596	29.8583	-81.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	07:03:00	\N	0.27	06:02:00	\N	0.21	\N	\N	Tocoi	FL
62368	Palmetto Bluff, Florida	NOS	8720653	29.7633	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	07:36:00	\N	0.47	06:35:00	\N	0.23	\N	\N	Palmetto Bluff	FL
62369	Fort Matanzas, Matanzas River, ICWW, Florida	NOS	8720686	29.715	-81.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:49:00	\N	0.95	00:03:00	\N	0.65	\N	\N	Fort Matanzas, Matanzas River, ICWW	FL
62370	Buffalo Bluff, St. Johns River, Florida (sub)	NOS	8720767	29.595	-81.6817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	08:58:00	\N	0.4	07:27:00	\N	0.21	\N	\N	Buffalo Bluff	FL
62371	Palatka, St. Johns River, Florida (sub)	NOS	8720774	29.6433	-81.6317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	08:38:00	\N	0.53	07:11:00	\N	0.25	\N	\N	Palatka	FL
62372	Sutherlands Still, Dunns Creek, Florida	NOS	8720782	29.5717	-81.6067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	09:05:00	\N	0.2	07:35:00	\N	0.18	\N	\N	Sutherlands Still, Dunns Creek	FL
62373	Welaka, St. Johns River, Florida (sub)	NOS	8720832	29.4767	-81.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	08:07:00	\N	0.27	07:16:00	\N	0.1	\N	\N	Welaka	FL
62374	Smith Creek, Flagler Beach, Florida	NOS	8720833	29.4783	-81.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	05:00:00	\N	0.3	04:33:00	\N	0.15	\N	\N	Smith Creek, Flagler Beach	FL
62375	Ormond Beach, Halifax River, Florida	NOS	8720954	29.285	-81.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	04:31:00	\N	0.45	03:17:00	\N	0.11	\N	\N	Ormond Beach, Halifax River	FL
62376	Daytona Beach Shores, Sunglow Pier, Florida (sub)	NOS	8721120	29.1467	-80.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:42:00	\N	0.84	-00:56:00	\N	0.65	\N	\N	Daytona Beach Shores, Sunglow Pier	FL
62377	Ponce Inlet, Halifax River, Florida	NOS	8721138	29.0817	-80.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:33:00	\N	1	00:05:00	\N	1.18	\N	\N	Ponce Inlet, Halifax River	FL
62378	Ponce De Leon Inlet South, Florida (sub)	NOS	8721147	29.0633	-80.915	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:19:00	\N	0.92	-00:11:00	\N	1.17	\N	\N	Ponce de Leon Inlet	FL
62379	Patrick Air Force Base, Florida	NOS	8721727	28.245	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:38:00	\N	1.43	-01:04:00	\N	1.5	\N	\N	Patrick Air Force Base	FL
62380	Canova Beach, Florida	NOS	8721804	28.1383	-80.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:26:00	\N	1.5	-00:53:00	\N	1.49	\N	\N	Canova Beach	FL
62381	Micco, Indian River, Florida	NOS	8721994	27.8733	-80.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:19:00	\N	0.57	01:14:00	\N	0.14	\N	\N	Micco	FL
62382	Sebastian Inlet bridge, Florida	NOS	8722004	27.86	-80.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:24:00	\N	1	-00:48:00	\N	0.93	\N	\N	Sebastian Inlet bridge	FL
62383	Sebastian, Indian River, Florida	NOS	8722029	27.8117	-80.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:36:00	\N	0.5	01:32:00	\N	0.15	\N	\N	Sebastian	FL
62384	Wabasso, Indian River, Florida	NOS	8722059	27.755	-80.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:24:00	\N	0.42	02:20:00	\N	0.17	\N	\N	Wabasso	FL
62385	Vero Beach (ocean), Florida	NOS	8722105	27.67	-80.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:35:00	\N	1.36	-00:55:00	\N	1.45	\N	\N	Vero Beach (ocean)	FL
62386	Vero Beach, Indian River, Florida (sub)	NOS	8722125	27.6317	-80.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:41:00	\N	0.79	02:56:00	\N	0.37	\N	\N	Vero Beach	FL
62387	Oslo, Indian River, Florida	NOS	8722146	27.5933	-80.3567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:59:00	\N	0.5	03:00:00	\N	0.34	\N	\N	Oslo	FL
62388	St. Lucie, Indian River, Florida	NOS	8722207	27.48	-80.3333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:46:00	\N	1	00:41:00	\N	0.48	\N	\N	St. Lucie	FL
62389	Fort Pierce Inlet, south jetty, Florida	NOS	8722212	27.47	-80.2883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:18:00	\N	1.5	-00:31:00	\N	1.14	\N	\N	Fort Pierce Inlet, south jetty	FL
62390	Ankona, Indian River, Florida	NOS	8722274	27.355	-80.2733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:03:00	\N	0.85	02:16:00	\N	0.52	\N	\N	Ankona	FL
62391	Eden, Nettles Island, Indian River, Florida	NOS	8722312	27.2867	-80.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:31:00	\N	0.92	02:35:00	\N	0.45	\N	\N	Eden, Nettles Island	FL
62392	North Fork, St. Lucie River, Florida	NOS	8722334	27.2433	-80.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:28:00	\N	0.92	02:28:00	\N	0.46	\N	\N	North Fork	FL
62393	Jensen Beach, Indian River, Florida	NOS	8722338	27.235	-80.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:04:00	\N	0.92	02:17:00	\N	0.48	\N	\N	Jensen Beach	FL
62394	Stuart, St. Lucie River, Florida	NOS	8722357	27.2	-80.2583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:30:00	\N	0.86	02:13:00	\N	0.4	\N	\N	Stuart	FL
62395	Seminole Shores, Florida	NOS	8722366	27.1833	-80.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:35:00	\N	1.28	-00:59:00	\N	1.29	\N	\N	Seminole Shores	FL
62396	Sewall Point, St. Lucie River, Florida	NOS	8722371	27.175	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:10:00	\N	0.93	01:13:00	\N	0.43	\N	\N	Sewall Point	FL
62397	South Fork, St. Lucie River, Florida	NOS	8722376	27.165	-80.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:32:00	\N	0.92	02:35:00	\N	0.43	\N	\N	South Fork	FL
62399	Port Salerno, Manatee Pocket, St. Lucie River, Florida	NOS	8722383	27.1517	-80.195	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:46:00	\N	0.92	00:51:00	\N	0.42	\N	\N	Port Salerno, Manatee Pocket	FL
62400	Peck Lake, ICWW, Florida	NOS	8722404	27.1133	-80.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:10:00	\N	1	01:13:00	\N	0.58	\N	\N	Peck Lake, ICWW	FL
62401	Gomez, South Jupiter Narrows, Florida	NOS	8722414	27.0933	-80.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:37:00	\N	1.07	01:33:00	\N	0.6	\N	\N	Gomez, South Jupiter Narrows	FL
62402	Hobe Sound bridge, Florida	NOS	8722429	27.065	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:25:00	\N	1	01:28:00	\N	0.68	\N	\N	Hobe Sound bridge	FL
62403	Hobe Sound, Jupiter Island, Florida	NOS	8722445	27.0367	-80.1067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:12:00	\N	1	01:16:00	\N	0.75	\N	\N	Hobe Sound, Jupiter Island	FL
62404	Conch Bar, Jupiter Sound, Florida	NOS	8722471	26.9883	-80.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:34:00	\N	1.07	00:56:00	\N	0.74	\N	\N	Conch Bar, Jupiter Sound	FL
62405	Boy Scout Dock, Loxahatchee River, Florida	NOS	8722472	26.9867	-80.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:57:00	\N	1.36	01:01:00	\N	0.92	\N	\N	Boy Scout Dock	FL
62406	North Fork, 2 miles above entrance, Loxahatchee River, Florida	NOS	8722478	26.975	-80.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:55:00	\N	1.14	01:04:00	\N	0.86	\N	\N	North Fork, 2 miles above entrance	FL
62407	3 miles above A1A highway bridge, Loxahatchee River, Florida	NOS	8722481	26.97	-80.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:49:00	\N	1.14	00:56:00	\N	0.86	\N	\N	3 miles above A1A highway bridge	FL
62408	Tequesta, North Fork, Loxahatchee River, Florida	NOS	8722486	26.96	-80.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:13:00	\N	1	01:14:00	\N	0.75	\N	\N	Tequesta, North Fork	FL
62409	Jupiter Sound, south end, Florida	NOS	8722491	26.9517	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:45:00	\N	1.36	00:22:00	\N	0.88	\N	\N	Jupiter Sound, south end	FL
62410	A1A highway bridge, Loxahatchee River, Florida	NOS	8722492	26.9467	-80.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:54:00	\N	1.14	00:34:00	\N	0.87	\N	\N	A1A highway bridge	FL
62411	Southwest Fork, 0.5 mile above entrance, Loxahatchee River, Florida	NOS	8722494	26.9433	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:35:00	\N	1.42	00:41:00	\N	0.89	\N	\N	Southwest Fork, 0.5 mile above entrance	FL
62412	Jupiter Inlet, south jetty, Florida	NOS	8722495	26.9433	-80.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:09:00	\N	1.42	-00:10:00	\N	1.08	\N	\N	Jupiter Inlet, south jetty	FL
62413	Southwest Fork (spillway), Loxahatchee River, Florida	NOS	8722496	26.935	-80.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:45:00	\N	1.28	00:52:00	\N	0.86	\N	\N	Southwest Fork (spillway)	FL
62414	Jupiter, Lake Worth Creek, ICWW, Florida	NOS	8722499	26.935	-80.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:12:00	\N	1.28	00:34:00	\N	0.91	\N	\N	Jupiter, Lake Worth Creek, ICWW	FL
62415	Lake Worth Creek, Day Beacon 19, ICWW, Florida	NOS	8722512	26.9117	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:08:00	\N	1.21	00:29:00	\N	0.92	\N	\N	Lake Worth Creek, Day Beacon 19, ICWW	FL
62416	Donald Ross Bridge, ICWW, Florida	NOS	8722528	26.8817	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:50:00	\N	1.21	00:20:00	\N	1	\N	\N	Donald Ross Bridge, ICWW	FL
62417	PGA Boulevard Bridge, Palm Beach, Florida (sub)	NOS	8722548	26.8433	-80.0667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:31:00	\N	1.36	-00:02:00	\N	1.16	\N	\N	PGA Boulevard Bridge, ICWW	FL
62418	North Palm Beach, Lake Worth, Florida	NOS	8722557	26.8267	-80.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:15:00	\N	1.29	-00:17:00	\N	1.22	\N	\N	North Palm Beach	FL
62419	Port of West Palm Beach, Florida (sub)	NOS	8722588	26.77	-80.0517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:04:00	\N	1.36	-00:21:00	\N	1.18	\N	\N	Port of Palm Beach	FL
62420	Palm Beach, Lake Worth, Florida	NOS	8722607	26.7333	-80.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:16:00	\N	1.29	-00:11:00	\N	1.17	\N	\N	Palm Beach	FL
62421	Palm Beach, Highway 704 bridge, Lake Worth, Florida	NOS	8722621	26.705	-80.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:40:00	\N	1.07	00:18:00	\N	1.1	\N	\N	Palm Beach, Highway 704 bridge	FL
62422	West Palm Beach Canal, Lake Worth, Florida	NOS	8722654	26.645	-80.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:35:00	\N	1.14	00:48:00	\N	1.07	\N	\N	West Palm Beach Canal	FL
62423	Lake Worth Pier, Florida (sub)	NOS	8722670	26.6127778	-80.0341667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:19:00	\N	1	-00:45:00	\N	1.16	\N	\N	Lake Worth Pier (ocean)	FL
62424	Boynton Beach, Lake Worth, Florida (sub)	NOS	8722706	26.54829978942871	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:07:00	\N	1.07	01:05:00	\N	1.06	\N	\N	Boynton Beach, Lake Worth	FL
62425	Delray Beach, ICWW, Florida	NOS	8722746	26.4733	-80.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:07:00	\N	1.14	01:24:00	\N	1.07	\N	\N	Delray Beach, ICWW	FL
62426	Yamato, ICWW, Florida	NOS	8722784	26.4033	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:57:00	\N	1.14	01:22:00	\N	1.02	\N	\N	Yamato, ICWW	FL
62427	Lake Wyman, ICWW, Florida (sub)	NOS	8722802	26.37	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:49:00	\N	1.14	01:17:00	\N	0.96	\N	\N	Lake Wyman, ICWW	FL
62428	Deerfield Beach, Hillsboro River, Florida	NOS	8722832	26.3133	-80.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:03:00	\N	1.07	00:28:00	\N	1.02	\N	\N	Deerfield Beach, Hillsboro River	FL
62429	Hillsboro Beach, ICWW, Florida	NOS	8722854	26.2733	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:34:00	\N	1.07	00:02:00	\N	1.06	\N	\N	Hillsboro Beach, ICWW	FL
62430	Hillsboro Inlet, Coast Guard Light Station, Florida	NOS	8722861	26.2583	-80.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:03:00	\N	1.14	-00:16:00	\N	1.08	\N	\N	Hillsboro Inlet, Coast Guard Light Station	FL
62431	Hillsboro Inlet (ocean), Florida	NOS	8722862	26.2567	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:00:00	\N	1.21	-00:23:00	\N	1.12	\N	\N	Hillsboro Inlet (ocean)	FL
62432	Andrews Avenue bridge, New River, Fort Lauderdale, Florida	NOS	8722937	26.1183	-80.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:51:00	\N	1.07	00:15:00	\N	0.92	\N	\N	Andrews Avenue bridge, New River	FL
62433	Bahia Mar Yacht Club, Fort Lauderdale, Florida	NOS	8722939	26.1133	-80.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:33:00	\N	1.21	-00:05:00	\N	1.05	\N	\N	Bahia Mar Yacht Club	FL
62434	Mayan Lake, Florida	NOS	8722946	26.1	-80.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:02:00	\N	1	00:20:00	\N	0.91	\N	\N	Mayan Lake	FL
62435	Port Everglades, Turning Basin, Florida	NOS	8722951	26.0917	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:09:00	\N	1.14	-00:29:00	\N	1.09	\N	\N	Port Everglades, Turning Basin	FL
62436	Whiskey Creek, north end, Florida	NOS	8722957	26.08	-80.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:06:00	\N	1.28	-00:23:00	\N	1.1	\N	\N	Whiskey Creek, north end	FL
62437	Port Laudania, Dania cut-off Canal, Florida	NOS	8722968	26.06	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:11:00	\N	1.21	00:01:00	\N	1	\N	\N	Port Laudania, Dania cut-off Canal	FL
62438	Whiskey Creek, south entrance, ICWW, Florida	NOS	8722971	26.055	-80.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:31:00	\N	1.14	00:04:00	\N	0.96	\N	\N	Whiskey Creek, south entrance, ICWW	FL
62439	Hollywood Beach, West Lake, north end, Florida	NOS	8722977	26.0433	-80.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:42:00	\N	1.07	01:08:00	\N	0.85	\N	\N	Hollywood Beach, West Lake, north end	FL
62440	Hollywood Beach, Florida	NOS	8722979	26.04	-80.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:41:00	\N	1.14	00:37:00	\N	0.91	\N	\N	Hollywood Beach	FL
62441	Hollywood Beach, West Lake, south end, Florida	NOS	8722982	26.0333	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:45:00	\N	1.14	01:02:00	\N	0.88	\N	\N	Hollywood Beach, West Lake, south end	FL
62442	Golden Beach, ICWW, Florida	NOS	8723026	25.9667	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:57:00	\N	1.07	01:13:00	\N	0.91	\N	\N	Golden Beach, ICWW	FL
62443	Dumfoundling Bay, Florida	NOS	8723044	25.9417	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:07:00	\N	1	01:17:00	\N	0.88	\N	\N	Dumfoundling Bay	FL
62444	North Miami Beach, Newport Fishing Pier, Florida	NOS	8723050	25.93	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:00:00	\N	1.21	-00:22:00	\N	1.08	\N	\N	North Miami Beach, Newport Fishing Pier	FL
62445	Bakers Haulover Inlet (inside), Florida	NOS	8723073	25.9033	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:37:00	\N	0.92	00:57:00	\N	0.87	\N	\N	Bakers Haulover Inlet (inside)	FL
62446	Haulover Pier, N. Miami Beach, Florida (sub)	NOS	8723080	25.9033	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:06:00	\N	1	-00:29:00	\N	1.06	\N	\N	Haulover Pier, N. Miami Beach	FL
62447	Sunny Isles, Biscayne Creek, Florida	NOS	8723087	25.9283	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:24:00	\N	0.71	02:00:00	\N	0.77	\N	\N	Sunny Isles, Biscayne Creek	FL
62448	Biscayne Creek, ICWW, Florida	NOS	8723089	25.88	-80.1633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:39:00	\N	1	00:47:00	\N	0.93	\N	\N	Biscayne Creek, ICWW	FL
62449	Indian Creek Golf Club, ICWW, Florida	NOS	8723094	25.875	-80.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:46:00	\N	0.92	01:13:00	\N	0.92	\N	\N	Indian Creek Golf Club, ICWW	FL
62450	Dodge Island, Fishermans Channel, Biscayne Bay, Florida	NOS	8723155	25.77	-80.1683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:10:00	\N	1	00:34:00	\N	0.91	\N	\N	Dodge Island, Fishermans Channel	FL
62451	San Marino Island, Biscayne Bay, Florida	NOS	8723156	25.7933	-80.1633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:58:00	\N	1	00:37:00	\N	0.92	\N	\N	San Marino Island	FL
62452	Miami, Miamarina, Biscayne Bay, Florida (sub)	NOS	8723165	25.7783	-80.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:49:00	\N	0.92	00:20:00	\N	0.94	\N	\N	Miami Miamarina, Biscayne Bay	FL
62453	Miami Beach (city pier), Florida (sub)	NOS	8723170	25.7683	-80.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:02:00	\N	1.14	-00:22:00	\N	1.07	\N	\N	Miami Harbor Entrance	FL
62454	Dinner Key Marina, Biscayne Bay, Florida	NOS	8723205	25.7267	-80.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:48:00	\N	0.92	00:54:00	\N	0.84	\N	\N	Dinner Key Marina	FL
62455	Virginia Key, Bear Cut, Biscayne Bay, Florida (sub)	NOS	8723214	25.7314	-80.1618	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:51:00	\N	0.86	00:28:00	\N	0.88	\N	\N	Bear Cut, Virginia Key	FL
62456	Key Biscayne Yacht Club, Biscayne Bay, Florida	NOS	8723232	25.6983	-80.17	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:31:00	\N	0.92	00:44:00	\N	0.86	\N	\N	Key Biscayne Yacht Club, Biscayne Bay	FL
62457	Coral Shoal, Biscayne Channel, Florida	NOS	8723251	25.6517	-80.16	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:37:00	\N	0.92	00:11:00	\N	0.88	\N	\N	Coral Shoal, Biscayne Channel	FL
62458	Soldier Key, Florida	NOS	8723303	25.59	-80.1617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:16:00	\N	0.71	00:30:00	\N	0.81	\N	\N	Soldier Key	FL
62459	Ragged Keys, Biscayne Bay, Florida	NOS	8723350	25.5333	-80.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:18:00	\N	1	00:43:00	\N	0.73	\N	\N	Ragged Keys, Biscayne Bay	FL
62460	Sands Key, northwest point, Biscayne Bay, Florida	NOS	8723372	25.5067	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:26:00	\N	0.64	01:25:00	\N	0.63	\N	\N	Sands Key, northwest point, Biscayne Bay	FL
62461	Coon Point, Elliott Key, Biscayne Bay, Florida	NOS	8723391	25.48	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:56:00	\N	0.71	01:55:00	\N	0.63	\N	\N	Coon Point, Elliott Key, Biscayne Bay	FL
62462	Sea Grape Point, Elliott Key, Florida	NOS	8723393	25.4767	-80.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:05:00	\N	1.03	-00:25:00	\N	1.03	\N	\N	Sea Grape Point, Elliott Key	FL
62463	Billys Point, south of, Elliott Key, Biscayne Bay, Florida	NOS	8723439	25.415	-80.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:20:00	\N	0.64	02:08:00	\N	0.63	\N	\N	Billys Point, south of, Elliott Key, Biscayne Bay	FL
62464	Adams Key, south end, Biscayne Bay, Florida	NOS	8723453	25.3967	-80.2333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:08:00	\N	1	01:01:00	\N	0.67	\N	\N	Adams Key, south end, Biscayne Bay	FL
62465	Christmas Point, Elliott Key, Florida	NOS	8723457	25.3917	-80.23	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:37:00	\N	1.07	00:13:00	\N	0.8	\N	\N	Christmas Point, Elliott Key	FL
62466	Totten Key, west side, Biscayne Bay, Florida	NOS	8723467	25.3783	-80.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:21:00	\N	0.57	02:19:00	\N	0.54	\N	\N	Totten Key, west side, Biscayne Bay	FL
62467	Card Sound, western side, Florida	NOS	8723491	25.345	-80.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:40:00	\N	0.43	02:51:00	\N	0.3	\N	\N	Card Sound, western side	FL
62468	Wednesday Point, Key Largo, Card Sound, Florida	NOS	8723518	25.31	-80.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:30:00	\N	0.57	02:38:00	\N	0.34	\N	\N	Wednesday Point, Key Largo, Card Sound	FL
62469	Ocean Reef Harbor, Key Largo, Florida	NOS	8723519	25.3083	-80.2767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:17:00	\N	1.5	-00:08:00	\N	1.02	\N	\N	Ocean Reef Harbor, Key Largo	FL
62470	Cormorant Point, Key Largo, Card Sound, Florida	NOS	8723532	25.29	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:01:00	\N	0.5	02:45:00	\N	0.32	\N	\N	Cormorant Point, Key Largo, Card Sound	FL
62471	Main Key, Barnes Sound, Florida	NOS	8723571	25.24	-80.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	06:16:00	\N	0.36	05:04:00	\N	0.19	\N	\N	Main Key, Barnes Sound	FL
62472	Manatee Creek, Manatee Bay, Barnes Sound, Florida	NOS	8723575	25.235	-80.43	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	06:20:00	\N	0.36	05:14:00	\N	0.18	\N	\N	Manatee Creek, Manatee Bay, Barnes Sound	FL
62473	Carysfort Reef, Florida	NOS	8723583	25.2217	-80.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:39:00	\N	1.36	00:19:00	\N	1.03	\N	\N	Carysfort Reef	FL
62474	Garden Cove, Key Largo, Florida	NOS	8723622	25.1717	-80.3667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:25:00	\N	1.14	-00:01:00	\N	0.94	\N	\N	Garden Cove, Key Largo	FL
62475	Flamingo, Florida Bay, Florida	NOS	8723644	25.1417	-80.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	07:20:00	\N	1.08	05:28:00	\N	1.47	\N	\N	Flamingo, Florida Bay	FL
62476	Largo Sound, Key Largo, Florida	NOS	8723651	25.14	-80.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:03:00	\N	0.5	02:13:00	\N	0.35	\N	\N	Largo Sound, Key Largo	FL
62477	Key Largo, South Sound, Key Largo, Florida	NOS	8723667	25.113333333332992	-80.41666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:49:00	\N	0.64	00:23:00	\N	0.66	\N	\N	Key Largo, South Sound, Key Largo	FL
62478	Rock Harbor, Key Largo, Florida	NOS	8723689	25.0817	-80.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:36:00	\N	1.21	00:22:00	\N	0.94	\N	\N	Rock Harbor, Key Largo	FL
62479	Point Charles, Key Largo, Florida	NOS	8723691	25.0817	-80.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:53:00	\N	0.64	00:25:00	\N	0.77	\N	\N	Point Charles, Key Largo	FL
62480	Crane Keys, north side, Florida Bay, Florida	NOS	8723746	25.005	-80.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	04:35:00	\N	0.21	02:52:00	\N	0.17	\N	\N	Crane Keys, north side, Florida Bay	FL
62481	Tavernier Harbor, Hawk Channel, Florida	NOS	8723747	25.005	-80.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:26:00	\N	1.36	00:07:00	\N	0.9	\N	\N	Tavernier Harbor, Hawk Channel	FL
62482	Tavernier Creek, Hwy. 1 bridge, Hawk Channel, Florida	NOS	8723748	25.0033	-80.53	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:52:00	\N	1.07	00:25:00	\N	0.6	\N	\N	Tavernier Creek, Hwy. 1 bridge, Hawk Channel	FL
62483	East Key, southern end, Florida Bay, Florida	NOS	8723752	24.9967	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	04:06:00	\N	0.14	02:43:00	\N	0.22	\N	\N	East Key, southern end, Florida Bay	FL
62484	Plantation Key, Hawk Channel, Florida	NOS	8723769	24.9733	-80.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:12:00	\N	1.21	00:05:00	\N	0.96	\N	\N	Plantation Key, Hawk Channel	FL
62485	Yacht Harbor, Cowpens Anchorage, Plantation Key, Florida	NOS	8723776	24.965	-80.5683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	04:00:00	\N	0.29	02:45:00	\N	0.23	\N	\N	Yacht Harbor, Cowpens Anchorage, Plantation Key	FL
62486	Snake Creek, USCG Station, Plantation Key, Florida	NOS	8723786	24.9533	-80.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:56:00	\N	0.5	01:08:00	\N	0.36	\N	\N	Snake Creek, USCG Station, Plantation Key	FL
62487	Snake Creek, Hwy. 1 bridge, Windley Key, Florida	NOS	8723787	24.9517	-80.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:56:00	\N	0.5	00:49:00	\N	0.46	\N	\N	Snake Creek, Hwy. 1 bridge, Windley Key	FL
62488	Whale Harbor, Windley Key, Hawk Channel, Florida	NOS	8723795	24.94	-80.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:51:00	\N	0.36	00:07:00	\N	0.65	\N	\N	Whale Harbor, Windley Key, Hawk Channel	FL
62489	Whale Harbor Channel, Hwy. 1 bridge, Windley Key, Florida	NOS	8723797	24.9383	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:00:00	\N	0.71	00:16:00	\N	0.59	\N	\N	Whale Harbor Channel, Hwy. 1 bridge, Windley Key	FL
62490	Shell Key, northwest side, Lignumvitae Basin, Florida	NOS	8723807	24.9233	-80.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:57:00	\N	0.46	00:31:00	\N	0.46	\N	\N	Shell Key, northwest side, Lignumvitae Basin	FL
62491	Islamorada, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723808	24.925	-80.6317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:07:00	\N	0.37	00:39:00	\N	0.37	\N	\N	Islamorada, Upper Matecumbe Key, Florida Bay	FL
62492	Shell Key Channel, Florida Bay, Florida	NOS	8723812	24.9133	-80.66	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:45:00	\N	0.78	-00:20:00	\N	0.78	\N	\N	Shell Key Channel, Florida Bay	FL
62493	Little Basin, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723813	24.915	-80.64	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:15:00	\N	0.61	00:08:00	\N	0.61	\N	\N	Little Basin, Upper Matecumbe Key, Florida Bay	FL
62494	Upper Matecumbe Key, Hawk Channel, Florida	NOS	8723814	24.915	-80.6317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:49:00	\N	1.21	00:34:00	\N	0.87	\N	\N	Upper Matecumbe Key, Hawk Channel	FL
62495	Lignumvitae Key, NE side, Florida Bay, Florida	NOS	8723824	24.9033	-80.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:31:00	\N	0.52	00:09:00	\N	0.52	\N	\N	Lignumvitae Key, NE side, Florida Bay	FL
62496	Lignumvitae Key, west side, Florida Bay, Florida	NOS	8723825	24.9	-80.705	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:54:00	\N	0.47	00:32:00	\N	0.47	\N	\N	Lignumvitae Key, west side, Florida Bay	FL
62497	Upper Matecumbe Key, west end, Hawk Channel, Florida	NOS	8723828	24.8967	-80.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:14:00	\N	0.33	-01:00:00	\N	0.98	\N	\N	Upper Matecumbe Key, west end, Hawk Channel	FL
62498	Indian Key, Hawk Channel, Florida	NOS	8723843	24.8767	-80.6767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:35:00	\N	0.71	-00:58:00	\N	1.3	\N	\N	Indian Key, Hawk Channel	FL
62499	Indian Key Anchorage, Lower Matecumbe Key, Florida	NOS	8723851	24.8683	-80.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:54:00	\N	0.88	-01:25:00	\N	1.38	\N	\N	Indian Key Anchorage, Lower Matecumbe Key	FL
62500	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723852	24.865	-80.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:33:00	\N	0.38	-00:18:00	\N	0.55	\N	\N	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay	FL
62501	Alligator Reef, Hawk Channel, Florida	NOS	8723861	24.85	-80.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:24:00	\N	1.36	00:08:00	\N	0.86	\N	\N	Alligator Reef, Hawk Channel	FL
62502	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723862	24.8517	-80.74	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:23:00	\N	0.33	-00:25:00	\N	0.59	\N	\N	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay	FL
62503	Channel Two, east, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723868	24.845	-80.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:42:00	\N	0.54	-00:49:00	\N	0.85	\N	\N	Channel Two, east, Lower Matecumbe Key, Fla. Bay	FL
62504	Channel Two, west side, Hawk Channel, Florida	NOS	8723869	24.8417	-80.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:54:00	\N	0.75	-01:06:00	\N	1.12	\N	\N	Channel Two, west side, Hawk Channel	FL
62505	Channel Five, west side, Hawk Channel, Florida	NOS	8723872	24.84	-80.78	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:41:00	\N	0.67	-00:58:00	\N	1	\N	\N	Channel Five, west side, Hawk Channel	FL
62506	Jewfish Hole, Long Key, Florida Bay, Florida	NOS	8723873	24.8383	-80.7983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:32:00	\N	0.38	-00:11:00	\N	0.42	\N	\N	Jewfish Hole, Long Key, Florida Bay	FL
62507	Channel Five, east side, Hawk Channel, Florida	NOS	8723874	24.8367	-80.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:42:00	\N	0.58	-00:54:00	\N	0.9	\N	\N	Channel Five, east side, Hawk Channel	FL
62508	Long Key Bight, Long Key, Florida	NOS	8723879	24.8283	-80.8083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:43:00	\N	0.62	-00:59:00	\N	1.03	\N	\N	Long Key Bight, Long Key	FL
62509	Long Key Lake, Long Key, Florida	NOS	8723887	24.82	-80.8167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:57:00	\N	0.46	00:33:00	\N	0.62	\N	\N	Long Key Lake, Long Key	FL
62510	Long Key, western end, Florida	NOS	8723899	24.8033	-80.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:54:00	\N	0.33	-01:01:00	\N	0.82	\N	\N	Long Key, western end	FL
62511	Conch Key, eastern end, Florida	NOS	8723906	24.7917	-80.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:45:00	\N	0.54	-01:09:00	\N	0.85	\N	\N	Conch Key, eastern end	FL
62512	Toms Harbor Cut, Florida	NOS	8723912	24.7833	-80.9067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:30:00	\N	0.38	-01:19:00	\N	0.37	\N	\N	Toms Harbor Cut	FL
62513	Toms Harbor Channel, Hwy. 1 bridge, Florida	NOS	8723918	24.7767	-80.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:49:00	\N	0.38	05:07:00	\N	0.38	\N	\N	Toms Harbor Channel, Hwy. 1 bridge	FL
62514	Grassy Key, north side, Florida Bay, Florida	NOS	8723921	24.7717	-80.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	06:48:00	\N	1.04	05:40:00	\N	0.73	\N	\N	Grassy Key, north side, Florida Bay	FL
62515	Duck Key, Hawk Channel, Florida	NOS	8723927	24.765	-80.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:40:00	\N	0.55	-01:11:00	\N	0.97	\N	\N	Duck Key, Hawk Channel	FL
62516	Grassy Key, south side, Hawk Channel, Florida	NOS	8723933	24.755	-80.9583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:26:00	\N	0.71	-00:52:00	\N	1.22	\N	\N	Grassy Key, south side, Hawk Channel	FL
62517	Fat Deer Key, Florida Bay, Florida	NOS	8723949	24.7333	-81.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	06:26:00	\N	0.87	05:09:00	\N	0.87	\N	\N	Fat Deer Key, Florida Bay	FL
62518	Vaca Key-Fat Deer Key bridge, Florida	NOS	8723950	24.73	-81.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:36:00	\N	0.71	-01:11:00	\N	0.95	\N	\N	Vaca Key-Fat Deer Key bridge	FL
62519	Key Colony Beach, Florida (sub)	NOS	8723962	24.7183	-81.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:53:00	\N	0.83	-01:17:00	\N	1.22	\N	\N	Key Colony Beach	FL
62520	Boot Key Harbor bridge, Boot Key, Florida	NOS	8723971	24.7033	-81.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:37:00	\N	0.75	-01:03:00	\N	1.13	\N	\N	Boot Key Harbor bridge, Boot Key	FL
62521	Sombrero Key, Hawk Channel, Florida	NOS	8723999	24.6267	-81.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:39:00	\N	0.79	-01:03:00	\N	1.18	\N	\N	Sombrero Key, Hawk Channel	FL
62522	Knight Key Channel, Knight Key, Florida Bay, Florida	NOS	8724008	24.7067	-81.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:18:00	\N	0.5	-00:02:00	\N	0.54	\N	\N	Knight Key Channel, Knight Key, Florida Bay	FL
62523	Pigeon Key, south side, Hawk Channel, Florida	NOS	8724032	24.7033	-81.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:26:00	\N	0.5	-00:55:00	\N	0.81	\N	\N	Pigeon Key, south side, Hawk Channel	FL
62524	Pigeon Key, north side, Florida Bay, Florida	NOS	8724033	24.705	-81.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:45:00	\N	0.46	-00:10:00	\N	0.46	\N	\N	Pigeon Key, north side, Florida Bay	FL
62525	Molasses Key Channel, Molasses Keys, Florida	NOS	8724062	24.6833	-81.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:16:00	\N	0.5	-00:56:00	\N	0.79	\N	\N	Molasses Key Channel, Molasses Keys	FL
62526	Money Key, Florida	NOS	8724082	24.6833	-81.2167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:17:00	\N	0.58	00:03:00	\N	0.58	\N	\N	Money Key	FL
62527	Little Duck Key, east end, Hawk Channel, Florida	NOS	8724093	24.6817	-81.2283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:05:00	\N	0.67	-00:49:00	\N	0.67	\N	\N	Little Duck Key, east end, Hawk Channel	FL
62528	East Bahia Honda Key, south end, Florida Bay, Florida	NOS	8724094	24.775	-81.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:49:00	\N	0.69	04:04:00	\N	0.69	\N	\N	East Bahia Honda Key, south end, Florida Bay	FL
62529	Cocoanut Key, Florida Bay, Florida	NOS	8724098	24.745	-81.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:50:00	\N	0.55	03:52:00	\N	0.55	\N	\N	Cocoanut Key, Florida Bay	FL
62530	Missouri Key-Little Duck Key Channel, Florida	NOS	8724099	24.68	-81.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:36:00	\N	0.46	-00:52:00	\N	0.7	\N	\N	Missouri Key-Little Duck Key Channel	FL
62531	Missouri Key-Ohio Key Channel, west side, Florida	NOS	8724107	24.6733	-81.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:22:00	\N	0.5	-00:47:00	\N	0.77	\N	\N	Missouri Key-Ohio Key Channel, west side	FL
62532	Ohio Key-Bahia Honda Key Channel, west side, Florida	NOS	8724112	24.67	-81.2517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:14:00	\N	0.62	-00:57:00	\N	0.81	\N	\N	Ohio Key-Bahia Honda Key Channel, west side	FL
62533	West Bahia Honda Key, Florida	NOS	8724129	24.78	-81.2717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:01:00	\N	1	03:59:00	\N	0.97	\N	\N	West Bahia Honda Key	FL
62534	Bahia Honda Key, Bahia Honda Channel, Florida	NOS	8724138	24.655	-81.2817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:28:00	\N	0.63	-00:46:00	\N	0.86	\N	\N	Bahia Honda Key, Bahia Honda Channel	FL
62535	Horseshoe Keys, south end, Florida	NOS	8724139	24.7667	-81.2833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:09:00	\N	1	03:54:00	\N	0.86	\N	\N	Horseshoe Keys, south end	FL
62536	Johnson Keys, south end, Florida	NOS	8724153	24.7433	-81.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:33:00	\N	0.96	03:36:00	\N	0.72	\N	\N	Johnson Keys, south end	FL
62537	Little Pine Key, south end, Florida	NOS	8724154	24.7133	-81.3033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:07:00	\N	0.79	01:07:00	\N	0.56	\N	\N	Little Pine Key, south end	FL
62538	No Name Key, east side, Bahia Honda Channel, Florida	NOS	8724168	24.6983	-81.3183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:33:00	\N	0.83	01:35:00	\N	0.58	\N	\N	No Name Key, east side, Bahia Honda Channel	FL
62539	Johnson Keys, north end, Florida	NOS	8724172	24.7667	-81.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:22:00	\N	1.38	03:35:00	\N	1.31	\N	\N	Johnson Keys, north end	FL
62540	Little Pine Key, north end, Florida	NOS	8724177	24.75	-81.3283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:28:00	\N	1.21	03:38:00	\N	1.05	\N	\N	Little Pine Key, north end	FL
62541	Big Pine Key, Spanish Harbor, Florida	NOS	8724178	24.6483	-81.33	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:03:00	\N	0.42	-00:44:00	\N	0.75	\N	\N	Big Pine Key, Spanish Harbor	FL
62542	Water Key, west end, Big Spanish Channel, Florida	NOS	8724189	24.74	-81.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:37:00	\N	1.04	03:23:00	\N	0.81	\N	\N	Water Key, west end, Big Spanish Channel	FL
62543	Big Pine Key, Coupon Bight, Florida	NOS	8724192	24.6517	-81.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:49:00	\N	0.5	-00:20:00	\N	0.87	\N	\N	Big Pine Key, Coupon Bight	FL
62544	Big Pine Key, Bogie Channel Bridge, Florida	NOS	8724193	24.6967	-81.3483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:11:00	\N	0.83	02:10:00	\N	0.65	\N	\N	Big Pine Key, Bogie Channel Bridge	FL
62545	Porpoise Key, Big Spanish Channel, Florida	NOS	8724196	24.7183	-81.3517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:29:00	\N	1	03:23:00	\N	0.72	\N	\N	Porpoise Key, Big Spanish Channel	FL
62546	Crawl Key, Big Spanish Channel, Florida	NOS	8724199	24.7567	-81.3583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:13:00	\N	1.33	03:34:00	\N	1.33	\N	\N	Crawl Key, Big Spanish Channel	FL
62547	Big Pine Key, Doctors Arm, Bogie Channel, Florida	NOS	8724201	24.69	-81.3567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:47:00	\N	0.71	00:41:00	\N	0.63	\N	\N	Big Pine Key, Doctors Arm, Bogie Channel	FL
62548	Mayo Key, Big Spanish Channel, Florida	NOS	8724205	24.7333	-81.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:01:00	\N	1.08	03:35:00	\N	0.92	\N	\N	Mayo Key, Big Spanish Channel	FL
62549	Little Spanish Key, Spanish Banks, Florida	NOS	8724209	24.7733	-81.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:30:00	\N	1.62	03:25:00	\N	1.74	\N	\N	Little Spanish Key, Spanish Banks	FL
62550	Big Pine Key, Pine Channel Bridge, north side, Florida	NOS	8724211	24.67	-81.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:43:00	\N	0.33	00:03:00	\N	0.57	\N	\N	Big Pine Key, Pine Channel Bridge, north side	FL
62551	Big Pine Key, Pine Channel Bridge, south side, Florida	NOS	8724213	24.6683	-81.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:03:00	\N	0.33	-00:13:00	\N	0.67	\N	\N	Big Pine Key, Pine Channel Bridge, south side	FL
62552	Big Pine Key, Newfound Harbor Channel, Florida	NOS	8724215	24.6517	-81.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:44:00	\N	0.46	-00:09:00	\N	0.82	\N	\N	Big Pine Key, Newfound Harbor Channel	FL
62553	Little Torch Key, Pine Channel Bridge, south side, Florida	NOS	8724223	24.665	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:57:00	\N	0.33	-00:15:00	\N	0.68	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
62554	Little Torch Key, Pine Channel Bridge, south side, Florida (2)	NOS	8724224	24.665	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:54:00	\N	0.38	-00:13:00	\N	0.69	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
62555	Big Pine Key, northeast shore, Florida	NOS	8724226	24.7283	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:30:00	\N	1.08	03:19:00	\N	0.86	\N	\N	Big Pine Key, northeast shore	FL
62556	Big Pine Key, west side, Pine Channel, Florida	NOS	8724227	24.69	-81.3833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:52:00	\N	0.42	00:21:00	\N	0.52	\N	\N	Big Pine Key, west side, Pine Channel	FL
62557	Annette Key, north end, Big Spanish Channel, Florida	NOS	8724229	24.7583	-81.39	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:33:00	\N	1.29	03:30:00	\N	1.44	\N	\N	Annette Key, north end, Big Spanish Channel	FL
62558	Big Pine Key, north end, Florida	NOS	8724231	24.745	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:56:00	\N	0.83	04:24:00	\N	0.96	\N	\N	Big Pine Key, north end	FL
62559	Little Torch Key, Torch Channel, Florida	NOS	8724232	24.665	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:45:00	\N	0.33	00:11:00	\N	0.57	\N	\N	Little Torch Key, Torch Channel	FL
62560	Middle Torch Key, Torch Ramrod Channel, Florida	NOS	8724237	24.6617	-81.4017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:29:00	\N	0.38	-00:16:00	\N	0.69	\N	\N	Middle Torch Key, Torch Ramrod Channel	FL
62561	Munson Island, Newfound Harbor Channel, Florida	NOS	8724238	24.6233	-81.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:12:00	\N	0.67	-00:40:00	\N	0.98	\N	\N	Munson Island, Newfound Harbor Channel	FL
62562	Ramrod Key, Newfound Harbor, Florida	NOS	8724239	24.65	-81.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:05:00	\N	0.5	-00:41:00	\N	0.9	\N	\N	Ramrod Key, Newfound Harbor	FL
62563	Howe Key, south end, Harbor Channel, Florida	NOS	8724243	24.725	-81.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:49:00	\N	0.62	04:43:00	\N	0.72	\N	\N	Howe Key, south end, Harbor Channel	FL
62564	Big Spanish Key, Florida	NOS	8724246	24.7883	-81.4117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:29:00	\N	1.5	03:19:00	\N	1.97	\N	\N	Big Spanish Key	FL
62565	Ramrod Key, Niles Channel Bridge, Florida	NOS	8724255	24.66	-81.4233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:12:00	\N	0.46	-00:13:00	\N	0.67	\N	\N	Ramrod Key, Niles Channel Bridge	FL
62566	Howe Key, northwest end, Florida	NOS	8724257	24.7583	-81.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:22:00	\N	1.33	03:29:00	\N	1.68	\N	\N	Howe Key, northwest end	FL
62567	Big Torch Key, Niles Channel, Florida	NOS	8724264	24.705	-81.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:05:00	\N	0.71	03:15:00	\N	0.61	\N	\N	Big Torch Key, Niles Channel	FL
62568	Summerland Key, Niles Channel South, Florida	NOS	8724266	24.6517	-81.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:11:00	\N	0.71	-00:36:00	\N	0.85	\N	\N	Summerland Key, Niles Channel South	FL
62569	Summerland Key, Niles Channel Bridge, Florida	NOS	8724267	24.66	-81.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:56:00	\N	0.58	-00:10:00	\N	0.67	\N	\N	Summerland Key, Niles Channel Bridge	FL
62570	Water Keys, south end, Harbor Channel, Florida	NOS	8724273	24.7467	-81.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:41:00	\N	1	03:42:00	\N	1.52	\N	\N	Water Keys, south end, Harbor Channel	FL
62571	Big Torch Key, Harbor Channel, Florida	NOS	8724274	24.7367	-81.4433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:51:00	\N	1.29	03:47:00	\N	1.58	\N	\N	Big Torch Key, Harbor Channel	FL
62572	Summerland Key, southwest side, Kemp Channel, Florida	NOS	8724276	24.65	-81.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:50:00	\N	0.54	-00:26:00	\N	0.81	\N	\N	Summerland Key, southwest side, Kemp Channel	FL
62573	Kemp Channel Viaduct, Florida Keys, Florida	NOS	8724292	24.6617	-81.4683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:04:00	\N	0.46	00:47:00	\N	0.58	\N	\N	Kemp Channel Viaduct	FL
62574	Key Lois, southeast end, Florida	NOS	8724293	24.6067	-81.47	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:45:00	\N	0.75	-01:15:00	\N	1.06	\N	\N	Key Lois, southeast end	FL
62575	Knockemdown Key, north end, Florida	NOS	8724302	24.715	-81.4783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:54:00	\N	1.21	03:30:00	\N	1.35	\N	\N	Knockemdown Key, north end	FL
62576	Gopher Key, Cudjoe Bay, Florida	NOS	8724306	24.6417	-81.485	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:17:00	\N	0.71	-00:46:00	\N	0.9	\N	\N	Gopher Key, Cudjoe Bay	FL
62577	Content Keys, Content Passage, Florida	NOS	8724307	24.79	-81.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:49:00	\N	1.83	02:46:00	\N	2.13	\N	\N	Content Keys, Content Passage	FL
62578	Raccoon Key, east side, Florida	NOS	8724311	24.7417	-81.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:09:00	\N	1.21	03:20:00	\N	1.5	\N	\N	Raccoon Key, east side	FL
62579	Cudjoe Key, Cudjoe Bay, Florida	NOS	8724313	24.66	-81.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:41:00	\N	0.71	-00:38:00	\N	0.87	\N	\N	Cudjoe Key, Cudjoe Bay	FL
62580	Sugarloaf Key, Pirates Cove, Florida	NOS	8724326	24.6533	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:41:00	\N	0.75	-00:48:00	\N	0.59	\N	\N	Sugarloaf Key, Pirates Cove	FL
62581	Sugarloaf Key, east side, Tarpon Creek, Florida	NOS	8724327	24.6283	-81.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:15:00	\N	0.58	-00:41:00	\N	0.89	\N	\N	Sugarloaf Key, east side, Tarpon Creek	FL
63040	Ayock Point, Washington	NOS	9445388	47.5083	-123.052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:05:00	\N	1.07	-00:03:00	\N	0.99	\N	\N	Ayock Point	WA
62582	Cudjoe Key, north end, Kemp Channel, Florida	NOS	8724328	24.7	-81.505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:40:00	\N	1.46	03:33:00	\N	1.61	\N	\N	Cudjoe Key, north end, Kemp Channel	FL
62583	Cudjoe Key, Pirates Cove, Florida	NOS	8724332	24.6617	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:54:00	\N	0.79	03:50:00	\N	0.77	\N	\N	Cudjoe Key, Pirates Cove	FL
62584	Tarpon Creek, Upper Sugarloaf Sound, Florida	NOS	8724334	24.63	-81.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:17:00	\N	0.38	-00:29:00	\N	0.35	\N	\N	Tarpon Creek	FL
62585	Sugarloaf Key, northeast side, Bow Channel, Florida	NOS	8724347	24.6717	-81.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:24:00	\N	0.71	03:47:00	\N	1.01	\N	\N	Sugarloaf Key, northeast side, Bow Channel	FL
62586	Park Channel Bridge, Upper Sugarloaf Sound, Florida	NOS	8724353	24.655	-81.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	08:33:00	\N	0.29	05:47:00	\N	0.26	\N	\N	Park Channel Bridge	FL
62587	North Harris Channel, Upper Sugarloaf Sound, Florida	NOS	8724367	24.6533	-81.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	08:04:00	\N	0.25	05:32:00	\N	0.25	\N	\N	North Harris Channel	FL
62588	Sugarloaf Key, north end, Bow Channel, Florida	NOS	8724368	24.6933	-81.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:20:00	\N	0.75	03:37:00	\N	1.29	\N	\N	Sugarloaf Key, north end, Bow Channel	FL
62589	Sawyer Key, inside, Cudjoe Channel, Florida	NOS	8724369	24.7583	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:19:00	\N	0.5	02:37:00	\N	1.43	\N	\N	Sawyer Key, inside, Cudjoe Channel	FL
62590	Sawyer Key, outside, Cudjoe Channel, Florida	NOS	8724370	24.7583	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:24:00	\N	0.5	02:45:00	\N	1.57	\N	\N	Sawyer Key, outside, Cudjoe Channel	FL
62591	Pumpkin Key, Bow Channel, Florida	NOS	8724373	24.7167	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:39:00	\N	1.17	03:17:00	\N	1.56	\N	\N	Pumpkin Key, Bow Channel	FL
62592	Perky, Upper Sugarloaf Sound, Florida	NOS	8724378	24.6483	-81.57	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	08:25:00	\N	0.08	05:37:00	\N	0.28	\N	\N	Perky	FL
62593	Johnston Key, southwest end, Turkey Basin, Florida	NOS	8724397	24.71	-81.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:38:00	\N	0.5	03:26:00	\N	1.1	\N	\N	Johnston Key, southwest end, Turkey Basin	FL
62594	Saddlebunch Keys, Channel No. 3, Florida	NOS	8724405	24.6233	-81.6033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:10:00	\N	0.21	01:44:00	\N	0.43	\N	\N	Saddlebunch Keys, Channel No. 3	FL
62595	Snipe Keys, southeast end, Inner Narrows, Florida	NOS	8724409	24.6583	-81.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:39:00	\N	0.83	03:25:00	\N	1.28	\N	\N	Snipe Keys, southeast end, Inner Narrows	FL
62596	Saddlebunch Keys, Channel No. 4, Florida	NOS	8724417	24.615	-81.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:36:00	\N	0.29	04:35:00	\N	0.54	\N	\N	Saddlebunch Keys, Channel No. 4	FL
62597	Saddlebunch Keys, Similar Sound, Florida	NOS	8724422	24.6	-81.6217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:41:00	\N	0.21	00:39:00	\N	0.37	\N	\N	Saddlebunch Keys, Similar Sound	FL
62598	Saddlebunch Keys, Channel No. 5, Florida	NOS	8724423	24.6117	-81.6233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	06:58:00	\N	1.12	04:32:00	\N	0.66	\N	\N	Saddlebunch Keys, Channel No. 5	FL
62599	Snipe Keys, Middle Narrows, Florida	NOS	8724427	24.6667	-81.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:54:00	\N	0.67	03:44:00	\N	1.02	\N	\N	Snipe Keys, Middle Narrows	FL
62600	Bird Key, Similar Sound, Florida	NOS	8724436	24.5883	-81.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:03:00	\N	0.42	-00:21:00	\N	0.59	\N	\N	Bird Key, Similar Sound	FL
62601	Shark Key, southeast end, Similar Sound, Florida	NOS	8724438	24.6033	-81.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:51:00	\N	0.46	00:18:00	\N	0.52	\N	\N	Shark Key, southeast end, Similar Sound	FL
62602	O'Hara Key, north end, Waltz Key Basin, Florida	NOS	8724441	24.6167	-81.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:39:00	\N	0.83	03:53:00	\N	1.03	\N	\N	O'Hara Key, north end, Waltz Key Basin	FL
62603	Waltz Key, Waltz Key Basin, Florida	NOS	8724448	24.6467	-81.6533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:33:00	\N	0.96	03:53:00	\N	1.03	\N	\N	Waltz Key, Waltz Key Basin	FL
62604	Rockland Key, Rockland Channel Bridge, Florida	NOS	8724459	24.5917	-81.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	06:06:00	\N	0.88	05:02:00	\N	0.76	\N	\N	Rockland Key, Rockland Channel Bridge	FL
62605	Snipe Keys, Snipe Point, Florida	NOS	8724463	24.6917	-81.6733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:33:00	\N	1.29	02:15:00	\N	1.69	\N	\N	Snipe Keys, Snipe Point	FL
62606	Duck Key Point, Duck Key, Waltz Key Basin, Florida	NOS	8724474	24.6233	-81.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:57:00	\N	0.96	03:27:00	\N	1.19	\N	\N	Duck Key Point, Duck Key, Waltz Key Basin	FL
62607	Boca Chica Key, Long Point, Florida	NOS	8724485	24.6033	-81.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:22:00	\N	0.71	03:54:00	\N	0.94	\N	\N	Boca Chica Key, Long Point	FL
62608	Big Coppitt Key, northeast side, Waltz Key Basin, Florida	NOS	8724489	24.6017	-81.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	06:54:00	\N	0.33	04:21:00	\N	0.84	\N	\N	Big Coppitt Key, northeast side, Waltz Key Basin	FL
62609	Boca Chica Key, Southwest end, Florida	NOS	8724499	24.5633	-81.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:16:00	\N	0.63	-00:14:00	\N	0.66	\N	\N	Boca Chica Key, Southwest end	FL
62610	Boca Chica Channel Bridge, Florida	NOS	8724503	24.5767	-81.7217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:29:00	\N	0.67	01:23:00	\N	0.57	\N	\N	Boca Chica Channel Bridge	FL
62611	Channel Key, west side, Florida	NOS	8724507	24.6033	-81.725	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:07:00	\N	0.71	03:09:00	\N	0.7	\N	\N	Channel Key, west side	FL
62612	Key Haven - Stock Island Channel, Florida	NOS	8724517	24.58	-81.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:57:00	\N	0.79	02:25:00	\N	0.73	\N	\N	Key Haven - Stock Island Channel	FL
62613	Cow Key Channel, Florida	NOS	8724527	24.57	-81.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:05:00	\N	0.71	01:55:00	\N	0.65	\N	\N	Cow Key Channel	FL
62614	Riviera Canal, Key West, Florida	NOS	8724529	24.565	-81.7517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:00:00	\N	0.63	-00:12:00	\N	0.65	\N	\N	Riveria Canal, Key West	FL
62615	Sigsbee Park, Garrison Bight Channel, Florida	NOS	8724542	24.585	-81.775	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:06:00	\N	0.88	01:59:00	\N	0.81	\N	\N	Sigsbee Park, Garrison Bight Channel	FL
62616	Key West, south side, White Street Pier, Florida	NOS	8724557	24.545	-81.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:31:00	\N	0.92	-00:53:00	\N	1.07	\N	\N	Key West, south side, White Street Pier	FL
62617	Sand Key Lighthouse, Sand Key Channel, Florida (sub)	NOS	8724635	24.4533	-81.8783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:32:00	\N	0.88	-00:43:00	\N	0.95	\N	\N	Sand Key Lighthouse, Sand Key Channel	FL
62618	Garden Key, Dry Tortugas, Florida	NOS	8724697	24.6267	-82.8717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:33:00	\N	1.33	00:29:00	\N	0.94	\N	\N	Garden Key, Dry Tortugas	FL
62619	Shark River entrance, Florida	NOS	8724769	25.345	-81.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:45:00	\N	0.98	00:57:00	\N	1.43	\N	\N	Shark River entrance	FL
62620	Lostmans River entrance, Florida	NOS	8724842	25.5533	-81.2133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:59:00	\N	0.98	01:09:00	\N	1.33	\N	\N	Lostmans River entrance	FL
62621	Onion Key, Lostmans River, Florida	NOS	8724863	25.6117	-81.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	04:53:00	\N	0.16	03:09:00	\N	0.26	\N	\N	Onion Key, Lostmans River	FL
62622	Chatham River entrance, Florida	NOS	8724891	25.69	-81.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:53:00	\N	0.66	00:59:00	\N	1.43	\N	\N	Chatham River entrance	FL
62623	Chokoloskee, Florida	NOS	8724919	25.8133	-81.3633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	03:14:00	\N	0.62	02:15:00	\N	1.11	\N	\N	Chokoloskee	FL
62624	Cape Romano, Florida	NOS	8724947	25.8533	-81.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:04:00	\N	0.98	00:43:00	\N	1.19	\N	\N	Cape Romano	FL
62625	Everglades City, Barron River, Florida	NOS	8724948	25.8583	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	03:26:00	\N	0.57	02:25:00	\N	0.99	\N	\N	Everglades City, Barron River	FL
62626	Dismal Key, Pumpkin Bay, Florida (sub)	NOS	8724963	25.895	-81.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	03:07:00	\N	0.49	02:39:00	\N	0.89	\N	\N	Pumpkin Bay	FL
62627	Coon Key Pass, Gullivan Bay, Florida (sub)	NOS	8724964	25.8967	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:31:00	\N	0.98	01:15:00	\N	1.19	\N	\N	Coon Key	FL
62628	Naples, Naples Bay, north end, Florida	NOS	8725114	26.1367	-81.7883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	00:56:00	\N	0.9	00:43:00	\N	0.97	\N	\N	Naples, Naples Bay, north end	FL
62629	Cocohatchee River, U.S. 41 bridge, Florida	NOS	8725228	26.2817	-81.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:28:00	\N	0.65	01:10:00	\N	0.74	\N	\N	Cocohatchee River, U.S. 41 bridge	FL
62630	Wiggins Pass, Cocohatchee River, Florida	NOS	8725235	26.29	-81.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	00:59:00	\N	0.73	00:44:00	\N	0.77	\N	\N	Wiggins Pass, Cocohatchee River	FL
62631	Little Hickory Island, Estero Bay, Florida	NOS	8725283	26.3533	-81.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:05:00	\N	1.09	-00:58:00	\N	1.09	\N	\N	Little Hickory Island	FL
62632	Carlos Point, Estero Bay, Florida	NOS	8725325	26.405	-81.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:28:00	\N	1.17	-01:08:00	\N	1.17	\N	\N	Carlos Point	FL
62633	Estero River, Estero Bay, Florida	NOS	8725346	26.43	-81.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:10:00	\N	1.11	-00:45:00	\N	1.09	\N	\N	Estero River	FL
62634	Matanzas Pass (fixed bridge) Estero Island, Florida	NOS	8725366	26.4567	-81.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:34:00	\N	1.22	-01:10:00	\N	1.22	\N	\N	Matanzas Pass (fixed bridge) Estero Island	FL
62635	Captiva Island (outside), Florida	NOS	8725383	26.4783	-82.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-02:28:00	\N	1.13	-02:20:00	\N	1.13	\N	\N	Captiva Island (outside)	FL
62636	St. James City, Pine Island, Florida	NOS	8725393	26.4917	-82.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:44:00	\N	1.04	-00:30:00	\N	1.04	\N	\N	St. James City, Pine Island	FL
62637	Galt Island, Pine Island Sound, Florida	NOS	8725411	26.5133	-82.1067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:16:00	\N	0.91	-00:25:00	\N	0.91	\N	\N	Galt Island, Pine Island Sound	FL
62638	Captiva Island, Pine Island Sound, Florida	NOS	8725417	26.5217	-82.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:20:00	\N	0.91	-00:46:00	\N	0.91	\N	\N	Captiva Island, Pine Island Sound	FL
62639	Iona Shores, Caloosahatchee River, Florida	NOS	8725418	26.5217	-81.965	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:40:00	\N	0.43	01:08:00	\N	0.43	\N	\N	Iona Shores	FL
62640	Tropical Homesites Landing, Pine Island, Florida	NOS	8725439	26.5483	-82.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:22:00	\N	0.87	-00:08:00	\N	0.87	\N	\N	Tropical Homesites Landing, Pine Island	FL
62641	Redfish Pass, Captiva Island (north end), Florida	NOS	8725441	26.55	-82.1967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:14:00	\N	0.91	-00:55:00	\N	0.91	\N	\N	Redfish Pass, Captiva Island (north end)	FL
62642	Cape Coral Bridge, Caloosahatchee River, Florida	NOS	8725451	26.5633	-81.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	02:02:00	\N	0.43	01:15:00	\N	0.43	\N	\N	Cape Coral Bridge	FL
62643	Matlacha Pass (bascule bridge), Florida	NOS	8725506	26.6317	-82.0683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:28:00	\N	0.83	00:43:00	\N	0.83	\N	\N	Matlacha Pass (bascule bridge)	FL
62644	Fort Myers, Caloosahatchee River, Florida (sub)	NOS	8725520	26.6477	-81.8712	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	02:23:00	\N	0.39	01:56:00	\N	0.56	\N	\N	Fort Myers	FL
62645	Pineland, Pine Island, Florida	NOS	8725528	26.66	-82.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:26:00	\N	0.83	-00:19:00	\N	0.83	\N	\N	Pineland, Pine Island	FL
62646	Placida, Gasparilla Sound, Florida	NOS	8725667	26.8333	-82.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:56:00	\N	0.94	-00:43:00	\N	0.59	\N	\N	Placida, Gasparilla Sound	FL
62647	Punta Gorda, Charlotte Harbor, Florida	NOS	8725744	26.9283	-82.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:27:00	\N	0.83	01:06:00	\N	0.83	\N	\N	Punta Gorda, Charlotte Harbor	FL
62648	Englewood, Lemon Bay, Florida	NOS	8725747	26.9333	-82.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:17:00	\N	0.82	-00:17:00	\N	0.66	\N	\N	Englewood, Lemon Bay	FL
62649	El Jobean, Myakka River, Florida	NOS	8725769	26.9617	-82.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:56:00	\N	0.83	01:38:00	\N	0.83	\N	\N	El Jobean, Myakka River	FL
62650	Venice Inlet (inside), Florida	NOS	8725889	27.1117	-82.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:38:00	\N	0.91	-02:02:00	\N	0.91	\N	\N	Venice Inlet (inside)	FL
62651	Sarasota, Sarasota Bay, Florida	NOS	8726083	27.3317	-82.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:58:00	\N	0.91	-01:38:00	\N	0.91	\N	\N	Sarasota, Sarasota Bay	FL
62652	Cortez, Sarasota Bay, Florida	NOS	8726217	27.4667	-82.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:25:00	\N	0.96	-02:00:00	\N	0.96	\N	\N	Cortez, Sarasota Bay	FL
62653	Anna Maria Key, Bradenton Beach, Florida	NOS	8726243	27.4967	-82.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-03:32:00	\N	1	-02:27:00	\N	0.99	\N	\N	Anna Maria Key, Bradenton Beach	FL
62654	Bradenton, Manatee River, Florida	NOS	8726247	27.5	-82.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:55:00	\N	0.95	-01:24:00	\N	0.97	\N	\N	Bradenton, Manatee River	FL
62655	Redfish Point, Manatee River, Florida	NOS	8726278	27.5267	-82.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:14:00	\N	1	-00:30:00	\N	0.92	\N	\N	Redfish Point, Manatee River	FL
62656	Anna Maria Key, city pier, Florida	NOS	8726282	27.5333	-82.73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-02:19:00	\N	0.99	-02:10:00	\N	0.99	\N	\N	Anna Maria Key, city pier	FL
62657	Egmont Key, Egmont Channel, Tampa Bay, Florida (sub)	NOS	8726347	27.6017	-82.76	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-03:20:00	\N	1	-02:15:00	\N	0.96	\N	\N	Egmont Key, Egmont Channel	FL
62658	Mullet Key Channel (Skyway), Tampa Bay, Florida (sub)	NOS	8726364	27.615	-82.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-02:01:00	\N	0.92	-02:03:00	\N	0.92	\N	\N	Mullet Key Channel (Skyway)	FL
62659	Port Manatee, Tampa Bay, Florida (sub)	NOS	8726384	27.6383333	-82.5625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:48:00	\N	0.95	-01:00:00	\N	0.97	\N	\N	Port Manatee	FL
62660	Point Pinellas, Florida	NOS	8726454	27.7017	-82.64	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:29:00	\N	0.86	-00:22:00	\N	0.86	\N	\N	Point Pinellas	FL
62661	Shell Point, Florida	NOS	8726468	27.7183	-82.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:17:00	\N	0.91	00:08:00	\N	0.91	\N	\N	Shell Point	FL
62662	Gulfport, Boca Ciega Bay, Florida	NOS	8726486	27.7367	-82.7067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:05:00	\N	0.96	-01:32:00	\N	0.96	\N	\N	Gulfport	FL
62663	Long Key, 0.5mi N. of Corey Causeway, Boca Ciega Bay, Florida	NOS	8726494	27.7517	-82.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:44:00	\N	1	-01:18:00	\N	0.92	\N	\N	Long Key, 0.5mi N. of Corey Causeway	FL
62664	Johns Pass, Boca Ciega Bay, Florida	NOS	8726533	27.785	-82.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-02:04:00	\N	1.02	-02:14:00	\N	0.97	\N	\N	Johns Pass	FL
62665	Apollo Beach, Hillsborough Bay, Tampa Bay, Florida	NOS	8726537	27.786699295043945	-82.42669677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:32:00	\N	1.2	00:53:00	\N	1.1	\N	\N	APOLLO BEACH, HILLSBOROUGH BAY	FL
62666	Madeira Beach Causeway, Boca Ciega Bay, Florida	NOS	8726574	27.8083	-82.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:45:00	\N	1.18	-01:32:00	\N	1.08	\N	\N	Madeira Beach Causeway	FL
62667	Port Tampa, Old Tampa Bay, Florida (sub)	NOS	8726607	27.8577778	-82.5527778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:39:00	\N	1.18	00:25:00	\N	1.1	\N	\N	Old Port Tampa	FL
62668	Indian Rocks Beach (inside), Florida	NOS	8726625	27.8767	-82.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-00:53:00	\N	0.63	-00:57:00	\N	0.65	\N	\N	Indian Rocks Beach (inside)	FL
62669	Gandy Bridge, Old Tampa Bay, Florida	NOS	8726641	27.8933	-82.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:57:00	\N	1.24	00:59:00	\N	1.12	\N	\N	Gandy Bridge, Old Tampa Bay	FL
62670	Pendola Point, Hillsborough Bay, Florida	NOS	8726651	27.8983	-82.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:05:00	\N	1.18	00:21:00	\N	1.14	\N	\N	Pendola Point, Hillsborough Bay	FL
62671	Davis Island, Hillsborough Bay, Florida	NOS	8726657	27.9083	-82.4517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:32:00	\N	1.24	00:03:00	\N	1.16	\N	\N	Davis Island, Hillsborough Bay	FL
62672	CSX Rockport, Mckay Bay Entrance, Florida (sub)	NOS	8726667	27.91333333333333	-82.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:28:00	\N	1.26	00:02:00	\N	1.19	\N	\N	McKay Bay entrance	FL
62673	Bay Aristocrat Village, Old Tampa Bay, Florida	NOS	8726689	27.9417	-82.72	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:32:00	\N	1.37	01:01:00	\N	1.24	\N	\N	Bay Aristocrat Village, Old Tampa Bay	FL
62674	Clearwater, Florida	NOS	8726706	27.955	-82.8067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:35:00	\N	0.63	-01:48:00	\N	0.65	\N	\N	Clearwater	FL
62675	Clearwater Beach, Gulf Of Mexico, Florida (sub)	NOS	8726724	27.9783	-82.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-02:19:00	\N	0.84	-02:07:00	\N	0.69	\N	\N	Clearwater Beach	FL
62676	Safety Harbor, Old Tampa Bay, Florida (sub)	NOS	8726738	27.9883	-82.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:34:00	\N	1.39	01:32:00	\N	1.23	\N	\N	Safety Harbor, Old Tampa Bay	FL
62677	Dunedin, St. Joseph Sound, Florida	NOS	8726761	28.0133	-82.7933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:45:00	\N	0.79	-01:50:00	\N	0.7	\N	\N	Dunedin, St. Joseph Sound	FL
62678	Mobbly Bayou, Florida	NOS	8726769	28.0217	-82.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	02:54:00	\N	0.45	02:38:00	\N	0.71	\N	\N	Mobbly Bayou	FL
62679	Tarpon Springs, Anclote River, Florida	NOS	8726905	28.16	-82.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:03:00	\N	0.83	-01:16:00	\N	0.77	\N	\N	Tarpon Springs, Anclote River	FL
62680	Anclote, Anclote River, Florida	NOS	8726924	28.1717	-82.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:24:00	\N	0.87	-01:28:00	\N	0.78	\N	\N	Anclote, Anclote River	FL
62681	North Anclote Key, Florida	NOS	8726942	28.21	-82.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:38:00	\N	0.86	-01:55:00	\N	0.8	\N	\N	North Anclote Key	FL
62682	Gulf Harbors, Florida	NOS	8726995	28.2433	-82.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-00:52:00	\N	0.9	-01:15:00	\N	0.84	\N	\N	Gulf Harbors	FL
62683	New Port Richey, Pithlachascotee River, Florida	NOS	8727001	28.2483	-82.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-00:11:00	\N	0.87	-00:58:00	\N	0.88	\N	\N	New Port Richey, Pithlachascotee River	FL
62684	Hwy. 19 bridge, Pithlachascotee River, Florida	NOS	8727012	28.2683	-82.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-00:40:00	\N	0.84	-01:16:00	\N	0.85	\N	\N	Hwy. 19 bridge, Pithlachascotee River	FL
62685	Hudson, Hudson Creek, Florida	NOS	8727061	28.3617	-82.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:02:00	\N	0.89	-01:12:00	\N	0.91	\N	\N	Hudson, Hudson Creek	FL
62686	Aripeka, Hammock Creek, Florida	NOS	8727097	28.4333	-82.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:23:00	\N	0.63	-00:37:00	\N	0.81	\N	\N	Aripeka, Hammock Creek	FL
62687	Hernando Beach, Rocky Creek, Little Pine I. Bay, Florida	NOS	8727122	28.4867	-82.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:58:00	\N	0.83	-00:20:00	\N	0.83	\N	\N	Hernando Beach, Rocky Creek, Little Pine I. Bay	FL
62688	Johns Island, Chassahowitzka Bay, Florida (sub)	NOS	8727235	28.6917	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	02:14:00	\N	0.49	01:09:00	\N	0.62	\N	\N	Johns Island, Chassahowitzka Bay	FL
62689	Chassahowitzka, Chassahowitzka River, Florida (sub)	NOS	8727246	28.715	-82.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	05:45:00	\N	0.16	03:59:00	\N	0.14	\N	\N	Chassahowitzka, Chassahowitzka River	FL
62690	Mason Creek, Homosassa Bay, Florida (sub)	NOS	8727274	28.7617	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	04:44:00	\N	0.25	03:09:00	\N	0.32	\N	\N	Mason Creek, Homosassa Bay	FL
62691	Tuckers Island, Homosassa River, Florida (sub)	NOS	8727277	28.7717	-82.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	02:23:00	\N	0.33	01:26:00	\N	0.47	\N	\N	Tuckers Island, Homosassa River	FL
62692	Halls River bridge, Homosassa River, Florida (sub)	NOS	8727293	28.8	-82.6033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	05:41:00	\N	0.13	04:30:00	\N	0.16	\N	\N	Halls River bridge, Homosassa River	FL
62693	Ozello, St. Martin's River, Florida (sub)	NOS	8727306	28.825	-82.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	05:21:00	\N	0.14	04:25:00	\N	0.17	\N	\N	Ozello, St. Martins River	FL
62694	Ozello North, Crystal Bay, Florida (sub)	NOS	8727328	28.8633	-82.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	03:17:00	\N	0.25	01:25:00	\N	0.5	\N	\N	Ozello north, Crystal Bay	FL
62695	Mangrove Pt., Crystal Bay, Florida (sub)	NOS	8727333	28.87	-82.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:41:00	\N	0.76	00:22:00	\N	0.95	\N	\N	Mangrove Pt., Crystal Bay	FL
62696	Dixie Bay, Salt River, Crystal Bay, Florida (sub)	NOS	8727336	28.8817	-82.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	03:06:00	\N	0.33	02:00:00	\N	0.55	\N	\N	Dixie Bay, Salt River, Crystal Bay	FL
62697	Crystal River, Kings Bay, Florida (sub)	NOS	8727343	28.8983	-82.5983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	03:07:00	\N	0.41	02:20:00	\N	0.59	\N	\N	Kings Bay	FL
62698	Twin Rivers Marina, Crystal River, Florida (sub)	NOS	8727348	28.905	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	02:30:00	\N	0.49	01:46:00	\N	0.64	\N	\N	Twin Rivers Marina	FL
62699	Shell Island, north end, Crystal River, Florida (sub)	NOS	8727359	28.9233	-82.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	01:30:00	\N	0.59	00:36:00	\N	0.79	\N	\N	Shell Island, north end	FL
62700	Florida Power, Crystal River, Florida	NOS	8727386	28.96	-82.725	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:30:00	\N	0.89	-00:03:00	\N	1.04	\N	\N	Florida Power	FL
62701	Withlacoochee River entrance, Florida	NOS	8727395	29.0017	-82.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:55:00	\N	0.95	00:07:00	\N	0.91	\N	\N	Withlacoochee River entrance	FL
62702	Suwannee, Salt Creek, Florida	NOS	8727577	29.3283	-83.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:24:00	\N	0.83	-00:07:00	\N	0.91	\N	\N	Suwannee, Salt Creek	FL
62703	Steinhatchee River ent., Deadman Bay, Florida	NOS	8727695	29.6717	-83.39	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:00:00	\N	1.08	00:02:00	\N	1.03	\N	\N	Steinhatchee River ent., Deadman Bay	FL
62704	Mandalay, Aucilla River, Apalachee Bay, Florida	NOS	8727989	30.1267	-83.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	00:57:00	\N	0.55	00:25:00	\N	0.69	\N	\N	Mandalay, Aucilla River	FL
62705	St. Marks, St. Marks River, Apalachee Bay, Florida	NOS	8728142	30.1533	-84.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	01:04:00	\N	0.91	00:36:00	\N	0.93	\N	\N	St. Marks, St. Marks River	FL
62706	Shell Point, Walker Creek, Apalachee Bay, Florida (sub)	NOS	8728229	30.06	-84.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	-00:03:00	\N	1.08	-00:03:00	\N	1.02	\N	\N	Shell Point, Walker Creek	FL
62707	Bald Point, Ochlockonee Bay, Apalachee Bay, Florida	NOS	8728237	29.9483	-84.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	00:19:00	\N	0.7	00:33:00	\N	0.85	\N	\N	Bald Point, Ochlockonee Bay	FL
62708	Panacea, Dickerson Bay, Apalachee Bay, Florida	NOS	8728269	30.0283	-84.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	00:20:00	\N	0.82	00:16:00	\N	1.01	\N	\N	Panacea, Dickerson Bay	FL
62709	Alligator Point, St. James Island, Apalachee Bay, Florida	NOS	8728288	29.9033	-84.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	00:11:00	\N	0.73	-00:08:00	\N	0.75	\N	\N	Alligator Point, St. James Island	FL
62710	Turkey Point, Apalachee Bay, St. James Island, Florida (sub)	NOS	8728360	29.915	-84.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	-00:21:00	\N	0.98	-00:16:00	\N	0.78	\N	\N	Turkey Point, St. James Island	FL
62711	Carrabelle, Carrabelle River, St. George Sound, Florida (sub)	NOS	8728464	29.85	-84.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-02:13:00	\N	1.6	-01:25:00	\N	1.6	\N	\N	Carrabelle, Carrabelle River	FL
62712	Dog Island, west end, St. George Sound, Florida	NOS	8728465	29.785	-84.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-02:38:00	\N	1.4	-01:53:00	\N	1.73	\N	\N	Dog Island, west end	FL
62713	St. George Island, East End, St. George Sound, Florida	NOS	8728548	29.6867	-84.7867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-02:48:00	\N	1	-02:02:00	\N	1.13	\N	\N	St. George Island, East End	FL
62714	St. George Island, Rattlesnake Cove, St. George Sound, Florida	NOS	8728552	29.6917	-84.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-01:35:00	\N	1.2	-01:00:00	\N	1.33	\N	\N	St. George Island, Rattlesnake Cove	FL
62715	Cat Point, Apalachicola Bay, Florida (sub)	NOS	8728619	29.7233	-84.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-01:17:00	\N	0.6	-00:40:00	\N	1.07	\N	\N	Cat Point	FL
62716	St. George Island, 12th St. W (bayside), St. George Sound, Florida (sub)	NOS	8728626	29.6533	-84.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-01:08:00	\N	1.26	-00:55:00	\N	1.26	\N	\N	St. George Island, 12th St. W (Bayside)	FL
62717	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida (sub)	NOS	8728711	29.7633	-85.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	00:35:00	\N	0.83	00:28:00	\N	0.85	\N	\N	Apalachicola River (A&N RR bridge)	FL
62718	West Pass, Apalachicola Bay, Florida	NOS	8728766	29.6333	-85.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-00:27:00	\N	1	-00:27:00	\N	0.87	\N	\N	West Pass	FL
62719	Port Saint Joe, St. Joseph Bay, Florida (sub)	NOS	8728912	29.815	-85.3133	:America/New_York	USA	feet	\N	\N	\N	Reference is in time zone :America/Chicago; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-02:45:00	\N	1.11	-02:06:00	\N	1.11	\N	\N	Port Saint Joe, St. Joseph Bay	FL
62720	Wetappo Creek, East Bay, St. Andrew Bay, Florida	NOS	8728973	30.0383	-85.3933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	01:40:00	\N	1.1	01:01:00	\N	1.1	\N	\N	Wetappo Creek, East Bay	FL
62721	Allanton, East Bay, St. Andrew Bay, Florida	NOS	8729015	30.03	-85.465	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:01:00	\N	1.15	-00:16:00	\N	1.15	\N	\N	Allanton, East Bay	FL
62722	Farmdale, East Bay, St. Andrew Bay, Florida	NOS	8729017	30.0167	-85.47	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-00:59:00	\N	1.17	-00:16:00	\N	1.17	\N	\N	Farmdale, East Bay	FL
62723	Laird Bayou, East Bay, St. Andrew Bay, Florida	NOS	8729045	30.1217	-85.5283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:05:00	\N	1.13	-00:28:00	\N	1.13	\N	\N	Laird Bayou, East Bay	FL
62724	Parker, St. Andrew Bay, Florida	NOS	8729084	30.1267	-85.6117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	00:22:00	\N	1.2	-00:05:00	\N	1.2	\N	\N	Parker	FL
62725	Lynn Haven, North Bay, St. Andrew Bay, Florida	NOS	8729102	30.255	-85.6483	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:01:00	\N	1.1	-00:31:00	\N	1.1	\N	\N	Lynn Haven, North Bay	FL
62726	Panama City, St. Andrew Bay, Florida (sub)	NOS	8729108	30.15227777777778	-85.66694444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:11:00	\N	1.66	-00:57:00	\N	1.05	\N	\N	Panama City	FL
62727	Channel entrance, St. Andrew Bay, Florida	NOS	8729136	30.125	-85.73	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:50:00	\N	1.02	-01:39:00	\N	1.02	\N	\N	Channel entrance	FL
62728	Alligator Bayou, St. Andrew Bay, Florida	NOS	8729152	30.17	-85.755	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:10:00	\N	1.07	-00:47:00	\N	1.07	\N	\N	Alligator Bayou	FL
62729	West Bay Creek, West Bay, St. Andrew Bay, Florida	NOS	8729197	30.2933	-85.8583	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-00:47:00	\N	1.13	-00:10:00	\N	1.13	\N	\N	West Bay Creek, West Bay	FL
62730	East Pass (Destin), Choctawhatchee Bay, Florida	NOS	8729511	30.395	-86.5133	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-00:34:00	\N	0.33	-00:33:00	\N	0.49	\N	\N	East Pass (Destin)	FL
62731	Shalimar, Garnier Bayou, Choctawhatchee Bay, Florida	NOS	8729538	30.435	-86.5867	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	03:03:00	\N	0.32	03:33:00	\N	0.32	\N	\N	Shalimar, Garnier Bayou	FL
62732	Harris, The Narrows, Florida	NOS	8729613	30.4083	-86.7317	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	02:51:00	\N	1.1	01:37:00	\N	1.1	\N	\N	Harris, The Narrows	FL
62733	Navarre Beach, Florida (sub)	NOS	8729678	30.3767	-86.865	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-02:26:00	\N	1.67	-02:07:00	\N	1.07	\N	\N	Navarre Beach	FL
62734	East Bay, Pensacola Bay, Florida (sub)	NOS	8729702	30.45	-86.9183	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	01:17:00	\N	1.2	00:44:00	\N	1.2	\N	\N	East Bay	FL
62735	Bay Point, Blackwater River, Pensacola Bay, Florida	NOS	8729742	30.5717	-87.005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	01:27:00	\N	1.2	01:23:00	\N	1.2	\N	\N	Bay Point, Blackwater River	FL
62736	Fishing Bend, Santa Rosa Sound, Florida (sub)	NOS	8729806	30.3367	-87.14	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	00:51:00	\N	1.1	00:41:00	\N	1.1	\N	\N	Fishing Bend, Santa Rosa Sound	FL
62737	Lora Point, Escambia Bay, Pensacola Bay, Florida (sub)	NOS	8729816	30.515	-87.1617	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	01:03:00	\N	1.2	00:36:00	\N	1.2	\N	\N	Lora Point, Escambia Bay	FL
62738	Warrington, 2 miles south of, Pensacola Bay, Florida	NOS	8729868	30.345	-87.2733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-00:30:00	\N	1	-00:27:00	\N	1	\N	\N	Warrington, 2 miles south of	FL
62739	Fort McRee Breakwater, Pensacola Bay, Florida	NOS	8729887	30.3267	-87.3117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-00:34:00	\N	0.8	-01:23:00	\N	0.8	\N	\N	Fort McRee Breakwater	FL
62740	Nix Point, Perdido Bay, Florida	NOS	8729962	30.3933	-87.425	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	03:37:00	\N	0.33	02:29:00	\N	0.57	\N	\N	Nix Point, Perdido Bay	FL
62741	Bon Secour, Bon Secour River, Alabama	NOS	8731952	30.3033	-87.735	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60696	-01:17:00	\N	1.07	-01:13:00	\N	1.07	\N	\N	Bon Secour, Bon Secour River	AL
62742	Mobile Point (Fort Morgan), Alabama	NOS	8734635	30.2333	-88.02	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60696	-01:32:00	\N	0.8	-01:46:00	\N	0.8	\N	\N	Mobile Point (Fort Morgan)	AL
62743	Lower Hall Landing, Tensaw River, Alabama	NOS	8737182	30.8183	-87.915	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60696	03:05:00	\N	0.87	02:16:00	\N	0.87	\N	\N	Lower Hall Landing, Tensaw River	AL
62744	Bayou La Batre, Mississippi Sound, Alabama	NOS	8739051	30.3717	-88.275	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:14:00	\N	1.23	01:52:00	\N	1.23	\N	\N	Bayou La Batre, Mississippi Sound	AL
62745	Point of Pines, Bayou Cumbest, Mississippi	NOS	8740448	30.3867	-88.44	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:09:00	\N	1.25	01:49:00	\N	1.25	\N	\N	Point of Pines, Bayou Cumbest	MS
62746	Pascagoula Point, Mississippi Sound, Mississippi (sub)	NOS	8741196	30.34	-88.5333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	00:48:00	\N	1.21	01:20:00	\N	1.21	\N	\N	Pascagoula, Mississippi Sound	MS
62747	Horn Island, Mississippi Sound, Mississippi (sub)	NOS	8742221	30.2383	-88.6667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	00:59:00	\N	1.25	01:34:00	\N	1.25	\N	\N	Horn Island, Mississippi Sound	MS
62748	Hollingsworth Point, Davis Bayou, Mississippi (sub)	NOS	8743081	30.3867	-88.7733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:52:00	\N	1.42	02:24:00	\N	1.42	\N	\N	Hollingsworth Point, Davis Bayou	MS
62749	Biloxi (Cadet Point), Biloxi Bay, Mississippi (sub)	NOS	8743735	30.39	-88.8567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:30:00	\N	1.38	02:04:00	\N	1.38	\N	\N	Biloxi (Cadet Point), Biloxi Bay	MS
62750	Ship Island, Mississippi Sound, Mississippi (sub)	NOS	8744756	30.2133	-88.9717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:22:00	\N	1.3	01:52:00	\N	1.3	\N	\N	Ship Island, Mississippi Sound	MS
62751	Turkey Creek, Bernard Bayou, Mississippi	NOS	8745375	30.4267	-89.0533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:27:00	\N	1.54	03:23:00	\N	1.54	\N	\N	Turkey Creek, Bernard Bayou	MS
62752	Gulfport, Gulfport Harbor, Mississippi (sub)	NOS	8745557	30.36	-89.0817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:09:00	\N	1.29	02:09:00	\N	1.29	\N	\N	Gulfport Harbor, Mississippi Sound	MS
62753	Cat Island, Mississippi	NOS	8745799	30.2317	-89.1167	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:00:00	\N	1.23	02:13:00	\N	1.23	\N	\N	Cat Island	MS
62754	Pass Christian Yacht Club, Mississippi Sound, Mississippi (sub)	NOS	8746819	30.31	-89.245	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:04:00	\N	1.37	02:36:00	\N	1.37	\N	\N	Pass Christian Yacht Club, Mississippi Sound	MS
62755	Bay Waveland Yacht Club, Bay St. Louis, Mississippi (sub)	NOS	8747437	30.325	-89.325	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:57:00	\N	1.36	03:17:00	\N	1.36	\N	\N	St. Louis Bay entrance	MS
62756	Waveland, Mississipi Sound, Mississippi (sub)	NOS	8747766	30.2817	-89.3667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:49:00	\N	1.28	03:09:00	\N	1.28	\N	\N	Waveland	MS
62757	Wolf River, Henderson Avenue bridge, Mississippi	NOS	8748038	30.358333333332993	-89.27333333333299	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:51:00	\N	1.36	03:18:00	\N	1.36	\N	\N	Wolf River, Henderson Avenue bridge	MS
62758	Pearlington, Pearl River, Mississippi	NOS	8749704	30.24	-89.615	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	05:31:00	\N	0.99	05:51:00	\N	0.99	\N	\N	Pearlington, Pearl River	MS
62759	Chandeleur Light, Louisiana	NOS	8760172	30.0483	-88.8717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:54:00	\N	0.98	01:50:00	\N	0.98	\N	\N	Chandeleur Light	LA
62760	North Pass, Mississippi River, Louisiana	NOS	8760412	29.205	-89.0367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	00:43:00	\N	0.91	00:42:00	\N	0.91	\N	\N	North Pass, Pass a Loutre	LA
62761	Southeast Pass, Mississippi River, Louisiana	NOS	8760416	29.1167	-89.045	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	-00:28:00	\N	0.98	00:37:00	\N	0.98	\N	\N	Southeast Pass	LA
62762	Lonesome Bayou (Thomasin), Louisiana	NOS	8760424	29.2283	-89.05	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	-00:29:00	\N	0.9	00:34:00	\N	0.9	\N	\N	Lonesome Bayou (Thomasin)	LA
62763	Port Eads, South Pass, Mississippi River, Louisiana	NOS	8760579	29.015	-89.16	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	-00:17:00	\N	0.9	00:56:00	\N	0.9	\N	\N	Port Eads, South Pass	LA
62765	Joseph Bayou, Mississippi River, Louisiana	NOS	8760736	29.0583	-89.2717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	-00:17:00	\N	1.15	00:37:00	\N	1.15	\N	\N	Joseph Bayou	LA
62766	Comfort Island, Louisiana	NOS	8760742	29.8233	-89.27	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:14:00	\N	1.28	02:47:00	\N	1.28	\N	\N	Comfort Island	LA
62767	Jack Bay, Louisiana	NOS	8760841	29.3667	-89.345	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:48:00	\N	1	03:12:00	\N	1	\N	\N	Jack Bay	LA
62768	Olga Compressor Station, Grand Bay, Louisiana (sub)	NOS	8760889	29.38655555555556	-89.3801388888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:56:00	\N	1.08	02:54:00	\N	1.08	\N	\N	Grand Bay	LA
62769	Southwest Pass, Mississippi River, Louisiana	NOS	8760959	28.9317	-89.4283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	-00:13:00	\N	1.07	00:35:00	\N	1.07	\N	\N	Southwest Pass	LA
62770	Bay Gardene, Louisiana	NOS	8761108	29.5983	-89.6183	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	04:04:00	\N	1.16	04:04:00	\N	1.16	\N	\N	Bay Gardene	LA
62771	Empire Jetty, Louisiana	NOS	8761212	29.25	-89.6083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	-01:45:00	\N	1.23	-01:03:00	\N	1.23	\N	\N	Empire Jetty	LA
62772	Bastian Island, Louisiana	NOS	8761289	29.2867	-89.6633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	00:12:00	\N	1.13	00:41:00	\N	1.13	\N	\N	Bastian Island	LA
62773	Shell Beach, Lake Borgne, Louisiana (sub)	NOS	8761305	29.86811111111111	-89.67325	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	05:45:00	\N	1.13	05:45:00	\N	1.13	\N	\N	Shell Beach, Lake Borgne	LA
62774	Bayou BonFouca, Route 433, Louisiana	NOS	8761473	30.2717	-89.7933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	11:31:00	\N	0.43	11:12:00	\N	0.43	\N	\N	Bayou BonFouca, Route 433	LA
62775	Chef Menteur, Chef Menteur Pass, Louisiana	NOS	8761487	30.065	-89.8	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	06:27:00	\N	0.88	06:25:00	\N	0.88	\N	\N	Chef Menteur, Chef Menteur Pass	LA
62776	Quatre Bayous Pass, Louisiana	NOS	8761557	29.31	-89.8533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	00:17:00	\N	1.23	02:18:00	\N	1.23	\N	\N	Quatre Bayous Pass	LA
62777	Independence Island, Barataria Bay, Louisiana	NOS	8761677	29.31	-89.9383	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	01:59:00	\N	0.85	02:29:00	\N	0.85	\N	\N	Independence Island	LA
62778	Michoud Substation, ICWW, Louisiana	NOS	8761678	30.0067	-89.9367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	06:22:00	\N	1.09	06:37:00	\N	1.09	\N	\N	Michoud Substation, ICWW	LA
62779	Barataria Pass, Louisiana	NOS	8761687	29.275	-89.945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	-00:10:00	\N	1.13	01:00:00	\N	1.13	\N	\N	Barataria Pass	LA
62780	Manilla, Barataria Bay, Louisiana	NOS	8761732	29.4267	-89.9767	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	03:13:00	\N	0.94	02:32:00	\N	0.94	\N	\N	Manilla	LA
62781	New Canal USCG station, Lake Pontchartrain, Louisiana (sub)	NOS	8761927	30.02722222222222	-90.11333333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	12:09:00	\N	0.43	11:47:00	\N	0.43	\N	\N	New Canal USCG station, Lake Pontchartrain	LA
62782	Tchefuncta River, Lake Pontchartrain, Louisiana	NOS	8761993	30.3783	-90.16	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	12:21:00	\N	0.48	11:36:00	\N	0.48	\N	\N	Tchefuncta River, Lake Pontchartrain	LA
62783	Pelican Islands, Timbalier Bay, Louisiana	NOS	8762481	29.1283	-90.4233	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	02:26:00	\N	1.13	02:26:00	\N	1.13	\N	\N	Pelican Islands, Timbalier Bay	LA
62784	Timbalier Island, Timbalier Bay, Louisiana	NOS	8762675	29.0867	-90.5267	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	00:23:00	\N	1.13	00:19:00	\N	1.13	\N	\N	Timbalier Island, Timbalier Bay	LA
62785	Wine Island, Terrebonne Bay, Louisiana	NOS	8762850	29.0783	-90.5867	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	01:02:00	\N	1.23	01:08:00	\N	1.23	\N	\N	Wine Island, Terrebonne Bay	LA
62786	Caillou Boca, Louisiana	NOS	8763206	29.0633	-90.8067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	00:48:00	\N	1.32	00:40:00	\N	1.32	\N	\N	Caillou Boca	LA
62787	Raccoon Point, Caillou Bay, Louisiana	NOS	8763506	29.0633	-90.9617	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	-00:20:00	\N	1.6	-00:03:00	\N	1.6	\N	\N	Raccoon Point, Caillou Bay	LA
62788	Ship Shoal Light, Louisiana	NOS	8763719	28.915	-91.0717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	-01:50:00	\N	1.51	-01:54:00	\N	1.51	\N	\N	Ship Shoal Light	LA
62789	Shell Island, Atchafalaya Bay, Louisiana	NOS	8764165	29.4733	-91.305	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-00:39:00	\N	1.07	00:54:00	\N	1.07	\N	\N	Shell Island	LA
62790	Point Au Fer, Atchafalaya Bay, Louisiana	NOS	8764256	29.3333	-91.3533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-02:26:00	\N	1.4	-00:21:00	\N	1.4	\N	\N	Point Au Fer	LA
62791	Point Chevreuil, Atchafalaya Bay, Louisiana	NOS	8764634	29.5183	-91.555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-00:54:00	\N	1.07	01:02:00	\N	1.07	\N	\N	Point Chevreuil	LA
62792	Rabbit Island, 5 miles south of, Atchafalaya Bay, Louisiana	NOS	8764706	29.42	-91.5933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-02:00:00	\N	1.4	-00:13:00	\N	1.4	\N	\N	Rabbit Island, 5 miles south of	LA
62793	Cote Blanche Island, West Cote Blanche Bay, Louisiana	NOS	8764931	29.735	-91.7133	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	02:16:00	\N	1	02:19:00	\N	1	\N	\N	Cote Blanche Island, West Cote Blanche Bay	LA
62794	South Point, Marsh Island, Atchafalaya Bay, Louisiana	NOS	8765026	29.485	-91.7633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-01:57:00	\N	1.3	-00:19:00	\N	1.3	\N	\N	South Point, Marsh Island	LA
62795	Southwest Pass, Vermilion Bay, Louisiana	NOS	8765551	29.58	-92.035	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-00:33:00	\N	1.14	-00:32:00	\N	1.14	\N	\N	Southwest Pass, Vermilion Bay	LA
62796	Lighthouse Point, Atchafalaya Bay, Louisiana	NOS	8765568	29.5233	-92.0433	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-02:17:00	\N	1.4	-01:16:00	\N	1.4	\N	\N	Lighthouse Point	LA
62797	Point Barrow, Trinity Bay, Galveston Bay, Texas	NOS	8770557	29.74	-94.8317	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	04:43:00	\N	0.79	05:48:00	\N	0.79	\N	\N	Point Barrow, Trinity Bay	TX
62798	Round Point, Trinity Bay, Galveston Bay, Texas (sub)	NOS	8770559	29.7133	-94.69	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	05:15:00	\N	0.71	10:39:00	\N	0.71	\N	\N	Round Point, Trinity Bay	TX
62799	Sabine Pass (north), Texas (sub)	NOS	8770570	29.7284	-93.8701	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-00:38:00	\N	1.14	-01:18:00	\N	1.14	\N	\N	Sabine Pass	TX
62800	Barbours Cut, Morgans Point, Galveston Bay, Texas (sub)	NOS	8770613	29.68169444444445	-94.985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	04:17:00	\N	0.4	05:11:00	\N	0.95	\N	\N	Morgans Point, Barbours Cut	TX
62801	Lynchburg Landing, San Jacinto River, Galveston Bay, Texas (sub)	NOS	8770733	29.76486111111111	-95.07886111111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	04:51:00	\N	0.57	04:55:00	\N	1.05	\N	\N	Lynchburg Landing, San Jacinto River	TX
62802	Houston Ship Channel, Galveston Bay, Manchester, Texas (sub)	NOS	8770777	29.72622222222222	-95.26577777777777	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	05:05:00	\N	0.83	04:55:00	\N	1.15	\N	\N	Manchester, Houston Ship Channel	TX
62803	Clear Lake, Galveston Bay, Texas (sub)	NOS	8770933	29.5633	-95.0667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	05:19:00	\N	0.83	06:57:00	\N	0.83	\N	\N	Clear Lake	TX
62804	Eagle Point, Galveston Bay, Texas (sub)	NOS	8771013	29.48	-94.91830555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	02:38:00	\N	0.8	05:34:00	\N	0.8	\N	\N	Eagle Point	TX
62805	Port Bolivar, Galveston Bay, Texas (sub)	NOS	8771328	29.365	-94.78	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	00:09:00	\N	0.63	00:57:00	\N	1	\N	\N	Port Bolivar	TX
62806	Galveston Pleasure Pier, Gulf Of Mexico, Texas (sub)	NOS	8771510	29.2853	-94.7894	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-01:03:00	\N	1.3	-01:33:00	\N	1.4	\N	\N	Galveston Pleasure Pier	TX
62807	Jamaica Beach, West Bay, Galveston Bay, Texas	NOS	8771721	29.2	-94.985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	03:31:00	\N	0.71	02:38:00	\N	0.71	\N	\N	Jamaica Beach, West Bay	TX
62808	Alligator Point, West Bay, Texas	NOS	8771801	29.1667	-95.125	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	02:33:00	\N	0.64	02:39:00	\N	0.64	\N	\N	Alligator Point, West Bay	TX
62809	Christmas Bay, Texas	NOS	8772132	29.0417	-95.175	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	02:37:00	\N	0.23	04:47:00	\N	0.58	\N	\N	Christmas Bay	TX
62810	Freeport, DOW Barge Canal, Texas (sub)	NOS	8772440	28.9483	-95.3083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-01:08:00	\N	0.9	-01:17:00	\N	1.23	\N	\N	Freeport Harbor	TX
62811	Queen Isabella Causeway (east end), Texas	NOS	8779724	26.0783	-97.17	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60818	00:21:00	\N	0.75	00:24:00	\N	0.87	\N	\N	Queen Isabella Causeway (east end)	TX
62812	Queen Isabella Causeway (west end), Texas	NOS	8779739	26.0717	-97.1917	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60818	00:30:00	\N	0.63	00:52:00	\N	0.81	\N	\N	Queen Isabella Causeway (west end)	TX
62813	South Bay entrance, Texas	NOS	8779768	26.0517	-97.1817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60818	00:21:00	\N	0.94	00:14:00	\N	0.91	\N	\N	South Bay entrance	TX
62814	Port Isabel, Laguna Madre, Texas (sub)	NOS	8779770	26.06116666666667	-97.21552777777778	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60818	00:26:00	\N	1	00:10:00	\N	0.92	\N	\N	Port Isabel	TX
62815	San Nicolas Island, California	NOS	9410068	33.2667	-119.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:21:00	\N	0.88	00:10:00	\N	0.88	\N	\N	San Nicolas Island	CA
62816	Avalon, Santa Catalina Island, California (sub)	NOS	9410079	33.345	-118.325	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:09:00	\N	0.96	00:06:00	\N	0.96	\N	\N	Avalon, Santa Catalina Island	CA
62817	Catalina Harbor, Santa Catalina Island, California	NOS	9410092	33.4317	-118.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:17:00	\N	0.94	00:11:00	\N	0.94	\N	\N	Catalina Harbor, Santa Catalina Island	CA
62818	Imperial Beach, California	NOS	9410120	32.5783	-117.135	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	-00:03:00	\N	0.96	00:00:00	\N	0.93	\N	\N	Imperial Beach	CA
62819	National City, San Diego Bay, California	NOS	9410152	32.665	-117.118	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	00:10:00	0	\N	00:04:00	0.2	\N	\N	\N	National City, San Diego Bay	CA
62820	San Diego, Quarantine Station, California	NOS	9410166	32.7033	-117.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	00:02:00	\N	0.96	-00:04:00	\N	0.96	\N	\N	San Diego, Quarantine Station	CA
62821	Crown Point, Mission Bay, California	NOS	9410191	32.775	-117.233	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	00:16:00	\N	0.96	-00:03:00	\N	0.96	\N	\N	Crown Point, Mission Bay	CA
62822	La Jolla (Scripps Institution Wharf), California (sub)	NOS	9410230	32.86688888888889	-117.2571388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	-00:04:00	\N	0.97	00:00:00	\N	0.92	\N	\N	La Jolla (Scripps Institution Wharf)	CA
62823	Newport Beach, Newport Bay Entrance, Corona del Mar, California (sub)	NOS	9410580	33.6033	-117.883	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	-00:04:00	\N	0.98	-00:03:00	\N	0.98	\N	\N	Newport Bay Entrance, Corona del Mar	CA
62824	Balboa Pier, Newport Beach, California	NOS	9410583	33.6	-117.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:00:00	\N	0.96	-00:09:00	\N	0.96	\N	\N	Balboa Pier, Newport Beach	CA
62825	Santa Ana River entrance (inside), California	NOS	9410599	33.63	-117.958	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	01:47:00	\N	0.2	00:23:00	\N	0.54	\N	\N	Santa Ana River entrance (inside)	CA
62826	Cabrillo Beach, California	NOS	9410650	33.7067	-118.273	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:00:00	\N	1	00:00:00	\N	1	\N	\N	Cabrillo Beach	CA
62827	Long Beach, Terminal Island, California (sub)	NOS	9410680	33.7517	-118.227	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:00:00	\N	1.01	-00:01:00	\N	1.01	\N	\N	Long Beach, Terminal Island	CA
62828	Long Beach, Inner Harbor, California	NOS	9410686	33.7717	-118.21	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:05:00	\N	0.96	00:04:00	\N	0.96	\N	\N	Long Beach, Inner Harbor	CA
62829	King Harbor, Santa Monica Bay, California	NOS	9410738	33.8467	-118.398	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:07:00	\N	1	00:08:00	\N	0.96	\N	\N	King Harbor, Santa Monica Bay	CA
62830	El Segundo, Santa Monica Bay, California	NOS	9410777	33.9083	-118.433	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:13:00	\N	0.96	00:13:00	\N	0.96	\N	\N	El Segundo, Santa Monica Bay	CA
62831	Santa Monica, Municipal Pier, San Pedro Channel, California (sub)	NOS	9410840	34.0083	-118.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:03:00	\N	0.99	00:03:00	\N	0.99	\N	\N	Santa Monica, Municipal Pier	CA
62832	Bechers Bay, Santa Rosa Island, California	NOS	9410962	34.0083	-120.047	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:27:00	\N	1.03	00:27:00	\N	0.93	\N	\N	Bechers Bay, Santa Rosa Island	CA
62833	Prisoners Harbor, Santa Cruz Island, California	NOS	9410971	34.02	-119.683	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:18:00	\N	1.01	00:19:00	\N	0.94	\N	\N	Prisoners Harbor, Santa Cruz Island	CA
63180	Shakan Bay Entrance, Alaska	NOS	9450982	56.14	-133.61	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:12:00	0	\N	-00:13:00	1.8	\N	\N	\N	Shakan Bay Entrance	AK
62834	Cuyler Harbor, San Miguel Island, California	NOS	9410988	34.0567	-120.355	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:34:00	\N	0.94	00:33:00	\N	0.94	\N	\N	Cuyler Harbor, San Miguel Island	CA
62835	Port Hueneme, California	NOS	9411065	34.1483	-119.203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:13:00	0	\N	00:10:00	-0.1	\N	\N	\N	Port Hueneme	CA
62836	Ventura, California	NOS	9411189	34.2667	-119.283	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:16:00	0	\N	00:09:00	-0.1	\N	\N	\N	Ventura	CA
62837	Rincon Island, Mussel Shoals, Santa Barbara Channel, California (sub)	NOS	9411270	34.3483	-119.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:18:00	\N	1.05	00:20:00	\N	0.99	\N	\N	Rincon Island, Mussel Shoals	CA
62838	Santa Barbara, California (sub)	NOS	9411340	34.40311111111111	-119.6928055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:21:00	\N	1.04	00:23:00	\N	0.98	\N	\N	Santa Barbara	CA
62839	San Simeon, California	NOS	9412553	35.6417	-121.188	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60835	00:07:00	\N	1	00:08:00	\N	0.99	\N	\N	San Simeon	CA
62840	Carmel Cove, Carmel Bay, California	NOS	9413375	36.52	-121.94	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	-00:04:00	\N	0.99	-00:03:00	\N	0.97	\N	\N	Carmel Cove, Carmel Bay	CA
62841	Ocean Pier, Moss Landing, Monterey Bay, California	NOS	9413616	36.8017	-121.79	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	-00:01:00	\N	0.9	-00:01:00	\N	0.95	\N	\N	Moss Landing, Ocean Pier	CA
62842	General Fish Company Pier, Moss Landing, Monterey Bay, California	NOS	9413617	36.8017	-121.787	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	00:01:00	\N	0.95	00:01:00	\N	0.98	\N	\N	General Fish Company Pier	CA
62843	Elkhorn Slough, Highway 1 Bridge, Monterey Bay, California	NOS	9413623	36.81	-121.785	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	-00:02:00	\N	0.9	00:03:00	\N	0.95	\N	\N	Elkhorn Slough, Highway 1 Bridge	CA
62844	Pacific Mariculture Dock, Monterey Bay, California	NOS	9413624	36.8133	-121.758	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	00:07:00	\N	0.98	00:15:00	\N	1	\N	\N	Pacific Mariculture Dock	CA
62845	Elkhorn Yacht Club, Monterey Bay, California	NOS	9413626	36.8133	-121.787	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	00:02:00	\N	0.95	00:00:00	\N	0.97	\N	\N	Elkhorn Yacht Club	CA
62846	Santa Cruz, Monterey Bay, California	NOS	9413745	36.9583	-122.017	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	-00:11:00	\N	0.99	-00:06:00	\N	0.97	\N	\N	Santa Cruz, Monterey Bay	CA
62847	Ano Nuevo Island, California	NOS	9413878	37.1083	-122.338	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-01:04:00	-0.1	\N	-01:24:00	-0.7	\N	\N	\N	Ano Nuevo Island	CA
62848	Southeast Farallon Island, California	NOS	9414262	37.7	-123	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:19:00	0	\N	-00:39:00	-0.3	\N	\N	\N	Southeast Farallon Island	CA
62849	Ocean Beach, outer coast, California	NOS	9414275	37.775	-122.513	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:35:00	0	\N	-00:49:00	0.1	\N	\N	\N	Ocean Beach, outer coast	CA
62850	North Point, Pier 41, San Francisco, San Francisco Bay, California (sub)	NOS	9414305	37.81	-122.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:11:00	0	\N	00:13:00	0.2	\N	\N	\N	San Francisco, North Point, Pier 41	CA
62851	Rincon Point, Pier 22, San Francisco Bay, California (sub)	NOS	9414317	37.79	-122.387	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:25:00	0	\N	00:23:00	0.4	\N	\N	\N	Rincon Point, Pier 22 1/2	CA
62852	Potrero Point, San Francisco Bay, California	NOS	9414334	37.7583	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:46:00	0	\N	00:33:00	0.5	\N	\N	\N	Potrero Point	CA
62853	Hunters Point, San Francisco Bay, California (sub)	NOS	9414358	37.73	-122.357	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:39:00	0	\N	00:25:00	0.9	\N	\N	\N	Hunters Point	CA
62854	Borden Highway Bridge, San Joaquin River, San Joaquin River, California	NOS	9414367	37.93666666666701	-121.33333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:48:00	\N	0.64	04:28:00	\N	0.78	\N	\N	Borden Highway Bridge, San Joaquin River	CA
62855	South San Francisco, San Francisco Bay, California	NOS	9414391	37.6667	-122.39	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:56:00	0	\N	00:38:00	1.2	\N	\N	\N	South San Francisco	CA
63321	Day Harbor, Alaska	NOS	9455036	60.01	-149.062	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:00:00	\N	1.01	-00:02:00	\N	0.99	\N	\N	Day Harbor	AK
62856	Oyster Point Marina, San Francisco Bay, California (sub)	NOS	9414392	37.665	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:00:00	\N	1	00:41:00	\N	1.23	\N	\N	Oyster Point Marina	CA
62857	Point San Bruno, San Francisco Bay, California	NOS	9414402	37.65	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:10:00	0.1	\N	00:38:00	1.1	\N	\N	\N	Point San Bruno	CA
62858	Seaplane Harbor, San Francisco Bay, California	NOS	9414413	37.6367	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:03:00	0	\N	00:42:00	1.4	\N	\N	\N	Seaplane Harbor	CA
62859	Coyote Point Marina, San Francisco Bay, California	NOS	9414449	37.5917	-122.313	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:08:00	\N	1.01	00:42:00	\N	1.29	\N	\N	Coyote Point Marina	CA
62860	San Mateo Bridge (west end), San Francisco Bay, California (sub)	NOS	9414458	37.58	-122.253	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:11:00	\N	1.04	00:44:00	\N	1.36	\N	\N	San Mateo Bridge (west end)	CA
62861	Bay Slough, west end, San Francisco Bay, California	NOS	9414483	37.5517	-122.243	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:28:00	\N	1	00:48:00	\N	1.35	\N	\N	Bay Slough, west end	CA
62862	Bay Slough, east end, San Francisco Bay, California	NOS	9414486	37.545	-122.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:52:00	\N	0.77	00:49:00	\N	1.27	\N	\N	Bay Slough, east end	CA
62863	Redwood Creek Marker 8, San Francisco Bay, California (sub)	NOS	9414501	37.5333	-122.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:28:00	\N	1.05	00:53:00	\N	1.41	\N	\N	Redwood Creek Marker 8	CA
62864	Corkscrew Slough, San Francisco Bay, California	NOS	9414505	37.5083	-122.21	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:42:00	0.1	\N	01:03:00	2.2	\N	\N	\N	Corkscrew Slough	CA
62865	Newark Slough, San Francisco Bay, California	NOS	9414506	37.5133	-122.08	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:58:00	0.1	\N	01:11:00	2.6	\N	\N	\N	Newark Slough	CA
62866	West Point Slough, San Francisco Bay, California	NOS	9414507	37.505	-122.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:30:00	\N	1.04	00:56:00	\N	1.44	\N	\N	West Point Slough	CA
62867	Dumbarton Highway Bridge, San Francisco Bay, California (sub)	NOS	9414509	37.5067	-122.115	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:15:00	\N	1.05	00:50:00	\N	1.51	\N	\N	Dumbarton Highway Bridge	CA
62868	Smith Slough, San Francisco Bay, California	NOS	9414511	37.5017	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:58:00	0	\N	01:15:00	2.1	\N	\N	\N	Smith Slough	CA
62869	Granite Rock, Redwood Creek, San Francisco Bay, California	NOS	9414513	37.495	-122.213	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:31:00	\N	1.04	00:55:00	\N	1.43	\N	\N	Granite Rock, Redwood Creek	CA
62870	Mowry Slough, San Francisco Bay, California	NOS	9414519	37.4933	-122.042	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:07:00	0	\N	01:12:00	2.6	\N	\N	\N	Mowry Slough	CA
62871	Redwood City, Wharf 5, San Francisco Bay, California (sub)	NOS	9414523	37.50677777777778	-122.2115277777778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:15:00	\N	1.05	00:48:00	\N	1.45	\N	\N	Redwood City, Wharf 5	CA
62872	Palo Alto Yacht Harbor, San Francisco Bay, California	NOS	9414525	37.4583	-122.105	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:14:00	\N	0.68	00:59:00	\N	1.34	\N	\N	Palo Alto Yacht Harbor	CA
62873	Calaveras Point, west of, San Francisco Bay, California	NOS	9414539	37.4667	-122.067	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:49:00	0.1	\N	01:05:00	2.8	\N	\N	\N	Calaveras Point, west of	CA
62874	Upper Guadalupe Slough, San Francisco Bay, California	NOS	9414549	37.435	-122.007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:13:00	\N	1.13	01:14:00	\N	1.66	\N	\N	Upper Guadalupe Slough	CA
62875	Gold Street Bridge, Alviso Slough, San Francisco Bay, California	NOS	9414551	37.4233	-121.975	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:21:00	\N	0.96	01:03:00	\N	1.67	\N	\N	Gold Street Bridge, Alviso Slough	CA
62876	Coyote Creek, Tributary no.1, San Francisco Bay, California	NOS	9414561	37.4467	-121.963	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:45:00	-0.3	\N	01:21:00	2.6	\N	\N	\N	Coyote Creek, Tributary no.1	CA
62877	Coyote Creek, Alviso Slough, San Francisco Bay, California (sub)	NOS	9414575	37.465	-122.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:49:00	\N	1.09	00:59:00	\N	1.61	\N	\N	Coyote Creek, Alviso Slough	CA
62878	South Bay Wreck, San Francisco Bay, California	NOS	9414609	37.5517	-122.162	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:37:00	0.1	\N	01:02:00	2.2	\N	\N	\N	South Bay Wreck	CA
62879	Coyote Hills Slough entrance, San Francisco Bay, California	NOS	9414621	37.5633	-122.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:21:00	\N	0.45	00:52:00	\N	1.17	\N	\N	Coyote Hills Slough entrance	CA
62880	Alameda Creek, San Francisco Bay, California	NOS	9414632	37.595	-122.145	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:25:00	\N	0.27	00:57:00	\N	1.05	\N	\N	Alameda Creek	CA
62881	San Mateo Bridge (east end), San Francisco Bay, California	NOS	9414637	37.6083	-122.182	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:19:00	0	\N	00:48:00	1.8	\N	\N	\N	San Mateo Bridge (east end)	CA
62882	San Leandro Marina, San Francisco Bay, California (sub)	NOS	9414688	37.695	-122.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:23:00	\N	1.01	00:54:00	\N	1.28	\N	\N	San Leandro Marina	CA
62883	Oakland Airport, San Francisco Bay, California	NOS	9414711	37.7317	-122.208	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:45:00	\N	0.96	00:40:00	\N	1.15	\N	\N	Oakland Airport	CA
62884	San Leandro Channel, San Leandro Bay, San Francisco Bay, California	NOS	9414724	37.7483	-122.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:52:00	\N	0.98	00:42:00	\N	1.16	\N	\N	San Leandro Channel, San Leandro Bay	CA
62885	Alameda, San Francisco Bay, California (sub)	NOS	9414750	37.7717	-122.3	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:39:00	\N	0.99	00:29:00	\N	1.11	\N	\N	Alameda	CA
62886	Oakland Berth 67, San Francisco Bay, California	NOS	9414763	37.795	-122.283	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:42:00	0	\N	00:33:00	0.4	\N	\N	\N	Oakland Harbor, Grove Street	CA
62887	Oakland Pier, San Francisco Bay, California	NOS	9414765	37.795	-122.33	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:48:00	0	\N	00:33:00	0.2	\N	\N	\N	Oakland Pier	CA
62888	Alameda Naval Air Station fuel pier, San Francisco Bay, California (sub)	NOS	9414767	37.7933	-122.315	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:33:00	\N	1	00:24:00	\N	1.11	\N	\N	Alameda Naval Air Station	CA
62889	Oakland Middle Harbor, San Francisco Bay, California	NOS	9414777	37.805	-122.338	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:31:00	\N	0.96	00:21:00	\N	1.07	\N	\N	Oakland Middle Harbor	CA
62890	Oakland, Matson Wharf, San Francisco Bay, California	NOS	9414779	37.81	-122.327	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:36:00	0	\N	00:28:00	0.3	\N	\N	\N	Oakland, Matson Wharf	CA
62891	Yerba Buena Island, San Francisco Bay, California	NOS	9414782	37.81	-122.36	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:33:00	\N	0.99	00:25:00	\N	1.06	\N	\N	Yerba Buena Island	CA
62892	Grant Line Canal (drawbridge), San Joaquin River, California	NOS	9414785	37.82	-121.447	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	06:20:00	\N	0.68	06:14:00	\N	0.76	\N	\N	Grant Line Canal (drawbridge)	CA
62893	Alcatraz Island, San Francisco Bay, California	NOS	9414792	37.8267	-122.417	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:18:00	0	\N	00:14:00	0	\N	\N	\N	Alcatraz Island	CA
62894	Sausalito, San Francisco Bay, California (sub)	NOS	9414806	37.8467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:14:00	\N	1	00:10:00	\N	0.97	\N	\N	Sausalito	CA
62895	Nurse Slough, Bradmoor Island, Suisun Bay, California (sub)	NOS	9414811	38.1833	-121.923	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:06:00	\N	0.99	00:59:00	\N	1.07	\N	\N	Bradmoor Island, Nurse Slough	CA
62896	Angel Island (west side), San Francisco Bay, California	NOS	9414817	37.86	-122.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:21:00	0	\N	00:13:00	-0.2	\N	\N	\N	Angel Island (west side)	CA
62897	Angel Island, East Garrison, San Francisco Bay, California	NOS	9414818	37.8633	-122.42	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:20:00	\N	1.04	00:16:00	\N	1.02	\N	\N	Angel Island, East Garrison	CA
62898	Sausalito, Corps of Engineers Dock, San Francisco Bay, California (sub)	NOS	9414819	37.865	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:21:00	\N	1	00:10:00	\N	0.98	\N	\N	Sausalito, Corps of Engineers Dock	CA
62899	Borden Highway Bridge, Middle River, San Joaquin River, California	NOS	9414835	37.8917	-121.488	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:54:00	\N	0.62	04:50:00	\N	0.67	\N	\N	Borden Highway Bridge, Middle River	CA
62900	Borden Highway Bridge, Old River, San Joaquin River, California	NOS	9414836	37.8833	-121.577	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:35:00	\N	0.61	04:40:00	\N	0.64	\N	\N	Borden Highway Bridge, Old River	CA
62901	Point Chauncey, San Francisco Bay, California	NOS	9414837	37.8917	-122.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:32:00	\N	0.96	00:28:00	\N	0.98	\N	\N	Point Chauncey	CA
62902	Point Isabel, San Francisco Bay, California	NOS	9414843	37.8983	-122.32	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:33:00	0	\N	00:23:00	0.1	\N	\N	\N	Point Isabel	CA
62903	Richmond Inner Harbor, San Francisco Bay, California	NOS	9414849	37.91	-122.358	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:30:00	\N	0.98	00:16:00	\N	1.04	\N	\N	Richmond Inner Harbor	CA
62904	Chevron Oil Company Pier, Richmond, San Francisco Bay, California (sub)	NOS	9414863	37.923	-122.4095833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:38:00	\N	0.98	00:24:00	\N	1.04	\N	\N	Chevron Oil Company Pier, Richmond	CA
62905	Holt, Whiskey Slough, San Joaquin River, California	NOS	9414866	37.935	-121.435	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:39:00	\N	0.68	04:18:00	\N	0.8	\N	\N	Holt, Whiskey Slough	CA
62906	Orwood, Old River, San Joaquin River, California	NOS	9414868	37.9383	-121.56	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:33:00	\N	0.68	04:32:00	\N	0.76	\N	\N	Orwood, Old River	CA
62907	Point San Quentin, San Francisco Bay, California	NOS	9414873	37.945	-122.475	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:50:00	\N	0.93	00:42:00	\N	0.99	\N	\N	Point San Quentin	CA
62908	Corte Madera Creek, San Francisco Bay, California	NOS	9414874	37.9433	-122.513	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:51:00	\N	0.95	00:36:00	\N	0.99	\N	\N	Corte Madera Creek	CA
62909	Point Orient, San Francisco Bay, California	NOS	9414881	37.9583	-122.425	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:52:00	\N	0.96	00:50:00	\N	1.03	\N	\N	Point Orient	CA
62910	Stockton, San Joaquin River, California	NOS	9414883	37.9583	-121.29	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:33:00	\N	0.66	04:06:00	\N	0.81	\N	\N	Stockton	CA
62911	Point Bonita, Bonita Cove, San Francisco Bay, California	NOS	9414906	37.8183	-122.528	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:10:00	0	\N	-00:17:00	0.3	\N	\N	\N	Point Bonita, Bonita Cove	CA
62912	Bolinas, Bolinas Lagoon, California (sub)	NOS	9414958	37.907779693603516	-122.6786117553711	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:38:00	\N	0.61	-00:10:00	\N	0.7	\N	\N	Bolinas Lagoon	CA
62913	Point San Pedro, San Pablo Bay, California	NOS	9415009	37.9933	-122.447	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:07:00	\N	0.92	01:02:00	\N	1.01	\N	\N	Point San Pedro	CA
62914	Blackslough Landing, San Joaquin River, California (sub)	NOS	9415021	37.99469444444444	-121.4190444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:15:00	\N	0.62	04:00:00	\N	0.75	\N	\N	Blackslough Landing	CA
62915	Gallinas, Gallinas Creek, San Pablo Bay, California	NOS	9415052	38.015	-122.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:25:00	\N	0.89	01:18:00	\N	1.02	\N	\N	Gallinas, Gallinas Creek	CA
62916	Davis Slough, San Joaquin River, California	NOS	9415053	38.0117	-121.638	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	02:46:00	\N	0.72	02:33:00	\N	0.68	\N	\N	Dutch Slough	CA
62917	Antioch, San Joaquin River, California (sub)	NOS	9415064	38.02	-121.815	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:26:00	\N	0.78	01:12:00	\N	0.77	\N	\N	Antioch	CA
62918	Hercules, Refugio Landing, San Pablo Bay, California	NOS	9415074	38.0233	-122.292	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:39:00	\N	0.85	01:15:00	\N	1.05	\N	\N	Hercules, Refugio Landing	CA
62919	Irish Landing, Sand Mound Slough, San Joaquin River, California	NOS	9415095	38.0333	-121.583	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	03:34:00	\N	0.68	03:29:00	\N	0.73	\N	\N	Irish Landing, Sand Mound Slough	CA
62920	Pittsburg, New York Slough, Suisun Bay, California	NOS	9415096	38.0367	-121.88	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:05:00	\N	0.84	00:59:00	\N	0.83	\N	\N	Pittsburg, New York Slough	CA
62921	Wards Island, Little Connection Slough, San Joaquin River, California (sub)	NOS	9415105	38.05002527777778	-121.4968555555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	03:51:00	\N	0.61	03:45:00	\N	0.68	\N	\N	Wards Island, Little Connection Slough	CA
62923	Mallard Island Ferry Wharf, Suisun Bay, California (sub)	NOS	9415112	38.0433	-121.918	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:57:00	\N	0.81	00:54:00	\N	0.83	\N	\N	Mallard Island Ferry Wharf	CA
62924	Bishop Cut, Disappointment Slough, San Joaquin River, California	NOS	9415117	38.045	-121.42	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:12:00	\N	0.66	04:12:00	\N	0.79	\N	\N	Bishop Cut, Disappointment Slough	CA
62925	Selby, California	NOS	9415142	38.0583	-122.243	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:04:00	0	\N	01:29:00	0.6	\N	\N	\N	Selby	CA
62926	Crockett, Carquinez Strait, California (sub)	NOS	9415143	38.0583	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	-01:05:00	\N	1.31	-00:58:00	\N	1.22	\N	\N	Crockett	CA
62927	False River, San Joaquin River, California	NOS	9415145	38.055	-121.657	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	02:45:00	\N	0.64	02:45:00	\N	0.66	\N	\N	False River	CA
62928	Prisoners Point, San Joaquin River, California	NOS	9415149	38.0617	-121.555	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	03:29:00	\N	0.69	03:25:00	\N	0.73	\N	\N	Prisoners Point	CA
62929	Vallejo, Mare Island Strait, California	NOS	9415165	38.1117	-122.273	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:12:00	\N	0.84	01:47:00	\N	1.02	\N	\N	Vallejo, Mare Island Strait	CA
62930	Collinsville, Sacramento River, California	NOS	9415176	38.0733	-121.848	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:20:00	\N	0.8	01:11:00	\N	0.8	\N	\N	Collinsville	CA
62931	Threemile Slough entrance, San Joaquin River, California (sub)	NOS	9415193	38.0867	-121.685	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	02:52:00	\N	0.68	02:27:00	\N	0.71	\N	\N	Threemile Slough entrance	CA
62932	Montezuma Slough, Suisun Bay, California	NOS	9415205	38.0767	-121.885	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:27:00	\N	0.82	01:16:00	\N	0.84	\N	\N	Montezuma Slough	CA
62933	Mare Island Naval Shipyard, Carquinez Strait, California (sub)	NOS	9415218	38.07	-122.25	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:58:00	\N	0.84	01:32:00	\N	1.01	\N	\N	Mare Island	CA
62934	Point Buckler, Suisun Bay, California	NOS	9415227	38.1	-122.033	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:22:00	\N	1.08	00:13:00	\N	1.12	\N	\N	Point Buckler	CA
62935	Inverness, Tomales Bay, California	NOS	9415228	38.1133	-122.868	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:08:00	\N	0.91	00:29:00	\N	0.94	\N	\N	Inverness, Tomales Bay	CA
62936	Threemile Slough, Sacramento River, California	NOS	9415236	38.1067	-121.7	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:58:00	\N	0.78	01:49:00	\N	0.82	\N	\N	Threemile Slough	CA
62937	Petaluma River entrance, San Pablo Bay, California (sub)	NOS	9415252	38.11530555555556	-122.5056666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:08:00	\N	0.86	01:23:00	\N	1.06	\N	\N	Petaluma River entrance	CA
62938	Terminous, South Fork, Mokelumne River, California	NOS	9415257	38.11	-121.498	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:11:00	\N	0.59	03:53:00	\N	0.7	\N	\N	Terminous, South Fork	CA
62961	Clarksburg, Sacramento River, California	NOS	9415846	38.4167	-121.523	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	05:02:00	\N	0.41	03:58:00	\N	0.6	\N	\N	Clarksburg	CA
62939	Suisun Slough entrance, Suisun Bay, California (sub)	NOS	9415265	38.1283	-122.073	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:26:00	\N	0.93	00:13:00	\N	0.97	\N	\N	Suisun Slough entrance	CA
62940	Pierce Harbor, Goodyear Slough, Suisun Bay, California	NOS	9415266	38.1267	-122.1	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:41:00	\N	0.96	00:27:00	\N	1	\N	\N	Pierce Harbor, Goodyear Slough	CA
62941	Georgiana Slough entrance, Mokelumne River, California	NOS	9415287	38.125	-121.578	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	03:41:00	\N	0.59	03:29:00	\N	0.67	\N	\N	Georgiana Slough entrance	CA
62942	Meins Landing, Montezuma Slough, Suisun Bay, California	NOS	9415307	38.1367	-121.907	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:11:00	\N	0.93	00:57:00	\N	1.01	\N	\N	Meins Landing, Montezuma Slough	CA
62943	Rio Vista, Sacramento River, California (sub)	NOS	9415316	38.145	-121.692	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	02:02:00	\N	0.78	01:51:00	\N	0.88	\N	\N	Rio Vista	CA
62944	Reynolds, Tomales Bay, California	NOS	9415320	38.1467	-122.883	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:59:00	\N	0.83	00:26:00	\N	0.89	\N	\N	Reynolds, Tomales Bay	CA
62945	Marshall, Tomales Bay, California	NOS	9415339	38.1617	-122.893	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:16:00	-0.1	\N	00:38:00	-0.6	\N	\N	\N	Marshall, Tomales Bay	CA
62946	Hog Island, San Antonio Creek, San Pablo Bay, California	NOS	9415344	38.1617	-122.55	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:36:00	\N	0.79	01:47:00	\N	1.07	\N	\N	Hog Island, San Antonio Creek	CA
62947	Joice Island, Suisun Slough, Suisun Bay, California	NOS	9415379	38.18	-122.045	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:41:00	\N	1	00:21:00	\N	1.07	\N	\N	Joice Island, Suisun Slough	CA
62948	Blakes Landing, Tomales Bay, California	NOS	9415396	38.19	-122.917	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:15:00	\N	0.79	00:32:00	\N	0.86	\N	\N	Blakes Landing, Tomales Bay	CA
62949	Montezuma Slough Bridge, Suisun Bay, California	NOS	9415402	38.1867	-121.98	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:46:00	\N	0.95	00:37:00	\N	1.01	\N	\N	Montezuma Slough Bridge	CA
62950	Steamboat Slough, Snug Harbor Marina, Sacramento River, California	NOS	9415414	38.1833	-121.655	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	02:48:00	\N	0.65	02:24:00	\N	0.8	\N	\N	Steamboat Slough, Snug Harbor Marina	CA
62951	Edgerley Island, Napa River, California	NOS	9415415	38.1917	-122.312	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:29:00	\N	0.76	02:02:00	\N	1.06	\N	\N	Edgerley Island, Napa River	CA
62952	Brazos Drawbridge, Napa River, California	NOS	9415446	38.21	-122.307	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:29:00	\N	0.86	02:02:00	\N	1.14	\N	\N	Brazos Drawbridge, Napa River	CA
62953	Wingo, Sonoma Creek, San Pablo Bay, California	NOS	9415447	38.21	-122.427	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	03:11:00	-0.3	\N	02:12:00	0.1	\N	\N	\N	Wingo, Sonoma Creek	CA
62954	Tomales Bay entrance, California	NOS	9415469	38.2283	-122.977	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:20:00	\N	0.91	-00:12:00	\N	0.87	\N	\N	Tomales Bay entrance	CA
62955	New Hope Bridge, Mokelumne River, California	NOS	9415478	38.2267	-121.49	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:56:00	\N	0.68	04:22:00	\N	0.73	\N	\N	New Hope Bridge	CA
62956	Suisun City, Suisun Slough, Suisun Bay, California	NOS	9415498	38.2367	-122.03	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:01:00	\N	1	00:36:00	\N	1.11	\N	\N	Suisun City, Suisun Slough	CA
62957	Snodgrass Slough, Sacramento River, California	NOS	9415565	38.2767	-121.495	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	05:36:00	\N	0.39	05:00:00	\N	0.49	\N	\N	Snodgrass Slough	CA
62958	Upper drawbridge, Petaluma River, San Pablo Bay, California (sub)	NOS	9415584	38.2283	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:59:00	\N	0.82	02:11:00	\N	1.15	\N	\N	Upper drawbridge, Petaluma River	CA
62959	Napa, Napa River, California	NOS	9415623	38.2983	-122.28	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:37:00	\N	0.9	02:05:00	\N	1.22	\N	\N	Napa, Napa River	CA
62960	Bodega Harbor entrance, California	NOS	9415625	38.3083	-123.055	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:16:00	0.1	\N	-00:38:00	-0.2	\N	\N	\N	Bodega Harbor entrance	CA
62963	Sacramento, Sacramento River, California	NOS	9416174	38.58	-121.507	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	06:32:00	\N	0.41	05:07:00	\N	0.6	\N	\N	Sacramento	CA
62964	Westport, California	NOS	9417624	39.6333	-123.783	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60883	00:00:00	\N	0.95	00:14:00	\N	0.98	\N	\N	Westport	CA
62965	Hookton Slough, Humboldt Bay, California	NOS	9418686	40.6867	-124.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:15:00	\N	0.98	00:06:00	\N	1.01	\N	\N	Hookton Slough	CA
62966	Elk River Railroad Bridge, Humboldt Bay, California	NOS	9418757	40.7567	-124.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	01:32:00	\N	0.31	00:19:00	\N	0.71	\N	\N	Elk River Railroad Bridge	CA
62967	Bucksport, Humboldt Bay, California	NOS	9418778	40.7783	-124.197	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:16:00	\N	1	00:17:00	\N	1.01	\N	\N	Bucksport	CA
62968	Eureka, Humboldt Bay, California	NOS	9418801	40.8067	-124.167	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:13:00	\N	1.03	00:26:00	\N	1.06	\N	\N	Eureka	CA
62969	Eureka Slough Bridge, Humboldt Bay, California	NOS	9418802	40.8067	-124.142	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:19:00	\N	1.02	00:33:00	\N	1.08	\N	\N	Eureka Slough Bridge	CA
62970	Arcata Wharf, Humboldt Bay, California	NOS	9418851	40.85	-124.117	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:54:00	0.1	\N	00:48:00	0.1	\N	\N	\N	Arcata Wharf	CA
62971	Mad River Slough, Arcata Bay, Humboldt Bay, California	NOS	9418865	40.865	-124.148	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:35:00	\N	1.07	00:43:00	\N	1.12	\N	\N	Mad River Slough, Arcata Bay	CA
62972	Trinidad Harbor, California	NOS	9419059	41.0567	-124.147	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	-00:03:00	\N	0.98	-00:02:00	\N	0.97	\N	\N	Trinidad Harbor	CA
62973	Brookings, Chetco Cove, Oregon	NOS	9430104	42.0433	-124.285	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:04:00	\N	1	00:01:00	\N	1	\N	\N	Brookings, Chetco Cove	OR
62974	Bandon, Coquille River, Oregon	NOS	9432373	43.12	-124.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	00:02:00	\N	0.94	-00:05:00	\N	0.92	\N	\N	Bandon, Coquille River	OR
62975	Coos Bay, Oregon	NOS	9432845	43.38	-124.215	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	01:28:00	\N	0.88	01:26:00	\N	0.96	\N	\N	Coos Bay	OR
62976	Empire, Coos Bay, Oregon	NOS	9432864	43.3917	-124.28	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	00:50:00	\N	0.88	00:37:00	\N	0.86	\N	\N	Empire	OR
62977	Sitka Dock, Coos Bay, Oregon	NOS	9432879	43.3767	-124.297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	00:08:00	\N	1.01	00:07:00	\N	1.01	\N	\N	Sitka Dock, Coos Bay	OR
62978	Florence, Siuslaw River, Oregon	NOS	9434032	43.9667	-124.103	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	00:58:00	\N	0.8	00:44:00	\N	0.86	\N	\N	Florence	OR
62979	Siuslaw River entrance, Oregon	NOS	9434132	44.0167	-124.13	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	00:03:00	\N	0.96	-00:06:00	\N	0.96	\N	\N	Suislaw River Entrance	OR
62980	Drift Creek, Alsea River, Oregon	NOS	9434938	44.4133	-123.99	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	01:51:00	\N	0.53	00:44:00	\N	0.83	\N	\N	Drift Creek, Alsea River	OR
62981	Toledo, Yaquina River, Oregon	NOS	9435362	44.6167	-123.937	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:17:00	\N	1.02	01:02:00	\N	1.31	\N	\N	TOLEDO	OR
62982	South Beach, Yaquina Bay and River, Oregon (sub)	NOS	9435380	44.625	-124.043	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:34:00	\N	1.1	00:41:00	\N	1.23	\N	\N	Southbeach	OR
62983	Yaquina USCG station, Newport, Yaquina Bay, Oregon	NOS	9435385	44.6267	-124.055	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:35:00	\N	1.11	00:39:00	\N	1.22	\N	\N	YAQUINA USCG STA, NEWPORT	OR
62984	Depoe Bay, Oregon (sub)	NOS	9435827	44.81	-124.058	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:27:00	\N	1.1	00:27:00	\N	1.21	\N	\N	Depoe Bay	OR
62985	Kernville, Siletz River, Oregon	NOS	9436031	44.8967	-124	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:53:00	\N	0.67	01:24:00	\N	0.86	\N	\N	Kernville, Siletz River	OR
62986	Taft, Siletz Bay, Oregon	NOS	9436101	44.9267	-124.013	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:13:00	\N	0.75	00:48:00	\N	0.94	\N	\N	Taft, Siletz Bay	OR
62987	Netarts, Netarts Bay, Oregon	NOS	9437262	45.43	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:38:00	\N	0.85	01:17:00	\N	0.98	\N	\N	Netarts, Netarts Bay	OR
62988	Tillamook, Hoquarten Slough, Tillamook Bay, Oregon	NOS	9437331	45.46	-123.845	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	03:15:00	\N	0.58	01:52:00	\N	0.94	\N	\N	Tillamook, Hoquarten Slough	OR
62989	Garibaldi, Tillamook Bay, Oregon (sub)	NOS	9437540	45.55453	-123.91894444439146	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:11:00	\N	1.06	01:19:00	\N	1.19	\N	\N	Garibaldi	OR
62990	Barview, Tillamook Bay, Oregon	NOS	9437581	45.5683	-123.943	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:56:00	\N	0.92	00:42:00	\N	1.08	\N	\N	Barview	OR
62991	Brighton, Nehalem River, Oregon	NOS	9437815	45.67	-123.925	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:54:00	\N	1	00:51:00	\N	1.13	\N	\N	Brighton	OR
62992	Nehalem, Nehalem River, Oregon	NOS	9437908	45.71	-123.89	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:56:00	\N	0.75	01:17:00	\N	1.03	\N	\N	Nehalem	OR
62993	Astoria (Port Docks), Oregon	NOS	9439023	46.1867	-123.86	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:03:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Astoria (Port Docks), Oreg.	OR
62994	Astoria (Youngs Bay), Oregon	NOS	9439026	46.1717	-123.842	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:14:00	0.1	\N	-00:13:00	0.1	\N	\N	\N	Astoria (Youngs Bay), Oreg.	OR
62995	Settlers Point, Oregon	NOS	9439054	46.175	-123.678	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	00:53:00	-0.1	\N	00:22:00	-0.5	\N	\N	\N	Settlers Point, Oreg.	OR
62996	Knappa, Knappa Slough, Oregon	NOS	9439069	46.1867	-123.588	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	00:58:00	\N	0.86	00:29:00	\N	0.97	\N	\N	Knappa, Knappa Slough	OR
62997	Hungry Harbor, Washington	NOS	9440563	46.2583	-123.848	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:09:00	0.1	\N	00:04:00	-0.2	\N	\N	\N	Hungry Harbor, Wash.	WA
62998	Fort Canby, Jetty 'A', Washington	NOS	9440572	46.2683	-124.037	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-01:05:00	\N	1.22	-00:41:00	\N	0.97	\N	\N	Fort Canby, Jetty 'A', Wash.	WA
62999	Chinook, Baker Bay, Washington	NOS	9440573	46.2717	-123.948	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:52:00	\N	1.12	-00:30:00	\N	0.95	\N	\N	Chinook, Baker Bay, Wash.	WA
63000	Columbia River entrance (N. Jetty), Washington	NOS	9440574	46.2733	-124.072	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-01:00:00	0.1	\N	-00:44:00	-1	\N	\N	\N	Columbia River entrance (N. Jetty)	WA
63001	Ilwaco, Baker Bay, Washington	NOS	9440597	46.3033	-124.04	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	00:01:00	-0.1	\N	-00:13:00	-0.8	\N	\N	\N	Ilwaco, Baker Bay, Wash.	WA
63002	Naselle River, 4 miles above swing bridge, Willapa Bay, Washington	NOS	9440662	46.3883	-123.84	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	01:02:00	\N	0.93	01:02:00	\N	1.22	\N	\N	Naselle River, 4 miles above swing bridge	WA
63003	Naselle River, swing bridge, Willapa Bay, Washington	NOS	9440691	46.43	-123.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:37:00	\N	1.08	00:42:00	\N	1.22	\N	\N	Naselle River, swing bridge	WA
63004	Paradise Point, Long Island, Willapa Bay, Washington	NOS	9440723	46.4683	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:41:00	\N	1.04	00:43:00	\N	1.15	\N	\N	Paradise Point, Long Island	WA
63005	Nahcotta, Willapa Bay, Washington (sub)	NOS	9440747	46.5017	-124.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:28:00	\N	1.01	00:29:00	\N	1.13	\N	\N	Nahcotta	WA
63006	Palix River, south fork, Willapa Bay, Washington	NOS	9440813	46.5867	-123.91	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:31:00	\N	0.96	00:25:00	\N	1.04	\N	\N	Palix River, south fork	WA
63007	Bay Center, Palix River, Willapa Bay, Washington	NOS	9440846	46.6233	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:22:00	\N	1.03	00:09:00	\N	1.04	\N	\N	Bay Center, Palix River	WA
63008	South Bend, Willapa River, Willapa Bay, Washington (sub)	NOS	9440875	46.6633	-123.798	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:15:00	\N	1.05	00:14:00	\N	1.11	\N	\N	South Bend, Willapa River	WA
63009	Raymond, Willapa River, Willapa Bay, Washington	NOS	9440886	46.6833	-123.755	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:17:00	\N	1.04	00:27:00	\N	1.13	\N	\N	Raymond, Willapa River	WA
63010	Bay City, South Bay, Grays Harbor, Washington	NOS	9441038	46.8617	-124.06	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:26:00	\N	1.13	-00:01:00	\N	1.1	\N	\N	Bay City, South Bay	WA
63011	Markham, Grays Harbor, Washington	NOS	9441098	46.9067	-123.998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:15:00	\N	1.02	00:05:00	\N	1.06	\N	\N	Markham	WA
63012	Westport, Point Chehalis, Grays Harbor, Washington (sub)	NOS	9441102	46.90431	-124.1050833331214	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:29:00	\N	1.01	-00:11:00	\N	1.03	\N	\N	Westport, Point Chehalis	WA
63013	Point Brown, Grays Harbor, Washington	NOS	9441156	46.95	-124.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:24:00	\N	1.04	-00:09:00	\N	1.06	\N	\N	Point Brown	WA
63014	Cosmopolis, Chehalis River, Grays Harbor, Washington	NOS	9441158	46.9667	-123.778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:15:00	\N	1.12	00:26:00	\N	1.23	\N	\N	Cosmopolis, Chehalis River	WA
63015	Point Grenville, Washington	NOS	9441627	47.3033	-124.27	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:44:00	\N	0.9	-00:37:00	\N	0.92	\N	\N	Point Grenville	WA
63016	James Island, Washington	NOS	9442388	47.9067	-124.647	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:32:00	\N	0.96	-00:39:00	\N	0.92	\N	\N	James Island	WA
63017	La Push, Quillayute River, Washington (sub)	NOS	9442396	47.91333333333333	-124.6369444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:34:00	\N	0.94	-00:39:00	\N	0.91	\N	\N	La Push, Quillayute River	WA
63018	Makah Bay, Washington	NOS	9442861	48.2967	-124.672	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:28:00	\N	1.1	-00:25:00	\N	0.99	\N	\N	Makah Bay	WA
63019	Tatoosh Island, Cape Flattery, Strait of Juan de Fuca, Washington	NOS	9442971	48.391700744628906	-124.73699951171875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60937	-00:10:00	\N	1	-00:08:00	\N	1.01	\N	\N	Tatoosh Island, Cape Flattery	WA
63020	Twin Rivers, Strait of Juan de Fuca, Washington	NOS	9443644	48.17499923706055	-123.94999694824219	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60937	00:59:00	\N	1.2	00:47:00	\N	0.89	\N	\N	Twin Rivers	WA
63021	Crescent Bay, Strait of Juan de Fuca, Washington	NOS	9443826	48.1617	-123.725	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-02:02:00	\N	0.8	-02:41:00	\N	0.8	\N	\N	Crescent Bay	WA
63022	Port Angeles, Strait Of Juan De Fuca, Washington (sub)	NOS	9444090	48.12472222222223	-123.4411388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-01:14:00	\N	0.77	-01:45:00	\N	0.83	\N	\N	Port Angeles	WA
63023	Ediz Hook, Port Angeles, Strait of Juan de Fuca, Washington	NOS	9444122	48.14	-123.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-01:13:00	\N	0.9	-01:37:00	\N	0.81	\N	\N	Ediz Hook, Port Angeles	WA
63024	Dungeness, Strait of Juan de Fuca, Washington	NOS	9444471	48.1667	-123.117	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:38:00	\N	0.9	-00:54:00	\N	0.9	\N	\N	Dungeness	WA
63025	Sequim Bay entrance, Strait of Juan de Fuca, Washington	NOS	9444555	48.0817	-123.043	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:07:00	\N	0.94	-00:39:00	\N	0.94	\N	\N	Sequim Bay entrance	WA
63026	Gardiner, Discovery Bay, Strait of Juan de Fuca, Washington	NOS	9444705	48.0583	-122.917	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:17:00	\N	0.94	-00:47:00	\N	0.94	\N	\N	Gardiner, Discovery Bay	WA
63027	Mystery Bay, Marrowstone Island, Admiralty Inlet, Washington	NOS	9444971	48.0583	-122.692	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:52:00	\N	0.99	00:15:00	\N	0.95	\N	\N	Mystery Bay, Marrowstone Island	WA
63028	Marrowstone Point, Admiralty Inlet, Washington	NOS	9444972	48.0917	-122.69	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:05:00	-0.1	\N	00:02:00	0.4	\N	\N	\N	Marrowstone Point	WA
63029	Foulweather Bluff, Washington (sub)	NOS	9445016	47.9267	-122.617	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:07:00	\N	0.98	-00:11:00	\N	0.89	\N	\N	Foulweather Bluff	WA
63030	Port Ludlow, Washington	NOS	9445017	47.925	-122.68	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:14:00	\N	0.95	-00:14:00	\N	0.87	\N	\N	Port Ludlow	WA
63031	Port Gamble, Washington	NOS	9445059	47.8583	-122.58	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:05:00	\N	0.95	-00:09:00	\N	0.9	\N	\N	Port Gamble	WA
63032	Lofall, Washington	NOS	9445088	47.815	-122.657	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:06:00	\N	1.01	-00:08:00	\N	0.94	\N	\N	Lofall	WA
63033	Bangor Wharf, Washington (sub)	NOS	9445133	47.7483	-122.727	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:01:00	\N	1.03	-00:06:00	\N	0.97	\N	\N	Bangor Wharf	WA
63034	Whitney Point, Dabob Bay, Washington	NOS	9445246	47.7617	-122.85	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:02:00	\N	1.06	-00:05:00	\N	1.01	\N	\N	Whitney Point, Dabob Bay	WA
63035	Zelatched Point, Dabob Bay, Washington	NOS	9445269	47.7117	-122.822	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:05:00	\N	1.02	-00:09:00	\N	1	\N	\N	Zelatched Point, Dabob Bay	WA
63036	Quilcene, Quilcene Bay, Dabob Bay, Washington	NOS	9445272	47.8	-122.858	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:02:00	\N	1.04	-00:08:00	\N	1	\N	\N	Quilcene, Quilcene Bay, Dabob Bay	WA
63037	Pleasant Harbor, Washington	NOS	9445293	47.665	-122.912	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:01:00	\N	1.02	-00:14:00	\N	1.01	\N	\N	Pleasant Harbor	WA
63038	Seabeck, Seabeck Bay, Washington	NOS	9445303	47.6417	-122.828	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:01:00	\N	1.06	-00:04:00	\N	1.01	\N	\N	Seabeck, Seabeck Bay	WA
63039	Triton Head, Washington	NOS	9445326	47.6033	-122.982	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:06:00	\N	1.02	-00:06:00	\N	1	\N	\N	Triton Head	WA
63041	Lynch Cove Dock, Washington	NOS	9445441	47.4183	-122.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:06:00	\N	1.08	00:00:00	\N	1.07	\N	\N	Lynch Cove Dock	WA
63042	Hansville, Puget Sound, Washington	NOS	9445526	47.9183	-122.545	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:08:00	\N	0.98	-00:07:00	\N	0.92	\N	\N	Hansville	WA
63043	Kingston, Appletree Cove, Puget Sound, Washington	NOS	9445639	47.7967	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:05:00	\N	1	-00:05:00	\N	0.97	\N	\N	Kingston, Appletree Cove	WA
63044	Port Jefferson, Puget Sound, Washington	NOS	9445683	47.7467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:04:00	\N	0.98	-00:03:00	\N	0.95	\N	\N	Port Jefferson	WA
63045	Poulsbo, Liberty Bay, Puget Sound, Washington	NOS	9445719	47.725	-122.638	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:12:00	\N	1.01	00:05:00	\N	1.03	\N	\N	Poulsbo, Liberty Bay	WA
63046	Port Madison, Puget Sound, Washington	NOS	9445753	47.705	-122.525	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:03:00	\N	0.99	00:09:00	\N	1	\N	\N	Port Madison	WA
63047	Brownsville, Port Orchard, Puget Sound, Washington	NOS	9445832	47.6517	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:09:00	\N	1.03	00:07:00	\N	1.04	\N	\N	Brownsville, Port Orchard	WA
63048	Eagle Harbor, Bainbridge Island, Puget Sound, Washington	NOS	9445882	47.62	-122.515	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:05:00	\N	1.02	00:04:00	\N	1	\N	\N	Eagle Harbor, Bainbridge Island	WA
63049	Tracyton, Dyes Inlet, Puget Sound, Washington	NOS	9445901	47.61	-122.66	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:53:00	\N	0.95	00:28:00	\N	1.06	\N	\N	Tracyton, Dyes Inlet	WA
63050	Port Blakely, Puget Sound, Washington	NOS	9445913	47.5967	-122.51	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:04:00	\N	0.99	00:04:00	\N	1.01	\N	\N	Port Blakely	WA
63051	Clam Bay, Rich Passage, Puget Sound, Washington	NOS	9445938	47.5733	-122.543	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:04:00	\N	1	00:03:00	\N	1.01	\N	\N	Clam Bay, Rich Passage	WA
63052	Harper, Yukon Harbor, Puget Sound, Washington	NOS	9445993	47.5233	-122.517	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:01:00	\N	0.99	-00:06:00	\N	1.02	\N	\N	Harper, Yukon Harbor	WA
63053	Point Vashon, Vashon Island, Puget Sound, Washington	NOS	9446025	47.5117	-122.463	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:02:00	\N	1.01	00:02:00	\N	1.02	\N	\N	Point Vashon, Vashon Island	WA
63054	Des Moines, East Passage, Puget Sound, Washington	NOS	9446248	47.4	-122.328	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:08:00	\N	1.01	00:05:00	\N	1.03	\N	\N	Des Moines, East Passage	WA
63055	Burton, Quartermaster Hbr. (inside), Vashon I., Puget Sound, Washington	NOS	9446254	47.395	-122.463	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:03:00	\N	1.02	00:01:00	\N	1.06	\N	\N	Burton, Quartermaster Hbr. (inside), Vashon I.	WA
63056	Allyn, Case Inlet, Puget Sound, Washington	NOS	9446281	47.3833	-122.823	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:59:00	\N	1.07	00:48:00	\N	1.26	\N	\N	Allyn, Case Inlet	WA
63057	Vaughn, Case Inlet, Puget Sound, Washington	NOS	9446366	47.3417	-122.775	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:57:00	\N	1.06	00:51:00	\N	1.26	\N	\N	Vaughn, Case Inlet	WA
63058	Gig Harbor, Puget Sound, Washington	NOS	9446369	47.34	-122.588	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:22:00	\N	0.99	00:18:00	\N	1.05	\N	\N	Gig Harbor	WA
63059	Tahlequah, Neil Pt., Dalco Passage, Vashon I., Puget Sound, Washington	NOS	9446375	47.3333	-122.507	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:05:00	\N	1.01	00:04:00	\N	1.05	\N	\N	Tahlequah, Neil Pt., Dalco Passage, Vashon I.	WA
63060	Horsehead Bay, Carr Inlet, Puget Sound, Washington	NOS	9446451	47.3017	-122.682	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:46:00	\N	1.05	00:38:00	\N	1.2	\N	\N	Horsehead Bay, Carr Inlet	WA
63061	Tacoma, Commencement Bay, Sitcum Waterway, Puget Sound, Washington (sub)	NOS	9446484	47.26667	-122.41333333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:04:00	\N	1	00:04:00	\N	1.04	\N	\N	Tacoma, Commencement Bay, Sitcum Waterway	WA
63062	Tacoma Narrows Bridge, Puget Sound, Washington	NOS	9446486	47.2717	-122.552	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:23:00	\N	1.02	00:28:00	\N	1.11	\N	\N	Tacoma Narrows Bridge	WA
63063	Walkers Landing, Pickering Passage, Puget Sound, Washington	NOS	9446489	47.2817	-122.923	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:55:00	\N	1.07	00:44:00	\N	1.26	\N	\N	Walkers Landing, Pickering Passage	WA
63064	Arletta, Hale Passage, Puget Sound, Washington	NOS	9446491	47.28	-122.652	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:40:00	\N	1.04	00:31:00	\N	1.18	\N	\N	Arletta, Hale Passage	WA
63065	Home, Von Geldern Cove, Carr Inlet, Puget Sound, Washington	NOS	9446500	47.275	-122.758	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:45:00	\N	1.04	00:37:00	\N	1.19	\N	\N	Home, Von Geldern Cove, Carr Inlet	WA
63066	McMicken Island, Case Inlet, Puget Sound, Washington	NOS	9446583	47.2467	-122.862	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:52:00	\N	1.06	00:40:00	\N	1.24	\N	\N	McMicken Island, Case Inlet	WA
63067	Shelton, Oakland Bay, Puget Sound, Washington	NOS	9446628	47.215	-123.083	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	02:05:00	\N	0.92	01:26:00	\N	1.26	\N	\N	Shelton, Oakland Bay	WA
63068	Longbranch, Filucy Bay, Puget Sound, Washington	NOS	9446638	47.21	-122.753	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:47:00	\N	1.02	00:38:00	\N	1.2	\N	\N	Longbranch, Filucy Bay	WA
63069	Arcadia, Totten Inlet, Puget Sound, Washington	NOS	9446666	47.1967	-122.938	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	01:05:00	\N	1.06	00:49:00	\N	1.28	\N	\N	Arcadia, Totten Inlet	WA
63070	Devils Head, Drayton Passage, Puget Sound, Washington	NOS	9446671	47.1667	-122.763	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:50:00	\N	1.1	00:40:00	\N	1.25	\N	\N	Devils Head, Drayton Passage	WA
63071	Steilacoom, Cormorant Passage, Puget Sound, Washington	NOS	9446714	47.1733	-122.603	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:45:00	\N	1.05	00:37:00	\N	1.2	\N	\N	Steilacoom, Cormorant Passage	WA
63072	Barron Point, Little Snookum Inlet Entrance, Puget Sound, Washington	NOS	9446742	47.1567	-123.008	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:59:00	\N	1.06	00:50:00	\N	1.29	\N	\N	Barron Point, Little Snookum Inlet Entrance	WA
63073	Henderson Inlet, Puget Sound, Washington	NOS	9446752	47.155	-122.838	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:58:00	\N	1.06	00:47:00	\N	1.24	\N	\N	Henderson Inlet	WA
63074	Dofflemeyer Point, Boston Hbr., Budd Inlet, Puget Sound, Washington	NOS	9446800	47.1417	-122.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:57:00	\N	1.09	00:44:00	\N	1.28	\N	\N	Dofflemeyer Point, Boston Hbr., Budd Inlet	WA
63075	Dupont Wharf, Nisqually Reach, Puget Sound, Washington	NOS	9446828	47.1183	-122.665	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:49:00	\N	1.04	00:41:00	\N	1.2	\N	\N	Dupont Wharf, Nisqually Reach	WA
63076	Olympia, Budd Inlet, Puget Sound, Washington	NOS	9446969	47.06	-122.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:57:00	\N	1.08	00:45:00	\N	1.29	\N	\N	Olympia, Budd Inlet	WA
63077	Duwamish Waterway, Eighth Ave. South, Puget Sound, Washington	NOS	9447029	47.535	-122.322	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:11:00	\N	0.95	00:10:00	\N	0.97	\N	\N	Duwamish Waterway, Eighth Ave. South	WA
63078	Lockheed Shipyard, Harbor Island, Puget Sound, Washington	NOS	9447110	47.585	-122.362	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Lockheed Shipyard, Harbor Island	WA
63079	Meadow Point, Shilshole Bay, Puget Sound, Washington	NOS	9447265	47.6883	-122.403	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:01:00	\N	0.99	00:00:00	\N	0.98	\N	\N	Meadow Point, Shilshole Bay	WA
63080	Edmonds, Puget Sound, Washington	NOS	9447427	47.8133	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:04:00	\N	0.99	00:00:00	\N	0.96	\N	\N	Edmonds	WA
63081	Glendale, Whidbey Island, Washington	NOS	9447814	47.94	-122.357	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:03:00	\N	0.99	00:01:00	\N	0.97	\N	\N	Glendale, Whidbey Island	WA
63082	Bush Point, Whidbey Island, Admiralty Inlet, Washington	NOS	9447854	48.0333	-122.607	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:45:00	\N	1.08	00:10:00	\N	1.09	\N	\N	Bush Point, Whidbey Island	WA
63083	Holly Farms Harbor, Holmes Harbor, Whidbey I., Washington	NOS	9447855	48.0267	-122.535	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:04:00	\N	0.99	00:01:00	\N	1.01	\N	\N	Holly Farms Harbor, Holmes Harbor, Whidbey I.	WA
63084	Sandy Point, Whidbey Island, Washington	NOS	9447856	48.035	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:01:00	\N	1	00:03:00	\N	0.99	\N	\N	Sandy Point, Whidbey Island	WA
63085	Admiralty Head, Admiralty Inlet, Washington	NOS	9447905	48.1583	-122.668	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:20:00	-0.1	\N	-00:11:00	0	\N	\N	\N	Admiralty Head	WA
63086	Coupeville, Penn Cove, Whidbey Island, Washington	NOS	9447929	48.2233	-122.69	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:09:00	\N	0.99	00:15:00	\N	1.01	\N	\N	Coupeville, Penn Cove, Whidbey Island	WA
63087	Point Partridge, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447934	48.2317	-122.765	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:15:00	\N	0.92	-00:11:00	\N	0.92	\N	\N	Point Partridge, Whidbey Island	WA
63088	Sunset Beach, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447951	48.2833	-122.728	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:16:00	\N	0.95	-00:27:00	\N	0.87	\N	\N	Sunset Beach, Whidbey Island	WA
63089	Crescent Harbor, N. Whidbey Island, Washington	NOS	9447952	48.2867	-122.617	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:04:00	\N	0.99	00:04:00	\N	1.03	\N	\N	Crescent Harbor, N. Whidbey Island	WA
63090	Smith Island, Strait of Juan de Fuca, Washington	NOS	9447985	48.3167	-122.837	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:25:00	\N	0.83	-00:13:00	\N	0.83	\N	\N	Smith Island	WA
63091	Ala Spit, Whidbey Island, Washington	NOS	9447993	48.3967	-122.587	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:26:00	\N	0.95	00:12:00	\N	0.92	\N	\N	Ala Spit, Whidbey Island	WA
63092	Cornet Bay, Deception Pass, Washington	NOS	9447995	48.4017	-122.623	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:26:00	\N	0.95	00:15:00	\N	0.89	\N	\N	Cornet Bay, Deception Pass	WA
63093	Kayak Point, Washington	NOS	9448094	48.1367	-122.367	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:02:00	\N	0.99	00:00:00	\N	0.99	\N	\N	Kayak Point	WA
63094	La Conner, Swinomish Channel, Washington	NOS	9448558	48.3917	-122.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:39:00	\N	0.95	00:21:00	\N	0.9	\N	\N	La Conner, Swinomish Channel	WA
63095	Yokeko Point, Deception Pass, Washington (sub)	NOS	9448601	48.4133	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:38:00	-0.2	\N	00:26:00	-1	\N	\N	\N	Yokeko Point, Deception Pass	WA
63096	Burrows Bay (Allan Island), Washington	NOS	9448683	48.46	-122.695	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:03:00	\N	0.88	00:09:00	\N	0.95	\N	\N	Burrows Bay (Allan Island)	WA
63097	Ship Harbor, Fidalgo Island, Washington	NOS	9448772	48.5067	-122.677	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:29:00	\N	1.02	00:18:00	\N	0.93	\N	\N	Ship Harbor, Fidalgo Island	WA
63098	Anacortes, Guemes Channel, Washington	NOS	9448794	48.5183	-122.62	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:33:00	\N	1	00:22:00	\N	0.96	\N	\N	Anacortes, Guemes Channel	WA
63099	Strawberry Bay, Cypress Island, Washington	NOS	9448876	48.565	-122.722	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:52:00	\N	0.95	00:34:00	\N	0.95	\N	\N	Strawberry Bay, Cypress Island	WA
63100	Tide Point, Cypress Island, Washington	NOS	9448918	48.5867	-122.748	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:41:00	\N	0.95	00:31:00	\N	0.94	\N	\N	Tide Point, Cypress Island	WA
63101	Gooseberry Point, Hale Passage, Washington	NOS	9449184	48.73	-122.67	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:10:00	\N	0.97	00:41:00	\N	1.04	\N	\N	Gooseberry Point	WA
63102	Bellingham, Bellingham Bay, Washington	NOS	9449211	48.745	-122.495	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:11:00	\N	0.94	00:43:00	\N	0.99	\N	\N	Bellingham	WA
63103	Sandy Point, Lummi Bay, Washington	NOS	9449292	48.79	-122.708	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:24:00	\N	1.03	00:52:00	\N	1.05	\N	\N	Sandy Point, Lummi Bay	WA
63104	Drayton Harbor, Blaine, Strait of Georgia, Washington (sub)	NOS	9449679	48.9917	-122.765	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:27:00	\N	1.06	00:54:00	\N	1.11	\N	\N	Blaine, Semiahmoo Bay	WA
63105	Patos Island Wharf, Boundary Pass, Washington	NOS	9449704	48.7867	-122.97	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:30:00	0	\N	01:03:00	0.2	\N	\N	\N	Patos Island Wharf	WA
63106	Echo Bay, Sucia Islands, Strait of Georgia, Washington	NOS	9449712	48.7567	-122.897	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:34:00	0	\N	01:01:00	0.1	\N	\N	\N	Echo Bay, Sucia Islands	WA
63107	Orcas, Orcas Island, Washington	NOS	9449798	48.6	-122.95	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:56:00	\N	0.9	00:33:00	\N	0.9	\N	\N	Orcas, Orcas Island	WA
63108	Roche Harbor, San Juan Island, Haro Strait, Washington	NOS	9449834	48.61	-123.155	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:47:00	\N	0.99	00:33:00	\N	0.9	\N	\N	Roche Harbor, San Juan Island	WA
63109	Friday Harbor, San Juan Island, San Juan Channel, Washington (sub)	NOS	9449880	48.54530555555556	-123.0128888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:51:00	\N	0.92	00:33:00	\N	0.91	\N	\N	Friday Harbor, San Juan Island	WA
63110	Shaw Island, Ferry Terminal, Harney Channel, San Juan Channel, Washington	NOS	9449904	48.585	-122.928	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:56:00	\N	0.99	00:31:00	\N	0.9	\N	\N	Shaw Island, Ferry Terminal, Harney Channel	WA
63111	Aleck Bay, Lopez Island, Washington	NOS	9449994	48.425	-122.853	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:08:00	\N	0.88	-00:18:00	\N	0.88	\N	\N	Aleck Bay, Lopez Island	WA
63112	Minnie Bay, Alaska	NOS	9450041	54.7267	-132.302	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:00:00	0.1	\N	-00:05:00	2.7	\N	\N	\N	Minnie Bay	AK
63113	Security Cove, Dall Island, Alaska	NOS	9450055	54.7483	-132.855	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:24:00	0	\N	-00:20:00	1	\N	\N	\N	Security Cove	AK
63114	Nakat Harbor, Dixon Entrance, Alaska	NOS	9450104	54.82	-130.7	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:09:00	\N	0.89	00:01:00	\N	0.95	\N	\N	Nakat Harbor, Alaska	AK
63115	American Bay, Kaigani Strait, Alaska	NOS	9450125	54.85	-132.83	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:01:00	0	\N	00:01:00	2.5	\N	\N	\N	American Bay, Kaigani Strait	AK
63116	Hunter Bay, Alaska	NOS	9450139	54.8717	-132.322	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:03:00	0.1	\N	-00:02:00	2.7	\N	\N	\N	Hunter Bay	AK
63117	Kelp Island Passage, Duke Island, Dixon Entrance, Alaska	NOS	9450142	54.8767	-131.3	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:03:00	\N	0.96	-00:04:00	\N	0.94	\N	\N	Kelp Island Passage, Duke Island	AK
63118	Elbow Bay, Alaska	NOS	9450158	54.9	-132.653	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:04:00	0.1	\N	-00:04:00	2.6	\N	\N	\N	Elbow Bay	AK
63119	Morse Cove, Duke Island, Revillagigedo Channel, Alaska	NOS	9450172	54.92	-131.255	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:15:00	\N	0.96	00:03:00	\N	0.96	\N	\N	Morse Cove, Duke Island	AK
63120	Kassa Inlet entrance, Alaska	NOS	9450176	54.9267	-132.522	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:01:00	0.1	\N	-00:03:00	2.6	\N	\N	\N	Kassa Inlet entrance	AK
63121	Ingraham Bay, Prince of Wales Island, Alaska	NOS	9450212	54.98	-132.007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:04:00	\N	0.96	00:03:00	\N	0.93	\N	\N	Ingraham Bay, Prince of Wales Island	AK
63122	Mabel Island, Alaska	NOS	9450226	55	-132.592	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:01:00	0.1	\N	-00:10:00	2.8	\N	\N	\N	Mabel Island	AK
63123	Menefee Anch., Prince of Wales Island, Alaska	NOS	9450244	55.0267	-132.013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.89	-00:02:00	\N	0.94	\N	\N	Menefee Anch., Prince of Wales Island	AK
63124	Kah Shakes Cove, Revillagigedo Channel, Alaska	NOS	9450254	55.0417	-130.98	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:06:00	\N	0.96	00:00:00	\N	0.97	\N	\N	Kah Shakes Cove	AK
63125	Keete Island, Nutkwa Inlets, Alaska	NOS	9450258	55.0467	-132.577	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:05:00	0.1	\N	-00:13:00	2.8	\N	\N	\N	Keete Island, Nutkwa Inlets	AK
63126	Niblack Anchorage, Moira Sound, Alaska	NOS	9450271	55.0667	-132.12	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:09:00	\N	0.96	00:03:00	\N	0.94	\N	\N	Niblack Anchorage, Moira Sound	AK
63127	Sakie Bay, Dall Island, Alaska	NOS	9450272	55.0667	-133.2	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:05:00	0	\N	00:01:00	0.3	\N	\N	\N	Sakie Bay	AK
63128	Tamgas Harbor, Annette Island, Alaska	NOS	9450273	55.0667	-131.542	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:08:00	\N	0.89	-00:09:00	\N	0.98	\N	\N	Tamgas Harbor, Annette Island	AK
63129	Keete Inlet, Alaska	NOS	9450281	55.08	-132.49	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:01:00	0.1	\N	-00:11:00	2.9	\N	\N	\N	Keete Inlet	AK
63130	Mud Bay, Hetta Inlet, Alaska	NOS	9450282	55.0817	-132.632	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:01:00	0.1	\N	-00:05:00	2.8	\N	\N	\N	Mud Bay	AK
63131	View Cove, Tlevak Strait, Alaska	NOS	9450283	55.0833	-133.017	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:02:00	0	\N	-00:02:00	2.8	\N	\N	\N	View Cove	AK
63132	Boca de Quadra, Revillagigedo Channel, Alaska	NOS	9450305	55.1167	-130.798	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:02:00	\N	0.98	00:00:00	\N	0.98	\N	\N	Boca de Quadra	AK
63133	Sea Otter Harbor, Dall Island, Alaska	NOS	9450312	55.1267	-133.167	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:04:00	-0.1	\N	-00:04:00	-0.2	\N	\N	\N	Sea Otter Harbor	AK
63134	Metlakatla, Port Chester, Alaska (sub)	NOS	9450314	55.1283	-131.567	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:07:00	\N	0.96	-00:10:00	\N	0.95	\N	\N	Metlakatla, Port Chester	AK
63135	Nehenta Bay, Gravina Island, Alaska	NOS	9450339	55.1667	-131.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:01:00	\N	0.96	-00:01:00	\N	0.95	\N	\N	Nehenta Bay, Gravina Island	AK
63136	South Pass, Sukkwan Strait, Tlevak Strait, Alaska	NOS	9450341	55.1667	-132.87	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:02:00	0.1	\N	-00:02:00	2.9	\N	\N	\N	South Pass, Sukkwan Strait	AK
63137	Saltery Point, Tlevak Strait, Alaska	NOS	9450351	55.1817	-132.795	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:05:00	0.1	\N	-00:08:00	2.9	\N	\N	\N	Saltery Point	AK
63138	North Pass, West End, Tlevak Strait, Alaska	NOS	9450366	55.205	-132.94	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:06:00	0.1	\N	-00:12:00	3	\N	\N	\N	North Pass, West End	AK
63139	Copper Harbor, Hetta Inlet, Alaska	NOS	9450369	55.21	-132.625	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:08:00	0.1	\N	-00:10:00	2.8	\N	\N	\N	Copper Harbor	AK
63140	Lancaster Cove, Cholmondeley Sound, Alaska	NOS	9450373	55.2133	-132.095	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:03:00	\N	0.96	00:05:00	\N	0.98	\N	\N	Lancaster Cove, Cholmondeley Sound	AK
63141	Alva Bay, Revillagigedo Island, Alaska	NOS	9450382	55.2283	-131.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:03:00	\N	0.96	-00:05:00	\N	0.98	\N	\N	Alva Bay, Revillagigedo Island	AK
63142	Natalia Point, Tlevak Strait, Alaska	NOS	9450387	55.2333	-133.043	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:01:00	0.1	\N	-00:05:00	2.9	\N	\N	\N	Natalia Point	AK
63143	Divide Head, Cholmondeley Sound, Alaska	NOS	9450399	55.2517	-132.3	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:08:00	\N	0.96	-00:05:00	\N	0.98	\N	\N	Divide Head, Cholmondeley Sound	AK
63144	Block Island, Tlevak Strait, Alaska	NOS	9450406	55.263301849365234	-133.11500549316406	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:02:00	\N	1	00:07:00	\N	1.2	\N	\N	Block Island, Tlevak Narrows	AK
63145	Soda Bay, Tlevak Strait, Alaska	NOS	9450413	55.275	-132.967	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:07:00	0.1	\N	00:03:00	3	\N	\N	\N	Soda Bay	AK
63146	Sulzer, Hetta Inlet, Alaska	NOS	9450421	55.285	-132.622	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:08:00	0.1	\N	-00:02:00	2.9	\N	\N	\N	Sulzer	AK
63147	Mop Point, Thorne Arm, Revillagigedo Channel, Alaska	NOS	9450483	55.3833	-131.235	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:03:00	\N	0.98	-00:05:00	\N	0.98	\N	\N	Mop Point, Thorne Arm	AK
63148	Ward Cove, Revillagigedo Channel, Alaska	NOS	9450492	55.3983	-131.727	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:03:00	\N	0.96	-00:05:00	\N	1.02	\N	\N	Ward Cove	AK
63149	Saltery Cove, Skowl Arm, Kasaan Bay, Alaska	NOS	9450495	55.4017	-132.328	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:02:00	\N	1.01	00:04:00	\N	1.01	\N	\N	Saltery Cove, Skowl Arm	AK
63150	Vallenar Point, Alaska	NOS	9450511	55.4267	-131.847	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:06:00	\N	0.96	-00:01:00	\N	0.99	\N	\N	Vallenar Point	AK
63151	Coon Island, George Inlet, Revillagigedo Channel, Alaska	NOS	9450533	55.4617	-131.505	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:07:00	\N	0.96	-00:03:00	\N	0.99	\N	\N	Coon Island, George Inlet	AK
63152	Hollis Anchorage, Kasaan Bay, Alaska	NOS	9450544	55.48	-132.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:02:00	\N	1.01	00:06:00	\N	1.03	\N	\N	Hollis Anchorage	AK
63153	Craig, Klawock Inlet, Bucareli Bay, Alaska (sub)	NOS	9450551	55.4883	-133.142	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:08:00	\N	0.94	-00:08:00	\N	1.02	\N	\N	Craig, Klawock Inlet	AK
63154	Steamboat Bay, Noyes Island, Gulf of Esquibel, Alaska	NOS	9450578	55.5333	-133.637	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:13:00	\N	0.93	-00:12:00	\N	1.04	\N	\N	Steamboat Bay, Noyes Island	AK
63155	Kasaan, Kasaan Bay, Alaska	NOS	9450581	55.535	-132.397	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:03:00	\N	1.01	00:05:00	\N	1.02	\N	\N	Kasaan	AK
63156	Cruz Pass, San Fernando Island, Bucareli Bay, Alaska	NOS	9450584	55.5417	-133.315	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:12:00	-0.1	\N	-00:15:00	0.1	\N	\N	\N	Cruz Pass, San Fernando Island	AK
63157	Loring, Naha Bay, Alaska	NOS	9450624	55.6017	-131.632	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:06:00	\N	0.96	-00:02:00	\N	1.02	\N	\N	Loring, Naha Bay	AK
63158	Lindeman Cove, Kasaan Bay, Alaska (sub)	NOS	9450625	55.6017	-132.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:03:00	\N	1.01	00:06:00	\N	1.02	\N	\N	Lindeman Cove	AK
63159	Rudyerd Bay, Alaska	NOS	9450651	55.6417	-130.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:02:00	\N	0.96	00:01:00	\N	1.02	\N	\N	Rudyerd Bay	AK
63160	Anguilla Island, Gulf of Esquibel, Alaska	NOS	9450679	55.6833	-133.587	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:14:00	-0.1	\N	-00:18:00	0.4	\N	\N	\N	Anguilla Island	AK
63161	Nossuk Bay, Tonowek Bay, Gulf of Esquibel, Alaska (sub)	NOS	9450711	55.72166666666666	-133.35	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:14:00	\N	0.94	-00:14:00	\N	1.05	\N	\N	Nossuk Bay, Tonowek Bay	AK
63162	Davis River entrance, Alaska	NOS	9450729	55.76	-130.177	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:00:00	\N	0.96	-00:02:00	\N	1.08	\N	\N	Davis River entrance, Alaska	AK
63163	Port Alice, Heceta Island, Davidson Inlet, Alaska	NOS	9450768	55.8117	-133.605	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:14:00	0	\N	-00:20:00	0.9	\N	\N	\N	Port Alice, Heceta Island	AK
63164	Ratz Harbor, Prince of Wales Island, Alaska	NOS	9450815	55.88	-132.595	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:00:00	\N	0.99	00:09:00	\N	1.03	\N	\N	Ratz Harbor, Prince of Wales Island	AK
63165	Tuxekan, 0.5 mile south of, Davidson Inlet, Alaska	NOS	9450817	55.8833	-133.243	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:07:00	-0.1	\N	-00:17:00	0.9	\N	\N	\N	Tuxekan, 0.5 mile south of	AK
63166	Coronation Island, Alaska	NOS	9450829	55.9033	-134.118	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:17:00	0	\N	-00:16:00	0.8	\N	\N	\N	Coronation Island	AK
63167	Yes Cannery, Yes Bay, Alaska	NOS	9450836	55.9133	-131.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.96	00:00:00	\N	1.02	\N	\N	Yes Cannery, Yes Bay	AK
63168	El Capitan Island, Davidson Inlet, Alaska	NOS	9450851	55.9367	-133.325	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:10:00	-0.1	\N	-00:11:00	0.9	\N	\N	\N	El Capitan Island	AK
63169	Edna Bay, Davidson Inlet, Alaska	NOS	9450859	55.95	-133.662	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:08:00	0	\N	-00:20:00	0.9	\N	\N	\N	Edna Bay	AK
63170	Pole Anchorage, Kosciusko Island, Alaska	NOS	9450862	55.955	-133.81	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:22:00	-0.1	\N	-00:22:00	1.4	\N	\N	\N	Pole Anchorage, Kosciusko Island	AK
63171	Fitzgibbon Cove, Alaska	NOS	9450879	55.9833	-131.175	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:01:00	\N	0.96	-00:05:00	\N	1.02	\N	\N	Fitzgibbon Cove	AK
63172	Lake Bay, Alaska	NOS	9450904	56.0233	-132.92	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.89	00:10:00	\N	1.03	\N	\N	Lake Bay	AK
63173	Beck Island, Clarence Strait, Alaska	NOS	9450906	56.0467	-132.862	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:05:00	\N	1.01	00:10:00	\N	1.05	\N	\N	Beck Island, Clarence Strait	AK
63174	Kuiu Island, Affleck Canal, Alaska	NOS	9450913	56.0369	-134.115	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:06:00	\N	0.95	-00:09:00	\N	1.09	\N	\N	Affleck Canal entrance, Kuiu Island	AK
63175	El Capitan Passage, Alaska (sub)	NOS	9450937	56.0733	-133.313	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:02:00	-0.1	\N	-00:05:00	0.9	\N	\N	\N	El Capitan Passage, S. of Devilfish Bay	AK
63176	Thorne Island, Whale Passage, Alaska	NOS	9450938	56.0583	-132.968	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.98	00:12:00	\N	1.04	\N	\N	Thorne Island, Whale Passage	AK
63177	Point St. Albans, Alaska	NOS	9450943	56.0817	-133.97	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:13:00	0	\N	-00:17:00	1.4	\N	\N	\N	Point St. Albans	AK
63178	Thoms Point, Zimovia Strait, Alaska (sub)	NOS	9450970	56.1183	-132.078	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.99	00:07:00	\N	1.06	\N	\N	Thoms Point, Zimovia Strait	AK
63179	Blashke Island, Clarence Strait, Alaska	NOS	9450973	56.1267	-132.895	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:24:00	\N	0.93	00:13:00	\N	1.03	\N	\N	Blashke Island	AK
63181	Shakan Strait, Kosciusko Island, Alaska	NOS	9450987	56.1483	-133.46	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:10:00	\N	0.95	-00:07:00	\N	1.16	\N	\N	Shakan Strait, Kosciusko Island	AK
63182	Kell Bay, Affleck Canal, Kuiu Island, Alaska	NOS	9450988	56.15	-134.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:01:00	0	\N	00:01:00	1.3	\N	\N	\N	Kell Bay, Affleck Canal, Kuiu Island	AK
63183	Table Bay, Kuiu Island, Alaska	NOS	9451001	56.1667	-134.245	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:13:00	0	\N	-00:15:00	1.1	\N	\N	\N	Table Bay, Kuiu Island	AK
63184	Point Harrington, Clarence Strait, Alaska (sub)	NOS	9451005	56.1783	-132.697	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.97	00:09:00	\N	1.04	\N	\N	Point Harrington	AK
63185	Bradfield Canal, Alaska (sub)	NOS	9451012	56.1833	-131.572	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:05:00	\N	0.99	00:11:00	\N	1.08	\N	\N	Bradfield Canal, Ernest Sound	AK
63186	Village Rock, Zimovia Strait, Alaska (sub)	NOS	9451037	56.22	-132.297	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.97	00:09:00	\N	1.05	\N	\N	Village Rock, Zimovia Strait	AK
63187	Port Alexander, Baranof Island, Alaska (sub)	NOS	9451054	56.2467	-134.647	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:10:00	\N	1.01	00:07:00	\N	1.14	\N	\N	Port Alexander, Baranof Island	AK
63188	Bushy Island, Snow Passage, Alaska (sub)	NOS	9451074	56.2767	-132.985	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.93	00:03:00	\N	0.95	\N	\N	Bushy Island, Snow Passage	AK
63189	Port Beauclerc, Kuiu Island, Alaska	NOS	9451082	56.2883	-133.962	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:12:00	-0.1	\N	-00:14:00	1.9	\N	\N	\N	Port Beauclerc, Kuiu Island	AK
63190	Port Malmesbury, Kuiu Island, Alaska	NOS	9451093	56.305	-134.238	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:13:00	0.1	\N	00:04:00	1.2	\N	\N	\N	Port Malmesbury, Kuiu Island	AK
63191	Port Protection, Prince of Wales Island., Alaska	NOS	9451095	56.3083	-133.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:11:00	0	\N	-00:13:00	2.4	\N	\N	\N	Port Protection, Prince of Wales Island.	AK
63192	Reef Point, Stikine Strait, Alaska (sub)	NOS	9451124	56.3533	-132.553	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:02:00	\N	0.96	00:09:00	\N	1.04	\N	\N	Reef Point, Stikine Strait	AK
63193	Reid Bay, Alaska	NOS	9451148	56.3883	-133.883	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:19:00	0	\N	-00:11:00	2.5	\N	\N	\N	Reid Bay	AK
63194	Port Walter, Baranof Island, Alaska	NOS	9451151	56.3917	-134.66	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:13:00	0.1	\N	00:04:00	1.5	\N	\N	\N	Port Walter, Baranof Island	AK
63195	Madan Bay, Clarence Strait, Alaska (sub)	NOS	9451152	56.3922	-132.169	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:04:00	\N	0.98	00:12:00	\N	1.05	\N	\N	Madan Bay	AK
63196	Sumner Island, Alaska	NOS	9451163	56.41	-133.793	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:12:00	0	\N	-00:19:00	2.6	\N	\N	\N	Sumner Island	AK
63197	Wrangell, Wrangell Island, Alaska (sub)	NOS	9451204	56.47	-132.387	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.96	00:10:00	\N	1.04	\N	\N	Wrangell, Wrangell Island	AK
63198	Greys Island, Alaska	NOS	9451238	56.5217	-132.542	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:05:00	\N	0.94	00:11:00	\N	1.01	\N	\N	Greys Island	AK
63199	Monte Carlo Island, Keku Strait, Alaska (sub)	NOS	9451247	56.535	-133.767	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:03:00	\N	0.89	00:03:00	\N	0.8	\N	\N	Monte Carlo Island	AK
63200	Point Lockwood, Woewodski Island, Wrangell Narrows, Alaska (sub)	NOS	9451263	56.5583	-132.963	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:08:00	\N	0.98	00:15:00	\N	0.98	\N	\N	Point Lockwood, Woewodski Island	AK
63201	Beecher Pass, Wrangell Narrows, Alaska (sub)	NOS	9451287	56.595	-132.987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:14:00	\N	0.98	00:22:00	\N	1	\N	\N	Beecher Pass	AK
63202	Dry Strait, Frederick Sound, Alaska	NOS	9451301	56.615	-132.575	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:03:00	0	\N	-00:18:00	-0.2	\N	\N	\N	Dry Strait	AK
63203	Anchor Point, Wrangell Narrows, Alaska (sub)	NOS	9451317	56.6383	-132.927	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:40:00	\N	0.99	00:31:00	\N	1.04	\N	\N	Anchor Point	AK
63204	Cosmos Point, Frederick Sound, Alaska	NOS	9451335	56.6633	-132.617	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:05:00	\N	0.99	-00:05:00	\N	0.98	\N	\N	Cosmos Point	AK
63205	Papke's Landing, Wrangell Narrows, Alaska (sub)	NOS	9451346	56.6767	-132.933	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:50:00	\N	1.01	00:33:00	\N	1	\N	\N	Papke's Landing	AK
63206	The Summit, Keku Strait, Alaska (sub)	NOS	9451349	56.68242222222222	-133.7369083333333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:23:00	\N	0.99	00:19:00	\N	0.98	\N	\N	The Summit	AK
63207	Dorothy Cove, Necker Bay, Baranof Island, Alaska	NOS	9451376	56.7217	-135.075	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:02:00	\N	0.95	-00:02:00	\N	0.97	\N	\N	Dorothy Cove, Necker Bay	AK
63208	Turn Point, Alaska (sub)	NOS	9451434	56.8	-132.98	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:38:00	\N	0.96	00:25:00	\N	1.04	\N	\N	Turn Point	AK
63209	Entrance Island, Keku Strait, Alaska (sub)	NOS	9451438	56.8117	-133.787	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:20:00	\N	0.98	00:18:00	\N	0.94	\N	\N	Entrance Island	AK
63210	Petersburg, Wrangell Narrows, Alaska	NOS	9451439	56.815	-132.957	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:37:00	\N	0.97	00:28:00	\N	1.04	\N	\N	Petersburg	AK
63211	Symonds Bay, Biorka Island, Sitka Sound, Alaska	NOS	9451468	56.8567	-135.52	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:16:00	0	\N	-00:15:00	-0.1	\N	\N	\N	Symonds Bay, Biorka Island	AK
63212	Thomas Bay, Frederick Sound, Alaska	NOS	9451561	56.9967	-132.785	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:07:00	-0.1	\N	00:07:00	-0.8	\N	\N	\N	Thomas Bay	AK
63213	Baranof, Warm Spring Bay, Alaska (sub)	NOS	9451625	57.08833333333333	-134.825	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	-0.1	\N	-00:07:00	-2.8	\N	\N	\N	Baranof, Warm Spring Bay	AK
63214	Herring Bay, Frederick Sound, Alaska	NOS	9451634	57.1133	-134.38	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:07:00	\N	0.91	-00:08:00	\N	0.84	\N	\N	Herring Bay	AK
63215	Eliza Harbor, Admiralty Island, Frederick Sound, Alaska	NOS	9451706	57.1883	-134.287	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	\N	0.92	-00:06:00	\N	0.87	\N	\N	Eliza Harbor, Admiralty Island	AK
63216	Kasnyku Bay, Alaska	NOS	9451717	57.2167	-134.868	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:06:00	-0.1	\N	-00:10:00	-2.4	\N	\N	\N	Kasnyku Bay	AK
63217	Cleveland Passage, Whitney Island, Frederick Sound, Alaska	NOS	9451718	57.2183	-133.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:03:00	-0.1	\N	-00:01:00	-1.2	\N	\N	\N	Cleveland Passage, Whitney Island	AK
63218	Olga Point, Olga Strait, Sitka Sound, Alaska	NOS	9451725	57.2283	-135.537	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:14:00	0	\N	00:00:00	0	\N	\N	\N	Olga Point, Olga Strait	AK
63219	Cannery Cove, Pybus Bay, Frederick Sound, Alaska	NOS	9451781	57.3067	-134.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:06:00	\N	0.94	-00:08:00	\N	0.9	\N	\N	Cannery Cove, Pybus Bay	AK
63220	The Brothers, Stephens Passage, Alaska (sub)	NOS	9451785	57.295	-133.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	\N	0.98	-00:07:00	\N	0.91	\N	\N	The Brothers	AK
63221	Scraggy Point, Alaska	NOS	9451802	57.3367	-135.723	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:00:00	0.1	\N	-00:09:00	-0.1	\N	\N	\N	Scraggy Point	AK
63222	Scraggy Island, Alaska (sub)	NOS	9451805	57.34	-135.707	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:01:00	\N	1.03	00:00:00	\N	1	\N	\N	Scraggy Island	AK
63223	Haley Anchorage, Fish Bay, Alaska	NOS	9451826	57.3717	-135.618	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:12:00	0.1	\N	00:03:00	0.2	\N	\N	\N	Haley Anchorage, Fish Bay	AK
63224	Hobart Bay, Alaska	NOS	9451851	57.4067	-133.42	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:03:00	-0.1	\N	-00:06:00	-1.1	\N	\N	\N	Hobart Bay	AK
63225	Sergius Narrows, Alaska (sub)	NOS	9451853	57.41	-135.627	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:24:00	\N	1.05	00:19:00	\N	1.33	\N	\N	Serguis Narrows	AK
63226	Klokachef Island, Alaska	NOS	9451858	57.4167	-135.89	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:06:00	0.1	\N	-00:10:00	-0.1	\N	\N	\N	Klokachef Island	AK
63227	Bear Bay, Alaska	NOS	9451859	57.4183	-135.583	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:29:00	0.2	\N	00:18:00	3.7	\N	\N	\N	Bear Bay	AK
63228	Killisnoo, Alaska	NOS	9451895	57.47	-134.565	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	0	\N	-00:06:00	-2.1	\N	\N	\N	Killisnoo	AK
63229	Gambier Bay (cannery wharf), Alaska	NOS	9451906	57.4833	-133.96	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:01:00	\N	0.96	-00:01:00	\N	0.92	\N	\N	Gambier Bay (cannery wharf)	AK
63230	Good Island, Gambier Bay, Alaska	NOS	9451909	57.4867	-133.898	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	\N	0.96	-00:05:00	\N	0.93	\N	\N	Good Island, Gambier Bay	AK
63231	Provorotni Island, Alaska (sub)	NOS	9451936	57.515	-135.555	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:02:00	-0.1	\N	-00:09:00	-1.3	\N	\N	\N	Povorotni Island, Pogibshi Point	AK
63232	Windham Bay, Alaska	NOS	9451962	57.5433	-133.498	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:00:00	-0.1	\N	00:00:00	-1.1	\N	\N	\N	Windham Bay	AK
63233	Nismeni Cove, Alaska	NOS	9451979	57.5617	-135.412	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:03:00	-0.1	\N	-00:15:00	-1.3	\N	\N	\N	Nismeni Cove	AK
63234	Upper Endicott Arm, North Shore, Stephens Passage, Alaska	NOS	9452005	57.5217	-133.055	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:06:00	\N	0.99	00:01:00	\N	0.98	\N	\N	Upper Endicott Arm, North Shore	AK
63235	Sawyer Island, Tracy Arm, Alaska	NOS	9452022	57.8783	-133.19	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:06:00	\N	1.01	00:02:00	\N	0.97	\N	\N	Sawyer Island, Tracy Arm	AK
63236	Holkham Bay, Wood Spit, Alaska	NOS	9452064	57.7183	-133.578	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:06:00	-0.1	\N	00:03:00	-0.8	\N	\N	\N	Holkham Bay, Wood Spit	AK
63237	Holkham Bay, Tracy Arm Entrance, Alaska	NOS	9452067	57.76	-133.603	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:02:00	\N	0.96	00:01:00	\N	0.96	\N	\N	Holkham Bay, Tracy Arm Entrance	AK
63238	Port Snettisham, Crib Point, Alaska	NOS	9452082	58.0967	-133.742	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:03:00	\N	0.97	-00:03:00	\N	0.98	\N	\N	Port Snettisham, Crib Point	AK
63239	Taku Harbor, Alaska	NOS	9452123	58.0683	-134.012	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	\N	1	-00:03:00	\N	0.97	\N	\N	Taku Harbor	AK
63240	Taku Point, Taku Inlet, Alaska	NOS	9452124	58.4	-134.015	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:13:00	0	\N	00:14:00	0.4	\N	\N	\N	Taku Point, Taku Inlet	AK
63241	Rasp Ledge, Seymour Canal, Alaska	NOS	9452128	57.6783	-134.038	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:05:00	0.1	\N	00:06:00	-0.7	\N	\N	\N	Rasp Ledge, Seymour Canal	AK
63242	Greely Point, Taku Inlet, Alaska	NOS	9452133	58.2233	-134.06	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	-0.1	\N	-00:01:00	-0.6	\N	\N	\N	Greely Point, Taku Inlet	AK
63243	Young Bay, Alaska	NOS	9452249	58.1833	-134.587	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:02:00	\N	1	00:00:00	\N	1	\N	\N	Young Bay	AK
63244	Auke Bay, Alaska	NOS	9452263	58.3817	-134.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:03:00	0	\N	-00:06:00	-0.4	\N	\N	\N	Auke Bay	AK
63245	Hawk Inlet Entrance, Alaska (sub)	NOS	9452294	58.085	-134.777	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:01:00	\N	0.98	-00:04:00	\N	0.94	\N	\N	Hawk Inlet Entrance	AK
63246	Barlow Cove, Mansfield Peninsula, Lynn Canal, Alaska	NOS	9452318	58.3217	-134.878	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:01:00	\N	0.99	-00:04:00	\N	0.96	\N	\N	Barlow Cove, Mansfield Peninsula	AK
63247	Funter, Funter Bay, Lynn Canal, Alaska	NOS	9452321	58.255	-134.895	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:01:00	0	\N	00:00:00	-1.1	\N	\N	\N	Funter, Funter Bay	AK
63248	Lincoln Island, Lynn Canal, Alaska	NOS	9452336	58.4983	-134.965	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:01:00	\N	1	-00:03:00	\N	0.98	\N	\N	Lincoln Island	AK
63249	Cove Point, Berner's Bay, Lynn Canal, Alaska	NOS	9452346	58.7517	-135.028	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:00:00	\N	1.02	-00:02:00	\N	1	\N	\N	Cove Point, Berner's Bay	AK
63250	Swanson Harbor, Icy Strait, Alaska	NOS	9452368	58.215	-135.127	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:11:00	\N	1.08	00:14:00	\N	1.41	\N	\N	Swanson Harbor	AK
63251	Tenakee Springs, Tenakee Inlet, Alaska	NOS	9452386	57.78	-135.212	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:05:00	-0.1	\N	-00:04:00	-1.5	\N	\N	\N	Tenakee Springs, Tenakee Inlet	AK
63252	William Henry Bay, Lynn Canal, Alaska	NOS	9452391	58.7133	-135.232	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:09:00	0	\N	00:02:00	-0.5	\N	\N	\N	William Henry Bay	AK
63253	Skagway, Taiya Inlet, Lynn Canal, Alaska (sub)	NOS	9452400	59.45	-135.327	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:01:00	\N	1.01	-00:03:00	\N	1.03	\N	\N	Skagway, Taiya Inlet	AK
63254	Chilkat Inlet, Lynn Canal, Alaska (sub)	NOS	9452421	59.17	-135.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:01:00	\N	1	-00:04:00	\N	1.01	\N	\N	Chilkat Inlet	AK
63255	Taiyasanka Harbor, Taiya Inlet, Lynn Canal, Alaska	NOS	9452434	59.3017	-135.428	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:02:00	\N	1.01	-00:04:00	\N	1.03	\N	\N	Taiyasanka Harbor, Taiya Inlet	AK
63256	Haines Inlet, Lynn Canal, Alaska	NOS	9452435	59.23	-135.433	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:06:00	0	\N	-00:09:00	0.5	\N	\N	\N	Haines Inlet	AK
63257	Excursion Inlet Entrance, Icy Strait, Alaska	NOS	9452437	58.4167	-135.447	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:16:00	\N	1.05	00:15:00	\N	1.38	\N	\N	Excursion Inlet Entrance	AK
63258	Excursion Inlet, Icy Strait, Alaska	NOS	9452447	58.4967	-135.488	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:24:00	\N	1.07	00:26:00	\N	1.36	\N	\N	Excursion Inlet, North End	AK
63259	Point Adolphus, Icy Strait, Alaska	NOS	9452516	58.2867	-135.803	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:35:00	\N	1.11	00:29:00	\N	1.31	\N	\N	Point Adolphus	AK
63260	Bartlett Cove, Glacier Bay, Alaska	NOS	9452534	58.4567	-135.883	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:22:00	\N	1.11	00:19:00	\N	1.36	\N	\N	Bartlett Cove	AK
63261	Mud Bay, Goose Island, Icy Strait, Alaska	NOS	9452567	58.2117	-136.035	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:06:00	\N	0.96	00:06:00	\N	1.2	\N	\N	Mud Bay, Goose Island	AK
63262	Elbow Passage, Klag Bay, Chichagof Island, Alaska	NOS	9452579	57.6133	-136.087	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:13:00	\N	1.03	00:08:00	\N	0.98	\N	\N	Elbow Passage, Klag Bay	AK
63263	Kimshan Cove, Ogden Passage, Chichagof Island, Alaska	NOS	9452583	57.6867	-136.107	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:06:00	\N	1.03	00:05:00	\N	0.92	\N	\N	Kimshan Cove, Ogden Passage	AK
63264	Muir Inlet, Glacier Bay, Alaska (sub)	NOS	9452584	58.9133	-136.108	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:49:00	\N	1.19	00:39:00	\N	1.55	\N	\N	Muir Inlet	AK
63265	Willoughby Island, Glacier Bay, Alaska	NOS	9452586	58.6083	-136.117	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:50:00	\N	1.16	00:41:00	\N	1.5	\N	\N	Willoughby Island	AK
63266	Inian Cove, North Inian Pass, Cross Sound, Alaska	NOS	9452629	58.2633	-136.325	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:03:00	\N	1.01	00:12:00	\N	1.05	\N	\N	Inian Cove, North Inian Pass	AK
63267	Wachusett Inlet, Glacier Bay, Alaska	NOS	9452632	58.9467	-136.333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:50:00	\N	1.2	00:39:00	\N	1.57	\N	\N	Wachusett Inlet, Glacier Bay	AK
63268	Miner Island, Lisianski Strait and Inlet, Alaska	NOS	9452633	58.01	-136.342	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	-00:06:00	\N	0.96	-00:08:00	\N	0.94	\N	\N	Miner Island	AK
63269	Elfin Cove, Port Althorp, Cross Sound, Alaska (sub)	NOS	9452634	58.19472	-136.34694444444443	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:05:00	\N	1.01	00:04:00	\N	1.1	\N	\N	Elfin Cove, Port Althorp	AK
63270	Canoe Cove, North Pass, Lisianski Strait and Inlet, Alaska	NOS	9452649	57.8467	-136.422	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	-00:01:00	\N	0.89	00:02:00	\N	0.91	\N	\N	Canoe Cove, North Pass	AK
63271	Takanis Bay, Yakobi Island, outer coast, Alaska	NOS	9452671	57.9283	-136.52	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	-00:01:00	\N	1.03	-00:04:00	\N	0.9	\N	\N	Takanis Bay	AK
63272	Surge Bay, Yakobi Island, outer coast, Alaska	NOS	9452672	58.0183	-136.528	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:02:00	\N	0.96	00:00:00	\N	0.88	\N	\N	Surge Bay	AK
63273	Composite Island, Glacier Bay, Alaska	NOS	9452682	58.8883	-136.573	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:51:00	\N	1.2	00:45:00	\N	1.54	\N	\N	Composite Island	AK
63274	Graves Harbor, Alaska	NOS	9452704	58.2767	-136.678	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:07:00	\N	1.03	00:04:00	\N	0.91	\N	\N	Graves Harbor	AK
63275	Dixon Harbor, Alaska	NOS	9452747	58.3833	-136.867	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:07:00	\N	0.96	00:07:00	\N	0.89	\N	\N	Dixon Harbor	AK
63276	Lituya Bay, 2 miles inside entrance, Alaska	NOS	9452928	58.6167	-137.65	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:36:00	\N	0.89	00:06:00	\N	0.87	\N	\N	Lituya Bay, 2 miles inside entrance	AK
63277	Redfield Cove, Yakutat Bay, Alaska	NOS	9453208	59.6117	-139.58	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:00:00	\N	0.92	00:01:00	\N	1	\N	\N	Redfield Cove, Yakutat Bay	AK
63278	Point Latouche, Yakutat Bay, Alaska	NOS	9453210	59.9033	-139.627	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:03:00	\N	0.93	00:06:00	\N	1	\N	\N	Point Latouche, Yakutat Bay	AK
63279	Johnstone Passage, Yakutat Bay, Alaska	NOS	9453215	59.5817	-139.702	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:03:00	\N	1	00:01:00	\N	1	\N	\N	Johnstone Passage, Yakutat Bay	AK
63280	Yakutat, Yakutat Bay, Alaska (sub)	NOS	9453220	59.5485	-139.7334	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:16:00	\N	0.95	00:17:00	\N	1.01	\N	\N	Yakutat, Yakutat Bay	AK
63281	Tyndall Glacier, Icy Bay, Alaska	NOS	9453431	60.0783	-141.275	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:17:00	\N	0.97	00:20:00	\N	0.96	\N	\N	Tyndall Glacier, Icy Bay	AK
63282	Riou Bay, Alaska	NOS	9453456	59.885	-141.457	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:03:00	\N	1.01	00:02:00	\N	0.98	\N	\N	Icy Bay	AK
63283	Shag Rock, Orca Inlet, Alaska	NOS	9454125	60.465	-145.988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:16:00	-0.1	\N	-00:11:00	-1.1	\N	\N	\N	Shag Rock	AK
63284	Comfort Cove, Port Gravina, Prince William Sound, Alaska	NOS	9454157	60.71	-146.085	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:06:00	-0.1	\N	-00:16:00	-0.7	\N	\N	\N	Comfort Cove, Port Gravina	AK
63285	Middleton Island (north end), Alaska	NOS	9454224	59.4617	-146.31	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:14:00	-0.1	\N	-00:21:00	-2.2	\N	\N	\N	Middleton Island (north end)	AK
63286	Landlocked Bay, Port Fidalgo, Prince William Sound, Alaska	NOS	9454296	60.8533	-146.535	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:08:00	-0.1	\N	-00:12:00	-0.7	\N	\N	\N	Landlocked Bay, Port Fidalgo	AK
63287	Jack Bay, Valdez Arm, Alaska	NOS	9454309	61.04	-146.615	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61035	-00:02:00	\N	0.99	-00:01:00	\N	0.99	\N	\N	Jack Bay	AK
63288	Johnstone Point, Hinchinbrook Island, Alaska	NOS	9454319	60.4817	-146.61	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:02:00	-0.1	\N	-00:07:00	-0.8	\N	\N	\N	Johnstone Point	AK
63289	Cape Hinchinbrook, Hinchinbrook Island, Alaska	NOS	9454329	60.2383	-146.648	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:03:00	\N	0.98	-00:10:00	\N	0.88	\N	\N	Cape Hinchinbrook	AK
63290	Rocky Point, Valdez Arm, Alaska	NOS	9454363	60.9467	-146.755	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61035	-00:03:00	\N	0.99	00:00:00	\N	0.99	\N	\N	Rocky Point	AK
63291	Busby Island, Valdez Arm, Alaska	NOS	9454374	60.8983	-146.782	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61035	-00:02:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	Busby Island	AK
63292	Jackson Cove, Glacier Island, Prince William Sound, Alaska	NOS	9454507	60.88	-147.223	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:02:00	0	\N	-00:10:00	-0.6	\N	\N	\N	Jackson Cove, Glacier Island	AK
63293	Port Chalmers, Montague Island, Alaska	NOS	9454511	60.2418	-147.249	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:01:00	\N	0.97	-00:02:00	\N	0.94	\N	\N	Port Chalmers	AK
63294	Perch Point, Montague Island, Alaska (sub)	NOS	9454561	60.1267	-147.395	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:03:00	\N	0.94	-00:08:00	\N	0.92	\N	\N	Perch Point	AK
63295	Wooded Islands, Montague Island, Alaska (sub)	NOS	9454562	59.875	-147.403	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.95	-00:02:00	\N	0.8	\N	\N	Wooded Islands	AK
63296	Naked Island, McPherson Passage, Prince William Sound, Alaska	NOS	9454563	60.6833	-147.388	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:08:00	-0.1	\N	-00:18:00	-0.7	\N	\N	\N	Naked Island, McPherson Passage	AK
63297	Gibbon Anchorage, Green Island, Prince William Sound, Alaska	NOS	9454573	60.27	-147.438	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:06:00	-0.2	\N	-00:21:00	-0.8	\N	\N	\N	Gibbon Anchorage, Green Island	AK
63298	Patton Bay, Montague Island, Alaska	NOS	9454574	59.9067	-147.45	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:05:00	-0.1	\N	-00:12:00	-2.3	\N	\N	\N	Patton Bay	AK
63299	Montague Island, Alaska (sub)	NOS	9454616	60.025	-147.592	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.96	-00:02:00	\N	0.91	\N	\N	5 miles NE of Point Brazil, Montague Island	AK
63300	Louis Bay, Knight Island, Prince William Sound, Alaska	NOS	9454642	60.4617	-147.672	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:03:00	\N	1.04	00:00:00	\N	0.96	\N	\N	Louis Bay	AK
63301	Snug Harbor, Knight Island, Alaska (sub)	NOS	9454662	60.25	-147.717	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.97	-00:03:00	\N	0.91	\N	\N	Snug Harbor, Knight Island	AK
63302	Point Helen, Knight Island, Alaska	NOS	9454671	60.1533	-147.767	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:01:00	\N	1	-00:03:00	\N	0.92	\N	\N	Point Helen	AK
63303	Port Audrey, Knight Island, Alaska	NOS	9454673	60.3433	-147.768	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:03:00	\N	0.95	00:00:00	\N	0.92	\N	\N	Port Audrey	AK
63304	Macleod Harbor, Montague Island, Prince William Sound, Alaska	NOS	9454674	59.89	-147.795	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:04:00	\N	0.96	00:10:00	\N	0.89	\N	\N	Macleod Harbor	AK
63305	Herring Point, Knight Island, Prince William Sound, Alaska (sub)	NOS	9454691	60.475	-147.792	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	\N	1.01	-00:04:00	\N	0.95	\N	\N	Herring Point	AK
63306	Latouche, Latouche Island, Prince William Sound, Alaska	NOS	9454713	60.0533	-147.907	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:02:00	0	\N	-00:05:00	-1	\N	\N	\N	Latouche, Latouche Island	AK
63307	Eshamy Bay, Knight Island Passage, Prince William Sound, Alaska	NOS	9454735	60.4483	-147.978	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:04:00	0	\N	00:01:00	-0.4	\N	\N	\N	Eshamy Bay, Knight Island Passage	AK
63308	Guguak, Alaska (sub)	NOS	9454751	60.1	-148.038	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:03:00	\N	0.95	-00:07:00	\N	0.91	\N	\N	Guguak	AK
63309	Bainbridge Point, Bainbridge Island, Prince William Sound, Alaska	NOS	9454755	60.1967	-148.042	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	\N	0.98	-00:06:00	\N	0.93	\N	\N	Bainbridge Point, Bainbridge Island	AK
63310	Eshamy Lagoon, Prince William Sound, Alaska	NOS	9454757	60.4617	-148.045	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	1.03	-00:11:00	\N	0.92	\N	\N	Eshamy Lagoon	AK
63311	Sawmill Bay, Evans Island, Prince William Sound, Alaska	NOS	9454764	60.0517	-148.065	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:03:00	0	\N	-00:03:00	-1.2	\N	\N	\N	Sawmill Bay, Evans Island	AK
63312	Chenega Island, southwest end, Prince William Sound, Alaska	NOS	9454777	60.2833	-148.113	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	1	-00:03:00	\N	0.94	\N	\N	Chenega Island, southwest end	AK
63407	Unalga Bight, Adak Island, Alaska	NOS	9461341	51.78	-176.807	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:21:00	\N	0.97	-00:07:00	\N	0.97	\N	\N	Unalga Bight	AK
63313	Chenega Island, Dangerous Passage, Prince William Sound, Alaska	NOS	9454787	60.33	-148.143	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:06:00	0	\N	-00:01:00	-0.9	\N	\N	\N	Chenega Island, Dangerous Passage	AK
63314	Applegate Island, Prince William Sound, Alaska	NOS	9454794	60.6233	-148.165	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:06:00	0	\N	-00:01:00	-0.6	\N	\N	\N	Applegate Island	AK
63315	Culross Bay, Wells Passage, Prince William Sound, Alaska	NOS	9454798	60.7417	-148.172	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:01:00	0	\N	-00:15:00	-0.4	\N	\N	\N	Culross Bay, Wells Passage	AK
63316	Hogg Bay, Port Bainbridge, Prince William Sound, Alaska	NOS	9454805	60.0767	-148.195	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:03:00	-0.1	\N	-00:12:00	-1.9	\N	\N	\N	Hogg Bay, Port Bainbridge	AK
63317	Point Elrington, Elrington Island, Prince William Sound, Alaska (sub)	NOS	9454814	59.9383	-148.227	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:02:00	\N	0.94	-00:13:00	\N	0.84	\N	\N	Point Elrington, Elrington Island	AK
63318	Long Bay Entrance, Culross Passage, Prince William Sound, Alaska	NOS	9454825	60.6917	-148.263	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:09:00	-0.1	\N	00:03:00	-0.9	\N	\N	\N	Long Bay Entrance, Culross Passage	AK
63319	Kings Bay, Port Nellie Juan, Prince William Sound, Alaska	NOS	9454887	60.5417	-148.46	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:09:00	0	\N	-00:01:00	-0.6	\N	\N	\N	Kings Bay, Port Nellie Juan	AK
63320	Whittier, Prince William Sound, Alaska (sub)	NOS	9454949	60.7783	-148.665	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	0	\N	-00:05:00	-0.3	\N	\N	\N	Whittier, Passage Canal	AK
63322	Seward, Resurrection Bay, Alaska (sub)	NOS	9455090	60.12	-149.4266667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:13:00	\N	0.91	-00:06:00	\N	0.83	\N	\N	Seward, Resurrection Bay	AK
63323	Agnes Cove, Aialik Peninsula, Alaska (sub)	NOS	9455120	59.7733	-149.588	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.91	-00:06:00	\N	0.84	\N	\N	Agnes Cove, Aialik Peninsula	AK
63324	Bear Cove, Aialik Peninsula, Alaska	NOS	9455128	59.8017	-149.615	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:01:00	\N	0.97	00:01:00	\N	1	\N	\N	Bear Cove, Aialik Peninsula	AK
63325	Aialik Bay, north end, Alaska (sub)	NOS	9455145	59.9533	-149.715	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	\N	0.89	-00:06:00	\N	0.83	\N	\N	Aialik Bay, North end	AK
63326	Aialik Sill, Aialik Bay, Alaska (sub)	NOS	9455146	59.885	-149.718	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.9	-00:05:00	\N	0.83	\N	\N	Aialik Sill, Aialik Bay	AK
63327	Camp Cove, Harris Peninsula, Alaska (sub)	NOS	9455151	59.6933	-149.748	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.9	-00:06:00	\N	0.84	\N	\N	Camp Cove, Aialik Bay	AK
63328	Crater Bay, Harris Bay, Alaska (sub)	NOS	9455159	59.7133	-149.787	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	\N	0.87	-00:03:00	\N	0.84	\N	\N	Crater Bay, Harris Bay	AK
63329	Upper Northwestern Fiord, Harris Bay, Alaska (sub)	NOS	9455204	59.79	-150.032	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:11:00	\N	0.9	00:01:00	\N	0.85	\N	\N	Upper Northwestern Fiord, Harris Bay	AK
63330	Two Arm Bay, Harris Bay, Alaska	NOS	9455217	59.6617	-150.108	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	-00:05:00	\N	0.94	-00:10:00	\N	1.03	\N	\N	Two Arm Bay, Harris Bay	AK
63331	Chance Cove (Lagoon), Alaska	NOS	9455249	59.4883	-150.312	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:01:00	\N	1.01	00:00:00	\N	1.04	\N	\N	Chance Cove (Lagoon)	AK
63332	Beauty Bay, Nuka Bay, Alaska	NOS	9455304	59.5267	-150.628	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:14:00	\N	1.01	00:12:00	\N	1.08	\N	\N	Beauty Bay, Nuka Bay	AK
63333	Nuka Passage, Alaska	NOS	9455308	59.4083	-150.667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:12:00	\N	1.01	00:11:00	\N	1.09	\N	\N	Nuka Passage	AK
63334	Takoma Cove, Port Dick, Alaska	NOS	9455347	59.2617	-150.982	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:18:00	\N	1.01	00:23:00	\N	1.15	\N	\N	Takoma Cove, Port Dick	AK
63335	Picnic Harbor, Rocky Bay, Alaska	NOS	9455399	59.255	-151.42	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:21:00	\N	1.01	00:26:00	\N	1.23	\N	\N	Picnic Harbor, Rocky Bay	AK
63336	Port Chatham, Cook Inlet, Alaska	NOS	9455428	59.2133	-151.728	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:34:00	\N	0.92	-00:28:00	\N	0.78	\N	\N	Port Chatham	AK
63337	Port Graham, Cook Inlet, Alaska	NOS	9455437	59.35	-151.8266666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:14:00	0	\N	-00:08:00	-1	\N	\N	\N	Port Graham	AK
63338	Ushagat Island, Barren Islands, Cook Inlet, Alaska	NOS	9455478	58.9467	-152.268	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:04:00	\N	0.76	-00:08:00	\N	0.76	\N	\N	Ushagat Island, Barren Islands	AK
63339	Tutka Bay,Kachemak Bay, Cook Inlet, Alaska	NOS	9455506	59.4317	-151.357	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:01:00	0	\N	-00:01:00	0.2	\N	\N	\N	Tutka Bay,Kachemak Bay	AK
63340	Sadie Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455514	59.49	-151.365	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:04:00	-0.1	\N	-00:04:00	0.1	\N	\N	\N	Sadie Cove, Kachemak Bay	AK
63341	Halibut Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455556	59.5967	-151.22	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:05:00	0	\N	-00:03:00	0.7	\N	\N	\N	Halibut Cove, Kachemak Bay	AK
63342	Homer, Kachemak Bay, Cook Inlet, Alaska	NOS	9455557	59.6033	-151.42	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:03:00	\N	0.97	00:05:00	\N	1.01	\N	\N	Homer, Kachemak Bay	AK
63343	Bear Cove, Kachemak Bay, Cook Inlet, Alaska (sub)	NOS	9455595	59.725	-151.023	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:05:00	-0.1	\N	-00:04:00	0.4	\N	\N	\N	Bear Cove, Kachemak Bay	AK
63344	Anchor Point, Cook Inlet, Alaska (sub)	NOS	9455606	59.77197222222223	-151.8670277777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:21:00	0	\N	00:29:00	0.4	\N	\N	\N	Anchor Point	AK
63345	Drift River Terminal, Cook Inlet, Alaska	NOS	9455741	60.555	-152.133	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	02:04:00	\N	1.18	01:39:00	\N	1.01	\N	\N	Drift River Terminal	AK
63346	Kenai City Pier, Cook Inlet, Alaska	NOS	9455742	60.545	-151.218	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	02:55:00	-0.1	\N	01:54:00	1.9	\N	\N	\N	Kenai City Pier	AK
63347	Snug Harbor, Cook Inlet, Alaska	NOS	9456173	60.10747222222222	-152.5816666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	01:15:00	0	\N	01:04:00	-2.3	\N	\N	\N	Snug Harbor, Cook Inlet	AK
63348	Tuxedni Channel, Cook Inlet, Alaska	NOS	9456204	60.1533	-152.635	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:53:00	0.2	\N	00:39:00	-1.3	\N	\N	\N	Tuxedni Channel	AK
63349	Oil Bay, Kamishak Bay, Cook Inlet, Alaska	NOS	9456463	59.64	-153.262	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	01:16:00	\N	0.83	01:15:00	\N	0.77	\N	\N	Oil Bay, Kamishak Bay	AK
63350	Nukshak Island, Shelikof Strait, Alaska (sub)	NOS	9456717	58.3917	-153.958	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:07:00	\N	0.95	-00:01:00	\N	0.76	\N	\N	Nukshak Island, Shelikof Strait	AK
63351	Nordyke Island, Kamishak Bay, Cook Inlet, Alaska	NOS	9456822	59.1783	-154.087	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:22:00	-0.2	\N	00:10:00	-2.8	\N	\N	\N	Nordyke Island, Kamishak Bay	AK
63352	Kukak, Kukak Bay, Alaska	NOS	9456835	58.3417	-154.117	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:05:00	\N	0.74	-00:08:00	\N	0.74	\N	\N	Kukak, Kukak Bay	AK
63353	Aguchik Island, Kukak Bay, Alaska (sub)	NOS	9456901	58.29	-154.27	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:06:00	\N	0.94	-00:04:00	\N	0.75	\N	\N	Aguchik Island, Kukak Bay	AK
63354	Takli Island, Shelikof Strait, Alaska	NOS	9456992	58.0633	-154.477	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:03:00	\N	1	-00:09:00	\N	0.73	\N	\N	Takli Island, Shelikof Strait	AK
63355	Tonki Bay, Alaska	NOS	9457152	58.3167	-152.067	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:21:00	0.2	\N	00:12:00	2.3	\N	\N	\N	Tonki Bay	AK
63356	Seal Bay, Alaska	NOS	9457201	58.3717	-152.238	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:36:00	0.3	\N	00:29:00	2.4	\N	\N	\N	Seal Bay	AK
63357	Andreon Bay, Shuyak Island, Alaska	NOS	9457259	58.5183	-152.415	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:44:00	0.3	\N	00:35:00	2.5	\N	\N	\N	Andreon Bay, Shuyak Island	AK
63358	Kodiak, Port of Kodiak, Alaska	NOS	9457261	57.7833	-152.428	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:02:00	0	\N	-00:03:00	0	\N	\N	\N	Kodiak, Port of Kodiak	AK
63359	Spruce Island (north side), Alaska	NOS	9457262	57.9383	-152.417	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:08:00	0.1	\N	00:02:00	0.4	\N	\N	\N	Spruce Island (north side)	AK
63360	Perenosa Bay, Afognak Island, Alaska	NOS	9457271	58.3567	-152.448	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:39:00	0.3	\N	00:28:00	2.5	\N	\N	\N	Perenosa Bay	AK
63361	Kodiak, St. Paul Harbor, Alaska	NOS	9457283	57.745	-152.483	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:02:00	0	\N	-00:05:00	-0.1	\N	\N	\N	Kodiak, St. Paul Harbor	AK
63362	Ouzinkie, Spruce Island, Alaska (sub)	NOS	9457287	57.9217	-152.498	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:04:00	0	\N	-00:05:00	0.2	\N	\N	\N	Ouzinkie, Spruce Island	AK
63363	Carry Inlet, Shuyak Island, Alaska	NOS	9457293	58.5867	-152.513	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:07:00	\N	0.73	00:06:00	\N	0.73	\N	\N	Carry Inlet	AK
63364	Redfox Bay, Shuyak Strait, Alaska	NOS	9457316	58.4533	-152.595	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:02:00	-0.2	\N	-00:14:00	-4.4	\N	\N	\N	Redfox Bay, Shuyak Strait	AK
63365	Big Bay, Shuyak Island, Alaska	NOS	9457321	58.555	-152.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:15:00	\N	0.77	00:10:00	\N	0.77	\N	\N	Big Bay	AK
63366	Ugak Bay (Saltery Cove), Alaska	NOS	9457351	57.4817	-152.718	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:20:00	-0.1	\N	-00:29:00	-0.3	\N	\N	\N	Ugak Bay (Saltery Cove)	AK
63367	Fox Bay, Whale Island, Alaska	NOS	9457361	57.9783	-152.755	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:37:00	0.2	\N	00:22:00	1.2	\N	\N	\N	Fox Bay, Whale Island	AK
63369	Port Hobron, Sitkalidak Island, Alaska	NOS	9457479	57.1633	-153.152	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:06:00	0.1	\N	-00:18:00	-0.3	\N	\N	\N	Port Hobron, Sitkalidak Island	AK
63370	Dolphin Point, Raspberry Strait, Alaska	NOS	9457481	58.11	-153.155	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:05:00	-0.1	\N	-00:25:00	-4.1	\N	\N	\N	Dolphin Point, Raspberry Strait	AK
63371	Zachar Bay, Uyak Bay, Alaska	NOS	9457648	57.5483	-153.735	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:00:00	\N	0.77	-00:09:00	\N	0.77	\N	\N	Zachar Bay	AK
63372	Mining Camp, Uyak Bay, Alaska	NOS	9457671	57.46	-153.817	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:10:00	-0.1	\N	-00:37:00	-4.1	\N	\N	\N	Mining Camp	AK
63373	Moser Bay (Trap Point), Alaska	NOS	9457773	57.0017	-154.148	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61086	00:10:00	\N	1.01	00:11:00	\N	0.99	\N	\N	Moser Bay (Trap Point)	AK
63374	Olga Bay (A. P. A. Cannery), Alaska	NOS	9457798	57.1617	-154.228	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61086	03:54:00	\N	0.06	03:46:00	\N	0.1	\N	\N	Olga Bay (A. P. A. Cannery)	AK
63375	Alitak, Lazy Bay, Alaska (sub)	NOS	9457804	56.8974	-154.248	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:19:00	\N	1.42	00:02:00	\N	1.38	\N	\N	Alitak, Lazy Bay	AK
63376	Puale Bay, Alaska (sub)	NOS	9458209	57.7067	-155.393	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:03:00	\N	0.67	-00:22:00	\N	0.67	\N	\N	Puale Bay	AK
63377	Kanatak Lagoon, Portage Bay, Alaska	NOS	9458365	57.52	-156.052	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:51:00	0.3	\N	00:21:00	3	\N	\N	\N	Kanatak Lagoon, Portage Bay	AK
63378	Chowiet Island, Semidi Island, Alaska (sub)	NOS	9458519	56.0517	-156.698	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:25:00	\N	1.29	00:15:00	\N	1.04	\N	\N	Chowiet Island, Semidi Island	AK
63379	Unavikshak Island, Alaska	NOS	9458762	56.4917	-157.74	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:44:00	\N	1.24	00:31:00	\N	1.05	\N	\N	Unavikshak Island	AK
63380	Nakchamik Island, Alaska	NOS	9458779	56.3517	-157.812	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:41:00	\N	1.33	00:29:00	\N	1.04	\N	\N	Nakchamik Island	AK
63381	Kujulik Bay (North Shore), Alaska	NOS	9458819	56.6133	-157.983	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:46:00	\N	1.35	00:31:00	\N	1.1	\N	\N	Kujulik Bay (North Shore)	AK
63382	Chankliut Island, Alaska	NOS	9458849	56.1467	-158.107	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:43:00	\N	1.27	00:32:00	\N	0.98	\N	\N	Chankliut Island	AK
63383	Chignik, Anchorage Bay, Alaska	NOS	9458917	56.2967	-158.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:44:00	\N	1.28	00:34:00	\N	1.04	\N	\N	Chignik, Anchorage Bay	AK
63384	Hump Island, Kuiukta Bay, Alaska (sub)	NOS	9458964	56.1133	-158.598	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:42:00	\N	1.23	00:35:00	\N	0.91	\N	\N	Hump Island, Kuiukta Bay	AK
63385	Mitrofania Island, Alaska (sub)	NOS	9459016	55.89	-158.82	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:39:00	\N	1.23	00:32:00	\N	0.88	\N	\N	Mitrofania Island	AK
63386	Chiachi Island (east side), Alaska	NOS	9459085	55.8433	-159.105	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:37:00	\N	1.28	00:22:00	\N	0.89	\N	\N	Chiachi Island (east side)	AK
63387	Kupreanof Harbor, Paul Island, Alaska	NOS	9459145	55.79	-159.35	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:35:00	\N	1.28	00:19:00	\N	0.89	\N	\N	Kupreanof Harbor, Paul Island	AK
63388	Dent Point, Stepovak Bay, Alaska	NOS	9459281	55.7833	-159.88	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:33:00	\N	1.19	00:17:00	\N	0.86	\N	\N	Dent Point, Stepovak Bay	AK
63389	Sanborn Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	9459311	55.155	-159.995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	-00:03:00	\N	0.98	00:03:00	\N	1	\N	\N	Sanborn Harbor, Nagai Island	AK
63390	Pirate Cove, Popof Island, Shumagin Islands, Alaska	NOS	9459398	55.3617	-160.36	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:03:00	\N	0.98	00:08:00	\N	1.03	\N	\N	Pirate Cove, Popof Island	AK
63391	Albatross Anchorage, Balboa Bay, Alaska	NOS	9459464	55.59	-160.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:03:00	\N	1.05	-00:02:00	\N	1.06	\N	\N	Albatross Anchorage, Balboa Bay	AK
63393	Seal Cape, Coal Bay, Alaska	NOS	9459643	55.365	-161.325	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:05:00	\N	1.05	00:00:00	\N	0.98	\N	\N	Seal Cape, Coal Bay	AK
63394	Ukolnoi Island, Alaska	NOS	9459696	55.2583	-161.537	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:00:00	\N	0.98	00:07:00	\N	0.97	\N	\N	Ukolnoi Island	AK
63395	Lenard Harbor, Cold Bay, Alaska	NOS	9459895	55.1183	-162.378	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:17:00	\N	0.98	00:12:00	\N	0.98	\N	\N	Lenard Harbor, Cold Bay	AK
63396	Peterson Bay, Sanak Islands, Alaska	NOS	9459939	54.3933	-162.637	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	-00:08:00	\N	1.05	-00:05:00	\N	0.83	\N	\N	Peterson Bay	AK
63397	Sanak Harbor, Sanak Islands, Alaska	NOS	9459968	54.4817	-162.812	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:03:00	\N	1.05	00:14:00	\N	0.89	\N	\N	Sanak Harbor	AK
63398	Ogliuga Island (east coast), Delarof Islands, Alaska	NOS	9461081	51.6033	-178.617	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:43:00	\N	0.95	00:01:00	\N	0.95	\N	\N	Ogliuga Island (east coast)	AK
63399	Lash Bay, Tanaga Island, Alaska	NOS	9461132	51.6717	-178.045	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-01:39:00	\N	1.14	-00:56:00	\N	1.14	\N	\N	Lash Bay	AK
63400	Tanaga Bay, Tanaga Island, Alaska	NOS	9461138	51.7183	-177.997	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:32:00	\N	1.08	-00:06:00	\N	1.08	\N	\N	Tanaga Bay	AK
63401	Hot Springs Bay, Tanaga Island, Alaska	NOS	9461162	51.7783	-177.8	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:12:00	\N	0.84	-00:40:00	\N	0.84	\N	\N	Hot Springs Bay	AK
63402	Cape Chunu, Kanaga Island, Alaska	NOS	9461183	51.665	-177.637	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-01:54:00	\N	1.11	-01:44:00	\N	1.11	\N	\N	Cape Chunu	AK
63403	Kanaga Bay, Kanaga Island, Alaska	NOS	9461264	51.7183	-177.2	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-01:44:00	\N	1.05	-01:39:00	\N	1.05	\N	\N	Kanaga Bay	AK
63404	Cape Chlanak, Kanaga Island, Alaska	NOS	9461276	51.71	-177.145	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-01:34:00	\N	0.92	-01:22:00	\N	0.92	\N	\N	Cape Chlanak	AK
63405	Shoal Point, Kanaga Island, Alaska	NOS	9461292	51.87	-177.068	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:16:00	\N	0.86	00:01:00	\N	0.86	\N	\N	Shoal Point	AK
63406	Bay of Waterfalls, Adak Island, Alaska	NOS	9461337	51.6417	-176.825	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:04:00	\N	0.95	-01:20:00	\N	0.95	\N	\N	Bay of Waterfalls	AK
63408	Boot Bay, Adak Island, Alaska	NOS	9461391	51.7133	-176.53	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:09:00	\N	0.97	-01:38:00	\N	0.97	\N	\N	Boot Bay	AK
63409	Adak Bight, Adak Island, Alaska	NOS	9461406	51.77	-176.435	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:02:00	\N	1	-01:24:00	\N	1	\N	\N	Adak Bight	AK
63410	Laska Cove, Kagalaska Island, Aleutian Islands, Alaska	NOS	9461411	51.825	-176.402	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	00:07:00	\N	0.97	-00:04:00	\N	0.97	\N	\N	Laska Cove, Kagalaska Island	AK
63411	Sand Bay, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461453	51.9733	-176.085	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:20:00	\N	0.97	-00:05:00	\N	0.97	\N	\N	Sand Bay, Great Sitkin Island	AK
63412	Bugle Point, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461467	52.0383	-175.98	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:05:00	\N	0.89	00:01:00	\N	0.89	\N	\N	Bugle Point, Great Sitkin Island	AK
63413	Fenimore Pass, Aleutian Islands, Alaska	NOS	9461519	51.96	-175.588	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:13:00	\N	0.89	-00:04:00	\N	0.89	\N	\N	Fenimore Pass	AK
63414	Atka Pass, east end, Atka Island, Alaska	NOS	9461555	52.0067	-175.32	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:10:00	\N	1.24	-01:07:00	\N	1.24	\N	\N	Atka Pass, east end	AK
63415	Bechevin Bay, Atka Island, Alaska	NOS	9461582	52.0367	-175.115	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	00:04:00	\N	0.95	00:11:00	\N	0.95	\N	\N	Bechevin Bay	AK
63416	Explorer Bay, Atka Island, Alaska	NOS	9461656	52.0733	-174.568	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:24:00	\N	1.24	-02:43:00	\N	1.24	\N	\N	Explorer Bay	AK
63417	Sagchudak Island, Atka Island, Alaska	NOS	9461667	52.0267	-174.48	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:25:00	\N	1.24	-01:26:00	\N	1.24	\N	\N	Sagchudak Island	AK
63418	Martin Harbor, Korovin Bay, Atka Island, Alaska	NOS	9461693	52.2267	-174.292	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	00:21:00	\N	0.87	00:19:00	\N	0.87	\N	\N	Martin Harbor, Korovin Bay	AK
63419	Cape Utalug (4 miles west of), Atka Island, Alaska	NOS	9461704	52.1183	-174.207	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:32:00	\N	1.19	-01:38:00	\N	1.19	\N	\N	Cape Utalug (4 miles west of)	AK
63420	Finch Cove, Seguam Island, Aleutian Islands, Alaska	NOS	9461945	52.3917	-172.405	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	00:07:00	\N	0.87	-01:00:00	\N	0.87	\N	\N	Finch Cove, Seguam Island	AK
63421	North side, Yunaska Island, Alaska	NOS	9462144	52.6817	-170.707	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-01:29:00	\N	1.19	-01:05:00	\N	1.02	\N	\N	North side	AK
63422	East Cove, Yunaska Island, Alaska	NOS	9462161	52.6533	-170.563	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-02:35:00	\N	0.85	-01:36:00	\N	0.88	\N	\N	East Cove	AK
63423	Applegate Cove, Chuginadak Island, Aleutian Islands, Alaska	NOS	9462239	52.8617	-169.862	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:58:00	\N	1.27	-00:21:00	\N	1.08	\N	\N	Applegate Cove, Chuginadak Island	AK
63424	Adugak Island, Aleutian Islands, Alaska	NOS	9462317	52.9117	-169.165	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:56:00	\N	1.1	-00:33:00	\N	1.02	\N	\N	Adugak Island	AK
63425	Cape Sagak, Umnak Island, Alaska	NOS	9462331	52.8417	-169.043	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:16:00	\N	1.02	-03:03:00	\N	1.2	\N	\N	Cape Sagak	AK
63426	Okee Bay, Umnak Island, Alaska	NOS	9462354	53.0167	-168.835	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:43:00	\N	1.1	-00:07:00	\N	0.99	\N	\N	Okee Bay	AK
63427	Driftwood Bay, Umnak Island, Alaska	NOS	9462367	52.9583	-168.72	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:22:00	\N	1.1	-02:56:00	\N	1.35	\N	\N	Driftwood Bay	AK
63428	Kigul Island, Umnak Island, Alaska	NOS	9462398	53.045	-168.442	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:42:00	\N	1.27	-03:04:00	\N	1.37	\N	\N	Kigul Island	AK
63429	Inanudak Bay, Umnak Island, Alaska	NOS	9462408	53.2967	-168.352	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:30:00	\N	0.93	-00:06:00	\N	0.96	\N	\N	Inanudak Bay	AK
63430	Bogoslof Island, Aleutian Islands, Alaska	NOS	9462444	53.93	-168.033	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:55:00	\N	1.1	-00:30:00	\N	1.08	\N	\N	Bogoslof Island	AK
63431	Otter Point, Umnak Island, Alaska	NOS	9462465	53.3967	-167.843	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:40:00	\N	0.93	-00:27:00	\N	0.88	\N	\N	Otter Point	AK
63432	Chernofski Harbor, Unalaska Island, Alaska	NOS	9462501	53.395	-167.533	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:29:00	\N	1.1	-00:10:00	\N	1.02	\N	\N	Chernofski Harbor	AK
63433	Skan Bay, Unalaska Island, Alaska	NOS	9462554	53.61	-167.045	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:19:00	\N	1.1	-00:07:00	\N	1.05	\N	\N	Skan Bay	AK
63434	Kuliliak Bay, Unalaska Island, Alaska	NOS	9462557	53.4617	-167.02	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:35:00	\N	1.27	-03:10:00	\N	1.46	\N	\N	Kuliliak Bay	AK
63435	Raven Bay, Unalaska Island, Alaska	NOS	9462573	53.475	-166.873	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:48:00	\N	1.27	-03:16:00	\N	1.49	\N	\N	Raven Bay	AK
63436	Anderson Bay, Unalaska Island, Alaska	NOS	9462578	53.6783	-166.832	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	00:28:00	\N	1.1	-00:01:00	\N	1.08	\N	\N	Anderson Bay	AK
63437	Usof Bay, Unalaska Island, Alaska	NOS	9462582	53.515	-166.79	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:45:00	\N	1.19	-03:30:00	\N	1.55	\N	\N	Usof Bay	AK
63438	Kisselen Bay, Beaver Inlet, Unalaska Island, Alaska	NOS	9462606	53.7133	-166.572	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:14:00	\N	1.1	-02:59:00	\N	1.4	\N	\N	Kisselen Bay, Beaver Inlet	AK
63439	Dutch Harbor, Amaknak Island, Unalaska Island, Alaska	NOS	9462611	53.8917	-166.537	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:07:00	\N	1	00:00:00	\N	1	\N	\N	Dutch Harbor, Amaknak Island	AK
63440	Udagak Strait, Unalaska Island, Alaska	NOS	9462637	53.7367	-166.295	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:59:00	\N	1.02	-03:32:00	\N	1.37	\N	\N	Udagak Strait	AK
63441	English Bay, Unalaska Island, Alaska	NOS	9462641	53.925	-166.257	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:01:00	\N	0.76	00:16:00	\N	0.79	\N	\N	English Bay	AK
63442	Biorka Village, Biverly Inlet, Alaska (sub)	NOS	9462645	53.82891666666667	-166.21625	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:25:00	\N	1.35	-03:13:00	\N	1.35	\N	\N	Udamat Bay, Sedanka Island	AK
63443	Akutan Harbor, Akutan Island, Aleutian Islands, Alaska	NOS	9462691	54.1283	-165.808	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:07:00	\N	1.1	-00:17:00	\N	1.08	\N	\N	Akutan Harbor, Akutan Island	AK
63444	Trident Bay, Akun Island, Aleutian Islands, Alaska (sub)	NOS	9462721	54.14	-165.527	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-04:11:00	\N	0.76	-03:59:00	\N	0.99	\N	\N	Trident Bay, Akun Island	AK
63445	Cape Sarichef, Unimak Island, Alaska (sub)	NOS	9462787	54.6	-164.928	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:56:00	\N	1.27	-00:24:00	\N	1.37	\N	\N	Cape Sarichef	AK
63446	Scotch Cap, Unimak Island, Alaska (sub)	NOS	9462808	54.39363888888889	-164.7457222222222	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-02:49:00	\N	1.27	-02:27:00	\N	1.4	\N	\N	Scotch Cap	AK
63447	Cape Mordvinof, Unimak Island, Alaska	NOS	9462838	54.9283	-164.467	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	00:19:00	\N	1.36	00:26:00	\N	1.73	\N	\N	Cape Mordvinof	AK
63448	St. Catherine Cove, Unimak Island, Alaska	NOS	9462944	55.01	-163.507	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:18:00	\N	1.36	00:04:00	\N	1.23	\N	\N	St. Catherine Cove	AK
63449	Dora Harbor, Unimak Island, Alaska	NOS	9462971	54.71	-163.267	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:15:00	\N	1.05	00:15:00	\N	0.87	\N	\N	Dora Harbor	AK
63450	Amak Island, Bristol Bay, Alaska	NOS	9462987	55.4133	-163.115	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	01:48:00	\N	1.78	01:47:00	\N	2.13	\N	\N	Amak Island	AK
63451	Grant Point, Izembek Lagoon, Bristol Bay, Alaska	NOS	9463058	55.27	-162.9	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	04:05:00	\N	0.85	03:03:00	\N	1.23	\N	\N	Grant Point, Izembek Lagoon	AK
63452	Settlement Point, Pavlof Bay, Alaska	NOS	9463195	55.5	-161.46666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:08:00	\N	0.9	00:09:00	\N	0.98	\N	\N	Settlement Point, Pavlof Bay	AK
63453	Port Heiden, Bristol Bay, Alaska	NOS	9464096	56.9333	-158.728	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	02:05:00	\N	1.18	01:43:00	\N	1.15	\N	\N	Port Heiden	AK
63454	Village Cove, St. Paul Island, Bering Sea, Alaska (sub)	NOS	9464212	57.12530555555556	-170.2851666666667	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	00:27:00	\N	1.06	00:26:00	\N	0.93	\N	\N	Village Cove, St. Paul Island	AK
63455	Egegik, Egegik River, Alaska	NOS	9464874	58.2167	-157.375	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	05:36:00	\N	0.36	03:42:00	\N	1.2	\N	\N	Egegik	AK
63456	Egegik River entrance, Alaska	NOS	9464881	58.2383	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	03:47:00	\N	1.14	03:16:00	\N	1.69	\N	\N	Egegik River Ent, Bristol Bay	AK
63457	Middle Bluff, Kvichak Bay, Bristol Bay, Alaska	NOS	9465022	58.4533	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	04:10:00	\N	1.14	03:56:00	\N	1.84	\N	\N	Middle Bluff, Kvichak Bay	AK
63458	King Salmon Airport, Naknek River, Alaska	NOS	9465149	58.6717	-156.657	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	09:46:00	\N	0.09	05:43:00	\N	0.24	\N	\N	King Salmon Airport	AK
63459	Omakstalia Point, Naknek River, Alaska	NOS	9465174	58.7067	-156.757	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	08:35:00	\N	0.14	04:58:00	\N	0.69	\N	\N	Omakstalia Point	AK
63460	Black Rock, Walrus Islands, Nushagak Bay, Alaska (sub)	NOS	9465182	58.7083	-160.188	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	04:53:00	\N	0.82	04:53:00	\N	0.8	\N	\N	Black Rock, Walrus Islands	AK
63461	Naknek River entrance, Alaska	NOS	9465183	58.7217	-157.057	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	05:26:00	\N	1	04:27:00	\N	2.15	\N	\N	Naknek River Entrance, Kvichak B	AK
63462	Kvichak, Kvichak River, Alaska	NOS	9465342	58.97	-156.947	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	07:49:00	\N	0.41	05:21:00	\N	1.54	\N	\N	Kvichak	AK
63463	Goodnews Bay entrance, Alaska	NOS	9465368	59.045	-161.808	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61137	00:11:00	\N	0.95	00:04:00	\N	1.01	\N	\N	Goodnews Bay entrance	AK
63464	Snag Point, Dillingham, Alaska (sub)	NOS	9465374	59.04	-158.447	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61133	00:54:00	\N	0.97	00:28:00	\N	1.03	\N	\N	Snag Point	AK
63465	Platinum, Alaska (sub)	NOS	9465396	59.0467	-161.818	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61133	05:41:00	\N	0.25	06:17:00	\N	0.38	\N	\N	Platinum	AK
63466	Levelock, Kvichak River, Alaska	NOS	9465419	59.1133	-156.832	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	09:34:00	\N	0.23	06:13:00	\N	0.9	\N	\N	Levelock	AK
63467	Apokak Creek entrance, Alaska	NOS	9466079	60.1367	-162.158	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61137	04:30:00	\N	0.79	03:18:00	\N	1.47	\N	\N	Apokak Creek entrance	AK
63468	St. Matthew Island, Bering Sea, Alaska	NOS	9466203	60.3583	-172.715	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	00:50:00	\N	0.57	00:22:00	\N	0.57	\N	\N	St. Matthew Island	AK
63469	Bethel, Kuskokwim River, Alaska (sub)	NOS	9466477	60.8	-161.75	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61133	03:47:00	\N	0.16	01:48:00	\N	0.15	\N	\N	Bethel	AK
63470	Pikmiktalik River entrance, Norton Sound, Alaska	NOS	9468011	63.28	-162.602	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61154	-01:13:00	\N	1.08	-01:13:00	\N	1.08	\N	\N	Pikmiktalik River entrance	AK
63471	Fossil River entrance, St. Lawrence Island, Alaska	NOS	9468123	63.4667	-170.017	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	-03:08:00	\N	0.67	-03:00:00	\N	1.13	\N	\N	Fossil River entrance	AK
63472	St. Michael, Norton Sound, Alaska (sub)	NOS	9468132	63.475	-162.027	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61154	-02:16:00	\N	1	-00:11:00	\N	1	\N	\N	St. Michael	AK
63473	Niyrakpak Lagoon entrance, St. Lawrence Island, Alaska	NOS	9468216	63.62	-171.383	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	-03:31:00	\N	0.67	-03:27:00	\N	0.83	\N	\N	Niyrakpak Lagoon entrance	AK
63474	North Bay, Stuart Island, Norton Sound, Alaska	NOS	9468226	63.6283	-162.517	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61154	-00:28:00	\N	0.72	-00:28:00	\N	0.72	\N	\N	North Bay, Stuart Island	AK
63475	Point Spencer, Port Clarence, Norton Sound, Alaska (sub)	NOS	9469237	65.2567	-166.847	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	05:26:00	\N	0.35	05:15:00	\N	0.81	\N	\N	Point Spencer, Port Clarence	AK
63476	Teller, Port Clarence, Alaska (sub)	NOS	9469239	65.2667	-166.353	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	04:13:00	\N	0.87	04:01:00	\N	0.8	\N	\N	Teller, Port Clarance	AK
63477	Lost River, Seward Peninsula, Alaska (sub)	NOS	9469338	65.39	-167.145	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	05:30:00	\N	0.29	06:43:00	\N	0.71	\N	\N	Lost River, Seward Peninsula	AK
63478	Tin City, Bering Sea, Alaska (sub)	NOS	9469439	65.55833333333334	-167.975	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	06:14:00	\N	0.32	07:30:00	\N	0.61	\N	\N	Tin City	AK
63479	Point Barrow, Alaska	NOS	9495048	71.36	-156.353	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:26:00	\N	0.04	-00:37:00	\N	0.04	\N	\N	Point Barrow	AK
63480	Redhook Bay, St. Thomas, Virgin Islands	NOS	9751540	18.3267	-64.8517	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61186	00:44:00	\N	1.28	-00:46:00	\N	1.28	\N	\N	Redhook Bay, St. Thomas Island	VI
63481	Mayagez, Puerto Rico (sub)	NOS	9759394	18.21888888888889	-67.1625	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61196	-00:11:00	\N	0.76	-00:09:00	\N	0.93	\N	\N	Mayaguez	PR
63482	Troy, Hudson River, New York	NOS	TEC1603	42.71666666666667	-73.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60323	00:10:00	\N	1	00:08:00	\N	1	\N	\N	Troy	NY
63483	Chelsea, Arthur Kill, New Jersey	NOS	TEC1645	40.6	-74.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:37:00	\N	1.05	00:23:00	\N	1.07	\N	\N	Chelsea	NJ
63484	Oregon Inlet, North Carolina	NOS	TEC2771	35.76666666666701	-75.516666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	-00:27:00	\N	0.71	-00:03:00	\N	1.98	\N	\N	Oregon Inlet	NC
63485	Cape Hatteras, North Carolina	NOS	TEC2789	35.23333333333299	-75.516666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:01:00	\N	1.08	00:01:00	\N	1	\N	\N	Cape Hatteras	NC
63486	Hatteras Inlet, North Carolina	NOS	TEC2791	35.2	-75.733333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:13:00	\N	0.83	00:08:00	\N	0.66	\N	\N	Hatteras Inlet	NC
63487	Ocracoke Inlet, North Carolina	NOS	TEC2793	35.06666666666701	-76.016666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:11:00	\N	0.83	00:09:00	\N	0.63	\N	\N	Ocracoke Inlet	NC
63488	Shell Point, Harkers Island, North Carolina	NOS	TEC2801	34.68333333333299	-76.53333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	02:34:00	\N	0.83	01:52:00	\N	0.54	\N	\N	Shell Point, Harkers Island	NC
63489	N.C. State Fisheries, North Carolina	NOS	TEC2831	34.71666666666701	-76.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:32:00	\N	0.83	01:05:00	\N	0.66	\N	\N	N.C. State Fisheries	NC
63490	Bogue Inlet, North Carolina	NOS	TEC2837	34.65	-77.1	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:15:00	\N	0.83	00:13:00	\N	0.73	\N	\N	Bogue Inlet	NC
63491	Cape Fear, North Carolina	NOS	TEC2847	33.85	-77.96666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:07:00	\N	1.33	00:04:00	\N	1.47	\N	\N	Cape Fear	NC
63492	Castle Hayne, Northeast River, Cape Fear River, North Carolina	NOS	TEC2863	34.35	-77.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	02:54:00	\N	0.42	02:44:00	\N	0.42	\N	\N	Castle Hayne, Northeast River	NC
63493	Bannermans Branch, Northeast River, Cape Fear River, North Carolina	NOS	TEC2865	34.583333333332995	-77.766666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	06:08:00	\N	0.31	05:58:00	\N	0.32	\N	\N	Bannermans Branch, Northeast River	NC
63494	Lockwoods Folly Inlet, North Carolina	NOS	TEC2869	33.916666666667005	-78.233333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:15:00	\N	1	00:04:00	\N	0.84	\N	\N	Lockwoods Folly Inlet	NC
63495	Winyah Bay Entrance (South Jetty), South Carolina	NOS	TEC2929	33.18333333333299	-79.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:24:00	\N	0.89	-00:21:00	\N	0.87	\N	\N	Winyah Bay Entrance (South Jetty)	SC
63496	Frazier Point, South Carolina	NOS	TEC2937	33.31666666666701	-79.28333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:07:00	\N	0.68	01:26:00	\N	0.66	\N	\N	Frazier Point	SC
63497	North Santee River Inlet, South Carolina	NOS	TEC2991	33.13333333333299	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:04:00	\N	0.84	-00:09:00	\N	0.85	\N	\N	North Santee River Inlet	SC
63498	Brown Island, South Santee River, South Carolina	NOS	TEC3001	33.15	-79.33333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:31:00	\N	0.79	00:27:00	\N	0.78	\N	\N	Brown Island, South Santee River	SC
63499	Cape Romain, 46 miles east of, South Carolina	NOS	TEC3011	33.1	-78.433333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-01:13:00	\N	0.79	-01:05:00	\N	0.78	\N	\N	Cape Romain, 46 miles east of	SC
63500	Jack Creek entrance, Bulls Bay, South Carolina	NOS	TEC3023	32.93333333333299	-79.58333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:15:00	\N	0.95	-00:14:00	\N	0.95	\N	\N	Jack Creek entrance	SC
63501	Sullivans Island (outer coast), South Carolina	NOS	TEC3047	32.76666666666701	-79.83333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:12:00	\N	1	-00:08:00	\N	0.99	\N	\N	Sullivans Island (outer coast)	SC
63502	Shipyard Creek, 0.8 mile above entrance., South Carolina	NOS	TEC3061	32.833333333332995	-79.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:20:00	\N	1	00:34:00	\N	1.01	\N	\N	Shipyard Creek, 0.8 mile above entrance.	SC
63503	Folly Island (outer coast), South Carolina	NOS	TEC3127	32.65	-79.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:14:00	\N	1	-00:08:00	\N	0.98	\N	\N	Folly Island (outer coast)	SC
63504	Euhaw Creek, 2.5 mi. above entrance, Broad River, South Carolina	NOS	TEC3327	32.435	-80.85166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:09:00	\N	0.91	01:33:00	\N	1.14	\N	\N	Euhaw Creek, 2.5 mi. above entrance	SC
63505	Tybee Creek entrance, Georgia	NOS	TEC3399	31.983333333332993	-80.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:05:00	\N	1	-00:09:00	\N	0.99	\N	\N	Tybee Creek entrance	GA
63506	Beach Hammock, Georgia	NOS	TEC3401	31.95	-80.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:07:00	\N	1	-00:01:00	\N	1	\N	\N	Beach Hammock	GA
63507	Romerly Marsh Creek, Georgia	NOS	TEC3403	31.933333333332993	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:03:00	\N	1.03	00:08:00	\N	1.03	\N	\N	Romerly Marsh Creek	GA
63508	Savannah Sheraton Resort Hotel, Wilmington River, Georgia	NOS	TEC3405	32	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:06:00	\N	1.14	00:14:00	\N	1.13	\N	\N	Savannah Sheraton Resort Hotel	GA
63509	Thunderbolt, Wilmington River, Georgia	NOS	TEC3407	32.03333333333299	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:12:00	\N	1.14	00:32:00	\N	1.15	\N	\N	Thunderbolt	GA
63510	North entrance, Wilmington River, Georgia	NOS	TEC3409	32.06666666666701	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:44:00	\N	1.09	00:40:00	\N	1.1	\N	\N	North entrance	GA
63511	Isle of Hope, Skidaway River, Georgia	NOS	TEC3411	31.983333333332993	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:28:00	\N	1.13	00:50:00	\N	1.13	\N	\N	Isle of Hope, Skidaway River	GA
63512	Egg Islands, Georgia	NOS	TEC3413	31.83333333333299	-81.08333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:10:00	\N	1.04	00:04:00	\N	1.04	\N	\N	Egg Islands	GA
63513	Coffee Bluff, Forest River, Georgia	NOS	TEC3417	31.933333333332993	-81.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:42:00	\N	1.09	01:05:00	\N	1.09	\N	\N	Coffee Bluff, Forest River	GA
63514	Fort McAllister, Ogeechee River, Georgia	NOS	TEC3419	31.883333333332992	-81.21666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:16:00	\N	1	00:48:00	\N	1	\N	\N	Fort McAllister, Ogeechee River	GA
63515	Highway bridge, Ogeechee River, Georgia	NOS	TEC3421	31.983333333332993	-81.28333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	04:25:00	\N	0.14	03:19:00	\N	0.15	\N	\N	Highway bridge, Ogeechee River	GA
63516	Florida Passage, Bear River, Georgia	NOS	TEC3425	31.816666666667007	-81.16666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:49:00	\N	0.95	00:46:00	\N	1.09	\N	\N	Florida Passage, Bear River	GA
63517	Cane Patch Creek entrance, Georgia	NOS	TEC3427	31.816666666667007	-81.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:43:00	\N	1.05	00:55:00	\N	1.05	\N	\N	Cane Patch Creek entrance	GA
63518	North Newport River, Georgia	NOS	TEC3445	31.66666666666701	-81.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:36:00	\N	1.09	00:56:00	\N	1.1	\N	\N	North Newport River	GA
63519	South Newport Cut, N. Newport River, Georgia	NOS	TEC3447	31.66666666666701	-81.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:54:00	\N	1.04	01:01:00	\N	1.08	\N	\N	South Newport Cut, N. Newport River	GA
63520	Dallas Bluff, Julienton River, Georgia	NOS	TEC3457	31.58333333333299	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:04:00	\N	1.09	00:48:00	\N	1.1	\N	\N	Dallas Bluff, Julienton River	GA
63521	Blackbeard Island, Georgia	NOS	TEC3463	31.53333333333299	-81.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:22:00	\N	1	00:18:00	\N	1	\N	\N	Blackbeard Island	GA
63522	Wolf Island, south end, Georgia	NOS	TEC3491	31.33333333333299	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:45:00	\N	1.09	00:25:00	\N	0.97	\N	\N	Wolf Island, south end	GA
63523	Hampton River entrance, Georgia	NOS	TEC3495	31.21666666666701	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:04:00	\N	0.95	00:16:00	\N	0.96	\N	\N	Hampton River entrance	GA
63524	Jones Creek entrance, Hampton River, Georgia	NOS	TEC3497	31.3	-81.33333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:13:00	\N	1.05	01:03:00	\N	1.05	\N	\N	Jones Creek entrance, Hampton River	GA
63525	St. Simons Sound Bar, Georgia	NOS	TEC3499	31.1	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:02:00	\N	0.95	-00:01:00	\N	0.95	\N	\N	St. Simons Sound Bar	GA
63526	Allied Chemical Corp. docks, Turtle River, Georgia	NOS	TEC3515	31.183333333332993	-81.516666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:42:00	\N	1.09	01:03:00	\N	1.1	\N	\N	Allied Chemical Corp. docks	GA
63527	Highway bridge, South Brunswick River, Georgia	NOS	TEC3521	31.15	-81.566666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:49:00	\N	1.09	01:07:00	\N	1.1	\N	\N	Highway bridge, South Brunswick River	GA
63528	Below Spring Bluff, Little Satilla River, Georgia	NOS	TEC3531	31.16666666666701	-81.616666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:31:00	\N	1.23	01:09:00	\N	1.23	\N	\N	Below Spring Bluff	GA
63529	Burnt Fort, Satilla River, Georgia	NOS	TEC3541	30.95	-81.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	05:05:00	\N	0.53	03:55:00	\N	0.53	\N	\N	Burnt Fort	GA
63530	Cape Canaveral, Florida	NOS	TEC3693	28.433333333332993	-80.566666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:44:00	\N	1.42	-01:06:00	\N	1.5	\N	\N	Cape Canaveral	FL
63531	Jupiter Inlet, U.S. Highway 1 Bridge, Florida	NOS	TEC3783	26.948333333332993	-80.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:05:00	\N	1.14	00:28:00	\N	0.86	\N	\N	Jupiter Inlet, U.S. Highway 1 Bridge	FL
63532	Tequesta, Loxahatchee River, Florida	NOS	TEC3787	26.95	-80.10166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:58:00	\N	1.14	00:59:00	\N	0.8	\N	\N	Tequesta	FL
63533	Tequesta, North Fork entrance, Loxahatchee River, Florida	NOS	TEC3789	26.95166666666701	-80.10166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:42:00	\N	0.92	00:51:00	\N	0.78	\N	\N	Tequesta, North Fork entrance	FL
63534	Cape Sable, East Cape, Florida	NOS	TEC4165	25.116666666667008	-81.08333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:50:00	\N	0.98	01:33:00	\N	1.3	\N	\N	Cape Sable, East Cape	FL
63535	Whitewater Bay, Florida	NOS	TEC4169	25.316666666667007	-81.03333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	04:38:00	\N	0.33	03:53:00	\N	0.26	\N	\N	Whitewater Bay	FL
63536	Indian Key, Florida	NOS	TEC4183	25.8	-81.46666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:19:00	\N	0.98	00:55:00	\N	1.48	\N	\N	Indian Key	FL
63537	Round Key, Florida	NOS	TEC4185	25.83333333333299	-81.53333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:12:00	\N	0.98	00:54:00	\N	1.48	\N	\N	Round Key	FL
63538	Point Ybel, San Carlos Bay entrance, Florida	NOS	TEC4207	26.45	-82.016666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:12:00	\N	1.21	-01:50:00	\N	1.21	\N	\N	Point Ybel, San Carlos Bay entrance	FL
63539	Pass-a-Grille Beach, Boca Ciega Bay, Florida	NOS	TEC4271	27.683333333332993	-82.733333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:30:00	\N	0.87	-01:34:00	\N	0.87	\N	\N	Pass-a-Grille Beach	FL
63540	Suwannee River entrance, Florida	NOS	TEC4299	29.28333333333299	-83.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:18:00	\N	0.95	00:06:00	\N	0.88	\N	\N	Suwannee River entrance	FL
63541	Pepperfish Keys, Florida	NOS	TEC4301	29.5	-83.366666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:24:00	\N	0.95	00:12:00	\N	0.88	\N	\N	Pepperfish Keys	FL
63542	Fishermans Rest, Florida	NOS	TEC4305	29.733333333332993	-83.53333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	-00:02:00	\N	0.86	-00:14:00	\N	0.93	\N	\N	Fishermans Rest	FL
63543	Rock Islands, Florida	NOS	TEC4309	29.96666666666701	-83.83333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	00:04:00	\N	0.91	-00:03:00	\N	0.93	\N	\N	Rock Islands	FL
63544	Lower Anchorage, Apalachicola Bay, Florida	NOS	TEC4343	29.6	-85.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-00:35:00	\N	1	-00:17:00	\N	0.93	\N	\N	Lower Anchorage	FL
63545	Milton, Blackwater River, Pensacola Bay, Florida	NOS	TEC4383	30.616666666667008	-87.03333333333299	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	01:47:00	\N	1.2	01:40:00	\N	1.2	\N	\N	Milton, Blackwater River	FL
63546	Paris Road Bridge (ICWW), Louisiana	NOS	TEC4445	30	-89.933333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	05:58:00	\N	1.04	05:53:00	\N	1.04	\N	\N	Paris Road Bridge (ICWW)	LA
63547	Bayou Rigaud, Grand Isle, Barataria Bay, Louisiana	NOS	TEC4455	29.266666666667007	-89.96666666666701	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	00:46:00	\N	0.94	01:32:00	\N	0.94	\N	\N	Bayou Rigaud, Grand Isle	LA
63548	Mermentau River entrance, Louisiana	NOS	TEC4495	29.75	-93.1	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-00:59:00	\N	1.79	-01:54:00	\N	1.79	\N	\N	Mermentau River entrance	LA
63549	Galveston Bay entrance, south jetty, Texas	NOS	TEC4507	29.33333333333299	-94.7	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-01:05:00	\N	1.43	-00:39:00	\N	1.43	\N	\N	Galveston Bay entrance, south jetty	TX
63550	Texas City, Turning Basin, Galveston Bay, Texas	NOS	TEC4513	29.383333333332992	-94.883333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	00:41:00	\N	1	00:33:00	\N	1	\N	\N	Texas City, Turning Basin	TX
63551	Gilchrist, East Bay, Galveston Bay, Texas	NOS	TEC4525	29.516666666667007	-94.483333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	04:18:00	\N	0.86	03:16:00	\N	0.86	\N	\N	Gilchrist, East Bay	TX
63552	Guanica, Puerto Rico	NOS	TEC4731	17.96666666666701	-66.91666666666701	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	00:18:00	\N	1	-01:22:00	\N	1	\N	\N	Guanica	PR
63553	Playa de Ponce, Puerto Rico	NOS	TEC4733	17.96666666666701	-66.616666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	-00:13:00	\N	1.14	-00:39:00	\N	1.14	\N	\N	Playa de Ponce	PR
63554	Playa Cortada, Puerto Rico	NOS	TEC4735	17.983333333332993	-66.45	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	-00:37:00	\N	1.14	00:16:00	\N	1.14	\N	\N	Playa Cortada	PR
63555	Arroyo, Puerto Rico	NOS	TEC4737	17.96666666666701	-66.066666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	00:13:00	\N	1.14	00:52:00	\N	1.14	\N	\N	Arroyo	PR
63556	Puerto Maunabo, Puerto Rico	NOS	TEC4739	18	-65.883333333333	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	01:13:00	\N	1	-00:56:00	\N	1	\N	\N	Puerto Maunabo	PR
63557	Culebrita, Isla, Puerto Rico	NOS	TEC4741	18.316666666667007	-65.233333333333	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	02:40:00	\N	1.57	-02:34:00	\N	1.57	\N	\N	Culebrita, Isla	PR
63558	Puerto Ferro, Isla de Vieques, Puerto Rico	NOS	TEC4743	18.1	-65.433333333333	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	03:01:00	\N	1.14	-02:26:00	\N	1.14	\N	\N	Puerto Ferro, Isla de Vieques	PR
63559	Punta Mulas, Isla de Vieques, Puerto Rico	NOS	TEC4745	18.15	-65.433333333333	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61196	-00:17:00	\N	0.72	-00:14:00	\N	0.72	\N	\N	Punta Mulas, Isla de Vieques	PR
63560	Roosevelt Roads, Puerto Rico	NOS	TEC4747	18.233333333332993	-65.616666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61196	00:20:00	\N	0.63	00:02:00	\N	0.63	\N	\N	Roosevelt Roads	PR
63561	Ensenada Honda, Culebra Island, Puerto Rico	NOS	TEC4749	18.3	-65.28333333333299	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61196	-00:15:00	\N	0.63	-00:34:00	\N	0.63	\N	\N	Ensenada Honda, Culebra Island	PR
63562	Playa de Fajardo, Puerto Rico	NOS	TEC4751	18.33333333333299	-65.633333333333	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61196	-00:13:00	\N	0.99	-00:10:00	\N	0.99	\N	\N	Playa de Fajardo	PR
63563	Magens Bay, St. Thomas, Virgin Islands	NOS	TEC4759	18.366666666667008	-64.91666666666701	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61186	-00:17:00	\N	1.59	-00:06:00	\N	1.59	\N	\N	Magens Bay, St. Thomas Island	VI
63564	Pagan Island, Marianas	NOS	TPT2621	18.1333	145.76666	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60147	00:01:00	\N	0.94	00:05:00	\N	0.94	\N	\N	Pagan Island	MP
63565	Saipan Harbor, Saipan Island, Marianas	NOS	TPT2623	15.2	145.71666666667008	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60147	00:07:00	\N	0.8	00:02:00	\N	0.8	\N	\N	Saipan Harbor, Saipan Island	MP
63566	Tinian Island, Marianas	NOS	TPT2625	14.966666666667008	145.61666666667008	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60147	-00:23:00	\N	0.33	-00:02:00	\N	0.74	\N	\N	Tinian Island	MP
63567	Rota Island, Marianas	NOS	TPT2627	14.1333	145.1333	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60147	-00:06:00	\N	0.94	-00:03:00	\N	0.94	\N	\N	Rota Island	MP
63568	Ifalik Atoll, Caroline Islands, FSM	NOS	TPT2647	7.25	144.45	:Pacific/Yap	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60147	-00:13:00	\N	1.33	-00:54:00	\N	1	\N	\N	Ifalik Atoll	FM
63569	Pulap Atoll, Chuuk, FSM	NOS	TPT2651	7.633333333333304	149.41666666667007	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:43:00	\N	0.74	-00:53:00	\N	0.74	\N	\N	Pulap Atoll	FM
63570	Namonuito Atoll, Caroline Islands, FSM	NOS	TPT2653	8.583333333333297	149.65	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:21:00	\N	0.69	-01:23:00	\N	0.69	\N	\N	Namonuito Atoll	FM
63571	Nomwin Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2655	8.45	151.78333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:20:00	\N	0.8	-00:08:00	\N	0.8	\N	\N	Nomwin Atoll, Hall Islands	FM
63572	Murilo Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2657	8.6	152.25	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:00:00	\N	0.85	-00:28:00	\N	0.85	\N	\N	Murilo Atoll, Hall Islands	FM
63573	Chuuk, Moen Island, E. Caroline Islands, FSM (sub)	NOS	TPT2659	7.45	151.85	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:11:00	\N	0.85	00:10:00	\N	0.85	\N	\N	Moen Island, Truk Islands	FM
63574	Dublon Island, Chuuk, FSM	NOS	TPT2661	7.366666666666704	151.88333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:30:00	\N	1.07	00:02:00	\N	1.07	\N	\N	Dublon Island, Truk Islands	FM
63575	Losap Atoll, Chuuk, FSM	NOS	TPT2663	6.9	152.7333333333299	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:25:00	\N	0.8	-00:03:00	\N	0.8	\N	\N	Losap Atoll	FM
63576	Namoluk Atoll, Chuuk, FSM	NOS	TPT2665	5.9	153.13333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:27:00	\N	0.8	-00:01:00	\N	0.8	\N	\N	Namoluk Atoll	FM
63577	Satawan Anchorage, Nomoi Islands, Chuuk, FSM	NOS	TPT2667	5.333333333333304	153.7333333333299	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:25:00	\N	0.96	-00:03:00	\N	0.96	\N	\N	Satawan Anchorage, Nomoi Islands	FM
63578	Bikini Atoll, Marshall Islands	NOS	TPT2687	11.6	165.55	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:19:00	0	\N	-00:19:00	0	\N	\N	\N	Bikini Atoll	MH
63579	Eniirikku Island, Bikini Atoll, Marshall Islands	NOS	TPT2689	11.5	165.33333333332993	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:16:00	\N	0.85	-00:15:00	\N	0.85	\N	\N	Eniirikku Island, Bikini Atoll	MH
63580	Rongelap Island, Rongelap Atoll, Marshall Islands	NOS	TPT2691	11.15	166.9	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:07:00	\N	0.96	-00:07:00	\N	0.96	\N	\N	Rongelap Island, Rongelap Atoll	MH
63581	Rongerik Atoll, Marshall Islands	NOS	TPT2693	11.383333333333008	167.5166666666701	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:15:00	0	\N	-00:14:00	0.1	\N	\N	\N	Rongerik Atoll	MH
63582	Ujae Atoll, Marshall Islands	NOS	TPT2695	9.033333333333296	165.6	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ujae Atoll	MH
63583	Kwajalein Atoll (Namur Island), Marshall Islands	NOS	TPT2697	9.4	167.4833333333299	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:05:00	0	\N	-00:02:00	0	\N	\N	\N	Kwajalein Atoll (Namur Island)	MH
63584	Ailinglapalap Atoll, Marshall Islands	NOS	TPT2701	7.283333333333304	168.75	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	00:07:00	0.3	\N	00:08:00	0.4	\N	\N	\N	Ailinglapalap Atoll	MH
63585	Jaluit Atoll (SE Pass), Marshall Islands	NOS	TPT2703	5.916666666666696	169.65	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:08:00	-0.1	\N	-00:12:00	-0.1	\N	\N	\N	Jaluit Atoll (SE Pass)	MH
63586	Ebon (Boston) Atoll, Marshall Islands	NOS	TPT2705	4.6	168.68333333332993	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:10:00	0.1	\N	-00:10:00	0.1	\N	\N	\N	Ebon (Boston) Atoll	MH
63587	Taongi Atoll, Marshall Islands	NOS	TPT2707	14.566666666667007	168.95	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:20:00	0	\N	-00:20:00	0	\N	\N	\N	Taongi Atoll	MH
63588	Bikar (Dawson) Atoll, Marshall Islands	NOS	TPT2709	12.25	170.13333333332992	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Bikar (Dawson) Atoll	MH
63589	Ailuk Atoll, Marshall Islands	NOS	TPT2711	10.216666666667008	169.9833333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ailuk Atoll	MH
63590	Likiep Atoll, Marshall Islands	NOS	TPT2713	9.816666666666704	169.31666666667007	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:01:00	0	\N	00:00:00	0.1	\N	\N	\N	Likiep Atoll	MH
63591	Wotje Atoll, Marshall Islands	NOS	TPT2715	9.466666666666704	170.2333333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:11:00	-0.2	\N	-00:11:00	-0.2	\N	\N	\N	Wotje Atoll	MH
63592	Erikub Atoll, Marshall Islands	NOS	TPT2717	9.2	169.91666666667007	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Erikub Atoll	MH
63593	Maloelap Atoll, Marshall Islands	NOS	TPT2719	8.716666666666704	171.2333333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:05:00	-0.1	\N	-00:04:00	0.1	\N	\N	\N	Maloelap Atoll	MH
63594	Majuro Atoll, Marshall Islands	NOS	TPT2721	7.116666666666704	171.36666666667008	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:06:00	0.1	\N	-00:05:00	0.3	\N	\N	\N	Majuro Atoll	MH
63595	Arno Atoll, Marshall Islands	NOS	TPT2723	7.133333333333304	171.7	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:05:00	-0.1	\N	-00:04:00	0.6	\N	\N	\N	Arno Atoll	MH
63596	Port Rhin, Mili Atoll, Marshall Islands	NOS	TPT2725	6.233333333333296	171.8	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	00:04:00	0	\N	00:04:00	0.7	\N	\N	\N	Port Rhin, Mili Atoll	MH
63597	Howland Island	NOS	TPT2737	0.8	-176.63333333332992	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	03:46:00	0.4	\N	03:48:00	4.2	\N	\N	\N	Howland Island	\N
63598	Palmyra Island	NOS	TPT2739	5.883333333333304	-162.08333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	01:13:00	-0.2	\N	01:19:00	0.6	\N	\N	\N	Palmyra Island	\N
63599	Waikane, Kaneohe Bay, Oahu Island, Hawaii	NOS	TPT2777	21.5	-157.85	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60140	-00:04:00	\N	1	-00:22:00	\N	1.13	\N	\N	Waikane, Kaneohe Bay	HI
63600	Laie Bay, Oahu Island, Hawaii	NOS	TPT2779	21.65	-157.93333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60140	-00:32:00	\N	0.75	-00:21:00	\N	1	\N	\N	Laie Bay	HI
63601	Kihei, Maalaea Bay, Maui Island, Hawaii	NOS	TPT2797	20.78333333333299	-156.46666666667008	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60142	01:19:00	\N	0.54	01:52:00	\N	0.94	\N	\N	Kihei, Maalaea Bay	HI
63602	Lahaina, Maui Island, Hawaii	NOS	TPT2799	20.883333333332992	-156.68333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60142	01:01:00	\N	0.81	01:18:00	\N	0.89	\N	\N	Lahaina	HI
63603	Smuggler Cove, Kahoolawe Island, Hawaii	NOS	TPT2803	20.516666666667007	-156.68333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:03:00	0	\N	-00:15:00	0.2	\N	\N	\N	Smuggler Cove	HI
63604	Tau Island, Manua Islands, American Samoa	NOS	TPT2865	-14.21666666666667	-169.5333333333333	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60150	-00:24:00	\N	1	-00:25:00	\N	1.43	\N	\N	Tau Island, Manua Islands	AS
63605	Point Loma, California	NOS	TWC0405	32.666666666667005	-117.23333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	-00:02:00	\N	0.92	-00:09:00	\N	0.92	\N	\N	Point Loma	CA
63606	Quivira Basin, Mission Bay, California	NOS	TWC0413	32.76666666666701	-117.23333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	00:04:00	\N	0.95	00:05:00	\N	0.95	\N	\N	Quivira Basin, Mission Bay	CA
63607	San Clemente, California	NOS	TWC0419	33.416666666667005	-117.61666666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	-00:11:00	\N	0.92	-00:15:00	\N	0.92	\N	\N	San Clemente	CA
63608	Los Patos (highway bridge), California	NOS	TWC0427	33.71666666666701	-118.05	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	01:12:00	\N	0.6	01:00:00	\N	0.83	\N	\N	Los Patos (highway bridge)	CA
63609	Los Angeles Harbor, Mormon Island, California	NOS	TWC0439	33.75	-118.26666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:02:00	0	\N	00:04:00	-0.1	\N	\N	\N	Los Angeles Harbor, Mormon Island	CA
63610	Mugu Lagoon (ocean pier), California	NOS	TWC0445	34.1	-119.1	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:11:00	\N	0.96	00:03:00	\N	0.96	\N	\N	Mugu Lagoon (ocean pier)	CA
63611	Santa Barbara Island, California	NOS	TWC0463	33.48333333333299	-119.03333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:04:00	\N	0.92	-00:02:00	\N	0.92	\N	\N	Santa Barbara Island	CA
63612	Point Arguello, California	NOS	TWC0473	34.583333333332995	-120.65	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60835	-00:08:00	\N	0.96	-00:03:00	\N	0.96	\N	\N	Point Arguello	CA
63613	San Francisco Bar, California	NOS	TWC0509	37.76666666666701	-122.63333333333004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:31:00	0	\N	-00:35:00	-0.2	\N	\N	\N	San Francisco Bar	CA
63614	Roberts Landing, 1.3 miles west of, San Francisco Bay, California	NOS	TWC0547	37.666666666667005	-122.2	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:28:00	0.1	\N	00:52:00	1.4	\N	\N	\N	Roberts Landing, 1.3 miles west of	CA
63615	Redwood Creek entrance (inside), San Francisco Bay, California	NOS	TWC0573	37.51666666666701	-122.2	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:38:00	0.1	\N	01:06:00	2.1	\N	\N	\N	Redwood Creek entrance (inside)	CA
63616	Lakeville, Petaluma River, San Pablo Bay, California	NOS	TWC0649	38.2	-122.56666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:50:00	\N	0.81	01:59:00	\N	1.11	\N	\N	Lakeville, Petaluma River	CA
63617	Point Arena, California	NOS	TWC0771	38.95	-123.73333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60883	00:01:00	\N	0.95	00:03:00	\N	0.98	\N	\N	Point Arena	CA
63618	Mendocino, Mendocino Bay, California	NOS	TWC0777	39.3	-123.8	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60883	00:01:00	\N	0.95	00:07:00	\N	0.98	\N	\N	Mendocino, Mendocino Bay	CA
63619	Wedderburn, Rogue River, Oregon	NOS	TWC0817	42.43333333333299	-124.41666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:16:00	\N	0.92	00:09:00	\N	0.95	\N	\N	Wedderburn, Rogue River	OR
63620	Gardiner, Umpqua River, Oregon	NOS	TWC0831	43.73333333333299	-124.11666666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	01:09:00	\N	0.8	00:56:00	\N	0.88	\N	\N	Gardiner	OR
63621	Nestucca Bay entrance, Oregon	NOS	TWC0857	45.166666666667005	-123.96666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:12:00	\N	0.92	00:55:00	\N	1.1	\N	\N	Nestucca Bay entrance	OR
63622	Miami Cove, Tillamook Bay, Oregon	NOS	TWC0863	45.55	-123.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:26:00	\N	0.92	01:15:00	\N	1.06	\N	\N	Miami Cove	OR
63623	Bay City, Tillamook Bay, Oregon	NOS	TWC0865	45.51666666666701	-123.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	02:00:00	\N	0.83	01:33:00	\N	1.02	\N	\N	Bay City	OR
63624	Point Adams, Oregon	NOS	TWC0881	46.2	-123.95	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:38:00	0.1	\N	-00:25:00	-0.2	\N	\N	\N	Point Adams, Oreg.	OR
63625	Warrenton, Skipanon River, Oregon	NOS	TWC0883	46.166666666667005	-123.91666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:19:00	0.1	\N	-00:13:00	-0.1	\N	\N	\N	Warrenton, Skipanon River, Oreg.	OR
63626	Harrington Point, Washington	NOS	TWC0895	46.26666666666701	-123.65	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	00:52:00	-0.2	\N	00:21:00	-0.8	\N	\N	\N	Harrington Point, Wash.	WA
63627	Tarlatt Slough, Willapa Bay, Washington	NOS	TWC0933	46.37	-124.005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	01:14:00	\N	1.05	00:45:00	\N	1.05	\N	\N	Tarlatt Slough	WA
63628	Mailboat Slough, Willapa River, Willapa Bay, Washington	NOS	TWC0940	46.68833333333299	-123.81666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:11:00	\N	1.02	00:18:00	\N	1.07	\N	\N	Mailboat Slough, Willapa River	WA
63629	Montesano, Chehalis River, Grays Harbor, Washington	NOS	TWC0959	46.96833333333299	-123.6	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	01:45:00	\N	0.94	01:34:00	\N	0.94	\N	\N	Montesano, Chehalis River	WA
63630	Destruction Island, Washington	NOS	TWC0965	47.666666666667005	-124.48333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:43:00	\N	1.02	-00:37:00	\N	0.98	\N	\N	Destruction Island	WA
63631	Burns Point, Totten Inlet, Puget Sound, Washington	NOS	TWC1113	47.12166666666701	-123.05666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	01:07:00	\N	1.06	00:54:00	\N	1.33	\N	\N	Burns Point, Totten Inlet	WA
63632	Rocky Point, Eld Inlet, Puget Sound, Washington	NOS	TWC1115	47.081666666667005	-123.005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:56:00	\N	1.1	00:39:00	\N	1.31	\N	\N	Rocky Point, Eld Inlet	WA
63633	Marysville, Quilceda Creek, Washington	NOS	TWC1125	48.045	-122.21166666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:29:00	\N	0.89	00:09:00	\N	0.95	\N	\N	Marysville, Quilceda Creek	WA
63634	Stanwood, Stillaguamish River, Washington	NOS	TWC1131	48.21666666666667	-122.3666666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	02:14:00	\N	0.29	00:23:00	\N	0.62	\N	\N	Stanwood, Stillaguamish River	WA
63635	Peavine Pass, Washington	NOS	TWC1165	48.6	-122.8	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:18:00	\N	0.92	00:34:00	\N	0.98	\N	\N	Peavine Pass	WA
63636	Chuckanut Bay, Bellingham Bay, Washington	NOS	TWC1169	48.666666666667005	-122.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:53:00	-0.1	\N	00:33:00	0	\N	\N	\N	Chuckanut Bay	WA
63637	Point Migley, Hale Passage, Washington	NOS	TWC1173	48.75	-122.71666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:51:00	0	\N	00:56:00	0.1	\N	\N	\N	Point Migley	WA
63638	Ferndale, Strait of Georgia, Washington	NOS	TWC1189	48.833333333332995	-122.71666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:20:00	0	\N	00:49:00	0.5	\N	\N	\N	Ferndale	WA
63639	Tah Bay, Alaska	NOS	TWC1487	54.833333333332995	-132.33333333332993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:03:00	0.1	\N	-00:04:00	2.6	\N	\N	\N	Tah Bay	AK
63640	Kasook Inlet, Sukkwan Island, Tlevak Strait, Alaska	NOS	TWC1513	55.01666666666701	-132.78333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:05:00	0	\N	-00:13:00	2.8	\N	\N	\N	Kasook Inlet, Sukkwan Island	AK
63641	Cyrus Cove, Sea Otter Sound, Davidson Inlet, Alaska	NOS	TWC1579	55.916666666667005	-133.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:12:00	0	\N	-00:16:00	1.1	\N	\N	\N	Cyrus Cove, Sea Otter Sound	AK
63642	Marble Island, Davidson Inlet, Alaska	NOS	TWC1583	56	-133.46666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:15:00	-0.1	\N	-00:19:00	0.8	\N	\N	\N	Marble Island	AK
63643	Port McArthur, Kuiu Island, Alaska	NOS	TWC1593	56.06666666666701	-134.11666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:07:00	-0.1	\N	-00:11:00	0.6	\N	\N	\N	Port McArthur, Kuiu Island	AK
63644	Ideal Cove, Mitkof Island, Frederick Sound, Alaska	NOS	TWC1657	56.666666666667005	-132.63333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:05:00	0	\N	-00:09:00	-0.2	\N	\N	\N	Ideal Cove, Mitkof Island	AK
63645	Brown Cove, Frederick Sound, Alaska	NOS	TWC1659	56.88333333333299	-132.8	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:10:00	-0.1	\N	-00:14:00	-0.3	\N	\N	\N	Brown Cove	AK
63646	Portage Bay, Kupreanof Island, Frederick Sound, Alaska	NOS	TWC1663	57	-133.31666666667007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:15:00	0	\N	-00:19:00	-0.7	\N	\N	\N	Portage Bay, Kupreanof Island	AK
63647	Eliza Harbor, Liesnoi Island, Frederick Sound, Alaska	NOS	TWC1669	57.166666666667005	-134.28333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:19:00	-0.1	\N	-00:19:00	-1.9	\N	\N	\N	Eliza Harbor, Liesnoi Island	AK
63648	Port Houghton, Robert Islands, Alaska	NOS	TWC1673	57.3	-133.46666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:17:00	-0.1	\N	-00:21:00	-0.8	\N	\N	\N	Port Houghton, Robert Islands	AK
63649	Windfall Harbor, Seymour Canal, Alaska	NOS	TWC1683	57.86666666666701	-134.2666666666701	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:18:00	0	\N	00:14:00	-0.2	\N	\N	\N	Windfall Harbor, Seymour Canal	AK
63650	Port Snettisham, Point Styleman, Alaska	NOS	TWC1687	57.96666666666701	-133.88333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:06:00	-0.1	\N	-00:12:00	-0.4	\N	\N	\N	Port Snettisham, Point Styleman	AK
63651	Fritz Cove, Douglas Island, Alaska	NOS	TWC1697	58.31666666666701	-134.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:05:00	-0.1	\N	-00:01:00	-0.3	\N	\N	\N	Fritz Cove, Douglas Island	AK
63652	Tebenkof Bay, Kuiu Island, Alaska	NOS	TWC1723	56.416666666667005	-134.13333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:11:00	0.1	\N	00:04:00	1.8	\N	\N	\N	Tebenkof Bay, Kuiu Island	AK
63653	Whitewater Bay, Admiralty Island, Alaska	NOS	TWC1731	57.23333333333299	-134.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:15:00	0.3	\N	-00:19:00	-2	\N	\N	\N	Whitewater Bay, Admiralty Island	AK
63654	Point Thatcher, Alaska	NOS	TWC1735	57.416666666667005	-134.85	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:11:00	0.2	\N	-00:15:00	-1.9	\N	\N	\N	Point Thatcher	AK
63655	Favorite Bay, Kootznahoo Inlet, Alaska	NOS	TWC1739	57.48333333333299	-134.55	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:15:00	0.3	\N	00:11:00	-2.8	\N	\N	\N	Favorite Bay	AK
63656	Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	TWC1741	57.53333333333299	-134.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	01:31:00	\N	0.62	01:22:00	\N	0.67	\N	\N	Mitchell Bay	AK
63657	Freshwater Bay, Chichagof Island, Alaska	NOS	TWC1743	57.85	-135.0166666666701	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:00:00	0.3	\N	-00:08:00	-1.5	\N	\N	\N	Freshwater Bay, Chichagof Island	AK
63658	Point Elizabeth, Alaska	NOS	TWC1783	57.51666666666701	-135.28333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:05:00	0	\N	-00:15:00	-1.6	\N	\N	\N	Point Elizabeth	AK
63659	Lindenburg Head, Alaska	NOS	TWC1785	57.45	-135.03333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:05:00	0	\N	-00:15:00	-1.8	\N	\N	\N	Lindenburg Head	AK
63660	Fairway Island, Alaska	NOS	TWC1787	57.45	-134.88333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:05:00	0	\N	-00:15:00	-2.1	\N	\N	\N	Fairway Island	AK
63661	Falcon Arm, Slocum Arm, Chichagof Island, Alaska	NOS	TWC1789	57.55	-135.93333333332993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	-00:07:00	\N	1.1	-00:05:00	\N	0.96	\N	\N	Falcon Arm, Slocum Arm	AK
63662	Wingham Island, Controller Bay, Alaska	NOS	TWC1863	60.05	-144.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:08:00	\N	1.01	00:05:00	\N	0.99	\N	\N	Wingham Island, Controller Bay	AK
63663	Pete Dahl Slough, Copper River Delta, Alaska	NOS	TWC1867	60.38333333333299	-145.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:38:00	0	\N	00:06:00	-2.4	\N	\N	\N	Pete Dahl Slough	AK
63664	Eyak River entrance, Alaska	NOS	TWC1869	60.46666666666701	-145.66666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:58:00	-0.1	\N	00:14:00	-1.6	\N	\N	\N	Eyak River entrance	AK
63665	Gravel Point, Orca Inlet, Alaska	NOS	TWC1875	60.46666666666701	-145.96666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:31:00	0	\N	00:01:00	-0.1	\N	\N	\N	Gravel Point	AK
63666	Orca, Orca Inlet, Alaska	NOS	TWC1879	60.583333333332995	-145.71666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	0	\N	00:01:00	-0.2	\N	\N	\N	Orca	AK
63667	Windy Bay, Hawkins Island, Prince William Sound, Alaska	NOS	TWC1881	60.56666666666701	-145.96666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:01:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Windy Bay, Hawkins Island	AK
63668	Port Etches, Hinchinbrook Island, Alaska	NOS	TWC1887	60.333333333332995	-146.55	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	-0.2	\N	-00:09:00	-1.3	\N	\N	\N	Port Etches	AK
63669	Hanning Bay, Montague Island, Alaska	NOS	TWC1893	59.95	-147.68333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:05:00	-0.1	\N	-00:08:00	-1	\N	\N	\N	Hanning Bay	AK
63670	Smith Island, Prince William Sound, Alaska	NOS	TWC1907	60.53333333333299	-147.31666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:04:00	-0.1	\N	-00:05:00	-0.8	\N	\N	\N	Smith Island	AK
63671	Snug Corner Cove, Port Fidalgo, Prince William Sound, Alaska	NOS	TWC1909	60.73333333333299	-146.65	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:06:00	0	\N	-00:07:00	-0.6	\N	\N	\N	Snug Corner Cove, Port Fidalgo	AK
63672	Cape Ninilchik, Cook Inlet, Alaska	NOS	TWC1979	60.01666666666701	-151.71666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:54:00	0.2	\N	00:41:00	1.2	\N	\N	\N	Cape Ninilchik	AK
63673	Kenai River entrance, Cook Inlet, Alaska	NOS	TWC1983	60.55	-151.28333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	02:18:00	0.5	\N	01:52:00	2.7	\N	\N	\N	Kenai River entrance	AK
63674	East Foreland, Cook Inlet, Alaska	NOS	TWC1989	60.71666666666701	-151.41666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	02:58:00	0.5	\N	02:37:00	3	\N	\N	\N	East Foreland	AK
63675	Iliamna Bay, Cook Inlet, Alaska	NOS	TWC2009	59.61666666666701	-153.58333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:16:00	\N	0.82	00:12:00	\N	0.8	\N	\N	Iliamna Bay	AK
63676	Marmot Island, Marmot Strait, Alaska	NOS	TWC2021	58.23333333333299	-151.86666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:07:00	0	\N	00:18:00	0.9	\N	\N	\N	Marmot Island, Marmot Strait	AK
63677	Izhut Bay, Alaska	NOS	TWC2023	58.21666666666701	-152.31666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:21:00	0	\N	00:12:00	0.1	\N	\N	\N	Izhut Bay	AK
63678	Kazakof Bay, Marmot Bay, Alaska	NOS	TWC2025	58.13333333333299	-152.56666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:06:00	0.2	\N	00:04:00	0.6	\N	\N	\N	Kazakof Bay, Marmot Bay	AK
63679	Kizhuyak Point, Alaska	NOS	TWC2031	57.9	-152.65	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:09:00	0.1	\N	00:05:00	0.6	\N	\N	\N	Kizhuyak Point	AK
63680	Three Saints Bay, Alaska	NOS	TWC2047	57.11666666666701	-153.5166666666701	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:13:00	0.1	\N	-00:22:00	-0.2	\N	\N	\N	Three Saints Bay	AK
63681	Sitkinak Lagoon, Alaska	NOS	TWC2051	56.5	-154.13333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:07:00	0.2	\N	-00:20:00	-1	\N	\N	\N	Sitkinak Lagoon	AK
63682	Village Islands, Uganik Bay, Alaska	NOS	TWC2067	57.78333333333299	-153.55	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:02:00	\N	0.8	-00:15:00	\N	0.8	\N	\N	Village Islands	AK
63683	Northeast Arm, Uganik Bay, Alaska	NOS	TWC2069	57.73333333333299	-153.33333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:01:00	\N	0.77	-00:12:00	\N	0.77	\N	\N	Northeast Arm	AK
63684	Uganik Passage, Uganik Bay, Alaska	NOS	TWC2071	57.8	-153.3	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:02:00	\N	0.81	-00:07:00	\N	0.81	\N	\N	Uganik Passage	AK
63685	Viekoda Bay, Alaska	NOS	TWC2073	57.9	-153.16666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:03:00	\N	0.8	-00:11:00	\N	0.8	\N	\N	Viekoda Bay	AK
63686	Onion Bay, Kupreanof Strait, Alaska	NOS	TWC2075	58.05	-153.2333333333299	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:01:00	\N	0.8	00:00:00	\N	0.8	\N	\N	Onion Bay	AK
63687	Dry Spruce Island, Kupreanof Strait, Alaska	NOS	TWC2077	57.95	-153.03333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:13:00	\N	0.77	00:02:00	\N	0.77	\N	\N	Dry Spruce Island	AK
63688	Malina Bay, Shelikof Strait, Alaska	NOS	TWC2085	58.18333333333299	-152.95	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:00:00	\N	0.81	-00:14:00	\N	0.81	\N	\N	Malina Bay, Shelikof Strait	AK
63689	Katmai Bay, Shelikof Strait, Alaska	NOS	TWC2095	58	-154.9833333333299	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:01:00	\N	0.71	-00:14:00	\N	0.71	\N	\N	Katmai Bay, Shelikof Strait	AK
63690	Lees Cabins, Wide Bay, Alaska	NOS	TWC2101	57.43333333333299	-156.3	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:32:00	0.2	\N	00:21:00	3.2	\N	\N	\N	Lees Cabins, Wide Bay	AK
63691	Three Star Point, Alaska	NOS	TWC2105	55.9	-159.16666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:37:00	\N	1.28	00:28:00	\N	0.9	\N	\N	Three Star Point	AK
63692	Fox Bay, Kupreanof Peninsula, Alaska	NOS	TWC2111	55.63333333333299	-159.61666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:33:00	\N	1.19	00:18:00	\N	0.86	\N	\N	Fox Bay, Kupreanof Peninsula	AK
63693	Mist Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	TWC2119	55.13333333333299	-159.85	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	-00:01:00	\N	0.9	00:01:00	\N	0.97	\N	\N	Mist Harbor, Nagai Island	AK
63694	Malga Bay, Unalga Island, Aleutian Islands, Alaska	NOS	TWC2175	53.98333333333299	-166.16666666667007	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-01:05:00	\N	0.93	-00:18:00	\N	0.85	\N	\N	Malga Bay, Unalga Island	AK
63695	Kashega Bay, Unalaska Island, Alaska	NOS	TWC2187	53.46666666666701	-167.08333333332993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:24:00	\N	1.19	-00:08:00	\N	1.08	\N	\N	Kashega Bay	AK
63696	Eagle Bay, Unalaska Island, Alaska	NOS	TWC2193	53.48333333333299	-166.93333333332993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:16:00	\N	1.02	-02:56:00	\N	1.46	\N	\N	Eagle Bay	AK
63697	Herbert Island, west side, Aleutian Islands, Alaska	NOS	TWC2223	52.71666666666701	-170.15	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-01:51:00	\N	0.93	-01:40:00	\N	1.14	\N	\N	Herbert Island, west side	AK
63698	Amukta Island, north side, Aleutian Islands, Alaska	NOS	TWC2229	52.51666666666701	-171.2333333333299	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-02:03:00	\N	1.1	-01:32:00	\N	0.94	\N	\N	Amukta Island, north side	AK
63699	Gareloi Island, Delarof Islands, Alaska	NOS	TWC2297	51.75	-178.8	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:30:00	\N	1	-00:08:00	\N	1	\N	\N	Gareloi Island	AK
63700	Constantine Harbor, Amchitka Island, Rat Islands, Alaska	NOS	TWC2303	51.416666666667005	179.28333333332992	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:06:00	\N	0.76	00:19:00	\N	0.76	\N	\N	Constantine Harbor, Amchitka Island	AK
63701	Gertrude Cove, Kiska Island, Rat Islands, Alaska	NOS	TWC2305	51.93333333333299	177.45	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:19:00	\N	0.86	00:02:00	\N	0.86	\N	\N	Gertrude Cove, Kiska Island	AK
63702	Kiska Harbor, Kiska Island, Rat Islands, Alaska	NOS	TWC2307	51.98333333333299	177.55	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:13:00	\N	0.97	00:24:00	\N	0.97	\N	\N	Kiska Harbor, Kiska Island	AK
63703	Alcan Harbor, Shemya Island, Aleutian Islands, Alaska	NOS	TWC2309	52.71666666666667	174.0666666666667	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	-00:03:00	\N	1.03	00:00:00	\N	1.03	\N	\N	Alcan Harbor, Shemya Island	AK
63704	Otkriti Bay, Agattu Island, Aleutian Islands, Alaska	NOS	TWC2311	52.36666666666667	173.6166666666667	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	-00:13:00	\N	1.03	-00:14:00	\N	1.03	\N	\N	Otkriti Bay, Agattu Island	AK
63705	Chichagof Harbor, Attu Island, Alaska	NOS	TWC2315	52.91666666666666	173.2166666666667	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	00:16:00	\N	1.09	00:13:00	\N	1.09	\N	\N	Chichagof Harbor	AK
63706	Holtz Bay, Attu Island, Alaska	NOS	TWC2317	52.91666666666666	173.1666666666667	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	00:18:00	\N	1.12	-00:04:00	\N	1.12	\N	\N	Holtz Bay	AK
63707	Steller Cove, Attu Island, Alaska	NOS	TWC2319	52.96666666666667	172.9	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	00:11:00	\N	1.12	-00:13:00	\N	1.12	\N	\N	Steller Cove	AK
63708	Etienne Bay, Attu Island, Alaska	NOS	TWC2321	52.91666666666666	172.6166666666667	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	00:03:00	\N	1.12	-00:17:00	\N	1.12	\N	\N	Etienne Bay	AK
63709	Zapadni Bay, St. George Island, Bering Sea, Alaska	NOS	TWC2375	56.56666666666701	-169.68333333332993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	01:18:00	\N	0.89	01:15:00	\N	0.89	\N	\N	Zapadni Bay, St. George Island	AK
63710	Apoon Mouth, Yukon River, Norton Sound, Alaska	NOS	TWC2405	63.05	-163.38333333332992	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61154	-01:30:00	\N	1.03	-01:30:00	\N	1.03	\N	\N	Apoon Mouth, Yukon River	AK
63711	Flaxman Island, Alaska	NOS	TWC2423	70.183333333333	-145.83333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:28:00	\N	0.09	-00:57:00	\N	0.08	\N	\N	Flaxman Island	AK
63712	Old Man Shoal, Nantucket Shoals, Massachusetts Current	NOS	ACT1591_1	41.22667	-69.98333	:America/New_York	USA	knots	225	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:14:00	\N	0.9	01:03:00	\N	0.9	01:23:00	01:17:00	Old Man Shoal, Nantucket Shoals	MA
63713	Miacomet Pond, 3.0 miles SSE of, Massachusetts Current	NOS	ACT1596_1	41.19	-70.09667	:America/New_York	USA	knots	280	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:16:00	\N	0.8	02:03:00	\N	0.6	02:19:00	02:22:00	Miacomet Pond, 3.0 miles SSE of	MA
63714	Tuckernuck Island, 4.2 miles SSW of, Massachusetts Current	NOS	ACT1601_1	41.22617	-70.28167	:America/New_York	USA	knots	280	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:56:00	\N	0.6	03:13:00	\N	0.3	04:08:00	02:17:00	Tuckernuck Island, 4.2 miles SSW of	MA
63715	Pollock Rip Channel, east end, Nantucket Sound entrance, Massachusetts Current	NOS	ACT1611_1	41.565	-69.92333	:America/New_York	USA	knots	212	53	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:38:00	\N	1.1	-00:39:00	\N	1	-00:14:00	-00:23:00	Pollock Rip Channel, east end	MA
63716	Monomoy Pt., channel 0.2 mile west of, Nantucket Sound, Massachusetts Current	NOS	ACT1626_1	41.55	-70.02167	:America/New_York	USA	knots	346	170	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:23:00	\N	1.2	00:39:00	\N	0.8	00:00:00	00:18:00	Monomoy Pt., channel 0.2 mile west of	MA
63717	Stage Harbor, west of Morris Island, Nantucket Sound, Massachusetts Current	NOS	ACT1636_1	41.65667	-69.975	:America/New_York	USA	knots	144	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:28:00	\N	0.6	01:29:00	\N	0.3	03:07:00	02:24:00	Stage Harbor, west of Morris Island	MA
63718	Dennis Port, 2.2 miles south of, Nantucket Sound, Massachusetts Current	NOS	ACT1641_1	41.61667	-70.115	:America/New_York	USA	knots	269	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:04:00	\N	0.2	00:52:00	\N	0.2	01:28:00	00:27:00	Dennis Port, 2.2 miles south of	MA
63719	Monomoy Point, 6 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1646_1	41.55833	-70.15	:America/New_York	USA	knots	275	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:22:00	\N	0.3	01:52:00	\N	0.2	01:22:00	01:09:00	Monomoy Point, 6 miles west of	MA
63720	Handkerchief Lighted Whistle Buoy 'H', Nantucket Sound, Massachusetts Current	NOS	ACT1651_1	41.48833	-70.06667	:America/New_York	USA	knots	251	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:59:00	\N	0.8	01:10:00	\N	0.6	01:08:00	00:49:00	Handkerchief Lighted Whistle Buoy 'H'	MA
63884	Quantico Creek entrance, Potomac River, Virginia Current	NOS	ACT5886_1	38.52833	-77.28833	:America/New_York	USA	knots	115	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:34:00	\N	0.6	-01:29:00	\N	0.6	-01:19:00	-01:57:00	Quantico Creek entrance	VA
63721	Halfmoon Shoal, 1.9 miles northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1656_1	41.48417	-70.1925	:America/New_York	USA	knots	265	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:44:00	\N	0.3	01:49:00	\N	0.4	01:42:00	01:24:00	Halfmoon Shoal, 1.9 miles northeast of	MA
63722	Halfmoon Shoal, 3.5 miles east of, Nantucket Sound, Massachusetts Current	NOS	ACT1661_1	41.46833	-70.15333	:America/New_York	USA	knots	295	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:11:00	\N	0.6	01:23:00	\N	0.5	01:13:00	01:06:00	Halfmoon Shoal, 3.5 miles east of	MA
63723	Great Point, 0.5 mile west of, Nantucket Sound, Massachusetts Current	NOS	ACT1666_1	41.39333	-70.06167	:America/New_York	USA	knots	195	29	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:33:00	\N	0.7	01:37:00	\N	0.6	00:25:00	01:13:00	Great Point, 0.5 mile west of	MA
63724	Great Point, 3 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1671_1	41.39	-70.11333	:America/New_York	USA	knots	248	66	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:08:00	\N	0.5	01:23:00	\N	0.4	01:15:00	00:51:00	Great Point, 3 miles west of	MA
63725	Tuckernuck Shoal, off east end, Nantucket Sound, Massachusetts Current	NOS	ACT1676_1	41.405	-70.17333	:America/New_York	USA	knots	287	113	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:10:00	\N	0.5	01:34:00	\N	0.5	01:22:00	01:09:00	Tuckernuck Shoal, off east end	MA
63726	Nantucket Harbor entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1686_1	41.30667	-70.1	:America/New_York	USA	knots	350	171	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:58:00	\N	0.9	01:55:00	\N	0.6	03:22:00	02:44:00	Nantucket Harbor entrance channel	MA
63727	Eel Pt., Nantucket I. 2.5 miles NE of, Nantucket Sound, Massachusetts Current	NOS	ACT1691_1	41.32167	-70.17	:America/New_York	USA	knots	284	94	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:15:00	\N	0.2	01:12:00	\N	0.3	01:13:00	01:02:00	Eel Pt., Nantucket I. 2.5 miles NE of	MA
63728	Muskeget I., channel 1 mile northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1696_1	41.35	-70.285	:America/New_York	USA	knots	295	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:56:00	\N	0.9	00:45:00	\N	0.6	01:29:00	00:57:00	Muskeget I., channel 1 mile northeast of	MA
63729	Muskeget Rock, 1.3 miles southwest of, Nantucket Sound, Massachusetts Current	NOS	ACT1701_1	41.32	-70.39333	:America/New_York	USA	knots	192	24	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:18:00	\N	0.6	00:23:00	\N	0.6	01:10:00	00:57:00	Muskeget Rock, 1.3 miles southwest of	MA
63730	Muskeget Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1706_1	41.34833	-70.42	:America/New_York	USA	knots	200	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:02:00	\N	1.9	00:38:00	\N	1.9	01:40:00	01:29:00	Muskeget Channel	MA
63731	Long Shoal-Norton Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1716_1	41.40833	-70.33333	:America/New_York	USA	knots	260	100	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:13:00	\N	0.6	01:12:00	\N	0.7	01:31:00	01:26:00	Long Shoal-Norton Shoal, between	MA
63732	Cape Poge Lt., 1.7 miles SSE of, Nantucket Sound, Massachusetts Current	NOS	ACT1721_1	41.4	-70.42667	:America/New_York	USA	knots	215	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:48:00	\N	0.7	-00:07:00	\N	0.8	00:58:00	00:49:00	Cape Poge Lt., 1.7 miles SSE of	MA
63733	Cross Rip Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1726_1	41.44833	-70.29167	:America/New_York	USA	knots	272	91	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:59:00	\N	0.5	01:48:00	\N	0.6	01:48:00	01:55:00	Cross Rip Channel	MA
63734	Cape Poge Lt., 3.2 miles northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1731_1	41.45833	-70.4	:America/New_York	USA	knots	300	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:37:00	\N	0.7	02:03:00	\N	0.8	02:42:00	02:33:00	Cape Poge Lt., 3.2 miles northeast of	MA
63735	Broken Ground-Horseshoe Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1736_1	41.55	-70.285	:America/New_York	USA	knots	276	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:20:00	\N	0.5	01:55:00	\N	0.5	01:46:00	01:15:00	Broken Ground-Horseshoe Shoal, between	MA
63736	Point Gammon, 1.2 miles south of, Nantucket Sound, Massachusetts Current	NOS	ACT1741_1	41.58833	-70.25667	:America/New_York	USA	knots	260	105	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:02:00	\N	0.6	01:03:00	\N	0.5	01:15:00	01:06:00	Point Gammon, 1.2 miles south of	MA
63737	Lewis Bay entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1751_1	41.63167	-70.27333	:America/New_York	USA	knots	184	4	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:22:00	\N	0.8	00:53:00	\N	0.5	02:46:00	02:44:00	Lewis Bay entrance channel	MA
63738	Cotuit Bay entrance (Bluff Point), Nantucket Sound, Massachusetts Current	NOS	ACT1756_1	41.61	-70.43	:America/New_York	USA	knots	218	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:35:00	\N	0.4	02:33:00	\N	0.3	02:44:00	02:51:00	Cotuit Bay entrance (Bluff Point)	MA
63739	Wreck Shoal-Eldridge Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1761_1	41.53333	-70.42833	:America/New_York	USA	knots	245	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:45:00	\N	0.8	01:32:00	\N	0.8	01:47:00	01:44:00	Wreck Shoal-Eldridge Shoal, between	MA
63740	Hedge Fence Lighted Gong Buoy 22, Nantucket Sound, Massachusetts Current	NOS	ACT1766_1	41.47167	-70.48333	:America/New_York	USA	knots	268	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:44:00	\N	0.7	02:34:00	\N	0.7	02:48:00	02:38:00	Hedge Fence Lighted Gong Buoy 22	MA
63741	Cape Poge Light, 1.4 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1771_1	41.42417	-70.48333	:America/New_York	USA	knots	250	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:39:00	\N	0.1	01:54:00	\N	0.2	02:13:00	01:26:00	Cape Poge Light, 1.4 miles west of	MA
63742	East Chop-Squash Meadow, between, Nantucket Sound, Massachusetts Current	NOS	ACT1786_1	41.465	-70.53667	:America/New_York	USA	knots	329	131	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:04:00	\N	1.1	00:55:00	\N	0.7	02:07:00	01:43:00	East Chop-Squash Meadow, between	MA
63743	East Chop, 1 mile north of, Nantucket Sound, Massachusetts Current	NOS	ACT1791_1	41.485	-70.55833	:America/New_York	USA	knots	297	116	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	1.3	01:52:00	\N	1.1	02:40:00	02:17:00	East Chop, 1 mile north of	MA
63744	West Chop, 0.8 mile north of, Nantucket Sound, Massachusetts Current	NOS	ACT1801_1	41.49333	-70.595	:America/New_York	USA	knots	282	96	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:35:00	\N	1.8	01:58:00	\N	1.6	02:49:00	02:20:00	West Chop, 0.8 mile north of	MA
63745	Hedge Fence-L'Hommedieu Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1806_1	41.505	-70.53667	:America/New_York	USA	knots	276	106	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:52:00	\N	1.3	01:38:00	\N	1	02:27:00	02:01:00	Hedge Fence-L'Hommedieu Shoal, between	MA
63746	Waquoit Bay entrance, Nantucket Sound, Massachusetts Current	NOS	ACT1811_1	41.54833	-70.53	:America/New_York	USA	knots	203	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:01:00	\N	0.8	02:14:00	\N	0.8	03:21:00	03:40:00	Waquoit Bay entrance	MA
63747	L'Hommedieu Shoal, north of west end, Nantucket Sound, Massachusetts Current	NOS	ACT1816_1	41.52667	-70.57667	:America/New_York	USA	knots	268	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	1.4	02:03:00	\N	1.2	02:30:00	02:12:00	L'Hommedieu Shoal, north of west end	MA
63748	Nobska Point, 1.8 miles east of, Nantucket Sound, Massachusetts Current	NOS	ACT1821_1	41.51833	-70.61833	:America/New_York	USA	knots	240	63	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:49:00	\N	1	01:45:00	\N	1.2	02:13:00	01:55:00	Nobska Point, 1.8 miles east of	MA
63749	West Chop, 0.2 mile west of, Vineyard Sound, Massachusetts Current	NOS	ACT1826_1	41.48333	-70.61	:America/New_York	USA	knots	241	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:16:00	\N	0.8	01:34:00	\N	1.3	01:19:00	01:50:00	West Chop, 0.2 mile west of	MA
63750	Nobska Point, 1 mile southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1831_1	41.50167	-70.64333	:America/New_York	USA	knots	259	71	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:19:00	\N	1.4	02:15:00	\N	1.3	02:33:00	02:25:00	Nobska Point, 1 mile southeast of	MA
63751	Norton Point, 0.5 mile north of, Vineyard Sound, Massachusetts Current	NOS	ACT1836_1	41.46833	-70.665	:America/New_York	USA	knots	240	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:12:00	\N	1.4	01:44:00	\N	1.7	01:55:00	02:01:00	Norton Point, 0.5 mile north of	MA
63752	Tarpaulin Cove, 1.5 miles east of, Vineyard Sound, Massachusetts Current	NOS	ACT1841_1	41.47167	-70.725	:America/New_York	USA	knots	232	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:33:00	\N	1.4	02:07:00	\N	1	02:49:00	02:12:00	Tarpaulin Cove, 1.5 miles east of	MA
63753	Robinsons Hole, 1.2 miles southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1846_1	41.435	-70.78	:America/New_York	USA	knots	240	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:02:00	\N	1.2	01:51:00	\N	1	02:30:00	02:11:00	Robinsons Hole, 1.2 miles southeast of	MA
63754	Gay Head, 3 miles northeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1851_1	41.385	-70.78333	:America/New_York	USA	knots	238	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	0.8	01:50:00	\N	0.5	02:25:00	01:42:00	Gay Head, 3 miles northeast of	MA
63755	Gay Head, 3 miles north of, Vineyard Sound, Massachusetts Current	NOS	ACT1861_1	41.40167	-70.85333	:America/New_York	USA	knots	255	74	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:17:00	\N	0.7	01:24:00	\N	0.6	02:13:00	01:55:00	Gay Head, 3 miles north of	MA
63756	Gay Head, 1.5 miles northwest of, Vineyard Sound, Massachusetts Current	NOS	ACT1866_1	41.36333	-70.86333	:America/New_York	USA	knots	249	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:16:00	\N	1.2	00:54:00	\N	1	01:30:00	01:42:00	Gay Head, 1.5 miles northwest of	MA
63757	Black Point, SW of, Sakonnet River (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2071_1	41.50667	-71.22	:America/New_York	USA	knots	194	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:26:00	\N	0.2	-01:55:00	\N	0.2	-02:54:00	-02:13:00	Black Point, SW of, Sakonnet River	RI
63758	Almy Point Bridge, south of, Sakonnet River (Depth 15ft), Rhode Island Current	NOS	ACT2076_1	41.62167	-71.22	:America/New_York	USA	knots	180	34	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-03:13:00	\N	0.8	-02:10:00	\N	0.2	-03:00:00	-02:30:00	Almy Point Bridge, south of, Sakonnet River	RI
63759	Brenton Point, 1.4 n.mi. southwest of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2096_1	41.43167	-71.37667	:America/New_York	USA	knots	170	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:04:00	\N	0.4	-00:38:00	\N	0.2	-01:03:00	-01:20:00	Brenton Point, 1.4 n.mi. southwest of	RI
63760	Castle Hill, west of, East Passage (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2101_1	41.45667	-71.37833	:America/New_York	USA	knots	237	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:29:00	\N	0.7	-00:42:00	\N	0.4	-00:06:00	-01:07:00	Castle Hill, west of, East Passage	RI
63761	Bull Point, east of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2106_1	41.48	-71.35	:America/New_York	USA	knots	206	1	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:33:00	\N	0.8	-00:47:00	\N	0.6	-01:10:00	-01:10:00	Bull Point, east of	RI
63762	Rose Island, northeast of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2121_1	41.50333	-71.33167	:America/New_York	USA	knots	124	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:08:00	\N	0.5	-00:07:00	\N	0.4	-01:57:00	-01:17:00	Rose Island, northeast of	RI
63763	Rose Island, northwest of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2126_1	41.50667	-71.35167	:America/New_York	USA	knots	190	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:39:00	\N	0.5	-00:26:00	\N	0.4	-01:38:00	-01:38:00	Rose Island, northwest of	RI
63764	Rose Island, west of, Narragansett Bay, Rhode Island Current	NOS	ACT2131_1	41.49667	-71.35	:America/New_York	USA	knots	172	1	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:28:00	\N	0.6	-00:34:00	\N	0.4	-00:42:00	-01:20:00	Rose Island, west of	RI
63765	Gould Island, southeast of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2136_1	41.525	-71.33667	:America/New_York	USA	knots	217	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:16:00	\N	0.4	-01:28:00	\N	0.3	-01:40:00	-01:14:00	Gould Island, southeast of	RI
63766	Gould Island, west of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2141_1	41.53167	-71.35833	:America/New_York	USA	knots	193	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:07:00	\N	0.4	-00:32:00	\N	0.3	-00:16:00	-01:13:00	Gould Island, west of	RI
63767	Dyer Island-Carrs Point (between), Narragansett Bay, Rhode Island Current	NOS	ACT2146_1	41.575	-71.29667	:America/New_York	USA	knots	236	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:37:00	\N	0.4	-01:13:00	\N	0.4	-01:56:00	-00:50:00	Dyer Island-Carrs Point (between)	RI
63768	Conanicut Point, ENE of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2151_1	41.575	-71.34167	:America/New_York	USA	knots	183	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:13:00	\N	0.2	-00:24:00	\N	0.2	-02:05:00	-01:18:00	Conanicut Point, ENE of	RI
63769	Dyer Island, west of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2156_1	41.58667	-71.30833	:America/New_York	USA	knots	216	23	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:34:00	\N	0.6	-00:46:00	\N	0.4	-01:04:00	-00:53:00	Dyer Island, west of	RI
63770	Mount Hope Bridge (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2166_1	41.64	-71.25833	:America/New_York	USA	knots	230	47	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:58:00	\N	0.8	-01:34:00	\N	0.6	-01:22:00	-01:08:00	Mount Hope Bridge	RI
63771	Hog Island, northwest of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2171_1	41.64667	-71.295	:America/New_York	USA	knots	199	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:04:00	\N	0.2	-00:04:00	\N	0.2	-02:16:00	-00:30:00	Hog Island, northwest of	RI
63772	Common Fence Point, west of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2176_1	41.65	-71.245	:America/New_York	USA	knots	224	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:37:00	\N	0.4	00:08:00	\N	0.2	-01:13:00	-01:00:00	Common Fence Point, west of	RI
63773	Mount Hope Point, northeast of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2181_1	41.68	-71.21167	:America/New_York	USA	knots	217	38	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:57:00	\N	0.2	-00:20:00	\N	0.2	-02:01:00	-01:03:00	Mount Hope Point, northeast of	RI
63774	Warren, Warren River, Narragansett Bay, Rhode Island Current	NOS	ACT2196_1	41.72833	-71.28833	:America/New_York	USA	knots	171	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:05:00	\N	0.5	00:11:00	\N	0.5	-00:14:00	-00:22:00	Warren, Warren River	RI
63775	Beavertail Point, 0.8 mile northwest of, Narragansett Bay, Rhode Island Current	NOS	ACT2201_1	41.45833	-71.41167	:America/New_York	USA	knots	188	3	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:19:00	\N	0.6	-00:54:00	\N	0.3	-00:11:00	-01:31:00	Beavertail Point, 0.8 mile northwest of	RI
63776	Dutch Island and Beaver Head, between, Narragansett Bay, Rhode Island Current	NOS	ACT2211_1	41.49667	-71.40333	:America/New_York	USA	knots	233	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:47:00	\N	0.6	-01:32:00	\N	0.5	-01:56:00	-01:58:00	Dutch Island and Beaver Head, between	RI
63777	Dutch Island, west of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2216_1	41.505	-71.41	:America/New_York	USA	knots	206	14	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:16:00	\N	0.7	-01:49:00	\N	0.7	-01:33:00	-01:21:00	Dutch Island, west of	RI
63778	Patience Island, narrows east of, Narragansett Bay, Rhode Island Current	NOS	ACT2236_1	41.65833	-71.35333	:America/New_York	USA	knots	157	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:37:00	\N	0.5	-02:29:00	\N	0.4	-02:41:00	-02:44:00	Patience Island, narrows east of	RI
63779	Patience I. and Warwick Neck, between, Narragansett Bay, Rhode Island Current	NOS	ACT2241_1	41.66333	-71.37333	:America/New_York	USA	knots	224	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:13:00	\N	0.5	-01:21:00	\N	0.3	-01:40:00	-01:18:00	Patience I. and Warwick Neck, between	RI
63780	Nayatt Point, WNW of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2246_1	41.72833	-71.36	:America/New_York	USA	knots	128	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:11:00	\N	0.1	00:47:00	\N	0.1	-02:24:00	-01:00:00	Nayatt Point, WNW of	RI
63781	Cryders Point, 0.4 mile NNW of, East River, New York Current	NOS	ACT3341_1	40.80033	-73.79867	:America/New_York	USA	knots^2	285	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:00:00	\N	0.2	-00:43:00	\N	0.4	-00:29:00	-00:30:00	Cryders Point, 0.4 mile NNW of	NY
63782	Bronx-Whitestone Bridge, East of (Depth 14ft), East River, New York Current	NOS	ACT3346_1	40.80167	-73.82667	:America/New_York	USA	knots^2	247	76	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:27:00	\N	0.2	-00:46:00	\N	0.5	-00:34:00	-00:10:00	Bronx-Whitestone Bridge, East of	NY
63783	College Point Reef, 0.25 n.mi. NW of (Depth 15ft), East River, New York Current	NOS	ACT3356_1	40.801	-73.85467	:America/New_York	USA	knots^2	261	74	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:00:00	\N	0.3	-00:47:00	\N	0.4	-00:27:00	-00:32:00	College Point Reef, 0.25 n.mi. NW of	NY
63784	Rikers I. chan., off La Guardia Field, East River, New York Current	NOS	ACT3366_1	40.78333	-73.88333	:America/New_York	USA	knots^2	261	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:08:00	\N	0.3	-00:04:00	\N	0.3	00:04:00	00:04:00	Rikers I. chan., off La Guardia Field	NY
63785	Hunts Point, southwest of, East River, New York Current	NOS	ACT3376_1	40.8	-73.88333	:America/New_York	USA	knots^2	280	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:05:00	\N	0.3	-00:10:00	\N	0.5	00:01:00	00:01:00	Hunts Point, southwest of	NY
63786	South Brother Island, NW of (Depth 15ft), East River, New York Current	NOS	ACT3381_1	40.79667	-73.90167	:America/New_York	USA	knots^2	252	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:12:00	\N	0.3	00:04:00	\N	0.4	-00:17:00	-00:06:00	South Brother Island, NW of	NY
63787	Off Winthrop Ave., Astoria, East River, New York Current	NOS	ACT3386_1	40.78667	-73.91667	:America/New_York	USA	knots^2	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.5	00:02:00	\N	1	00:04:00	-00:01:00	Off Winthrop Ave., Astoria	NY
63788	Mill Rock, northeast of, East River, New York Current	NOS	ACT3391_1	40.78167	-73.93667	:America/New_York	USA	knots^2	288	103	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:32:00	\N	0.1	00:05:00	\N	0.7	-00:23:00	-00:29:00	Mill Rock, northeast of	NY
63789	Mill Rock, west of, East River, New York Current	NOS	ACT3396_1	40.78	-73.94167	:America/New_York	USA	knots^2	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:17:00	\N	0.2	00:08:00	\N	0.4	-00:26:00	-00:02:00	Mill Rock, west of	NY
63790	Roosevelt Island, west of, off 75th Street, East River, New York Current	NOS	ACT3406_1	40.76667	-73.95	:America/New_York	USA	knots^2	215	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	1	-00:04:00	\N	1.1	-00:02:00	-00:08:00	west of, off 75th Street	NY
63791	Roosevelt Island, east of, off 36th Avenue, East River, New York Current	NOS	ACT3411_1	40.76667	-73.95	:America/New_York	USA	knots^2	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.7	-00:04:00	\N	1	-00:08:00	-00:08:00	east of, off 36th Avenue	NY
63792	Roosevelt Island, west of, off 67th Street, East River, New York Current	NOS	ACT3416_1	40.76233	-73.954	:America/New_York	USA	knots^2	230	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:11:00	\N	0.9	-00:08:00	\N	1.1	00:13:00	00:06:00	west of, off 67th Street	NY
63793	Roosevelt Island, west of, off 63rd Street, East River, New York Current	NOS	ACT3421_1	40.75967	-73.9545	:America/New_York	USA	knots^2	223	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:03:00	\N	0.6	-00:08:00	\N	0.8	-00:10:00	00:00:00	west of, off 63rd Street	NY
63794	Roosevelt Island, east of, East River, New York Current	NOS	ACT3426_1	40.75817	-73.95133	:America/New_York	USA	knots^2	200	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	0.6	-00:06:00	\N	0.8	00:00:00	00:02:00	east of	NY
63795	Manhattan, off 31st Street, East River, New York Current	NOS	ACT3431_1	40.73967	-73.9695	:America/New_York	USA	knots^2	175	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:36:00	\N	0.5	-00:11:00	\N	0.4	00:09:00	-00:02:00	Manhattan, off 31st Street	NY
63796	Pier 67, off 19th Street, East River, New York Current	NOS	ACT3441_1	40.73333	-73.96667	:America/New_York	USA	knots^2	179	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	0.4	00:08:00	\N	0.5	-00:08:00	-00:08:00	Pier 67, off 19th Street	NY
63797	Williamsburg Bridge, 0.3 mile north of, East River, New York Current	NOS	ACT3446_1	40.718	-73.97067	:America/New_York	USA	knots^2	220	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:10:00	\N	0.6	00:12:00	\N	0.8	-00:05:00	-00:01:00	Williamsburg Bridge, 0.3 mile north of	NY
63798	Manhattan Bridge, East of (Depth 15ft), East River, New York Current	NOS	ACT3451_1	40.70833	-73.99	:America/New_York	USA	knots^2	259	83	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:03:00	\N	0.5	00:19:00	\N	0.7	-00:28:00	-00:13:00	Manhattan Bridge, East of	NY
63799	Brooklyn Bridge, 0.1 mile southwest of, East River, New York Current	NOS	ACT3461_1	40.70333	-74	:America/New_York	USA	knots^2	222	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:07:00	\N	0.8	00:08:00	\N	0.9	-00:18:00	-00:04:00	Brooklyn Bridge, 0.1 mile southwest of	NY
63800	East 107th Street (Depth 15ft), Harlem River, New York Current	NOS	ACT3476_1	40.79	-73.935	:America/New_York	USA	knots^2	30	206	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:39:00	\N	0.2	-00:03:00	\N	0.2	-00:08:00	-01:09:00	East 107th Street	NY
63801	Willis Ave. Bridge, 0.1 mile NW of, Harlem River, New York Current	NOS	ACT3481_1	40.805	-73.93	:America/New_York	USA	knots^2	330	140	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:13:00	\N	0.3	00:00:00	\N	0.4	-00:30:00	-00:12:00	Willis Ave. Bridge, 0.1 mile NW of	NY
63802	Madison Ave. Bridge, Harlem River, New York Current	NOS	ACT3486_1	40.81333	-73.935	:America/New_York	USA	knots^2	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:14:00	\N	0.4	00:18:00	\N	0.5	-00:20:00	-00:21:00	Madison Ave. Bridge	NY
63803	Macombs Dam Bridge, Harlem River, New York Current	NOS	ACT3491_1	40.82833	-73.935	:America/New_York	USA	knots^2	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.3	00:14:00	\N	0.5	-00:20:00	-00:22:00	Macombs Dam Bridge	NY
63804	High Bridge, Harlem River, New York Current	NOS	ACT3496_1	40.84167	-73.93167	:America/New_York	USA	knots^2	15	189	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:08:00	\N	0.4	00:08:00	\N	0.6	-00:20:00	-00:23:00	High Bridge	NY
63805	West 207th Street Bridge, Harlem River, New York Current	NOS	ACT3501_1	40.86333	-73.915	:America/New_York	USA	knots^2	35	215	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:02:00	\N	0.4	00:05:00	\N	0.6	-00:22:00	-00:22:00	West 207th Street Bridge	NY
63806	Broadway Bridge, Harlem River, New York Current	NOS	ACT3506_1	40.87333	-73.91167	:America/New_York	USA	knots^2	299	116	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:04:00	\N	0.5	00:08:00	\N	0.6	-00:23:00	-00:20:00	Broadway Bridge	NY
63807	Henry Hudson Bridge, 0.7 nmi. SE of (Depth 16ft), Harlem River, New York Current	NOS	ACT3511_1	40.87667	-73.92167	:America/New_York	USA	knots^2	326	137	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:41:00	\N	0.3	00:31:00	\N	0.2	00:12:00	-00:31:00	Henry Hudson Bridge, 0.7 nmi. SE of	NY
63808	Bergen Point Reach (Bayonne Bridge) (Depth 29ft), Kill Van Kull, New York Current	NOS	ACT3951_2	40.64167	-74.14333	:America/New_York	USA	knots	79	263	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16145	-00:04:00	\N	0.9	00:02:00	\N	0.8	-00:15:00	00:14:00	BERGEN POINT REACH (BAYONNE BRIDGE)	NY
63809	Cedar Point, 2.9 n.mi. ENE of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_1	38.31083	-76.31333	:America/New_York	USA	knots	164	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:55:00	\N	0.8	-02:34:00	\N	0.5	-02:35:00	-03:16:00	Cedar Point, 2.9 n.mi. ENE of	MD
63810	Cedar Point, 2.9 n.mi. ENE of (Depth 50ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_2	38.31083	-76.31333	:America/New_York	USA	knots	141	326	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:15:00	\N	0.3	-03:30:00	\N	0.5	-04:08:00	-03:05:00	Cedar Point, 2.9 n.mi. ENE of	MD
63811	Cedar Point, 1.1 miles ENE of, Chesapeake Bay, Maryland Current	NOS	ACT4851_1	38.3045	-76.35167	:America/New_York	USA	knots	185	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.8	-02:50:00	\N	0.5	-03:23:00	-02:36:00	Cedar Point, 1.1 miles ENE of	MD
63812	Cove Point, 1.1 n.mi. east of (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_1	38.38133	-76.36033	:America/New_York	USA	knots	165	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:14:00	\N	0.9	-02:42:00	\N	0.9	-02:57:00	-02:40:00	Cove Point, 1.1 n.mi. east of	MD
63813	Cove Point, 1.1 n.mi. east of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_2	38.38133	-76.36033	:America/New_York	USA	knots	165	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:26:00	\N	0.7	-03:19:00	\N	0.8	-03:22:00	-02:38:00	Cove Point, 1.1 n.mi. east of	MD
63814	Cove Point, 2.7 n.mi. east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_1	38.38	-76.32533	:America/New_York	USA	knots	169	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:40:00	\N	0.9	-02:41:00	\N	0.5	-02:23:00	-02:59:00	Cove Point, 2.7 n.mi. east of	MD
63815	Cove Point, 2.7 n.mi. east of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_2	38.38	-76.32533	:America/New_York	USA	knots	170	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:40:00	\N	0.6	-02:39:00	\N	0.9	-03:15:00	-01:53:00	Cove Point, 2.7 n.mi. east of	MD
63816	Cove Point, 2.7 n.mi. east of (Depth 98ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_3	38.38	-76.32533	:America/New_York	USA	knots	165	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:36:00	\N	0.5	-04:02:00	\N	0.7	-03:49:00	-03:13:00	Cove Point, 2.7 n.mi. east of	MD
63817	Cove Point, 3.9 n.mi. east of (Depth 11ft), Chesapeake Bay, Maryland Current	NOS	ACT4871_1	38.37533	-76.29867	:America/New_York	USA	knots	171	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:44:00	\N	0.6	-03:36:00	\N	0.4	-03:29:00	-04:08:00	Cove Point, 3.9 n.mi. east of	MD
63818	Cove Point, 4.9 n.mi. NNE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_1	38.46717	-76.37667	:America/New_York	USA	knots	159	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:26:00	\N	0.7	-02:29:00	\N	0.7	-02:57:00	-02:24:00	Cove Point, 4.9 n.mi. NNE of	MD
63819	Cove Point, 4.9 n.mi. NNE of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_2	38.46717	-76.37667	:America/New_York	USA	knots	149	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:17:00	\N	0.4	-02:47:00	\N	1	-03:23:00	-01:58:00	Cove Point, 4.9 n.mi. NNE of	MD
63820	Cove Point, 4.9 n.mi. NNE of (Depth 67ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_3	38.46717	-76.37667	:America/New_York	USA	knots	135	321	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:58:00	\N	0.4	-03:38:00	\N	0.6	-03:55:00	-02:14:00	Cove Point, 4.9 n.mi. NNE of	MD
63821	Kenwood Beach, 1.5 miles northeast of, Chesapeake Bay, Maryland Current	NOS	ACT4881_1	38.51833	-76.48167	:America/New_York	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:37:00	\N	0.4	-02:41:00	\N	0.2	-01:56:00	-02:46:00	Kenwood Beach, 1.5 miles northeast of	MD
63822	James Island, 3.4 miles west of, Chesapeake Bay, Maryland Current	NOS	ACT4891_1	38.525	-76.42	:America/New_York	USA	knots	175	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:02:00	\N	0.4	-02:39:00	\N	0.5	-02:16:00	-03:01:00	James Island, 3.4 miles west of	MD
63823	James Island, 2.5 miles WNW of, Chesapeake Bay, Maryland Current	NOS	ACT4896_1	38.53333	-76.39333	:America/New_York	USA	knots	175	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:36:00	\N	0.6	-02:42:00	\N	0.5	-02:31:00	-02:18:00	James Island, 2.5 miles WNW of	MD
63824	Plum Point, 1.4 miles ESE of, Chesapeake Bay, Maryland Current	NOS	ACT4901_1	38.6125	-76.4775	:America/New_York	USA	knots	155	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:04:00	\N	0.7	-01:37:00	\N	0.2	-01:31:00	-02:20:00	Plum Point, 1.4 miles ESE of	MD
63825	Sharp Island Lt., 2.3 n.mi. SE of (Depth 20ft), Chesapeake Bay, Maryland Current	NOS	ACT4906_1	38.60717	-76.348	:America/New_York	USA	knots	203	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:54:00	\N	0.7	-03:34:00	\N	0.8	-03:15:00	-03:07:00	Sharp Island Lt., 2.3 n.mi. SE of	MD
63826	Sharp Island Lt., 2.1 n.mi. west of (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT4911_1	38.64333	-76.42033	:America/New_York	USA	knots	183	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:33:00	\N	0.5	-01:36:00	\N	0.4	-01:49:00	-01:33:00	Sharp Island Lt., 2.1 n.mi. west of	MD
63827	Sharp Island Lt., 3.4 n.mi. west of (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_1	38.64383	-76.448	:America/New_York	USA	knots	186	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:43:00	\N	0.5	-01:41:00	\N	0.4	-01:39:00	-01:57:00	Sharp Island Lt., 3.4 n.mi. west of	MD
63828	Sharp Island Lt., 3.4 n.mi. west of (Depth 35ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_2	38.64383	-76.448	:America/New_York	USA	knots	183	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:24:00	\N	0.4	-02:23:00	\N	0.4	-02:34:00	-02:23:00	Sharp Island Lt., 3.4 n.mi. west of	MD
63829	Plum Point, 2.1 n.mi. NNE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4921_1	38.645	-76.48717	:America/New_York	USA	knots	174	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:01:00	\N	0.5	-01:51:00	\N	0.4	-01:50:00	-01:51:00	Plum Point, 2.1 n.mi. NNE of	MD
63830	Poplar Island, 2.2 n.mi. WSW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT4926_1	38.75617	-76.4295	:America/New_York	USA	knots	185	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:49:00	\N	0.8	-01:26:00	\N	0.6	-00:44:00	-00:57:00	Poplar Island, 2.2 n.mi. WSW of	MD
63831	Poplar Island, 3.0 n.mi. WSW of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_1	38.74967	-76.4455	:America/New_York	USA	knots	189	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:08:00	\N	0.5	-01:22:00	\N	0.6	-01:08:00	-00:59:00	Poplar Island, 3.0 n.mi. WSW of	MD
63832	Poplar Island, 3.0 n.mi. WSW of (Depth 48ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_2	38.74967	-76.4455	:America/New_York	USA	knots	172	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:13:00	\N	0.4	01:21:00	\N	0.5	00:58:00	02:01:00	Poplar Island, 3.0 n.mi. WSW of	MD
63833	Holland Point, 2.0 n.mi east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4936_1	38.75167	-76.49883	:America/New_York	USA	knots	180	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:39:00	\N	0.4	-01:24:00	\N	0.2	-01:20:00	-01:45:00	Holland Point, 2.0 n.mi east of	MD
63834	Kent Point, 4 miles southwest of, Chesapeake Bay, Maryland Current	NOS	ACT4941_1	38.79167	-76.43333	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:05:00	\N	0.6	-01:04:00	\N	0.6	-01:03:00	-01:11:00	Kent Point, 4 miles southwest of	MD
63835	Kent Point, 1.3 miles south of, Chesapeake Bay, Maryland Current	NOS	ACT4946_1	38.81667	-76.36417	:America/New_York	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:47:00	\N	0.5	-03:38:00	\N	0.6	-03:27:00	-03:53:00	Kent Point, 1.3 miles south of	MD
63836	Horseshoe Point, 1.7 miles east of, Chesapeake Bay, Maryland Current	NOS	ACT4951_1	38.83833	-76.45333	:America/New_York	USA	knots	200	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:10:00	\N	0.6	-00:39:00	\N	0.6	-00:52:00	-00:49:00	Horseshoe Point, 1.7 miles east of	MD
63837	Bloody Point Bar Light, 0.6 mi. NW of (Depth 19ft), Chesapeake Bay, Maryland Current	NOS	ACT4956_1	38.8395	-76.40283	:America/New_York	USA	knots	190	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:05:00	\N	0.6	-00:23:00	\N	0.9	-00:08:00	00:02:00	Bloody Point Bar Light, 0.6 mi. NW of	MD
63838	Thomas Pt. Shoal Lt., 1.8 mi. SW of, Chesapeake Bay, Maryland Current	NOS	ACT4961_1	38.875	-76.46167	:America/New_York	USA	knots	190	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:17:00	\N	0.4	-02:27:00	\N	0.5	-02:24:00	-01:43:00	Thomas Pt. Shoal Lt., 1.8 mi. SW of	MD
63839	Thomas Pt. Shoal Lt., 2.0 n.mi. east of (Depth 22ft), Chesapeake Bay, Maryland Current	NOS	ACT4966_1	38.89583	-76.38683	:America/New_York	USA	knots	186	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:20:00	\N	0.6	-00:14:00	\N	0.6	-01:05:00	-00:22:00	Thomas Pt. Shoal Lt., 2.0 n.mi. east of	MD
63840	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_1	38.891	-76.427	:America/New_York	USA	knots	191	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:41:00	\N	1.3	-00:09:00	\N	1	-00:25:00	-00:43:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
63841	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of (Depth 33ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_2	38.891	-76.427	:America/New_York	USA	knots	196	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:20:00	\N	0.7	-01:18:00	\N	0.7	-00:54:00	-01:25:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
63842	Tolly Point, 1.6 miles east of, Chesapeake Bay, Maryland Current	NOS	ACT4976_1	38.9345	-76.417	:America/New_York	USA	knots	190	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:24:00	\N	0.9	-00:19:00	\N	0.6	-00:03:00	-00:32:00	Tolly Point, 1.6 miles east of	MD
63843	Chesapeake Bay Bridge, main channel, Chesapeake Bay, Maryland Current	NOS	ACT4981_1	38.99167	-76.385	:America/New_York	USA	knots	230	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:13:00	\N	1.1	00:08:00	\N	0.9	00:16:00	-00:17:00	Chesapeake Bay Bridge, main channel	MD
63844	Sandy Point, 2.3 n.mi. east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_1	39.00267	-76.34883	:America/New_York	USA	knots	199	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:29:00	\N	0.9	00:15:00	\N	1.1	00:19:00	00:13:00	Sandy Point, 2.3 n.mi. east of	MD
63845	Sandy Point, 2.3 n.mi. east of (Depth 41ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_2	39.00267	-76.34883	:America/New_York	USA	knots	210	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:39:00	\N	0.6	-01:14:00	\N	0.8	-01:33:00	-00:48:00	Sandy Point, 2.3 n.mi. east of	MD
63846	Sandy Point, 0.8 n.mi. ESE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_1	39.004	-76.38	:America/New_York	USA	knots	199	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:05:00	\N	1.5	00:24:00	\N	1.2	-00:11:00	-00:15:00	Sandy Point, 0.8 n.mi. ESE of	MD
63847	Sandy Point, 0.8 n.mi. ESE of (Depth 43ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_2	39.004	-76.38	:America/New_York	USA	knots	197	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:02:00	\N	1	-01:10:00	\N	1	-00:59:00	-00:59:00	Sandy Point, 0.8 n.mi. ESE of	MD
63848	Craighill Channel entrance, Buoy '2C' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_1	39.04033	-76.37783	:America/New_York	USA	knots	182	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:09:00	\N	0.9	00:26:00	\N	1	-00:04:00	00:01:00	Craighill Channel entrance, Buoy '2C'	MD
63849	Craighill Channel entrance, Buoy '2C' (Depth 38ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_2	39.04033	-76.37783	:America/New_York	USA	knots	147	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:18:00	\N	0.6	00:01:00	\N	0.5	00:00:00	-00:06:00	Craighill Channel entrance, Buoy '2C'	MD
63850	Love Point, 2.5 miles north of, Chesapeake Bay, Maryland Current	NOS	ACT5011_1	39.07967	-76.31217	:America/New_York	USA	knots	240	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:07:00	\N	0.5	00:19:00	\N	0.8	-00:48:00	00:27:00	Love Point, 2.5 miles north of	MD
63851	Craighill Channel, NE of Mountain Pt, Chesapeake Bay, Maryland Current	NOS	ACT5021_1	39.08133	-76.3945	:America/New_York	USA	knots	175	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:34:00	\N	0.9	00:40:00	\N	0.8	00:28:00	00:25:00	Craighill Channel, NE of Mountain Pt	MD
63852	Craighill Channel, Belvidere Shoal (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT5026_1	39.09467	-76.393	:America/New_York	USA	knots	186	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:19:00	\N	0.6	00:46:00	\N	0.7	00:10:00	00:33:00	Craighill Channel, Belvidere Shoal	MD
63853	Craighill Angle, right outside quarter, Chesapeake Bay, Maryland Current	NOS	ACT5031_1	39.12833	-76.38783	:America/New_York	USA	knots	170	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:23:00	\N	0.6	00:27:00	\N	0.6	00:12:00	00:34:00	Craighill Angle, right outside quarter	MD
63854	Swan Point, 2.7 n.mi. SW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_1	39.108	-76.30533	:America/New_York	USA	knots	170	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.5	00:42:00	\N	0.6	00:18:00	00:38:00	Swan Point, 2.7 n.mi. SW of	MD
63855	Swan Point, 2.7 n.mi. SW of (Depth 27ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_2	39.108	-76.30533	:America/New_York	USA	knots	142	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.4	00:30:00	\N	0.6	-00:27:00	01:17:00	Swan Point, 2.7 n.mi. SW of	MD
63856	Swan Point, 1.6 miles northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5046_1	39.1625	-76.30467	:America/New_York	USA	knots	215	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:57:00	\N	0.9	00:44:00	\N	0.8	00:53:00	00:38:00	Swan Point, 1.6 miles northwest of	MD
63857	Brewerton Channel Eastern Ext., Buoy '7' (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5051_1	39.163	-76.38967	:America/New_York	USA	knots	175	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:05:00	\N	0.4	-00:02:00	\N	0.5	00:16:00	-00:14:00	Brewerton Channel Eastern Ext., Buoy '7'	MD
63858	Tolchester Channel, SW of Bouy '58B' (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_1	39.1825	-76.28117	:America/New_York	USA	knots	229	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:54:00	\N	1.1	00:20:00	\N	1.1	00:44:00	00:48:00	Tolchester Channel, SW of Bouy '58B'	MD
63859	Tolchester Channel, SW of Bouy '58B' (Depth 25ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_2	39.1825	-76.28117	:America/New_York	USA	knots	217	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:48:00	\N	0.7	00:02:00	\N	0.9	-00:09:00	00:38:00	Tolchester Channel, SW of Bouy '58B'	MD
63860	Tolchester Channel, Buoy '22' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5061_1	39.19117	-76.26583	:America/New_York	USA	knots	231	61	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:23:00	\N	0.8	01:10:00	\N	0.9	01:43:00	00:59:00	Tolchester Channel, Buoy '22'	MD
63861	Tolchester Channel, south of Buoy '38B' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5066_1	39.19283	-76.28783	:America/New_York	USA	knots	208	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:50:00	\N	0.8	01:08:00	\N	0.7	00:51:00	00:59:00	Tolchester Channel, south of Buoy '38B'	MD
63862	North Point, 2.5 miles northeast of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5071_1	39.2145	-76.39533	:America/New_York	USA	knots	225	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:06:00	\N	0.5	01:00:00	\N	0.4	01:25:00	00:53:00	North Point, 2.5 miles northeast of	MD
63863	Tolchester Beach, 0.33 n.mi. west of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5076_1	39.21717	-76.24833	:America/New_York	USA	knots	201	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:24:00	\N	1.1	01:20:00	\N	1.2	00:49:00	01:22:00	Tolchester Beach, 0.33 n.mi. west of	MD
63864	Pooles Island, 4 miles southwest of, Chesapeake Bay, Maryland Current	NOS	ACT5081_1	39.22667	-76.33133	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:12:00	\N	0.8	00:48:00	\N	0.6	00:59:00	00:56:00	Pooles Island, 4 miles southwest of	MD
63865	Pooles Island 2.0 n.mi. SSW of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5086_1	39.24633	-76.29667	:America/New_York	USA	knots	238	38	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:29:00	\N	0.7	00:58:00	\N	0.7	01:01:00	01:03:00	Pooles Island 2.0 n.mi. SSW of	MD
63866	Pooles Island, 0.8 mile south of, Chesapeake Bay, Maryland Current	NOS	ACT5091_1	39.26167	-76.27333	:America/New_York	USA	knots	255	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:20:00	\N	1.2	01:24:00	\N	0.9	01:29:00	01:12:00	Pooles Island, 0.8 mile south of	MD
63867	Miller Island, 1.5 miles ENE of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5096_1	39.275	-76.33167	:America/New_York	USA	knots	185	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.3	00:15:00	\N	0.6	00:11:00	00:37:00	Miller Island, 1.5 miles ENE of	MD
63868	Pooles Island, 1.6 n.mi. east of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT5101_1	39.2745	-76.22617	:America/New_York	USA	knots	208	14	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:03:00	\N	1.1	01:34:00	\N	1.1	01:28:00	01:45:00	Pooles Island, 1.6 n.mi. east of	MD
63869	Robins Point, 0.7 mile ESE of (Depth 5ft), Chesapeake Bay, Maryland Current	NOS	ACT5106_1	39.29583	-76.26833	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:13:00	\N	1	-00:14:00	\N	1.4	-00:03:00	00:37:00	Robins Point, 0.7 mile ESE of	MD
63870	Worton Point, 1.5 n.mi. WSW of (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT5111_1	39.31167	-76.21717	:America/New_York	USA	knots	211	23	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:36:00	\N	1.1	01:45:00	\N	1	02:04:00	01:27:00	Worton Point, 1.5 n.mi. WSW of	MD
63871	Worton Point, 1.1 miles northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5116_1	39.33167	-76.2	:America/New_York	USA	knots	245	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:32:00	\N	1.5	01:43:00	\N	1.4	01:43:00	01:38:00	Worton Point, 1.1 miles northwest of	MD
63872	Howell Point, 0.8 n.mi. west of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5121_1	39.3705	-76.13	:America/New_York	USA	knots	235	51	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:33:00	\N	1.3	01:48:00	\N	1	02:30:00	01:19:00	Howell Point, 0.8 n.mi. west of	MD
63873	Howell Point, 0.4 mile NNW of, Chesapeake Bay, Maryland Current	NOS	ACT5126_1	39.37667	-76.115	:America/New_York	USA	knots	245	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:18:00	\N	1.1	01:24:00	\N	1.1	01:28:00	01:20:00	Howell Point, 0.4 mile NNW of	MD
63874	Grove Point, 0.7 n.mi.NW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5131_1	39.39633	-76.05033	:America/New_York	USA	knots	211	34	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	02:03:00	\N	1	02:01:00	\N	0.6	02:40:00	01:31:00	Grove Point, 0.7 n.mi.NW of	MD
63875	Turkey Point, 1.2 n.mi. SW of (Depth 9ft), Chesapeake Bay, Maryland Current	NOS	ACT5136_1	39.44333	-76.03383	:America/New_York	USA	knots	193	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:00:00	\N	0.8	01:30:00	\N	0.6	02:39:00	00:58:00	Turkey Point, 1.2 n.mi. SW of	MD
63876	Spesutie Island, channel north of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5141_1	39.4805	-76.08167	:America/New_York	USA	knots	100	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:40:00	\N	0.6	01:20:00	\N	0.8	01:42:00	01:49:00	Spesutie Island, channel north of	MD
63877	Rocky Pt. (Elk Neck), 0.25 n.mi. SW of (Depth 9ft), Chesapeake Bay, Maryland Current	NOS	ACT5146_1	39.48833	-75.9975	:America/New_York	USA	knots	196	9	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:49:00	\N	0.7	01:28:00	\N	0.6	02:42:00	01:14:00	Rocky Pt. (Elk Neck), 0.25 n.mi. SW of	MD
63878	Red Point, 0.2 mile W of, Northeast River (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5151_1	39.52917	-75.98467	:America/New_York	USA	knots	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:47:00	\N	0.6	01:28:00	\N	0.9	01:42:00	01:57:00	Red Point, 0.2 mile W of, Northeast River	MD
63879	Swan Point, Potomac River, Virginia Current	NOS	ACT5846_1	38.27333	-76.945	:America/New_York	USA	knots	140	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:09:00	\N	1	-02:04:00	\N	0.4	-01:54:00	-02:32:00	Swan Point	VA
63880	Persimmon Point, Potomac River, Maryland Current	NOS	ACT5861_1	38.36833	-76.99	:America/New_York	USA	knots	175	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:24:00	\N	1.8	-01:19:00	\N	1.5	-01:09:00	-01:47:00	Persimmon Point	MD
63881	Potomac River Bridge, 0.4 mile south of, Potomac River, Maryland Current	NOS	ACT5866_1	38.35633	-76.98667	:America/New_York	USA	knots	165	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:17:00	\N	1.8	-01:28:00	\N	1.1	-01:25:00	-01:38:00	Potomac River Bridge, 0.4 mile south of	MD
63882	Maryland Point, Potomac River, Maryland Current	NOS	ACT5876_1	38.34667	-77.19667	:America/New_York	USA	knots	80	270	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:19:00	\N	1.8	-01:14:00	\N	1.4	-01:04:00	-01:42:00	Maryland Point	MD
63883	Quantico, Potomac River, Virginia Current	NOS	ACT5881_1	38.52167	-77.27667	:America/New_York	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:09:00	\N	1.1	-01:04:00	\N	0.9	-00:54:00	-01:32:00	Quantico	VA
63885	Freestone Point, 2.3 miles east of, Potomac River, Maryland Current	NOS	ACT5891_1	38.59633	-77.198	:America/New_York	USA	knots	229	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:06:00	\N	0.9	-00:01:00	\N	0.9	-00:03:00	-00:28:00	Freestone Point, 2.3 miles east of	MD
63886	Hallowing Point, Potomac River, Maryland Current	NOS	ACT5896_1	38.645	-77.1275	:America/New_York	USA	knots	149	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:15:00	\N	1.4	-00:05:00	\N	1.4	00:12:00	-00:24:00	Hallowing Point	MD
63887	Jones Point, Alexandria, Potomac River, Virginia Current	NOS	ACT5901_1	38.79367	-77.03717	:America/New_York	USA	knots	171	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:07:00	\N	1.1	00:01:00	\N	1.2	00:36:00	00:09:00	Jones Point, Alexandria	VA
63888	Hains Point, Potomac River, DC Current	NOS	ACT5906_1	38.85133	-77.022	:America/New_York	USA	knots	176	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:18:00	\N	0.4	00:31:00	\N	0.8	00:20:00	00:04:00	Hains Point	DC
63889	Hog Point, 0.6 n.mi. north of (Depth 13ft), Patuxent River, Maryland Current	NOS	ACT5931_1	38.318	-76.40117	:America/New_York	USA	knots	70	258	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:00:00	\N	0.6	-05:29:00	\N	0.5	-04:45:00	-05:59:00	Hog Point, 0.6 n.mi. north of	MD
63890	Hog Point, 0.6 n.mi. north of (Depth 41ft), Patuxent River, Maryland Current	NOS	ACT5931_2	38.318	-76.40117	:America/New_York	USA	knots	61	263	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:38:00	\N	0.3	-05:38:00	\N	0.5	-06:24:00	-05:36:00	Hog Point, 0.6 n.mi. north of	MD
63891	Drum Point, 0.3 mile SSE of, Patuxent River, Maryland Current	NOS	ACT5936_1	38.3155	-76.41917	:America/New_York	USA	knots	65	245	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-05:16:00	\N	0.5	-05:20:00	\N	0.5	-05:19:00	-05:25:00	Drum Point, 0.3 mile SSE of	MD
63892	Sandy Point, 0.5 mile south of, Patuxent River, Maryland Current	NOS	ACT5941_1	38.30833	-76.455	:America/New_York	USA	knots	125	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:55:00	\N	0.6	-05:49:00	\N	0.5	-05:08:00	-05:53:00	Sandy Point, 0.5 mile south of	MD
63893	Point Patience, 0.1 mile southwest of (Depth 15ft), Patuxent River, Maryland Current	NOS	ACT5946_1	38.32833	-76.48667	:America/New_York	USA	knots	145	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:01:00	\N	1	-06:12:00	\N	0.6	-05:07:00	-06:46:00	Point Patience, 0.1 mile southwest of	MD
63894	Broomes Island, 0.4 mile south of, Patuxent River, Maryland Current	NOS	ACT5951_1	38.395	-76.55417	:America/New_York	USA	knots	110	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-05:02:00	\N	0.6	-05:16:00	\N	0.5	-05:01:00	-05:02:00	Broomes Island, 0.4 mile south of	MD
63895	Sheridan Point, 0.1 mile southwest of, Patuxent River, Maryland Current	NOS	ACT5956_1	38.46617	-76.648	:America/New_York	USA	knots	135	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:16:00	\N	0.8	-04:54:00	\N	0.8	-04:33:00	-04:38:00	Sheridan Point, 0.1 mile southwest of	MD
63896	Benedict, highway bridge, Patuxent River, Maryland Current	NOS	ACT5961_1	38.51167	-76.67217	:America/New_York	USA	knots	190	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:35:00	\N	0.6	-04:38:00	\N	1	-04:45:00	-04:09:00	Benedict, highway bridge	MD
63897	Lyons Creek Wharf, Patuxent River, Maryland Current	NOS	ACT5966_1	38.74667	-76.685	:America/New_York	USA	knots	140	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:29:00	\N	1.1	-03:24:00	\N	1.4	-03:14:00	-03:52:00	Lyons Creek Wharf	MD
63898	Ragged Point, 1.5 miles east of, Little Choptank River, Maryland Current	NOS	ACT5976_1	38.53	-76.24417	:America/New_York	USA	knots	235	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:57:00	\N	0.2	-05:15:00	\N	0.5	-04:53:00	-04:29:00	Ragged Point, 1.5 miles east of	MD
63899	Cook Point, 1.4 n.mi. NNW of (Depth 15ft), Choptank River, Maryland Current	NOS	ACT5981_1	38.64717	-76.30667	:America/New_York	USA	knots	241	49	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:24:00	\N	0.7	-04:06:00	\N	0.8	-03:52:00	-04:06:00	Cook Point, 1.4 n.mi. NNW of	MD
63900	Cook Point, 1.4 n.mi. NNW of (Depth 45ft), Choptank River, Maryland Current	NOS	ACT5981_2	38.64717	-76.30667	:America/New_York	USA	knots	232	68	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:12:00	\N	0.6	-04:05:00	\N	0.6	-04:09:00	-04:03:00	Cook Point, 1.4 n.mi. NNW of	MD
63901	Holland Point, 2.0 n.mi. SSW of (Depth 14ft), Choptank River, Maryland Current	NOS	ACT5986_1	38.67383	-76.2575	:America/New_York	USA	knots	262	89	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:00:00	\N	0.2	-04:21:00	\N	0.3	-03:54:00	-03:26:00	Holland Point, 2.0 n.mi. SSW of	MD
63902	Chlora Point, 0.5 n.mi. SSW of (Depth 17ft), Choptank River, Maryland Current	NOS	ACT5991_1	38.62833	-76.15167	:America/New_York	USA	knots	332	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:58:00	\N	0.5	-03:32:00	\N	0.6	-03:45:00	-03:22:00	Chlora Point, 0.5 n.mi. SSW of	MD
63921	Deep Point, Chester River, Maryland Current	NOS	ACT6141_1	39.10633	-76.1205	:America/New_York	USA	knots	260	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:18:00	\N	0.9	-00:33:00	\N	0.6	-00:31:00	-00:32:00	Deep Point	MD
63903	Chlora Point, 0.5 n.mi. SSW of (Depth 24ft), Choptank River, Maryland Current	NOS	ACT5991_2	38.62833	-76.15167	:America/New_York	USA	knots	323	143	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.4	-03:33:00	\N	0.4	-03:48:00	-03:13:00	Chlora Point, 0.5 n.mi. SSW of	MD
63904	Martin Point, 0.6 n.mi. west of (Depth 18ft), Choptank River, Maryland Current	NOS	ACT5996_1	38.62717	-76.13583	:America/New_York	USA	knots	341	155	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:34:00	\N	0.2	-03:42:00	\N	0.3	-03:18:00	-03:22:00	Martin Point, 0.6 n.mi. west of	MD
63905	Howell Point, 0.5 n.mi. south of (Depth 7ft), Choptank River, Maryland Current	NOS	ACT6001_1	38.60383	-76.1145	:America/New_York	USA	knots	274	122	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.5	-04:04:00	\N	0.4	-03:17:00	-03:52:00	Howell Point, 0.5 n.mi. south of	MD
63906	Cambridge hwy. bridge, W. of Swing Span (Depth 18ft), Choptank River, Maryland Current	NOS	ACT6006_1	38.57967	-76.06117	:America/New_York	USA	knots	316	132	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:13:00	\N	0.3	-03:05:00	\N	0.6	-02:48:00	-01:07:00	Cambridge hwy. bridge, W. of Swing Span	MD
63907	Off Jamaica Point, Choptank River, Maryland Current	NOS	ACT6011_1	38.60967	-75.98283	:America/New_York	USA	knots	205	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:26:00	\N	0.8	-02:32:00	\N	0.6	-02:13:00	-02:44:00	Off Jamaica Point	MD
63908	Poplar Point, south of, Choptank River, Maryland Current	NOS	ACT6016_1	38.67533	-75.96633	:America/New_York	USA	knots	100	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:15:00	\N	1	-02:05:00	\N	1	-01:52:00	-01:56:00	Poplar Point, south of	MD
63909	Dover Bridge, Choptank River, Maryland Current	NOS	ACT6021_1	38.75667	-75.99867	:America/New_York	USA	knots	235	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:47:00	\N	1	-01:50:00	\N	1.1	-01:19:00	-01:25:00	Dover Bridge	MD
63910	Bald Eagle Pt., east of, Harris Creek, Choptank River, Maryland Current	NOS	ACT6041_1	38.72917	-76.305	:America/New_York	USA	knots	175	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:14:00	\N	0.5	-04:27:00	\N	0.5	-04:07:00	-04:07:00	Bald Eagle Pt., east of, Harris Creek	MD
63911	Poplar Island, east of south end, Eastern Bay, Maryland Current	NOS	ACT6046_1	38.74833	-76.35333	:America/New_York	USA	knots	170	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:20:00	\N	0.8	-02:20:00	\N	1.2	-02:20:00	-02:20:00	Poplar Island, east of south end	MD
63912	Kent Point, 1.4 n.mi. east of (Depth 15ft), Eastern Bay, Maryland Current	NOS	ACT6051_1	38.83883	-76.3375	:America/New_York	USA	knots	233	43	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:12:00	\N	0.4	-03:18:00	\N	0.5	-03:04:00	-03:49:00	Kent Point, 1.4 n.mi. east of	MD
63913	Long Point, 1 mile southeast of, Eastern Bay, Maryland Current	NOS	ACT6056_1	38.84333	-76.32667	:America/New_York	USA	knots	235	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:40:00	\N	0.5	-03:40:00	\N	0.6	-03:40:00	-03:40:00	Long Point, 1 mile southeast of	MD
63914	Wye River, west of Bruffs Island (Depth 9ft), Eastern Bay, Maryland Current	NOS	ACT6081_1	38.85467	-76.198	:America/New_York	USA	knots	190	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:00:00	\N	0.9	-03:18:00	\N	0.8	-02:33:00	-03:17:00	Wye River, west of Bruffs Island	MD
63915	Deepwater Point, Miles River, Eastern Bay, Maryland Current	NOS	ACT6086_1	38.8055	-76.20917	:America/New_York	USA	knots	25	215	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:14:00	\N	0.6	-03:52:00	\N	0.6	-03:48:00	-03:43:00	Deepwater Point, Miles River	MD
63916	Greenbury Point, 1.8 miles east of (Depth 8ft), Maryland Current	NOS	ACT6106_1	38.97333	-76.41667	:America/New_York	USA	knots	245	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:47:00	\N	0.8	-01:05:00	\N	0.8	-00:57:00	-00:51:00	Greenbury Point, 1.8 miles east of	MD
63917	Mountain Point, Magothy River entrance, Maryland Current	NOS	ACT6121_1	39.05783	-76.43717	:America/New_York	USA	knots	125	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:04:00	\N	0.4	-02:00:00	\N	0.8	-02:20:00	-01:29:00	Mountain Point, Magothy River entrance	MD
63918	Love Point, 1.6 n.mi. east of (Depth 16ft), Chester River, Maryland Current	NOS	ACT6126_1	39.03417	-76.26783	:America/New_York	USA	knots	341	202	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:15:00	\N	0.4	-01:15:00	\N	0.6	-01:42:00	-00:47:00	Love Point, 1.6 n.mi. east of	MD
63919	Kent Island Narrows (highway bridge) (Depth 4ft), Chester River, Maryland Current	NOS	ACT6131_1	38.9705	-76.24717	:America/New_York	USA	knots	190	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:56:00	\N	1.1	-02:25:00	\N	1.2	-02:07:00	-02:11:00	Kent Island Narrows (highway bridge)	MD
63920	Hail Point, 0.7 n.mi.east of (Depth 16ft), Chester River, Maryland Current	NOS	ACT6136_1	39.0105	-76.1825	:America/New_York	USA	knots	168	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:37:00	\N	0.6	-01:08:00	\N	0.5	-00:51:00	-01:12:00	Hail Point, 0.7 n.mi.east of	MD
63922	Chestertown, Chester River, Maryland Current	NOS	ACT6146_1	39.20717	-76.06117	:America/New_York	USA	knots	220	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:17:00	\N	0.6	00:05:00	\N	0.8	-00:21:00	-00:02:00	Chestertown	MD
63923	Lynch Point, Back River, Maryland Current	NOS	ACT6186_1	39.25	-76.43833	:America/New_York	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:10:00	\N	0.5	-00:10:00	\N	0.7	00:00:00	00:00:00	Lynch Point, Back River	MD
63924	Gunpowder River entrance, Maryland Current	NOS	ACT6191_1	39.31167	-76.30833	:America/New_York	USA	knots	205	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:05:00	\N	0.4	-00:41:00	\N	0.5	-00:24:00	00:25:00	Gunpowder River entrance	MD
63925	Bush River, 0.4 mi. SW of Bush Point, Maryland Current	NOS	ACT6196_1	39.35667	-76.25667	:America/New_York	USA	knots	165	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:20:00	\N	0.6	-00:24:00	\N	0.8	00:07:00	00:21:00	Bush River, 0.4 mi. SW of Bush Point	MD
63926	Grove Point, Sassafrass River, Maryland Current	NOS	ACT6201_1	39.37833	-76.04333	:America/New_York	USA	knots	288	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:44:00	\N	0.4	00:46:00	\N	0.5	00:46:00	00:51:00	Grove Point	MD
63927	Ordinary Point, 0.4 mile west of, Sassafrass River, Maryland Current	NOS	ACT6206_1	39.37417	-75.9875	:America/New_York	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:58:00	\N	0.5	00:37:00	\N	0.6	00:50:00	01:17:00	Ordinary Point, 0.4 mile west of	MD
63928	Georgetown, Sassafrass River, Maryland Current	NOS	ACT6211_1	39.36117	-75.88617	:America/New_York	USA	knots	200	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:25:00	\N	0.5	00:25:00	\N	0.4	01:00:00	00:56:00	Georgetown	MD
63929	Arnold Point, 0.4 mile west of, Elk River, Maryland Current	NOS	ACT6216_1	39.46383	-75.97417	:America/New_York	USA	knots	215	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:32:00	\N	1	01:45:00	\N	1	01:39:00	01:24:00	Arnold Point, 0.4 mile west of	MD
63930	Old Town Point Wharf, northwest of (Depth 17ft), Elk River, Maryland Current	NOS	ACT6221_1	39.50383	-75.91867	:America/New_York	USA	knots	242	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:45:00	\N	1.6	01:53:00	\N	1.3	02:00:00	01:49:00	Old Town Point Wharf, northwest of	MD
63931	Old Town Point Wharf, northwest of (Depth 29ft), Elk River, Maryland Current	NOS	ACT6221_2	39.50383	-75.91867	:America/New_York	USA	knots	237	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:45:00	\N	1.4	02:04:00	\N	1.2	02:07:00	01:47:00	Old Town Point Wharf, northwest of	MD
63932	Hendersons Point, Elk River, Maryland Current	NOS	ACT6226_1	39.55333	-75.86	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	02:05:00	\N	0.9	02:05:00	\N	0.6	02:05:00	02:05:00	Hendersons Point	MD
63933	Bodie Island-Pea Island, between (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6271_1	35.77667	-75.535	:America/New_York	USA	knots	28	202	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:52:00	\N	0.6	02:20:00	\N	1.2	02:38:00	02:03:00	Bodie Island-Pea Island, between	NC
63934	Bodie Island-Pea Island, between (Depth 12ft), Oregon Inlet, North Carolina Current	NOS	ACT6271_2	35.77667	-75.535	:America/New_York	USA	knots	36	204	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.6	02:36:00	\N	1.2	02:49:00	02:02:00	Bodie Island-Pea Island, between	NC
63935	Coast Guard Tower, southwest of (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6276_1	35.76167	-75.53167	:America/New_York	USA	knots	28	205	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:18:00	\N	0.8	02:30:00	\N	0.8	03:04:00	01:53:00	Coast Guard Tower, southwest of	NC
63936	Coast Guard Tower, southwest of (Depth 12ft), Oregon Inlet, North Carolina Current	NOS	ACT6276_2	35.76167	-75.53167	:America/New_York	USA	knots	33	212	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:33:00	\N	0.7	02:33:00	\N	0.8	03:01:00	01:57:00	Coast Guard Tower, southwest of	NC
63937	Herbert C. Bonner Bridge, WSW of (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6281_1	35.77	-75.54667	:America/New_York	USA	knots	87	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:46:00	\N	0.9	02:55:00	\N	0.6	03:32:00	01:30:00	Herbert C. Bonner Bridge, WSW of	NC
63938	Hatteras Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6286_1	35.2	-75.75	:America/New_York	USA	knots	148	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:38:00	\N	1	02:42:00	\N	1.2	02:42:00	02:18:00	Hatteras Inlet	NC
63939	Channel entrance, Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6296_1	35.06533	-76.01883	:America/New_York	USA	knots	145	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:40:00	\N	1.2	02:24:00	\N	1	02:48:00	01:43:00	channel entrance	NC
63940	Teaches Hole Channel (Depth 10ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6301_1	35.07917	-76.00467	:America/New_York	USA	knots	195	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:47:00	\N	0.8	02:27:00	\N	0.6	02:49:00	01:42:00	Teaches Hole Channel	NC
63941	Blair Channel (Depth 10ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6306_1	35.08133	-76.03383	:America/New_York	USA	knots	140	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:03:00	\N	0.9	02:33:00	\N	0.6	02:52:00	01:48:00	Blair Channel	NC
63942	Wallace Channel (Depth 9ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6311_1	35.07967	-76.052	:America/New_York	USA	knots	140	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:13:00	\N	0.9	02:57:00	\N	0.9	02:51:00	02:03:00	Wallace Channel	NC
63943	Sheep Island Slue, Pamlico Sound, North Carolina Current	NOS	ACT6316_1	35.06667	-76.1	:America/New_York	USA	knots	95	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:56:00	\N	0.2	03:18:00	\N	0.1	02:33:00	01:35:00	Sheep Island Slue	NC
63944	Shackleford Banks, 0.8 mile S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6326_1	34.66633	-76.6555	:America/New_York	USA	knots	145	314	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.7	01:16:00	\N	0.8	01:19:00	00:30:00	Shackleford Banks, 0.8 mile S of	NC
63945	Approach, Beaufort Inlet, North Carolina Current	NOS	ACT6331_1	34.67167	-76.67	:America/New_York	USA	knots	161	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:57:00	\N	0.7	01:19:00	\N	0.2	02:03:00	00:37:00	Approach	NC
63946	Fort Macon, 0.6 mile SE of, Beaufort Inlet, North Carolina Current	NOS	ACT6336_1	34.68583	-76.66833	:America/New_York	USA	knots	154	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:38:00	\N	0.9	01:47:00	\N	0.7	01:42:00	00:51:00	Fort Macon, 0.6 mile SE of	NC
63947	Fort Macon, 0.2 mile NE of (Depth 10ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_1	34.69967	-76.67533	:America/New_York	USA	knots	151	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:21:00	\N	0.9	01:20:00	\N	1.1	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
63948	Fort Macon, 0.2 mile NE of (Depth 20ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_2	34.69967	-76.67533	:America/New_York	USA	knots	153	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:39:00	\N	0.9	01:18:00	\N	1.1	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
63949	Tombstone Point, 0.1 mile E of (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6346_1	34.70383	-76.68617	:America/New_York	USA	knots	128	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:27:00	\N	0.8	01:25:00	\N	0.9	01:13:00	00:34:00	Tombstone Point, 0.1 mile E of	NC
63950	Turning Basin (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_1	34.713	-76.69417	:America/New_York	USA	knots	144	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:32:00	\N	0.5	01:34:00	\N	0.8	01:11:00	00:50:00	Turning Basin	NC
63951	Turning Basin (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_2	34.713	-76.69417	:America/New_York	USA	knots	138	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:32:00	\N	0.5	01:34:00	\N	0.7	01:09:00	00:59:00	Turning Basin	NC
63952	Sugarloaf Island, 0.2 mile S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6356_1	34.7125	-76.71383	:America/New_York	USA	knots	94	266	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:14:00	\N	0.8	01:39:00	\N	0.7	01:58:00	01:22:00	Sugarloaf Island, 0.2 mile S of	NC
63953	Morehead City, S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6361_1	34.71667	-76.73283	:America/New_York	USA	knots	110	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:42:00	\N	0.7	01:47:00	\N	0.8	02:12:00	01:29:00	Morehead City, S of	NC
63954	Morehead City, RR. bridge, N of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6366_1	34.72283	-76.69383	:America/New_York	USA	knots	185	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:03:00	\N	0.5	01:01:00	\N	0.6	00:44:00	00:09:00	Morehead City, RR. bridge, N of	NC
63955	Newport Marshes, SE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_1	34.73133	-76.68333	:America/New_York	USA	knots	215	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:08:00	\N	0.6	01:02:00	\N	0.8	00:57:00	00:18:00	Newport Marshes, SE of	NC
63956	Newport Marshes, SE of (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_2	34.73133	-76.68333	:America/New_York	USA	knots	226	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:08:00	\N	0.6	01:15:00	\N	0.8	00:53:00	00:21:00	Newport Marshes, SE of	NC
63957	Newport Marshes, E of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6376_1	34.73783	-76.6805	:America/New_York	USA	knots	224	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.5	00:11:00	\N	0.6	00:07:00	-00:37:00	Newport Marshes, E of	NC
63958	Radio Island, E of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6381_1	34.71167	-76.67967	:America/New_York	USA	knots	202	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.6	00:55:00	\N	0.7	00:55:00	00:20:00	Radio Island, E of	NC
63959	Bird Shoal, SE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6391_1	34.7005	-76.65383	:America/New_York	USA	knots	304	126	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.4	01:34:00	\N	0.5	01:40:00	01:10:00	Bird Shoal, SE of	NC
63960	Shackleford Point, NE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6396_1	34.69217	-76.65217	:America/New_York	USA	knots	305	135	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:46:00	\N	0.6	01:28:00	\N	0.8	01:32:00	01:10:00	Shackleford Point, NE of	NC
63961	Carrot Island (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6401_1	34.70217	-76.6175	:America/New_York	USA	knots	262	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:49:00	\N	0.7	01:34:00	\N	0.5	01:49:00	01:15:00	Carrot Island	NC
63962	Middle Marshes, S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6406_1	34.67833	-76.61383	:America/New_York	USA	knots	275	123	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:18:00	\N	0.5	01:04:00	\N	0.8	00:59:00	01:03:00	Middle Marshes, S of	NC
63963	Winyah Bay entrance, Winyah Bay, South Carolina Current	NOS	ACT6531_1	33.20717	-79.1845	:America/New_York	USA	knots	140	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:20:00	\N	1	01:35:00	\N	1.1	01:47:00	01:05:00	Winyah Bay entrance	SC
63964	Range D, off Mosquito Creek, Winyah Bay, South Carolina Current	NOS	ACT6536_1	33.24417	-79.20583	:America/New_York	USA	knots	130	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:42:00	\N	1.1	01:57:00	\N	1.2	02:00:00	01:13:00	Range D, off Mosquito Creek	SC
63965	Frazier Point, south of, Winyah Bay, South Carolina Current	NOS	ACT6541_1	33.295	-79.27283	:America/New_York	USA	knots	115	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:59:00	\N	0.5	01:52:00	\N	1.1	01:52:00	02:20:00	Frazier Point, south of	SC
63966	Frazier Point, west of, Winyah Bay, South Carolina Current	NOS	ACT6546_1	33.30967	-79.28667	:America/New_York	USA	knots	170	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:41:00	\N	1	02:19:00	\N	0.9	02:23:00	02:01:00	Frazier Point, west of	SC
63967	Rabbit Island, northwest of, Winyah Bay, South Carolina Current	NOS	ACT6551_1	33.3395	-79.28133	:America/New_York	USA	knots	215	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:25:00	\N	0.9	02:46:00	\N	1.2	02:39:00	02:14:00	Rabbit Island, northwest of	SC
63968	Sampit River entrance, Winyah Bay, South Carolina Current	NOS	ACT6556_1	33.35133	-79.28033	:America/New_York	USA	knots	135	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:53:00	\N	0.7	01:20:00	\N	0.6	01:33:00	01:39:00	Sampit River entrance	SC
63969	Georgetown, Sampit River, Winyah Bay, South Carolina Current	NOS	ACT6561_1	33.35917	-79.2875	:America/New_York	USA	knots	80	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.6	01:18:00	\N	0.5	02:00:00	00:56:00	Georgetown, Sampit River	SC
63970	Pee Dee River, swing bridge, Winyah Bay, South Carolina Current	NOS	ACT6566_1	33.3705	-79.26383	:America/New_York	USA	knots	210	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:43:00	\N	0.5	03:13:00	\N	0.4	03:03:00	01:57:00	Pee Dee River, swing bridge	SC
63971	Lafayette swing bridge, Waccamaw River, Winyah Bay, South Carolina Current	NOS	ACT6571_1	33.36867	-79.252	:America/New_York	USA	knots	200	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:31:00	\N	0.6	03:04:00	\N	0.4	03:23:00	01:56:00	Lafayette swing bridge, Waccamaw River	SC
63972	Butler Island, 0.3 mile south of, Winyah Bay, South Carolina Current	NOS	ACT6576_1	33.41667	-79.212	:America/New_York	USA	knots	205	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:55:00	\N	0.5	03:34:00	\N	0.4	03:36:00	02:11:00	Butler Island, 0.3 mile south of	SC
63973	North Santee River entrance (Depth 6ft), South Carolina Current	NOS	ACT6581_1	33.13583	-79.24083	:America/New_York	USA	knots	165	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:01:00	\N	0.9	00:33:00	\N	0.9	01:00:00	00:03:00	North Santee River entrance	SC
63974	South Santee River entrance (Depth 5ft), South Carolina Current	NOS	ACT6586_1	33.12	-79.275	:America/New_York	USA	knots	240	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.8	00:38:00	\N	0.9	00:20:00	00:27:00	South Santee River entrance	SC
63975	Fort Sumter Range, Buoy '2', Charleston Harbor, South Carolina Current	NOS	ACT6611_1	32.683	-79.726	:America/New_York	USA	knots	104	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:03:00	\N	0.2	-00:51:00	\N	0.2	-01:05:00	-01:11:00	Fort Sumter Range, Buoy '2'	SC
63976	Fort Sumter Range, Buoy '4', Charleston Harbor, South Carolina Current	NOS	ACT6616_1	32.69767	-79.75567	:America/New_York	USA	knots	117	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:38:00	\N	0.2	-00:59:00	\N	0.3	-00:49:00	-01:10:00	Fort Sumter Range, Buoy '4'	SC
63977	Fort Sumter Range, Buoy '8', Charleston Harbor, South Carolina Current	NOS	ACT6621_1	32.715	-79.79233	:America/New_York	USA	knots	128	299	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.5	-00:16:00	\N	0.4	-00:15:00	00:17:00	Fort Sumter Range, Buoy '8'	SC
63978	Fort Sumter Range, Buoy '14', Charleston Harbor, South Carolina Current	NOS	ACT6626_1	32.72433	-79.81	:America/New_York	USA	knots	116	287	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:01:00	\N	0.8	-00:04:00	\N	0.6	-00:10:00	00:16:00	Fort Sumter Range, Buoy '14'	SC
63979	North Jetty, 0.8 mile southeast of, Charleston Harbor, South Carolina Current	NOS	ACT6631_1	32.7175	-79.8	:America/New_York	USA	knots	110	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:16:00	\N	0.6	-00:48:00	\N	0.2	-00:06:00	-01:09:00	North Jetty, 0.8 mile southeast of	SC
63980	Charleston Hbr. ent. (between jetties), Charleston Harbor, South Carolina Current	NOS	ACT6636_1	32.73333	-79.83333	:America/New_York	USA	knots	121	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.9	00:04:00	\N	1.1	-00:01:00	00:05:00	Charleston Hbr. ent. (between jetties)	SC
63981	Fort Sumter Range, Buoy '20', Charleston Harbor, South Carolina Current	NOS	ACT6641_1	32.7405	-79.8445	:America/New_York	USA	knots	128	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:51:00	\N	0.9	-00:15:00	\N	0.9	-00:33:00	-00:33:00	Fort Sumter Range, Buoy '20'	SC
63982	South Jetty, break in, Charleston Harbor, South Carolina Current	NOS	ACT6646_1	32.73117	-79.85033	:America/New_York	USA	knots	204	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	1.4	00:31:00	\N	0.7	00:38:00	00:06:00	South Jetty, break in	SC
63983	Ft. Sumter, 0.6 n.mi. NW of, Charleston Harbor, South Carolina Current	NOS	ACT6656_1	32.76117	-79.86717	:America/New_York	USA	knots	138	322	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:24:00	\N	0.9	-00:03:00	\N	0.9	-00:05:00	00:01:00	Ft. Sumter, 0.6 n.mi. NW of	SC
63984	South Chan., 0.8 mi. ENE of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6661_1	32.75867	-79.88467	:America/New_York	USA	knots	115	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:13:00	\N	1.3	00:11:00	\N	0.5	00:43:00	-00:12:00	South Chan., 0.8 mi. ENE of Ft. Johnson	SC
63985	South Chan., 0.4 mi. NW of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6666_1	32.758	-79.90633	:America/New_York	USA	knots	104	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	1	00:58:00	\N	0.4	01:10:00	00:16:00	South Chan., 0.4 mi. NW of Ft. Johnson	SC
63986	Sullivans I., 0.7 mi. NE of Ft. Sumter, Charleston Harbor, South Carolina Current	NOS	ACT6671_1	32.762	-79.8675	:America/New_York	USA	knots	132	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:03:00	\N	0.8	00:37:00	\N	0.8	00:17:00	00:01:00	Sullivans I., 0.7 mi. NE of Ft. Sumter	SC
63987	Castle Pinckney, 0.4 mile south of, Charleston Harbor, South Carolina Current	NOS	ACT6676_1	32.767	-79.91167	:America/New_York	USA	knots	98	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:58:00	\N	0.9	01:00:00	\N	0.5	00:40:00	00:14:00	Castle Pinckney, 0.4 mile south of	SC
63988	South Channel, Buoy '32', Charleston Harbor, South Carolina Current	NOS	ACT6681_1	32.76217	-79.911	:America/New_York	USA	knots	125	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.5	-00:04:00	\N	0.5	-00:01:00	00:18:00	South Channel, Buoy '32'	SC
63989	Castle Pinckney, 0.6 mile southwest of, Charleston Harbor, South Carolina Current	NOS	ACT6686_1	32.76633	-79.9195	:America/New_York	USA	knots	156	318	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:40:00	\N	0.7	01:20:00	\N	0.4	01:21:00	00:24:00	Castle Pinckney, 0.6 mile southwest of	SC
63990	Shutes Folly Island, 0.4 mile west of, Charleston Harbor, South Carolina Current	NOS	ACT6691_1	32.77633	-79.92083	:America/New_York	USA	knots	164	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:08:00	\N	1.1	00:59:00	\N	0.5	00:53:00	00:20:00	Shutes Folly Island, 0.4 mile west of	SC
63991	Customhouse Reach, off Customhouse, Charleston Harbor, South Carolina Current	NOS	ACT6696_1	32.7795	-79.9225	:America/New_York	USA	knots	190	9	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:23:00	\N	0.7	01:03:00	\N	0.6	00:49:00	00:59:00	Customhouse Reach, off Customhouse	SC
63992	Customhouse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6701_1	32.7825	-79.92	:America/New_York	USA	knots	153	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.9	00:37:00	\N	0.6	00:46:00	00:37:00	Customhouse Reach	SC
63993	Town Creek Lower Reach, Charleston Harbor, South Carolina Current	NOS	ACT6706_1	32.7925	-79.9245	:America/New_York	USA	knots	172	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:07:00	\N	1.1	00:24:00	\N	0.6	00:34:00	00:02:00	Town Creek Lower Reach	SC
63994	Town Creek, 0.2 mile above bridge, Charleston Harbor, South Carolina Current	NOS	ACT6711_1	32.80533	-79.93167	:America/New_York	USA	knots	166	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	1.3	00:54:00	\N	0.5	01:06:00	00:03:00	Town Creek, 0.2 mile above bridge	SC
63995	Rebellion Reach, 0.8 n.mi. N. of Ft. Sumter, Charleston Harbor, South Carolina Current	NOS	ACT6716_1	32.76633	-79.87333	:America/New_York	USA	knots	143	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:48:00	\N	0.4	00:27:00	\N	0.4	-00:06:00	-00:25:00	Rebellion Reach, 0.8 n.mi. N. of Ft. Sumter	SC
63996	The Cove, entrance on the Cove Range, Charleston Harbor, South Carolina Current	NOS	ACT6721_1	32.7675	-79.872	:America/New_York	USA	knots	151	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:10:00	\N	0.5	01:14:00	\N	0.7	00:28:00	00:06:00	The Cove, entrance on the Cove Range	SC
63997	Hog Island Channel, Charleston Harbor, South Carolina Current	NOS	ACT6726_1	32.78117	-79.87633	:America/New_York	USA	knots	125	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:20:00	\N	0.4	00:03:00	\N	0.5	-00:39:00	-00:29:00	Hog Island Channel	SC
63998	Folly I. Channel, N of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6731_1	32.76967	-79.90117	:America/New_York	USA	knots	104	301	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:59:00	\N	0.6	-00:03:00	\N	0.7	-01:09:00	-00:04:00	Folly I. Channel, N of Ft. Johnson	SC
63999	Folly Reach, Buoy '5', Charleston Harbor, South Carolina Current	NOS	ACT6736_1	32.77633	-79.89917	:America/New_York	USA	knots	110	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:13:00	\N	0.8	00:35:00	\N	0.7	00:02:00	00:18:00	Folly Reach, Buoy '5'	SC
64000	Shutes Reach, Buoy '8', Charleston Harbor, South Carolina Current	NOS	ACT6741_1	32.78217	-79.91083	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:25:00	\N	0.8	00:22:00	\N	0.7	00:18:00	00:15:00	Shutes Reach, Buoy '8'	SC
64001	Horse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6746_1	32.78617	-79.915	:America/New_York	USA	knots	146	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	1	00:23:00	\N	0.8	00:36:00	-00:12:00	Horse Reach	SC
64002	Hog Island Reach, Buoy '12', Charleston Harbor, South Carolina Current	NOS	ACT6751_1	32.7945	-79.915	:America/New_York	USA	knots	193	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:12:00	\N	0.7	00:28:00	\N	0.7	00:13:00	00:14:00	Hog Island Reach, Buoy '12'	SC
64003	Drum Island, 0.4 mile SSE of, Charleston Harbor, South Carolina Current	NOS	ACT6756_1	32.7945	-79.92083	:America/New_York	USA	knots	155	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.9	00:53:00	\N	0.8	00:34:00	00:11:00	Drum Island, 0.4 mile SSE of	SC
64004	Drum Island, east of (bridge), Charleston Harbor, South Carolina Current	NOS	ACT6761_1	32.8045	-79.91533	:America/New_York	USA	knots	183	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:06:00	\N	1	00:42:00	\N	0.7	00:30:00	00:15:00	Drum Island, east of (bridge)	SC
64005	Hog Island Reach, SW of Remley Point, Charleston Harbor, South Carolina Current	NOS	ACT6766_1	32.81183	-79.912	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:51:00	\N	0.7	00:44:00	\N	0.7	00:30:00	00:43:00	Hog Island Reach, SW of Remley Point	SC
64006	Drum Island Reach, off Drum I., Buoy '45', Charleston Harbor, South Carolina Current	NOS	ACT6771_1	32.81617	-79.92283	:America/New_York	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:00:00	\N	0.5	01:00:00	\N	0.4	00:26:00	01:06:00	Drum Island Reach, off Drum I., Buoy '45'	SC
64007	Drum Island, 0.2 mile above, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6776_1	32.81967	-79.92917	:America/New_York	USA	knots	152	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:37:00	\N	1.2	01:09:00	\N	0.6	01:12:00	00:01:00	Drum Island, 0.2 mile above	SC
64008	Daniel Island Reach, Buoy '48', Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6781_1	32.82717	-79.92883	:America/New_York	USA	knots	182	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:55:00	\N	0.7	01:29:00	\N	0.7	01:01:00	00:53:00	Daniel Island Reach, Buoy '48'	SC
64009	Shipyard Creek entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6786_1	32.83	-79.935	:America/New_York	USA	knots	197	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.8	01:06:00	\N	0.3	00:41:00	-00:29:00	Shipyard Creek entrance	SC
64010	Daniel Island Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6791_1	32.83283	-79.93	:America/New_York	USA	knots	190	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:51:00	\N	1.2	01:49:00	\N	0.8	01:29:00	00:42:00	Daniel Island Reach	SC
64011	Daniel Island Bend, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6796_1	32.84833	-79.92917	:America/New_York	USA	knots	153	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:39:00	\N	1.1	01:29:00	\N	0.7	00:55:00	00:55:00	Daniel Island Bend	SC
64012	North Charleston, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6806_1	32.86367	-79.95883	:America/New_York	USA	knots	142	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:17:00	\N	0.9	02:28:00	\N	0.6	01:26:00	01:04:00	North Charleston	SC
64013	Filbin Creek Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6811_1	32.88867	-79.96533	:America/New_York	USA	knots	180	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:27:00	\N	0.9	02:06:00	\N	0.7	01:31:00	01:08:00	Filbin Creek Reach	SC
64014	Filbin Creek Reach, 0.2 mile east of, Cooper River, South Carolina Current	NOS	ACT6816_1	32.888	-79.9605	:America/New_York	USA	knots	197	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:29:00	\N	0.7	01:47:00	\N	0.4	01:16:00	00:32:00	Filbin Creek Reach, 0.2 mile east of	SC
64015	Filbin Creek Reach, Buoy '58', Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6821_1	32.89633	-79.96117	:America/New_York	USA	knots	214	31	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:09:00	\N	0.7	02:04:00	\N	0.6	01:18:00	01:24:00	Filbin Creek Reach, Buoy '58'	SC
64016	Ordnance Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6826_1	32.90633	-79.95283	:America/New_York	USA	knots	242	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:07:00	\N	0.6	02:34:00	\N	0.6	01:35:00	01:05:00	Ordnance Reach	SC
64017	Yellow House Creek, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6831_1	32.90883	-79.93633	:America/New_York	USA	knots	270	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:12:00	\N	0.7	02:41:00	\N	0.4	02:06:00	00:57:00	Yellow House Creek	SC
64018	Yellow House Landing, 1 mile NW of, Cooper River, South Carolina Current	NOS	ACT6836_1	32.91967	-79.9305	:America/New_York	USA	knots	170	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:06:00	\N	0.9	02:43:00	\N	0.4	02:26:00	00:58:00	Yellow House Landing, 1 mile NW of	SC
64019	Woods Point, SE of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6841_1	32.92583084106445	-79.93283081054688	:America/New_York	USA	knots	157	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:09:00	\N	0.5	01:55:00	\N	0.5	01:48:00	01:55:00	Woods Point, SE of	SC
64020	Woods Point, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6846_1	32.93167	-79.93833	:America/New_York	USA	knots	201	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:43:00	\N	0.7	03:02:00	\N	0.5	02:41:00	01:11:00	Woods Point	SC
64021	Snow Point, 0.5 mile north of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6851_1	32.95167	-79.93	:America/New_York	USA	knots	210	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:33:00	\N	0.7	02:36:00	\N	0.6	02:15:00	01:48:00	Snow Point, 0.5 mile north of	SC
64022	Back River entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6856_1	32.96833	-79.93333	:America/New_York	USA	knots	67	252	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:34:00	\N	0.6	00:45:00	\N	0.6	00:46:00	00:48:00	Back River entrance	SC
64023	Amoco Pier, off, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6861_1	32.95917	-79.918	:America/New_York	USA	knots	191	24	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.5	02:49:00	\N	0.4	02:09:00	02:10:00	Amoco Pier, off	SC
64024	Moreland, 0.5 n.mi. below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6866_1	33.0005	-79.90467	:America/New_York	USA	knots	216	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:19:00	\N	1	02:58:00	\N	1.1	02:39:00	02:28:00	Moreland, 0.5 n.mi. below	SC
64025	Hagan Island, 1 n.mi. below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6871_1	33.03333	-79.91333	:America/New_York	USA	knots	134	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:37:00	\N	0.7	03:52:00	\N	0.8	02:39:00	02:27:00	Hagan Island, 1 n.mi. below	SC
64026	The Tee, 0.4 mile southwest of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6876_1	33.06333	-79.92967	:America/New_York	USA	knots	98	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:20:00	\N	0.9	04:20:00	\N	0.6	04:22:00	02:29:00	The Tee, 0.4 mile southwest of	SC
64027	The Tee, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6881_1	33.06583	-79.923	:America/New_York	USA	knots	161	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:43:00	\N	0.5	03:09:00	\N	0.6	03:00:00	02:36:00	The Tee	SC
64028	Childsbury, S.A.L. RR. bridge, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6886_1	33.09383	-79.9425	:America/New_York	USA	knots	141	309	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:34:00	\N	0.9	04:27:00	\N	0.4	04:43:00	02:15:00	Childsbury, S.A.L. RR. bridge	SC
64029	East Branch, 0.2 mile above entrance, Cooper River, South Carolina Current	NOS	ACT6891_1	33.06833	-79.92	:America/New_York	USA	knots	262	84	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:06:00	\N	0.9	03:07:00	\N	1.1	03:01:00	02:59:00	East Branch, 0.2 mile above entrance	SC
64030	Bonneau Ferry, east of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6896_1	33.07167	-79.88333	:America/New_York	USA	knots	197	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:36:00	\N	0.4	03:10:00	\N	0.4	03:27:00	02:44:00	Bonneau Ferry, east of	SC
64031	Remley Point, 0.2 mile northwest of, Wando River, South Carolina Current	NOS	ACT6901_1	32.81617	-79.9095	:America/New_York	USA	knots	191	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:04:00	\N	0.9	00:36:00	\N	0.8	-00:14:00	00:20:00	Remley Point, 0.2 mile northwest of	SC
64032	Wando River Upper Reach, Turning Basin, Wando River, South Carolina Current	NOS	ACT6906_1	32.83333	-79.89667	:America/New_York	USA	knots	192	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.6	-00:12:00	\N	0.6	-00:14:00	-00:09:00	Wando River Upper Reach, Turning Basin	SC
64033	Rathall Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6911_1	32.8595	-79.89617	:America/New_York	USA	knots	216	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:18:00	\N	0.9	00:35:00	\N	0.8	00:25:00	00:18:00	Rathall Creek entrance	SC
64034	Horlbeck Creek, 0.2 mile above entrance, Wando River, South Carolina Current	NOS	ACT6916_1	32.885	-79.845	:America/New_York	USA	knots	218	26	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.5	00:29:00	\N	0.6	00:28:00	00:31:00	Horlbeck Creek, 0.2 mile above entrance	SC
64035	Nowell Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6921_1	32.87833	-79.875	:America/New_York	USA	knots	171	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:39:00	\N	0.6	00:42:00	\N	0.4	-00:02:00	-00:12:00	Nowell Creek entrance	SC
64036	Buoy '19', off Nowell Creek, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6926_1	32.872	-79.8655	:America/New_York	USA	knots	261	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:19:00	\N	0.5	-00:06:00	\N	0.5	-00:08:00	00:04:00	Buoy '19', off Nowell Creek	SC
64037	Horlbeck Creek, 2.5 miles north of, Wando River, South Carolina Current	NOS	ACT6931_1	32.91833	-79.83833	:America/New_York	USA	knots	207	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:28:00	\N	0.7	00:41:00	\N	0.5	00:30:00	00:26:00	Horlbeck Creek, 2.5 miles north of	SC
64038	Battery, southwest of, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6936_1	32.76717	-79.93383	:America/New_York	USA	knots	114	303	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	0.9	00:09:00	\N	0.7	00:16:00	-00:24:00	Battery, southwest of	SC
64039	Wappoo Creek, off of, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6941_1	32.773	-79.95	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:41:00	\N	0.6	-00:05:00	\N	0.7	00:07:00	-00:06:00	Wappoo Creek, off of	SC
64040	Highway Bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6946_1	32.782	-79.96	:America/New_York	USA	knots	138	321	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:18:00	\N	0.6	00:30:00	\N	0.7	-00:09:00	-00:03:00	Highway Bridge	SC
64041	S.C.L. RR. bridge, 0.1 mile below, Ashley River, South Carolina Current	NOS	ACT6951_1	32.7955	-79.97333	:America/New_York	USA	knots	150	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:28:00	\N	0.6	00:44:00	\N	0.6	-00:06:00	-00:12:00	S.C.L. RR. bridge, 0.1 mile below	SC
64042	S.C.L. RR. bridge, 1.5 miles above, Ashley River, South Carolina Current	NOS	ACT6956_1	32.82	-79.965	:America/New_York	USA	knots	178	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.8	00:19:00	\N	0.7	00:22:00	00:17:00	S.C.L. RR. bridge, 1.5 miles above	SC
64043	State Hwy. 7 bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6961_1	32.83717	-79.982	:America/New_York	USA	knots	114	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:05:00	\N	0.5	-00:04:00	\N	0.6	00:06:00	00:05:00	State Hwy. 7 bridge	SC
64044	West Marsh Island, 0.1 mile east of, Ashley River, South Carolina Current	NOS	ACT6966_1	32.82833	-80.00833	:America/New_York	USA	knots	86	250	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:25:00	\N	0.5	00:30:00	\N	0.4	00:23:00	00:14:00	West Marsh Island, 0.1 mile east of	SC
64045	Bees Ferry Bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6971_1	32.84667	-80.05	:America/New_York	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	1.2	00:44:00	\N	1.1	01:13:00	00:37:00	Bees Ferry Bridge	SC
64046	Stono Inlet, Stono River, South Carolina Current	NOS	ACT6976_1	32.62667	-79.99333	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:45:00	\N	1.4	00:44:00	\N	1.1	-00:14:00	-00:09:00	Stono Inlet	SC
64047	Snake Island (Depth 12ft), Stono River, South Carolina Current	NOS	ACT6981_1	32.64	-80.02	:America/New_York	USA	knots	179	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:38:00	\N	0.5	-00:42:00	\N	0.7	-00:44:00	-00:30:00	Snake Island	SC
64048	Johns Island Airport, south of (Depth 12ft), Stono River, South Carolina Current	NOS	ACT6986_1	32.68333	-80.00333	:America/New_York	USA	knots	192	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:34:00	\N	0.8	-00:46:00	\N	0.9	-00:15:00	-00:13:00	Johns Island Airport, south of	SC
64049	Johns Island Bridge (Depth 14ft), Stono River, South Carolina Current	NOS	ACT6991_1	32.75333	-80.01	:America/New_York	USA	knots	182	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:10:00	\N	0.5	00:21:00	\N	0.5	00:40:00	00:33:00	Johns Island Bridge	SC
64050	Elliott Cut, west end, Stono River, South Carolina Current	NOS	ACT6996_1	32.76667	-80	:America/New_York	USA	knots	80	260	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:18:00	\N	1	-01:00:00	\N	0.9	00:10:00	-00:46:00	Elliott Cut, west end	SC
64051	Johns Island (Depth 12ft), Stono River, South Carolina Current	NOS	ACT7001_1	32.78667	-80.10667	:America/New_York	USA	knots	68	249	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:32:00	\N	0.4	01:48:00	\N	0.4	-00:24:00	00:29:00	Johns Island	SC
64052	Pleasant Point (Depth 12ft), Stono River, South Carolina Current	NOS	ACT7006_1	32.75	-80.13333	:America/New_York	USA	knots	196	8	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:37:00	\N	0.4	00:34:00	\N	0.3	02:04:00	03:54:00	Pleasant Point	SC
64053	Deveaux Banks, off North Edisto River entrance (Depth 12ft), South Carolina Current	NOS	ACT7021_1	32.545	-80.15667	:America/New_York	USA	knots	126	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:26:00	\N	1	-00:01:00	\N	0.8	-00:16:00	-00:04:00	Deveaux Banks, off North Edisto River entrance	SC
64054	North Edisto River entrance, South Carolina Current	NOS	ACT7026_1	32.56167	-80.18667	:America/New_York	USA	knots	142	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	1.9	01:10:00	\N	1.7	00:56:00	01:11:00	North Edisto River entrance	SC
64055	Wadmalaw Island, Wadmalaw River entrance (Depth 12ft), South Carolina Current	NOS	ACT7031_1	32.665	-80.235	:America/New_York	USA	knots	165	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:29:00	\N	0.4	00:11:00	\N	0.7	-01:02:00	00:06:00	Wadmalaw Island, Wadmalaw River entrance	SC
64056	Goshen Point, SE of, Wadmalaw River (Depth 12ft), South Carolina Current	NOS	ACT7036_1	32.71	-80.17167	:America/New_York	USA	knots	249	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.4	02:18:00	\N	0.5	00:51:00	01:47:00	Goshen Point, SE of, Wadmalaw River	SC
64057	Goshen Point, south of, Wadmalaw River (Depth 12ft), South Carolina Current	NOS	ACT7041_1	32.71333	-80.18667	:America/New_York	USA	knots	235	48	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:53:00	\N	0.5	02:03:00	\N	0.4	01:24:00	01:35:00	Goshen Point, south of, Wadmalaw River	SC
64058	White Point, south of, Dawho River (Depth 12ft), South Carolina Current	NOS	ACT7046_1	32.625	-80.28167	:America/New_York	USA	knots	44	234	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.4	00:02:00	\N	0.4	00:31:00	00:29:00	White Point, south of, Dawho River	SC
64059	Whooping Island, Dawho River (Depth 12ft), South Carolina Current	NOS	ACT7051_1	32.63667	-80.34	:America/New_York	USA	knots	70	246	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:37:00	\N	0.3	00:36:00	\N	0.5	01:36:00	01:35:00	Whooping Island, Dawho River	SC
64060	South Edisto River entrance, South Carolina Current	NOS	ACT7056_1	32.48833	-80.34833	:America/New_York	USA	knots	146	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	1.1	-00:14:00	\N	1.1	00:19:00	-00:09:00	South Edisto River entrance	SC
64061	Pine Island, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7061_1	32.50667	-80.36167	:America/New_York	USA	knots	163	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:37:00	\N	0.5	-00:09:00	\N	0.7	00:00:00	00:12:00	Pine Island, South Edisto River	SC
64062	Fenwick Island Cut, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7066_1	32.535	-80.41333	:America/New_York	USA	knots	23	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:26:00	\N	0.4	-00:55:00	\N	0.4	-02:43:00	-03:20:00	Fenwick Island Cut, South Edisto River	SC
64063	Sampson Island, S end, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7071_1	32.56333	-80.39167	:America/New_York	USA	knots	244	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.8	00:34:00	\N	0.8	00:59:00	00:59:00	Sampson Island, S end, South Edisto River	SC
64064	Sampson Island, NE end, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7076_1	32.61667	-80.38667	:America/New_York	USA	knots	156	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.8	01:15:00	\N	0.8	01:35:00	01:02:00	Sampson Island, NE end, South Edisto River	SC
64065	Jehossee Island, S tip, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7081_1	32.60333	-80.42	:America/New_York	USA	knots	69	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:05:00	\N	0.7	00:48:00	\N	0.7	01:44:00	00:53:00	Jehossee Island, S tip, South Edisto River	SC
64066	Smuggedy Swamp, South Edisto River (Depth 6ft), South Carolina Current	NOS	ACT7086_1	32.66	-80.41167	:America/New_York	USA	knots	166	349	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:25:00	\N	0.7	01:14:00	\N	0.5	02:26:00	01:01:00	Smuggedy Swamp, South Edisto River	SC
64067	Hutchinson Island, Ashepoo River (Depth 10ft), South Carolina Current	NOS	ACT7091_1	32.53167	-80.435	:America/New_York	USA	knots	68	278	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:56:00	\N	0.7	01:14:00	\N	0.6	01:21:00	00:54:00	Hutchinson Island, Ashepoo River	SC
64068	Ashepoo Coosaw Cutoff (Depth 6ft), South Carolina Current	NOS	ACT7096_1	32.525	-80.45333	:America/New_York	USA	knots	265	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:12:00	\N	0.6	00:36:00	\N	0.5	01:22:00	00:56:00	Ashepoo Coosaw Cutoff	SC
64069	Pelican Bank, St. Helena Sound (Depth 15ft), South Carolina Current	NOS	ACT7101_1	32.455	-80.42833	:America/New_York	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:35:00	\N	0.8	-00:33:00	\N	0.9	00:05:00	00:17:00	Pelican Bank, St. Helena Sound	SC
64070	Ashepoo River, off Jefford Creek entrance, South Carolina Current	NOS	ACT7106_1	32.50667	-80.41	:America/New_York	USA	knots	197	16	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	0.8	00:46:00	\N	0.9	01:04:00	01:00:00	Ashepoo River, off Jefford Creek entrance	SC
64071	Egg Bank, St. Helena Sound (Depth 10ft), South Carolina Current	NOS	ACT7111_1	32.435	-80.44333	:America/New_York	USA	knots	128	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:20:00	\N	0.8	-01:24:00	\N	0.8	-00:12:00	-00:06:00	Egg Bank, St. Helena Sound	SC
64072	Morgan Island, NE of, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7116_1	32.48833	-80.47333	:America/New_York	USA	knots	125	303	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:19:00	\N	1	00:27:00	\N	0.8	00:28:00	00:36:00	Morgan Island, NE of, Coosaw River	SC
64073	Ashe Island Cut, SW of, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7121_1	32.51	-80.505	:America/New_York	USA	knots	134	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.6	-00:09:00	\N	0.6	00:32:00	00:43:00	Ashe Island Cut, SW of, Coosaw River	SC
64074	Ashe Island Cut, St. Helena Sound (Depth 6ft), South Carolina Current	NOS	ACT7126_1	32.52	-80.48833	:America/New_York	USA	knots	34	232	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:13:00	\N	0.4	01:41:00	\N	0.5	00:31:00	01:01:00	Ashe Island Cut, St. Helena Sound	SC
64075	Combahee River (Depth 8ft), South Carolina Current	NOS	ACT7131_1	32.52667	-80.53667	:America/New_York	USA	knots	147	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:53:00	\N	0.8	00:59:00	\N	0.6	00:55:00	01:04:00	Combahee River	SC
64076	Combahee River (Depth 15ft), South Carolina Current	NOS	ACT7136_1	32.55	-80.56333	:America/New_York	USA	knots	73	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:03:00	\N	1	01:35:00	\N	0.8	01:36:00	01:33:00	Combahee River	SC
64077	Parrot Creek, Coosaw Island (Depth 15ft), South Carolina Current	NOS	ACT7141_1	32.47333	-80.545	:America/New_York	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:54:00	\N	0.6	-00:48:00	\N	0.7	00:12:00	00:24:00	Parrot Creek, Coosaw Island	SC
64078	Morgan Island, North end, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7146_1	32.50333	-80.53667	:America/New_York	USA	knots	85	271	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:30:00	\N	0.9	00:41:00	\N	0.8	00:34:00	00:27:00	Morgan Island, North end, Coosaw River	SC
64079	Williman Creek (Depth 10ft), South Carolina Current	NOS	ACT7151_1	32.56167	-80.59167	:America/New_York	USA	knots	160	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:04:00	\N	0.8	01:27:00	\N	0.6	00:40:00	01:02:00	Williman Creek	SC
64080	Coosaw Island, South of, Morgan River (Depth 10ft), South Carolina Current	NOS	ACT7156_1	32.45167	-80.58333	:America/New_York	USA	knots	58	252	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	0.7	00:55:00	\N	0.7	00:09:00	00:15:00	Coosaw Island, South of, Morgan River	SC
64081	Sams Point, Northwest of, Coosaw River (Depth 10ft), South Carolina Current	NOS	ACT7161_1	32.49333	-80.59333	:America/New_York	USA	knots	117	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.6	00:36:00	\N	0.5	00:34:00	00:31:00	Sams Point, Northwest of, Coosaw River	SC
64082	Whale Branch River (Depth 10ft), South Carolina Current	NOS	ACT7166_1	32.52667	-80.69167	:America/New_York	USA	knots	111	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.7	-00:09:00	\N	0.5	01:12:00	00:51:00	Whale Branch River	SC
64083	Fripps Inlet, Fripps Island (Depth 15ft), South Carolina Current	NOS	ACT7171_1	32.34	-80.465	:America/New_York	USA	knots	104	299	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:29:00	\N	0.6	01:12:00	\N	0.7	-00:29:00	-00:22:00	Fripps Inlet, Fripps Island	SC
64084	Southeast Channel entrance, Port Royal Sound, South Carolina Current	NOS	ACT7181_1	32.13333	-80.58333	:America/New_York	USA	knots	150	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:12:00	\N	0.8	-00:38:00	\N	0.8	-00:30:00	-00:09:00	Southeast Channel entrance	SC
64085	Port Royal Plantation Tower, east of (Depth 15ft), South Carolina Current	NOS	ACT7186_1	32.22333	-80.65667	:America/New_York	USA	knots	147	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	1	-00:16:00	\N	0.9	00:33:00	00:19:00	Port Royal Plantation Tower, east of	SC
64399	Ketchikan, Tongass Narrows, Alaska Current	NOS	PCT2786_1	55.33617	-131.64417	:America/Juneau	USA	knots	120	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:41:00	\N	0.1	00:08:00	\N	0.3	-00:50:00	00:04:00	Ketchikan	AK
64086	Bay Point Island, S of, Broad River entrance (Depth 15ft), South Carolina Current	NOS	ACT7191_1	32.23333	-80.63	:America/New_York	USA	knots	128	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:46:00	\N	0.9	-01:09:00	\N	0.7	00:39:00	00:06:00	Bay Point Island, S of, Broad River entrance	SC
64087	Broad River Entrance, Point Royal Sound (Depth 15ft), South Carolina Current	NOS	ACT7196_1	32.23167	-80.64	:America/New_York	USA	knots	138	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:25:00	\N	0.9	00:21:00	\N	1	00:36:00	00:32:00	Broad River Entrance, Point Royal Sound	SC
64088	Hilton Head, Port Royal Sound, South Carolina Current	NOS	ACT7201_1	32.25	-80.66667	:America/New_York	USA	knots	146	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:01:00	\N	0.9	00:49:00	\N	1.1	00:16:00	00:32:00	Hilton Head	SC
64089	Beaufort River Entrance (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7206_1	32.28833	-80.65167	:America/New_York	USA	knots	195	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:03:00	\N	0.7	01:11:00	\N	0.7	00:19:00	00:20:00	Beaufort River Entrance	SC
64090	Parris Island, Beaufort River (Depth 10ft), Port Royal Sound, South Carolina Current	NOS	ACT7211_1	32.32667	-80.65667	:America/New_York	USA	knots	175	356	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:00:00	\N	0.8	01:12:00	\N	0.7	00:29:00	00:11:00	Parris Island, Beaufort River	SC
64091	Chowan Creek (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7216_1	32.37	-80.63833	:America/New_York	USA	knots	246	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:34:00	\N	0.6	01:53:00	\N	0.6	00:24:00	00:23:00	Chowan Creek	SC
64092	Parris Island, Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7221_1	32.36	-80.675	:America/New_York	USA	knots	149	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	0.7	01:19:00	\N	0.7	00:56:00	00:51:00	Parris Island, Beaufort River	SC
64093	Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7226_1	32.40333	-80.67167	:America/New_York	USA	knots	200	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:33:00	\N	0.5	01:19:00	\N	0.5	01:04:00	01:01:00	Beaufort River	SC
64094	Beaufort, Beaufort River (Depth 12ft), Port Royal Sound, South Carolina Current	NOS	ACT7231_1	32.43	-80.67667	:America/New_York	USA	knots	257	73	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:17:00	\N	0.6	01:18:00	\N	0.7	00:55:00	01:08:00	Beaufort, Beaufort River	SC
64095	Beaufort Airport, Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7236_1	32.45	-80.66333	:America/New_York	USA	knots	152	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:08:00	\N	0.5	01:39:00	\N	0.5	01:25:00	01:21:00	Beaufort Airport, Beaufort River	SC
64096	Brickyard Creek (Depth 10ft), Port Royal Sound, South Carolina Current	NOS	ACT7241_1	32.47333	-80.69167	:America/New_York	USA	knots	171	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:58:00	\N	0.4	00:30:00	\N	0.5	01:48:00	02:50:00	Brickyard Creek	SC
64097	Skull Creek, north entrance, Port Royal Sound, South Carolina Current	NOS	ACT7246_1	32.26333	-80.74167	:America/New_York	USA	knots	35	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-02:14:00	\N	0.6	-01:20:00	\N	0.4	-01:50:00	-01:58:00	Skull Creek, north entrance	SC
64098	Daws Island, SE of, Broad River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7251_1	32.30167	-80.725	:America/New_York	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.8	00:05:00	\N	0.8	00:46:00	00:39:00	Daws Island, SE of, Broad River	SC
64099	Parris Island Lookout Tower, Broad River (Depth 15ft), South Carolina Current	NOS	ACT7256_1	32.31167	-80.70667	:America/New_York	USA	knots	152	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.7	-00:07:00	\N	0.7	00:39:00	00:29:00	Parris Island Lookout Tower, Broad River	SC
64100	Daws Island, south of, Chechessee River (Depth 15ft), South Carolina Current	NOS	ACT7261_1	32.28667	-80.74333	:America/New_York	USA	knots	142	317	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.7	-00:22:00	\N	0.6	00:31:00	00:34:00	Daws Island, south of, Chechessee River	SC
64101	Lemon Island South, Chechessee River (Depth 10ft), South Carolina Current	NOS	ACT7266_1	32.35	-80.80667	:America/New_York	USA	knots	175	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.7	01:19:00	\N	0.6	00:33:00	00:39:00	Lemon Island South, Chechessee River	SC
64102	Broad River Bridge, S of, Broad River (Depth 15ft), South Carolina Current	NOS	ACT7271_1	32.38167	-80.77667	:America/New_York	USA	knots	156	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:07:00	\N	0.8	-00:15:00	\N	0.6	00:52:00	00:49:00	Broad River Bridge, S of, Broad River	SC
64103	Byrd Creek Entrance, SE of, Broad River (Depth 12ft), South Carolina Current	NOS	ACT7276_1	32.45667	-80.81833	:America/New_York	USA	knots	174	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.5	00:51:00	\N	0.6	01:27:00	01:32:00	Byrd Creek Entrance, SE of, Broad River	SC
64104	Little Barnwell I., E of, Whale Branch River (Depth 6ft), South Carolina Current	NOS	ACT7281_1	32.50167	-80.78667	:America/New_York	USA	knots	175	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:40:00	\N	0.4	03:03:00	\N	0.6	01:41:00	01:54:00	Little Barnwell I., E of, Whale Branch River	SC
64105	Braddock Point, SW of, Calibogue Sound (Depth 10ft), South Carolina Current	NOS	ACT7286_1	32.105	-80.83667	:America/New_York	USA	knots	183	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:04:00	\N	1	00:16:00	\N	0.8	-00:15:00	-00:04:00	Braddock Point, SW of, Calibogue Sound	SC
64106	Haig Point Light, NW of, Cooper River (Depth 10ft), South Carolina Current	NOS	ACT7291_1	32.14833	-80.84167	:America/New_York	USA	knots	94	278	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.7	-00:05:00	\N	0.4	-00:51:00	-00:40:00	Haig Point Light, NW of, Cooper River	SC
64107	Ramshorn Creek Light, E of, Cooper River (Depth 6ft), South Carolina Current	NOS	ACT7296_1	32.13	-80.88167	:America/New_York	USA	knots	98	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:17:00	\N	0.7	-00:53:00	\N	0.5	00:06:00	00:15:00	Ramshorn Creek Light, E of, Cooper River	SC
64108	Spanish Wells, Calibogue Sound (Depth 30ft), Calibogue Sound, South Carolina Current	NOS	ACT7301_1	32.18667	-80.785	:America/New_York	USA	knots	204	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.7	00:51:00	\N	0.7	-00:14:00	00:12:00	Spanish Wells, Calibogue Sound	SC
64109	Skull Creek, south entrance (Depth 10ft), Calibogue Sound, South Carolina Current	NOS	ACT7306_1	32.22333	-80.785	:America/New_York	USA	knots	231	53	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:55:00	\N	0.4	02:57:00	\N	0.4	00:38:00	01:23:00	Skull Creek, south entrance	SC
64110	MacKay Creek, south entrance (Depth 10ft), Calibogue Sound, South Carolina Current	NOS	ACT7311_1	32.22	-80.79	:America/New_York	USA	knots	212	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:26:00	\N	0.6	00:03:00	\N	0.3	00:06:00	00:12:00	MacKay Creek, south entrance	SC
64111	Bloody Pt., 0.5 mile north of, New River, South Carolina Current	NOS	ACT7316_1	32.08833	-80.88	:America/New_York	USA	knots	147	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:13:00	\N	0.6	00:00:00	\N	0.6	-01:03:00	-00:53:00	Bloody Pt., 0.5 mile north of, New River	SC
64112	Bloody Pt., 0.5 mile west of, New River, South Carolina Current	NOS	ACT7321_1	32.08167	-80.88333	:America/New_York	USA	knots	92	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:26:00	\N	0.9	-00:21:00	\N	0.9	-00:47:00	-00:36:00	Bloody Pt., 0.5 mile west of, New River	SC
64113	Wright R., 0.2 mile above Walls Cut, South Carolina Current	NOS	ACT7326_1	32.085	-80.92167	:America/New_York	USA	knots	142	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.8	-00:16:00	\N	0.6	-00:38:00	-00:38:00	Wright R., 0.2 mile above Walls Cut	SC
64114	Walls Cut, Turtle Island (Depth 6ft), South Carolina Current	NOS	ACT7336_1	32.08167	-80.91667	:America/New_York	USA	knots	100	294	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-03:05:00	\N	0.5	-00:57:00	\N	0.5	-02:29:00	-01:12:00	Walls Cut, Turtle Island	SC
64115	Daufuskie Landing Light, south of (Depth 10ft), South Carolina Current	NOS	ACT7341_1	32.10167	-80.89833	:America/New_York	USA	knots	226	43	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:45:00	\N	0.8	01:04:00	\N	0.7	00:07:00	00:02:00	Daufuskie Landing Light, south of	SC
64116	Fort Pulaski, Savannah River, Georgia Current	NOS	ACT7356_1	32.03667	-80.90167	:America/New_York	USA	knots	98	283	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:09:00	\N	1.5	00:51:00	\N	0.9	00:42:00	00:15:00	Fort Pulaski	GA
64117	Fort Pulaski, 1.8 miles above, Savannah River, Georgia Current	NOS	ACT7361_1	32.045	-80.93167	:America/New_York	USA	knots	140	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:12:00	\N	1.4	00:18:00	\N	1.1	00:25:00	-00:01:00	Fort Pulaski, 1.8 miles above	GA
64118	Fort Pulaski, 4.8 miles above, Savannah River, Georgia Current	NOS	ACT7366_1	32.075	-80.97667	:America/New_York	USA	knots	116	296	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:16:00	\N	1.5	00:31:00	\N	1.1	00:36:00	00:06:00	Fort Pulaski, 4.8 miles above	GA
64119	McQueen Island Cut (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7371_1	32.065	-80.98667	:America/New_York	USA	knots	69	251	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:44:00	\N	0.6	-02:45:00	\N	0.3	-02:39:00	-01:04:00	McQueen Island Cut	GA
64120	Elba Island Cut, NE of, Savannah River (Depth 10ft), South Carolina Current	NOS	ACT7376_1	32.07333	-80.965	:America/New_York	USA	knots	104	288	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:14:00	\N	1.3	00:15:00	\N	0.7	00:26:00	-00:37:00	Elba Island Cut, NE of, Savannah River	SC
64121	Elba Island, NE of, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7381_1	32.09	-80.99333	:America/New_York	USA	knots	149	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:27:00	\N	1.2	00:40:00	\N	0.6	01:01:00	-00:35:00	Elba Island, NE of, Savannah River	GA
64122	Elba Island, west of, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7386_1	32.095	-81.02	:America/New_York	USA	knots	40	219	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:53:00	\N	0.8	00:52:00	\N	0.5	00:37:00	-00:30:00	Elba Island, west of, Savannah River	GA
64123	Fig Island, north of, Back River, Savannah River, Georgia Current	NOS	ACT7391_1	32.085	-81.05	:America/New_York	USA	knots	94	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	0.7	01:06:00	\N	0.5	00:14:00	-00:25:00	Fig Island, north of, Back River	GA
64124	South Channel, western end, Savannah River, Georgia Current	NOS	ACT7396_1	32.08833	-81.01667	:America/New_York	USA	knots	122	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:35:00	\N	0.7	00:18:00	\N	0.5	00:42:00	-00:33:00	South Channel, western end	GA
64125	Wilmington R. ent., south channel, Savannah River, Georgia Current	NOS	ACT7401_1	32.07667	-81.00167	:America/New_York	USA	knots	206	32	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	01:25:00	\N	0.8	-00:36:00	\N	0.5	00:42:00	01:28:00	Wilmington R. ent., south channel	GA
64126	Savannah, southeast of highway bridge (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7406_1	32.08667	-81.09667	:America/New_York	USA	knots	146	319	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:05:00	\N	1.3	00:41:00	\N	0.6	01:36:00	-00:24:00	Savannah, southeast of highway bridge	GA
64127	Savannah, Savannah River, Georgia Current	NOS	ACT7411_1	32.08333	-81.08333	:America/New_York	USA	knots	106	279	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:18:00	\N	1.1	00:45:00	\N	0.8	01:12:00	00:01:00	Savannah	GA
64128	Kings Island Channel, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7416_1	32.12667	-81.13667	:America/New_York	USA	knots	152	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	1	00:45:00	\N	0.8	01:21:00	00:06:00	Kings Island Channel, Savannah River	GA
64129	Seaboard Coast Line Railroad, Savannah River, Georgia Current	NOS	ACT7421_1	32.10333	-81.11833	:America/New_York	USA	knots	150	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:59:00	\N	1.7	00:45:00	\N	1.2	01:06:00	00:29:00	Seaboard Coast Line Railroad	GA
64130	King Island, west of, Savannah River, Georgia Current	NOS	ACT7426_1	32.12333	-81.135	:America/New_York	USA	knots	160	337	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:48:00	\N	1	00:54:00	\N	0.7	01:21:00	00:33:00	King Island, west of	GA
64149	Skidaway Narrows, Wassaw Sound, Georgia Current	NOS	ACT7526_1	31.95333	-81.065	:America/New_York	USA	knots	42	218	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.5	-00:24:00	\N	0.5	00:03:00	00:26:00	Skidaway Narrows	GA
64131	Port Wentworth, 0.2 mile above, Savannah River, Georgia Current	NOS	ACT7431_1	32.14667	-81.14	:America/New_York	USA	knots	210	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	01:19:00	\N	0.7	01:36:00	\N	0.5	02:00:00	00:24:00	Port Wentworth, 0.2 mile above	GA
64132	Wassaw Island, N of E end, Wassaw Sound (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7441_1	31.915	-80.93833	:America/New_York	USA	knots	108	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:33:00	\N	1	-00:50:00	\N	0.7	-00:48:00	-00:45:00	Wassaw Island, N of E end, Wassaw Sound	GA
64133	Entrance, off Beach Hammock, Wassaw Sound, Georgia Current	NOS	ACT7446_1	31.94167	-80.93167	:America/New_York	USA	knots	156	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:44:00	\N	1.1	-01:00:00	\N	0.9	-00:41:00	-00:54:00	Entrance, off Beach Hammock	GA
64134	Wilmington Island, SSE of, Bull River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7451_1	31.96667	-80.93	:America/New_York	USA	knots	218	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:00:00	\N	0.7	00:38:00	\N	0.4	-00:35:00	-00:40:00	Wilmington Island, SSE of, Bull River	GA
64135	Lazaretto Creek Entrance, N of, Bull River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7456_1	32	-80.92833	:America/New_York	USA	knots	207	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:04:00	\N	0.7	00:00:00	\N	0.5	-00:37:00	-00:33:00	Lazaretto Creek Entrance, N of, Bull River	GA
64136	Bull River, 2 miles below hwy. bridge, Wassaw Sound, Georgia Current	NOS	ACT7461_1	32.01833	-80.94	:America/New_York	USA	knots	151	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:57:00	\N	0.8	-00:18:00	\N	0.6	-00:18:00	-00:25:00	Bull River, 2 miles below hwy. bridge	GA
64137	Entrance, off Wassaw Island, Wassaw Sound, Georgia Current	NOS	ACT7466_1	31.91667	-80.94667	:America/New_York	USA	knots	105	277	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.9	-01:11:00	\N	0.7	-00:46:00	-00:42:00	Entrance, off Wassaw Island	GA
64138	Wilmington River ent. off Cabbage Island, Wassaw Sound, Georgia Current	NOS	ACT7471_1	31.93833	-80.97667	:America/New_York	USA	knots	138	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.8	-00:36:00	\N	0.6	-00:44:00	-00:45:00	Wilmington River ent. off Cabbage Island	GA
64139	Joe's Cut, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7476_1	31.94333	-80.985	:America/New_York	USA	knots	123	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:44:00	\N	1	-00:48:00	\N	0.6	-00:54:00	-00:34:00	Joe's Cut, Wilmington River	GA
64140	Wilmington R., 0.5 mi. S of Turners Creek, Wassaw Sound, Georgia Current	NOS	ACT7481_1	32.005	-81.00333	:America/New_York	USA	knots	154	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.7	-00:10:00	\N	0.5	-00:31:00	-00:37:00	Wilmington R., 0.5 mi. S of Turners Creek	GA
64141	Thunderbolt, SE of, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7486_1	32.02333	-81.045	:America/New_York	USA	knots	121	298	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:25:00	\N	0.5	-01:04:00	\N	0.4	-00:20:00	00:12:00	Thunderbolt, SE of, Wilmington River	GA
64142	Oatland Island, north tip (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7491_1	32.07333	-81.01	:America/New_York	USA	knots	138	317	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:32:00	\N	0.5	-02:14:00	\N	0.3	-03:20:00	-00:43:00	Oatland Island, north tip	GA
64143	Skidaway River, north entrance, Wassaw Sound, Georgia Current	NOS	ACT7496_1	32.00833	-81.01667	:America/New_York	USA	knots	16	204	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:11:00	\N	0.7	-00:02:00	\N	0.6	-00:46:00	-00:49:00	Skidaway River, north entrance	GA
64144	Skidaway Island, N End, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7501_1	32.01	-81.00833	:America/New_York	USA	knots	119	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:49:00	\N	0.9	00:16:00	\N	0.6	-00:33:00	-00:23:00	Skidaway Island, N End, Wilmington River	GA
64145	Dutch Island, SE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7506_1	31.99167	-81.02	:America/New_York	USA	knots	61	245	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:02:00	\N	0.6	00:16:00	\N	0.5	-00:40:00	-00:33:00	Dutch Island, SE of, Skidaway River	GA
64146	Isle of Hope City, SE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7511_1	31.97667	-81.04667	:America/New_York	USA	knots	72	268	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:40:00	\N	0.3	-00:30:00	\N	0.2	-00:17:00	-00:32:00	Isle of Hope City, SE of, Skidaway River	GA
64147	Isle of Hope City, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7516_1	31.98	-81.055	:America/New_York	USA	knots	28	212	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:25:00	\N	0.3	00:00:00	\N	0.4	-00:34:00	-00:19:00	Isle of Hope City, Skidaway River	GA
64148	Burntpot Island, west of, Skidaway River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7521_1	31.96833	-81.05333	:America/New_York	USA	knots	18	194	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:03:00	\N	0.5	-00:41:00	\N	0.5	-00:27:00	-00:13:00	Burntpot Island, west of, Skidaway River	GA
64150	Long Island, NNE of, Skidaway River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7531_1	31.95667	-81.06	:America/New_York	USA	knots	47	226	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:17:00	\N	0.4	-01:09:00	\N	0.4	-00:13:00	01:02:00	Long Island, NNE of, Skidaway River	GA
64151	Long Island, south of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7536_1	31.94333	-81.07333	:America/New_York	USA	knots	258	75	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-08:05:00	\N	0.3	-04:43:00	\N	0.2	-04:25:00	-06:07:00	Long Island, south of, Skidaway River	GA
64152	Pigeon Island, SSE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7541_1	31.93667	-81.07667	:America/New_York	USA	knots	150	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:16:00	\N	0.5	-02:43:00	\N	0.2	-02:37:00	-00:56:00	Pigeon Island, SSE of, Skidaway River	GA
64153	Burnside Island, SE of, Burnside River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7546_1	31.92167	-81.08	:America/New_York	USA	knots	295	114	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:05:00	\N	0.6	00:53:00	\N	0.4	-00:40:00	-00:20:00	Burnside Island, SE of, Burnside River	GA
64154	Little Don Island, east of, Vernon River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7551_1	31.87	-81.07333	:America/New_York	USA	knots	153	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:38:00	\N	0.7	-01:16:00	\N	0.7	-00:17:00	-00:03:00	Little Don Island, east of, Vernon River	GA
64155	Little Ogeechee River Entrance (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7556_1	31.88833	-81.09833	:America/New_York	USA	knots	71	259	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:06:00	\N	1	-00:59:00	\N	0.7	-00:15:00	-00:03:00	Little Ogeechee River Entrance	GA
64156	Little Ogeechee River Entrance (Depth 20ft), Wassaw Sound, Georgia Current	NOS	ACT7556_2	31.88833	-81.09833	:America/New_York	USA	knots	73	244	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:57:00	\N	0.9	-00:50:00	\N	0.6	-00:30:00	00:05:00	Little Ogeechee River Entrance	GA
64157	Montgomery, Vernon River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7561_1	31.935	-81.12833	:America/New_York	USA	knots	89	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:30:00	\N	0.6	00:00:00	\N	0.3	-00:32:00	-00:24:00	Montgomery, Vernon River	GA
64158	Odingsell River Entrance (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7566_1	31.86833	-81	:America/New_York	USA	knots	212	32	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:14:00	\N	0.9	00:44:00	\N	0.7	-00:54:00	-00:48:00	Odingsell River Entrance	GA
64159	Odingsell River Entrance (Depth 20ft), Wassaw Sound, Georgia Current	NOS	ACT7566_2	31.86833	-81	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:12:00	\N	0.8	00:42:00	\N	0.6	-01:19:00	-00:42:00	Odingsell River Entrance	GA
64160	Wassaw Island, SSW of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_1	31.85667	-81.00833	:America/New_York	USA	knots	123	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:01:00	\N	1.1	-01:04:00	\N	0.8	-00:26:00	-00:27:00	Wassaw Island, SSW of	GA
64161	Wassaw Island, SSW of (Depth 20ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_2	31.85667	-81.00833	:America/New_York	USA	knots	132	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:01:00	\N	0.9	-00:58:00	\N	0.7	-00:46:00	-00:33:00	Wassaw Island, SSW of	GA
64162	Bradley Point, NNE of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7576_1	31.83167	-81.03833	:America/New_York	USA	knots	125	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.8	-00:58:00	\N	0.6	-00:48:00	-00:48:00	Bradley Point, NNE of	GA
64163	Raccoon Key (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7581_1	31.86167	-81.055	:America/New_York	USA	knots	117	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:35:00	\N	0.9	-01:23:00	\N	0.8	-00:45:00	-00:36:00	Raccoon Key	GA
64164	Little Wassaw Island, SW of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7586_1	31.87	-81.05	:America/New_York	USA	knots	116	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.7	-00:17:00	\N	0.9	-01:05:00	-00:21:00	Little Wassaw Island, SW of	GA
64165	Vernon R., 1.2 miles S of Possum Point, Ossabaw Sound, Georgia Current	NOS	ACT7591_1	31.89833	-81.09833	:America/New_York	USA	knots	166	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:33:00	\N	0.8	00:02:00	\N	0.6	-00:24:00	-00:12:00	Vernon R., 1.2 miles S of Possum Point	GA
64166	Little Ogeechee River Entrance, north of (Depth 6ft), Ossabaw Sound, Georgia Current	NOS	ACT7596_1	31.89667	-81.095	:America/New_York	USA	knots	156	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:03:00	\N	0.8	00:29:00	\N	0.6	-00:41:00	-00:30:00	Little Ogeechee River Entrance, north of	GA
64167	Raccoon Key & Egg Island Shoal, between (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7601_1	31.84283	-81.0675	:America/New_York	USA	knots	129	254	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:57:00	\N	1	00:17:00	\N	0.8	00:20:00	-00:23:00	Raccoon Key & Egg Island Shoal, between	GA
64168	Florida Passage, N of, Ogeechee River (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7606_1	31.85667	-81.14333	:America/New_York	USA	knots	127	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:05:00	\N	1	00:01:00	\N	0.7	00:10:00	-00:01:00	Florida Passage, N of, Ogeechee River	GA
64169	Florida Passage (south) (Depth 6ft), Ossabaw Sound, Georgia Current	NOS	ACT7611_1	31.82967	-81.15783	:America/New_York	USA	knots	18	187	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.7	-01:13:00	\N	0.5	-01:48:00	-00:23:00	Florida Passage (south)	GA
64170	610 Statute Mile Mark (Depth 6ft), Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7616_1	31.8105	-81.17667	:America/New_York	USA	knots	175	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:39:00	\N	0.7	00:48:00	\N	0.5	00:20:00	-00:05:00	610 Statute Mile Mark	GA
64171	North of Big Tom Creek Entrance (Depth 10ft), Bear River, Georgia Current	NOS	ACT7621_1	31.78333	-81.16033	:America/New_York	USA	knots	179	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:25:00	\N	0.7	-00:13:00	\N	0.6	-00:24:00	-00:19:00	North of Big Tom Creek Entrance	GA
64172	South of Kilkenny Creek Entrance, Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7626_1	31.75833	-81.17333	:America/New_York	USA	knots	190	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	1	01:25:00	\N	0.6	00:26:00	-00:02:00	South of Kilkenny Creek Entrance	GA
64173	Northwest of Newell Creek Entrance (Depth 10ft), Bear River, Georgia Current	NOS	ACT7631_1	31.74883	-81.1655	:America/New_York	USA	knots	149	349	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.9	00:12:00	\N	0.6	-00:11:00	-00:16:00	Northwest of Newell Creek Entrance	GA
64174	Medway River at Marsh Island (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7636_1	31.74333	-81.22	:America/New_York	USA	knots	117	313	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:56:00	\N	0.8	-00:18:00	\N	0.3	00:20:00	-00:15:00	Medway River at Marsh Island	GA
64175	St. Catherines Sound Entrance (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7641_1	31.715	-81.1405	:America/New_York	USA	knots	126	291	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.8	-00:31:00	\N	0.9	-00:39:00	00:13:00	St. Catherines Sound Entrance	GA
64176	Medway River, northwest of Cedar Point (Depth 10ft), Georgia Current	NOS	ACT7646_1	31.7145	-81.19083	:America/New_York	USA	knots	146	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	0.8	-00:43:00	\N	0.7	-00:40:00	-00:23:00	Medway River, northwest of Cedar Point	GA
64177	N. Newport River, NE of Vandyke Creek (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7651_1	31.69117	-81.187	:America/New_York	USA	knots	45	233	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:21:00	\N	0.8	00:12:00	\N	0.7	-00:27:00	00:00:00	N. Newport River, NE of Vandyke Creek	GA
64178	N. Newport River, above Walburg Creek (Depth 6ft), St. Catherines Sound, Georgia Current	NOS	ACT7656_1	31.67383	-81.19533	:America/New_York	USA	knots	11	195	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:40:00	\N	0.8	00:30:00	\N	0.6	-00:34:00	-00:39:00	N. Newport River, above Walburg Creek	GA
64179	N. Newport River, NW of Johnson Creek (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7661_1	31.663	-81.2105	:America/New_York	USA	knots	138	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:27:00	\N	0.9	-01:01:00	\N	0.5	00:20:00	-00:37:00	N. Newport River, NW of Johnson Creek	GA
64180	N. Newport River, ESE of S. Newport Cut (Depth 6ft), Georgia Current	NOS	ACT7666_1	31.66533	-81.2645	:America/New_York	USA	knots	147	319	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:15:00	\N	0.7	-00:13:00	\N	0.5	00:32:00	00:27:00	N. Newport River, ESE of S. Newport Cut	GA
64181	S. Newport River, below S. Newport Cut (Depth 10ft), Georgia Current	NOS	ACT7671_1	31.65033	-81.302	:America/New_York	USA	knots	134	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	02:15:00	\N	0.5	01:30:00	\N	0.5	01:20:00	02:41:00	S. Newport River, below S. Newport Cut	GA
64182	S. Newport River, above Swain River Ent (Depth 10ft), Georgia Current	NOS	ACT7676_1	31.6245	-81.21667	:America/New_York	USA	knots	156	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:43:00	\N	0.6	-01:13:00	\N	0.6	-00:22:00	00:00:00	S. Newport River, above Swain River Ent	GA
64183	Entrance (Depth 19ft), Sapelo Sound, Georgia Current	NOS	ACT7681_1	31.54	-81.18	:America/New_York	USA	knots	118	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:59:00	\N	1.1	00:28:00	\N	0.9	-00:30:00	-00:06:00	Entrance	GA
64184	Entrance (Depth 29ft), Sapelo Sound, Georgia Current	NOS	ACT7681_2	31.54	-81.18	:America/New_York	USA	knots	116	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:02:00	\N	0.9	-00:36:00	\N	0.7	-00:48:00	-00:17:00	Entrance	GA
64185	Johnson Creek, midway between ends, Sapelo Sound, Georgia Current	NOS	ACT7686_1	31.62667	-81.18833	:America/New_York	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:59:00	\N	0.4	-01:08:00	\N	0.4	-01:50:00	-00:35:00	Johnson Creek, midway between ends	GA
64186	Cedar Hammock, south of (Depth 12ft), Sapelo Sound, Georgia Current	NOS	ACT7691_1	31.545	-81.24667	:America/New_York	USA	knots	96	277	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:38:00	\N	0.6	-01:00:00	\N	0.7	-00:26:00	-00:12:00	Cedar Hammock, south of	GA
64187	Sapelo River Entrance (Depth 11ft), Sapelo Sound, Georgia Current	NOS	ACT7696_1	31.535	-81.27167	:America/New_York	USA	knots	58	234	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:43:00	\N	0.6	-01:05:00	\N	0.6	-00:23:00	-00:13:00	Sapelo River Entrance	GA
64188	Sutherland Bluff, Sapelo River, Sapelo Sound, Georgia Current	NOS	ACT7701_1	31.54833	-81.33333	:America/New_York	USA	knots	104	281	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.6	00:10:00	\N	0.5	-00:30:00	-00:12:00	Sutherland Bluff, Sapelo River	GA
64189	Front River (Depth 13ft), Sapelo Sound, Georgia Current	NOS	ACT7706_1	31.51333	-81.29833	:America/New_York	USA	knots	56	227	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:05:00	\N	0.5	01:16:00	\N	0.4	-00:33:00	-00:25:00	Front River	GA
64190	New Teakettle Cr., 0.8 mi. N of, Mud River, Sapelo Sound, Georgia Current	NOS	ACT7711_1	31.49667	-81.29	:America/New_York	USA	knots	53	236	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:11:00	\N	0.5	-00:29:00	\N	0.4	-00:54:00	-01:08:00	New Teakettle Cr., 0.8 mi. N of	GA
64191	Crescent River (Depth 11ft), Sapelo Sound, Georgia Current	NOS	ACT7716_1	31.48667	-81.30667	:America/New_York	USA	knots	133	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:21:00	\N	0.5	01:07:00	\N	0.2	-01:27:00	-00:34:00	Crescent River	GA
64192	Old Teakettle Creek (north) (Depth 13ft), Sapelo Sound, Georgia Current	NOS	ACT7721_1	31.47833	-81.32833	:America/New_York	USA	knots	256	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:37:00	\N	0.6	00:01:00	\N	0.5	-00:35:00	00:14:00	Old Teakettle Creek (north)	GA
64193	Bar, Doboy Sound, Georgia Current	NOS	ACT7726_1	31.345	-81.235	:America/New_York	USA	knots	114	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:53:00	\N	0.7	-00:29:00	\N	0.7	-00:29:00	-00:09:00	Bar	GA
64194	Entrance (Depth 14ft), Doboy Sound, Georgia Current	NOS	ACT7731_1	31.34167	-81.26333	:America/New_York	USA	knots	106	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:49:00	\N	0.9	-00:10:00	\N	0.8	-00:32:00	-00:24:00	Entrance	GA
64195	Entrance (Depth 22ft), Doboy Sound, Georgia Current	NOS	ACT7731_2	31.34167	-81.26333	:America/New_York	USA	knots	99	276	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:26:00	\N	0.8	-00:05:00	\N	0.8	-00:56:00	-00:20:00	Entrance	GA
64196	Old Teakettle Creek Entrance, south of (Depth 15ft), Doboy Sound, Georgia Current	NOS	ACT7736_1	31.42	-81.315	:America/New_York	USA	knots	159	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.5	-00:59:00	\N	0.5	-00:45:00	00:00:00	Old Teakettle Creek Entrance, south of	GA
64197	Old Teakettle Creek (south) (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7741_1	31.43667	-81.30833	:America/New_York	USA	knots	207	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:44:00	\N	0.4	-01:45:00	\N	0.5	-03:12:00	-02:16:00	Old Teakettle Creek (south)	GA
64198	Folly River and Cardigan River, between (Depth 10ft), Doboy Sound, Georgia Current	NOS	ACT7746_1	31.44167	-81.33667	:America/New_York	USA	knots	150	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	0.3	-00:56:00	\N	0.3	-00:55:00	-00:16:00	Folly River and Cardigan River, between	GA
64199	South River (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7751_1	31.36667	-81.31167	:America/New_York	USA	knots	95	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.7	-00:25:00	\N	0.6	-00:22:00	-00:32:00	South River	GA
64200	South River (Depth 21ft), Doboy Sound, Georgia Current	NOS	ACT7751_2	31.36667	-81.31167	:America/New_York	USA	knots	95	286	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.4	-00:33:00	\N	0.5	-00:41:00	-00:29:00	South River	GA
64201	North River at Darien River (Depth 9ft), Doboy Sound, Georgia Current	NOS	ACT7756_1	31.38333	-81.335	:America/New_York	USA	knots	29	247	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:22:00	\N	0.2	-00:33:00	\N	0.2	-00:10:00	00:08:00	North River at Darien River	GA
64202	Doboy Island (North River) (Depth 12ft), Doboy Sound, Georgia Current	NOS	ACT7761_1	31.40333	-81.32833	:America/New_York	USA	knots	37	224	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:13:00	\N	0.5	-00:06:00	\N	0.6	-00:14:00	00:47:00	Doboy Island (North River)	GA
64203	Doboy Island (North River) (Depth 20ft), Doboy Sound, Georgia Current	NOS	ACT7761_2	31.40333	-81.32833	:America/New_York	USA	knots	43	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:22:00	\N	0.3	00:36:00	\N	0.5	-00:20:00	00:46:00	Doboy Island (North River)	GA
64204	Buzzard Roost Creek (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7766_1	31.415	-81.375	:America/New_York	USA	knots	2	177	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:28:00	\N	0.2	00:12:00	\N	0.3	00:22:00	00:56:00	Buzzard Roost Creek	GA
64205	Little Egg Island, northwest of (Depth 12ft), Altamaha Sound, Georgia Current	NOS	ACT7771_1	31.31833	-81.305	:America/New_York	USA	knots	110	296	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.6	-00:53:00	\N	0.6	-00:33:00	-00:25:00	Little Egg Island, northwest of	GA
64206	Little Mud River Range (Depth 9ft), Altamaha Sound, Georgia Current	NOS	ACT7776_1	31.32667	-81.31833	:America/New_York	USA	knots	116	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:06:00	\N	0.5	-01:05:00	\N	0.3	-00:38:00	-00:23:00	Little Mud River Range	GA
64207	Little St. Simon Island (north) (Depth 11ft), Altamaha Sound, Georgia Current	NOS	ACT7781_1	31.31167	-81.35333	:America/New_York	USA	knots	89	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:29:00	\N	0.8	00:06:00	\N	0.6	00:10:00	-00:15:00	Little St. Simon Island (north)	GA
64208	Onemile Cut, 1 mile southeast of, Altamaha Sound, Georgia Current	NOS	ACT7786_1	31.31333	-81.35167	:America/New_York	USA	knots	92	272	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:32:00	\N	0.9	00:03:00	\N	0.5	00:46:00	-01:09:00	Onemile Cut, 1 mile southeast of	GA
64209	Broughton Island (south) (Depth 9ft), Buttermilk Sound, Altamaha Sound, Georgia Current	NOS	ACT7791_1	31.31	-81.41333	:America/New_York	USA	knots	30	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.4	00:12:00	\N	0.4	-02:06:00	-00:01:00	Broughton Island (south)	GA
64210	Bar Channel (Depth 12ft), St. Simons Sound, Georgia Current	NOS	ACT7796_1	31.105	-81.33833	:America/New_York	USA	knots	119	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:02:00	\N	0.8	-00:44:00	\N	0.4	-00:13:00	00:09:00	Bar Channel	GA
64211	Entrance, north of channel (Depth 13ft), St. Simons Sound, Georgia Current	NOS	ACT7801_1	31.1335	-81.404	:America/New_York	USA	knots	107	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:11:00	\N	0.6	00:18:00	\N	0.9	-00:32:00	00:07:00	Entrance, north of channel	GA
64212	Entrance, south of channel (Depth 11ft), St. Simons Sound, Georgia Current	NOS	ACT7806_1	31.12667	-81.40333	:America/New_York	USA	knots	80	262	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:59:00	\N	1.1	-00:32:00	\N	0.8	-00:27:00	-00:21:00	Entrance, south of channel	GA
64248	Mandarin Point (Depth 15ft), St. Johns River, Florida Current	NOS	ACT8056_2	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.3	03:33:00	\N	0.3	03:13:00	03:24:00	Mandarin Point	FL
64213	Entrance, south of channel (Depth 29ft), St. Simons Sound, Georgia Current	NOS	ACT7806_2	31.12667	-81.40333	:America/New_York	USA	knots	92	257	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	0.8	-00:03:00	\N	0.6	-00:18:00	00:06:00	Entrance, south of channel	GA
64214	Back River entrance (Depth 10ft), St. Simons Sound, Georgia Current	NOS	ACT7811_1	31.14833	-81.44167	:America/New_York	USA	knots	111	288	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.5	01:34:00	\N	0.5	-00:37:00	00:06:00	Back River entrance	GA
64215	Back River entrance (Depth 18ft), St. Simons Sound, Georgia Current	NOS	ACT7811_2	31.14833	-81.44167	:America/New_York	USA	knots	109	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:15:00	\N	0.4	01:36:00	\N	0.5	-01:29:00	00:08:00	Back River entrance	GA
64216	Mackay R., 0.5 mi. N of Troup Creek entrance, St. Simons Sound, Georgia Current	NOS	ACT7816_1	31.225	-81.43333	:America/New_York	USA	knots	166	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:24:00	\N	0.7	00:09:00	\N	0.5	00:56:00	00:35:00	Mackay R., 0.5 mi. N of Troup Creek entrance	GA
64217	Brunswick River, off Quarantine Dock, St. Simons Sound, Georgia Current	NOS	ACT7821_1	31.11167	-81.47333	:America/New_York	USA	knots	125	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:39:00	\N	1	-00:03:00	\N	0.7	00:10:00	00:11:00	Brunswick River, off Quarantine Dock	GA
64218	Brunswick River Bridge, southeast of (Depth 13ft), St. Simons Sound, Georgia Current	NOS	ACT7826_1	31.115	-81.47667	:America/New_York	USA	knots	132	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:09:00	\N	0.7	00:13:00	\N	0.5	-00:15:00	00:26:00	Brunswick River Bridge, southeast of	GA
64219	Brunswick River Bridge, southeast of (Depth 21ft), St. Simons Sound, Georgia Current	NOS	ACT7826_2	31.115	-81.47667	:America/New_York	USA	knots	129	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:02:00	\N	0.7	00:42:00	\N	0.5	00:19:00	00:56:00	Brunswick River Bridge, southeast of	GA
64220	Brunswick, off Prince Street Dock, St. Simons Sound, Georgia Current	NOS	ACT7831_1	31.13833	-81.49667	:America/New_York	USA	knots	166	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:08:00	\N	0.6	00:55:00	\N	0.5	-00:01:00	00:06:00	Brunswick, off Prince Street Dock	GA
64221	Turtle River, off Allied Chemical Corp, St. Simons Sound, Georgia Current	NOS	ACT7836_1	31.17667	-81.525	:America/New_York	USA	knots	165	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:33:00	\N	0.8	00:18:00	\N	0.7	00:16:00	00:36:00	Turtle River, off Allied Chemical Corp	GA
64222	Turtle River, off Andrews Island (Depth 20ft), St. Simons Sound, Georgia Current	NOS	ACT7841_1	31.14333	-81.52667	:America/New_York	USA	knots	153	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:23:00	\N	0.7	00:40:00	\N	0.5	-00:21:00	00:31:00	Turtle River, off Andrews Island	GA
64223	Entrance, St. Andrews Sound, Georgia Current	NOS	ACT7846_1	30.98667	-81.405	:America/New_York	USA	knots	103	268	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	1.1	00:13:00	\N	1.1	-00:18:00	00:02:00	Entrance	GA
64224	Jekyll Creek, south entrance, St. Andrews Sound, Georgia Current	NOS	ACT7851_1	31.035	-81.43333	:America/New_York	USA	knots	232	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:20:00	\N	0.7	-00:21:00	\N	0.5	-00:21:00	-00:25:00	Jekyll Creek, south entrance	GA
64225	Cumberland River, north entrance, St. Andrews Sound, Georgia Current	NOS	ACT7856_1	30.95833	-81.43167	:America/New_York	USA	knots	18	191	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:18:00	\N	0.7	00:32:00	\N	0.7	-00:29:00	-00:17:00	Cumberland River, north entrance	GA
64226	Cabin Bluff, Cumberland River, St. Andrews Sound, Georgia Current	NOS	ACT7861_1	30.88167	-81.51333	:America/New_York	USA	knots	355	171	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:45:00	\N	0.6	01:29:00	\N	0.7	00:21:00	00:51:00	Cabin Bluff, Cumberland River	GA
64227	Mayport (Depth 7ft), St. Johns River, Florida Current	NOS	ACT7971_1	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-00:04:00	\N	1.6	01:02:00	\N	1.1	00:06:00	00:15:00	Mayport	FL
64228	Mayport (Depth 17ft), St. Johns River, Florida Current	NOS	ACT7971_2	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:05:00	\N	1.3	00:38:00	\N	1.1	-00:03:00	00:12:00	Mayport	FL
64229	Mayport (Depth 27ft), St. Johns River, Florida Current	NOS	ACT7971_3	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:14:00	\N	0.9	00:26:00	\N	0.9	-00:27:00	00:15:00	Mayport	FL
64230	Mile Point, southeast of (Depth 7ft), St. Johns River, Florida Current	NOS	ACT7976_1	30.38167	-81.445	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:44:00	\N	1.6	00:38:00	\N	1.5	00:06:00	00:48:00	Mile Point, southeast of	FL
64459	Cape Flores, Ulloa Channel, Alaska Current	NOS	PCT3301_1	55.35	-133.31667	:America/Juneau	USA	knots	330	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.1	-00:27:00	\N	0.7	-00:19:00	-00:37:00	Cape Flores	AK
64231	Mile Point, southeast of (Depth 18ft), St. Johns River, Florida Current	NOS	ACT7976_2	30.38167	-81.445	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:56:00	\N	1.2	00:38:00	\N	1.2	-00:12:00	00:54:00	Mile Point, southeast of	FL
64232	Mile Point, southeast of (Depth 29ft), St. Johns River, Florida Current	NOS	ACT7976_3	30.38167	-81.445	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:38:00	\N	0.9	00:38:00	\N	1.1	-00:42:00	01:00:00	Mile Point, southeast of	FL
64233	Pablo Creek bascule bridge (Depth 3ft), St. Johns River, Florida Current	NOS	ACT7986_1	30.32333	-81.43833	:America/New_York	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:59:00	\N	2.5	-00:18:00	\N	1.7	-00:14:00	00:49:00	Pablo Creek bascule bridge	FL
64234	Sisters Creek entrance (bridge) (Depth 4ft), St. Johns River, Florida Current	NOS	ACT7991_1	30.39	-81.46167	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-02:34:00	\N	0.8	-03:14:00	\N	0.8	-03:30:00	-02:13:00	Sisters Creek entrance (bridge)	FL
64235	Sisters Creek entrance (bridge) (Depth 10ft), St. Johns River, Florida Current	NOS	ACT7991_2	30.39	-81.46167	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-02:34:00	\N	0.6	-03:04:00	\N	0.6	-03:36:00	-02:07:00	Sisters Creek entrance (bridge)	FL
64236	Drummond Point, channel south of (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8016_1	30.40917	-81.60283	:America/New_York	USA	knots	60	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:00:00	\N	0.8	02:32:00	\N	0.7	01:51:00	02:44:00	Drummond Point, channel south of	FL
64237	Drummond Point, channel south of (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8016_2	30.40917	-81.60283	:America/New_York	USA	knots	61	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:01:00	\N	0.7	02:35:00	\N	0.7	01:34:00	02:51:00	Drummond Point, channel south of	FL
64238	Drummond Point, channel south of (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8016_3	30.40917	-81.60283	:America/New_York	USA	knots	57	243	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	02:51:00	\N	0.5	02:20:00	\N	0.6	01:21:00	02:46:00	Drummond Point, channel south of	FL
64239	Terminal Channel (north end) (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8031_1	30.357	-81.618	:America/New_York	USA	knots	1	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.6	03:16:00	\N	0.5	02:39:00	03:02:00	Terminal Channel (north end)	FL
64240	Terminal Channel (north end) (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8031_2	30.357	-81.618	:America/New_York	USA	knots	1	183	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:33:00	\N	0.5	03:06:00	\N	0.6	02:16:00	03:20:00	Terminal Channel (north end)	FL
64428	Eaton Point, Ernest Sound, Alaska Current	NOS	PCT3051_1	55.95283	-132.09	:America/Juneau	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	1	-00:07:00	\N	0.7	00:01:00	-00:17:00	Eaton Point	AK
64241	Terminal Channel (north end) (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8031_3	30.357	-81.618	:America/New_York	USA	knots	1	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:23:00	\N	0.3	03:28:00	\N	0.5	01:51:00	03:16:00	Terminal Channel (north end)	FL
64242	Commodore Point, terminal channel (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8036_1	30.3175	-81.62633	:America/New_York	USA	knots	72	197	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:37:00	\N	0.5	03:28:00	\N	0.5	02:39:00	03:10:00	Commodore Point, terminal channel	FL
64243	Commodore Point, terminal channel (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8036_2	30.3175	-81.62633	:America/New_York	USA	knots	51	221	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:25:00	\N	0.4	03:13:00	\N	0.5	02:12:00	03:23:00	Commodore Point, terminal channel	FL
64244	Commodore Point, terminal channel (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8036_3	30.3175	-81.62633	:America/New_York	USA	knots	35	221	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:08:00	\N	0.4	02:30:00	\N	0.6	01:43:00	03:38:00	Commodore Point, terminal channel	FL
64245	Jacksonville, off Washington St, St. Johns River, Florida Current	NOS	ACT8041_1	30.32167	-81.65333	:America/New_York	USA	knots	118	281	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:23:00	\N	0.9	03:10:00	\N	0.9	02:59:00	02:54:00	Jacksonville, off Washington St	FL
64246	Winter Point, St. Johns River, Florida Current	NOS	ACT8051_1	30.30833	-81.675	:America/New_York	USA	knots	15	200	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:59:00	\N	0.5	03:22:00	\N	0.6	02:59:00	04:04:00	Winter Point	FL
64247	Mandarin Point (Depth 6ft), St. Johns River, Florida Current	NOS	ACT8056_1	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.4	03:39:00	\N	0.3	03:07:00	03:24:00	Mandarin Point	FL
64249	Mandarin Point (Depth 24ft), St. Johns River, Florida Current	NOS	ACT8056_3	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:32:00	\N	0.3	03:33:00	\N	0.3	02:48:00	03:24:00	Mandarin Point	FL
64250	Red Bay Point, draw bridge (Depth 4ft), St. Johns River, Florida Current	NOS	ACT8061_1	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:02:00	\N	0.3	03:57:00	\N	0.5	02:48:00	05:24:00	Red Bay Point, draw bridge	FL
64251	Red Bay Point, draw bridge (Depth 6ft), St. Johns River, Florida Current	NOS	ACT8061_2	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:08:00	\N	0.3	03:57:00	\N	0.5	02:42:00	05:18:00	Red Bay Point, draw bridge	FL
64252	Red Bay Point, draw bridge (Depth 14ft), St. Johns River, Florida Current	NOS	ACT8061_3	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:08:00	\N	0.2	03:57:00	\N	0.4	02:48:00	05:30:00	Red Bay Point, draw bridge	FL
64253	Point Ybel, 0.4 mile northwest of, Florida Current	NOS	ACT8306_1	26.45667	-82.01867	:America/New_York	USA	knots	80	255	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:35:00	\N	0.7	-00:52:00	\N	0.8	-00:25:00	00:17:00	Point Ybel, 0.4 mile northwest of	FL
64254	Captiva Pass, Florida Current	NOS	ACT8311_1	26.60933	-82.22233	:America/New_York	USA	knots	251	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:23:00	\N	0.9	-01:29:00	\N	1.4	-00:53:00	-01:14:00	Captiva Pass	FL
64255	Boca Grande Pass, Charlotte Harbor, Florida Current	NOS	ACT8316_1	26.71433	-82.25667	:America/New_York	USA	knots	251	57	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:05:00	\N	1.3	-00:37:00	\N	1.7	-00:15:00	-00:15:00	Boca Grande Pass, Charlotte Harbor	FL
64256	Cape Haze, 2.3 mi. S of, Charlotte Hbr, Florida Current	NOS	ACT8331_1	26.745	-82.15167	:America/New_York	USA	knots	268	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	01:18:00	\N	0.4	00:41:00	\N	0.4	00:30:00	-00:20:00	Cape Haze, 2.3 mi. S of, Charlotte Hbr	FL
64257	Gasparilla Pass, Florida Current	NOS	ACT8346_1	26.81233	-82.281	:America/New_York	USA	knots	236	66	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:41:00	\N	0.8	-01:13:00	\N	0.8	-01:15:00	-00:35:00	Gasparilla Pass	FL
64258	Venice Inlet, Florida Current	NOS	ACT8351_1	27.11333	-82.46667	:America/New_York	USA	knots	262	87	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:59:00	\N	0.7	-02:08:00	\N	0.8	-02:05:00	-01:57:00	Venice Inlet	FL
64259	Blackburn Bay, south end, bridge, Florida Current	NOS	ACT8356_1	27.12333	-82.47	:America/New_York	USA	knots	180	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:10:00	\N	0.5	-01:20:00	\N	0.7	-00:55:00	-01:28:00	Blackburn Bay, south end, bridge	FL
64260	Little Sarasota Bay, south end, bridge, Florida Current	NOS	ACT8361_1	27.18	-82.495	:America/New_York	USA	knots	357	167	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:06:00	\N	0.5	-00:56:00	\N	1.1	-01:19:00	-00:57:00	Little Sarasota Bay, south end, bridge	FL
64261	Midnight Pass entrance, Florida Current	NOS	ACT8366_1	27.20667	-82.51	:America/New_York	USA	knots	242	61	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:13:00	\N	1.1	-01:59:00	\N	1.4	-01:43:00	-01:49:00	Midnight Pass entrance	FL
64262	Big Sarasota Pass, Sarasota Bay, Florida Current	NOS	ACT8371_1	27.3	-82.56333	:America/New_York	USA	knots	183	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-02:03:00	\N	0.8	-01:49:00	\N	1.2	-01:54:00	-01:34:00	Big Sarasota Pass	FL
64263	Sarasota Bay, south end, bridge, Sarasota Bay, Florida Current	NOS	ACT8376_1	27.30167	-82.54667	:America/New_York	USA	knots	13	196	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:32:00	\N	0.2	-01:39:00	\N	0.2	-01:25:00	-01:13:00	Sarasota Bay, south end, bridge	FL
64264	New Pass, Sarasota Bay, Florida Current	NOS	ACT8381_1	27.33167	-82.58167	:America/New_York	USA	knots	231	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:25:00	\N	0.8	-02:48:00	\N	1.2	-02:06:00	-01:18:00	New Pass	FL
64265	Golden Gate Point, off, Sarasota Bay, Florida Current	NOS	ACT8386_1	27.32833	-82.55667	:America/New_York	USA	knots	159	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:19:00	\N	0.2	-01:57:00	\N	0.3	-01:38:00	-01:25:00	Golden Gate Point, off	FL
64266	Longboat Pass, Sarasota Bay, Florida Current	NOS	ACT8391_1	27.44167	-82.69	:America/New_York	USA	knots	267	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:56:00	\N	1.2	-02:42:00	\N	1.4	-02:32:00	-01:51:00	Longboat Pass	FL
64267	Cortez, north of bridge, Sarasota Bay, Florida Current	NOS	ACT8396_1	27.47	-82.69333	:America/New_York	USA	knots	162	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:11:00	\N	0.1	-01:10:00	\N	0.5	-01:47:00	-00:25:00	Cortez, north of bridge	FL
64268	Egmont Channel, marker '10' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8401_1	27.6005	-82.86767	:America/New_York	USA	knots	259	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:31:00	\N	0.2	-03:17:00	\N	0.2	-02:04:00	-02:22:00	Egmont Channel, marker '10'	FL
64269	Egmont Channel (3 mi. W of Egmont Key Lt.), Tampa Bay, Florida Current	NOS	ACT8406_1	27.60833	-82.81833	:America/New_York	USA	knots	260	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:29:00	\N	0.5	-00:28:00	\N	0.4	-00:30:00	-00:30:00	Egmont Channel (3 mi. W of Egmont Key Lt.)	FL
64270	Southwest Channel (S of Egmont Key) (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8416_1	27.56167	-82.76733	:America/New_York	USA	knots	269	87	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:30:00	\N	0.9	-00:53:00	\N	0.6	-00:46:00	-00:40:00	Southwest Channel (S of Egmont Key)	FL
64271	Mullet Key Channel entrance, Tampa Bay, Florida Current	NOS	ACT8421_1	27.6045	-82.72383	:America/New_York	USA	knots	255	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:08:00	\N	0.8	-00:01:00	\N	0.8	-00:03:00	-00:23:00	Mullet Key Channel entrance	FL
64272	Passage Key Inlet (off Bean Pt.) (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8426_1	27.53933	-82.74767	:America/New_York	USA	knots	247	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:08:00	\N	0.7	-01:50:00	\N	0.6	-01:29:00	-01:13:00	Passage Key Inlet (off Bean Pt.)	FL
64273	Rattlesnake Key, 3.1 miles west of, Tampa Bay, Florida Current	NOS	ACT8431_1	27.55333	-82.68833	:America/New_York	USA	knots	250	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:04:00	\N	0.4	-00:05:00	\N	0.3	00:20:00	-00:51:00	Rattlesnake Key, 3.1 miles west of	FL
64274	Rattlesnake Key, 1.1 miles northwest of, Tampa Bay, Florida Current	NOS	ACT8436_1	27.57083	-82.64383	:America/New_York	USA	knots	210	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:09:00	\N	0.1	-00:34:00	\N	0.2	-00:28:00	-00:34:00	Rattlesnake Key, 1.1 miles northwest of	FL
64275	Mullet Key Channel, marker '24' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8441_1	27.60833	-82.694	:America/New_York	USA	knots	255	73	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:06:00	\N	0.7	-00:07:00	\N	0.7	-00:14:00	-00:06:00	Mullet Key Channel, marker '24'	FL
64276	Bunces Pass (West of Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8446_1	27.647	-82.7395	:America/New_York	USA	knots	315	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:02:00	\N	0.7	-00:46:00	\N	0.8	-00:47:00	-01:07:00	Bunces Pass (West of Bayway bridge)	FL
64277	Pine Key (Pinellas Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8451_1	27.6925	-82.71717	:America/New_York	USA	knots	280	100	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:00:00	\N	0.6	-00:29:00	\N	0.3	-00:32:00	-01:07:00	Pine Key (Pinellas Bayway bridge)	FL
64278	Cats Point (bridge west of), Tampa Bay, Florida Current	NOS	ACT8456_1	27.70833	-82.72467	:America/New_York	USA	knots	150	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:23:00	\N	0.5	-02:41:00	\N	0.5	-01:27:00	-02:12:00	Cats Point (bridge west of)	FL
64279	Cut A & B, Channel Junction, Tampa Bay, Florida Current	NOS	ACT8466_1	27.63883	-82.6255	:America/New_York	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:46:00	\N	0.7	00:07:00	\N	0.8	00:25:00	00:23:00	Cut A & B, Channel Junction	FL
64280	Joe Island, 1.8 miles northwest of, Tampa Bay, Florida Current	NOS	ACT8471_1	27.6125	-82.625	:America/New_York	USA	knots	245	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:02:00	\N	0.7	-00:07:00	\N	0.5	00:03:00	-00:24:00	Joe Island, 1.8 miles northwest of	FL
64281	Harbor Key, 1.3 miles west of, Tampa Bay, Florida Current	NOS	ACT8476_1	27.61117	-82.5945	:America/New_York	USA	knots	160	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:38:00	\N	0.3	-00:56:00	\N	0.2	-00:50:00	-01:06:00	Harbor Key, 1.3 miles west of	FL
64282	2.6 miles south of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8486_1	27.6605	-82.64167	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:34:00	\N	0.7	-00:23:00	\N	0.6	-00:46:00	-00:16:00	2.6 miles south of	FL
64283	0.5 mile southeast of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8491_1	27.697	-82.6325	:America/New_York	USA	knots	220	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:57:00	\N	0.2	-01:19:00	\N	0.2	-01:28:00	-01:53:00	0.5 mile southeast of	FL
64284	1.9 miles SE of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8496_1	27.68467	-82.60967	:America/New_York	USA	knots	180	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:20:00	\N	0.6	-00:32:00	\N	0.5	00:29:00	-00:06:00	1.9 miles SE of	FL
64285	3 miles southeast of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8501_1	27.673	-82.593	:America/New_York	USA	knots	200	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:47:00	\N	0.6	00:23:00	\N	0.6	00:29:00	00:20:00	3 miles southeast of	FL
64653	Edmonds, 2.5 miles west of (Depth 251ft), Washington Current	NOS	PUG1503_20	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64286	Port Manatee Channel entrance (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8506_1	27.662	-82.59917	:America/New_York	USA	knots	216	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:23:00	\N	0.6	00:08:00	\N	0.6	-00:01:00	00:24:00	Port Manatee Channel entrance	FL
64287	Port Manatee Channel, marker '4' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8511_1	27.6535	-82.58983	:America/New_York	USA	knots	242	56	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:01:00	\N	0.3	-00:11:00	\N	0.2	-00:34:00	-00:22:00	Port Manatee Channel, marker '4'	FL
64288	Piney Point, 0.6 mile NNW of, Tampa Bay, Florida Current	NOS	ACT8516_1	27.65367	-82.56217	:America/New_York	USA	knots	215	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:01:00	\N	0.4	-00:29:00	\N	0.3	00:12:00	-00:45:00	Piney Point, 0.6 mile NNW of	FL
64289	Pass-a-Grille Channel, Florida Current	NOS	ACT8606_1	27.685	-82.735	:America/New_York	USA	knots	186	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:17:00	\N	1	-00:43:00	\N	0.9	-00:30:00	-00:30:00	Pass-a-Grille Channel	FL
64290	Bridge, 0.8 mi. south of Maximo Pt., Florida Current	NOS	ACT8611_1	27.69333	-82.68	:America/New_York	USA	knots	255	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:50:00	\N	1	-01:22:00	\N	0.9	-01:05:00	-01:05:00	Bridge, 0.8 mi. south of Maximo Pt.	FL
64291	Blind Pass (north end), Florida Current	NOS	ACT8621_1	27.75667	-82.76167	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:12:00	\N	0.3	-01:25:00	\N	0.5	-01:20:00	-01:20:00	Blind Pass (north end)	FL
64292	The Narrows (Indian Rocks Beach Bridge), Florida Current	NOS	ACT8651_1	27.876670837402344	-82.8499984741211	:America/New_York	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:54:00	\N	0.1	-00:25:00	\N	0.5	-00:23:00	-01:17:00	The Narrows (Indian Rocks Beach Bridge)	FL
64293	Clearwater Pass, 0.2 mi. NE of Sand Key, Florida Current	NOS	ACT8656_1	27.95667	-82.82333	:America/New_York	USA	knots	348	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:50:00	\N	0.8	-02:49:00	\N	1	-02:24:00	-02:18:00	Clearwater Pass, 0.2 mi. NE of Sand Key	FL
64294	St. Marks River approach, Apalachee Bay, Florida Current	NOS	ACT8666_1	30.04667	-84.18	:America/New_York	USA	knots	170	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:08:00	\N	0.4	-00:46:00	\N	0.5	-00:57:00	-00:10:00	St. Marks River approach	FL
64295	Four Mile Point, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8671_1	30.11167	-84.20333	:America/New_York	USA	knots	187	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:26:00	\N	0.3	-00:14:00	\N	0.3	-00:13:00	00:24:00	Four Mile Point, St. Marks River	FL
64296	St. Marks, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8676_1	30.155	-84.20167	:America/New_York	USA	knots	247	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:23:00	\N	0.3	01:10:00	\N	0.2	01:38:00	-00:23:00	St. Marks, St. Marks River	FL
64297	Bolivar Roads (Depth 8ft), Galveston Bay, Texas Current	NOS	ACT8856_1	29.34333	-94.78133	:America/Chicago	USA	knots	125	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-00:01:00	\N	1.1	00:07:00	\N	1	00:09:00	-00:16:00	Bolivar Roads	TX
64298	Bolivar Roads (Depth 31ft), Galveston Bay, Texas Current	NOS	ACT8856_3	29.34333	-94.78133	:America/Chicago	USA	knots	115	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-00:08:00	\N	0.6	-00:11:00	\N	0.8	-00:32:00	00:17:00	Bolivar Roads	TX
64299	Houston Channel, W of Port Bolivar (Depth 3ft), Galveston Bay, Texas Current	NOS	ACT8876_1	29.36467	-94.79667	:America/Chicago	USA	knots	135	313	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:41:00	\N	1	-00:18:00	\N	1.1	-00:05:00	-02:14:00	Houston Channel, W of Port Bolivar	TX
64300	Houston Channel, W of Port Bolivar (Depth 14ft), Galveston Bay, Texas Current	NOS	ACT8876_2	29.36467	-94.79667	:America/Chicago	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:55:00	\N	0.9	-00:11:00	\N	1	-00:03:00	-02:15:00	Houston Channel, W of Port Bolivar	TX
64301	Houston Channel, W of Port Bolivar (Depth 26ft), Galveston Bay, Texas Current	NOS	ACT8876_3	29.36467	-94.79667	:America/Chicago	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:41:00	\N	0.8	-00:14:00	\N	0.9	-00:06:00	-02:12:00	Houston Channel, W of Port Bolivar	TX
64302	Houston Ship Channel (Red Fish Bar) (Depth 7ft), Galveston Bay, Texas Current	NOS	ACT8881_1	29.50733	-94.87467	:America/Chicago	USA	knots	154	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	00:50:00	\N	0.5	01:13:00	\N	0.5	00:41:00	01:13:00	Houston Ship Channel (Red Fish Bar)	TX
64303	Houston Ship Channel (Red Fish Bar) (Depth 14ft), Galveston Bay, Texas Current	NOS	ACT8881_2	29.50733	-94.87467	:America/Chicago	USA	knots	148	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:10:00	\N	0.7	01:28:00	\N	0.7	00:45:00	01:17:00	Houston Ship Channel (Red Fish Bar)	TX
64323	North Island (Depth 34ft), San Diego Bay, California Current	NOS	PCT0056_2	32.713	-117.21283	:America/Los_Angeles	USA	knots	241	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:33:00	\N	0.2	-01:05:00	\N	0.3	-00:43:00	-00:44:00	North Island	CA
64304	Houston Ship Channel (Red Fish Bar) (Depth 24ft), Galveston Bay, Texas Current	NOS	ACT8881_3	29.50733	-94.87467	:America/Chicago	USA	knots	144	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:42:00	\N	0.5	01:15:00	\N	0.5	00:48:00	01:20:00	Houston Ship Channel (Red Fish Bar)	TX
64305	Morgans Point (Depth 6ft), Galveston Bay, Texas Current	NOS	ACT8886_1	29.67983	-94.98167	:America/Chicago	USA	knots	163	336	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:16:00	\N	0.5	01:43:00	\N	0.3	02:15:00	-01:05:00	Morgans Point	TX
64306	Morgans Point (Depth 15ft), Galveston Bay, Texas Current	NOS	ACT8886_2	29.67983	-94.98167	:America/Chicago	USA	knots	159	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:11:00	\N	0.4	01:23:00	\N	0.3	01:44:00	-00:50:00	Morgans Point	TX
64307	Morgans Point (Depth 25ft), Galveston Bay, Texas Current	NOS	ACT8886_3	29.67983	-94.98167	:America/Chicago	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:20:00	\N	0.3	00:58:00	\N	0.2	00:47:00	-01:02:00	Morgans Point	TX
64308	Aransas Pass (Depth 15ft), Texas Current	NOS	ACT8896_1	27.83383	-97.04417	:America/Chicago	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	00:00:00	\N	1.5	00:00:00	\N	1.1	00:00:00	00:00:00	Aransas Pass	TX
64309	Aransas Pass (Depth 50ft), Texas Current	NOS	ACT8896_3	27.83383	-97.04417	:America/Chicago	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	00:00:00	\N	0.8	00:00:00	\N	0.9	00:00:00	00:00:00	Aransas Pass	TX
64310	Port Ingleside (Depth 5ft), Texas Current	NOS	ACT8901_1	27.815	-97.23	:America/Chicago	USA	knots	102	286	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	01:09:00	\N	0.5	01:48:00	\N	0.7	00:24:00	02:11:00	Port Ingleside	TX
64311	Punta Ostiones, 1.5 miles west of, Puerto Rico Current	NOS	ACT8921_1	18.08667	-67.22667	:America/Puerto_Rico	USA	knots	1	187	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-00:35:00	\N	1.3	-00:52:00	\N	1.7	-00:26:00	-00:04:00	Punta Ostiones, 1.5 miles west of	PR
64312	Vieques Sound, Puerto Rico Current	NOS	ACT8931_1	18.2645	-65.57	:America/Puerto_Rico	USA	knots	355	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:05:00	\N	0.9	-01:16:00	\N	0.7	-00:44:00	-01:28:00	Vieques Sound	PR
64313	Largo Shoals, west of, Puerto Rico Current	NOS	ACT8936_1	18.31667	-65.58333	:America/Puerto_Rico	USA	knots	330	186	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:08:00	\N	1	-01:28:00	\N	0.7	-00:52:00	-01:33:00	Largo Shoals, west of	PR
64314	Fajardo Harbor (channel), Puerto Rico Current	NOS	ACT8951_1	18.33333	-65.61667	:America/Puerto_Rico	USA	knots	339	162	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:45:00	\N	1.6	-01:52:00	\N	0.5	-01:13:00	-02:27:00	Fajardo Harbor (channel)	PR
64315	Point Loma Light, 0.8 nmi. east of (Depth 15ft), San Diego Bay, California Current	NOS	PCT0026_1	32.66583	-117.22617	:America/Los_Angeles	USA	knots	174	328	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:45:00	\N	0.4	-00:43:00	\N	0.5	-00:18:00	-00:05:00	Point Loma Light, 0.8 nmi. east of	CA
64316	Point Loma Light, 0.8 nmi. east of (Depth 33ft), San Diego Bay, California Current	NOS	PCT0026_2	32.66583	-117.22617	:America/Los_Angeles	USA	knots	166	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:23:00	\N	0.2	-00:46:00	\N	0.4	-01:08:00	-00:08:00	Point Loma Light, 0.8 nmi. east of	CA
64317	Ballast Point, south of (Depth 5ft), San Diego Bay, California Current	NOS	PCT0036_1	32.6845	-117.23217	:America/Los_Angeles	USA	knots	238	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-02:03:00	\N	0.2	-01:02:00	\N	0.4	-01:04:00	-01:01:00	Ballast Point, south of	CA
64318	Ballast Point, 100 yards north of, San Diego Bay, California Current	NOS	PCT0041_1	32.68333	-117.23333	:America/Los_Angeles	USA	knots	133	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:02:00	\N	0.9	-00:24:00	\N	1	-00:27:00	-00:23:00	Ballast Point, 100 yards north of	CA
64319	Ballast Point, 0.55 nmi. north of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0046_1	32.69583	-117.2325	:America/Los_Angeles	USA	knots	193	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:24:00	\N	0.4	-00:39:00	\N	0.5	-00:05:00	-00:34:00	Ballast Point, 0.55 nmi. north of	CA
64320	Ballast Point, 0.55 nmi. north of (Depth 34ft), San Diego Bay, California Current	NOS	PCT0046_2	32.69583	-117.2325	:America/Los_Angeles	USA	knots	147	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:03:00	\N	0.2	00:10:00	\N	0.5	-00:44:00	00:03:00	Ballast Point, 0.55 nmi. north of	CA
64321	Quarantine Station, La Playa, San Diego Bay, California Current	NOS	PCT0051_1	32.7	-117.23333	:America/Los_Angeles	USA	knots	200	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:20:00	\N	0.8	00:15:00	\N	0.8	-00:03:00	00:10:00	Quarantine Station, La Playa	CA
64322	North Island (Depth 14ft), San Diego Bay, California Current	NOS	PCT0056_1	32.713	-117.21283	:America/Los_Angeles	USA	knots	245	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:03:00	\N	0.4	-00:56:00	\N	0.5	-00:26:00	-00:54:00	North Island	CA
64324	Harbor Island (east end), SSW of (Depth 15ft), San Diego Bay, California Current	NOS	PCT0061_1	32.71917	-117.19167	:America/Los_Angeles	USA	knots	293	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:23:00	\N	0.3	00:09:00	\N	0.3	00:29:00	-00:24:00	Harbor Island (east end), SSW of	CA
64325	San Diego, 0.5 mile west of, San Diego Bay, California Current	NOS	PCT0066_1	32.71667	-117.18333	:America/Los_Angeles	USA	knots	304	121	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:12:00	\N	0.5	-00:08:00	\N	0.6	-00:16:00	-00:12:00	San Diego, 0.5 mile west of	CA
64326	G St. Pier (San Diego), 0.22 nmi. SW of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0081_1	32.70833	-117.1775	:America/Los_Angeles	USA	knots	304	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:41:00	\N	0.3	00:20:00	\N	0.3	00:10:00	-00:03:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
64327	G St. Pier (San Diego), 0.22 nmi. SW of (Depth 37ft), San Diego Bay, California Current	NOS	PCT0081_2	32.70833	-117.1775	:America/Los_Angeles	USA	knots	301	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:58:00	\N	0.2	00:21:00	\N	0.3	-00:23:00	-00:18:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
64328	Coronado, off northeast end (Depth 14ft), San Diego Bay, California Current	NOS	PCT0091_1	32.698	-117.16383	:America/Los_Angeles	USA	knots	317	128	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:09:00	\N	0.5	-00:58:00	\N	0.7	-00:24:00	-00:51:00	Coronado, off northeast end	CA
64329	Coronado, off northeast end (Depth 38ft), San Diego Bay, California Current	NOS	PCT0091_2	32.698	-117.16383	:America/Los_Angeles	USA	knots	319	130	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:03:00	\N	0.4	-00:59:00	\N	0.5	-00:41:00	-01:01:00	Coronado, off northeast end	CA
64330	28th St. Pier (San Diego), 0.92 nmi. SW (Depth 7ft), San Diego Bay, California Current	NOS	PCT0096_1	32.67467	-117.1495	:America/Los_Angeles	USA	knots	351	182	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:05:00	\N	0.1	-01:17:00	\N	0.2	-00:44:00	-01:10:00	28th St. Pier (San Diego), 0.92 nmi. SW	CA
64331	28th St. Pier (San Diego), 0.35 nmi. SW (Depth 14ft), San Diego Bay, California Current	NOS	PCT0101_1	32.68283	-117.14283	:America/Los_Angeles	USA	knots	317	133	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:13:00	\N	0.2	00:15:00	\N	0.3	-00:14:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
64332	28th St. Pier (San Diego), 0.35 nmi. SW (Depth 28ft), San Diego Bay, California Current	NOS	PCT0101_2	32.68283	-117.14283	:America/Los_Angeles	USA	knots	328	148	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:35:00	\N	0.2	00:24:00	\N	0.2	00:01:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
64333	National City, San Diego Bay, California Current	NOS	PCT0106_1	32.65	-117.11667	:America/Los_Angeles	USA	knots	2	166	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:50:00	\N	0.4	00:00:00	\N	0.4	00:23:00	-00:02:00	National City	CA
64334	National City, WSW of Pier 12 (Depth 32ft), San Diego Bay, California Current	NOS	PCT0111_1	32.66217	-117.1255	:America/Los_Angeles	USA	knots	351	178	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:58:00	\N	0.2	00:34:00	\N	0.2	00:22:00	00:34:00	National City, WSW of Pier 12	CA
64335	Sweetwater Channel, southwest of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0116_1	32.645	-117.12283	:America/Los_Angeles	USA	knots	348	203	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:46:00	\N	0.2	-00:33:00	\N	0.1	00:29:00	-00:05:00	Sweetwater Channel, southwest of	CA
64336	Coquille River entrance, Oregon Current	NOS	PCT1056_1	43.12167	-124.41967	:America/Los_Angeles	USA	knots	290	91	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:17:00	\N	0.6	-01:25:00	\N	0.4	-01:00:00	-01:27:00	Coquille River entrance	OR
64337	Coos Bay entrance, Oregon Current	NOS	PCT1061_1	43.355	-124.34117	:America/Los_Angeles	USA	knots	280	100	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1.1	-00:42:00	\N	0.6	-00:24:00	-00:42:00	Coos Bay entrance	OR
64338	Umpqua River entrance, Oregon Current	NOS	PCT1066_1	43.67833	-124.19333	:America/Los_Angeles	USA	knots	190	10	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.5	-00:32:00	\N	0.3	-00:14:00	-00:32:00	Umpqua River entrance	OR
64339	Heceta Head, Oregon Current	NOS	PCT1071_1	44.13333	-124.13333	:America/Los_Angeles	USA	knots	185	5	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.7	-00:12:00	\N	0.4	00:06:00	-00:12:00	Heceta Head	OR
64340	Yaquina Bay entrance, Yaquina Bay, Oregon Current	NOS	PCT1076_1	44.61667	-124.06667	:America/Los_Angeles	USA	knots	235	50	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:55:00	\N	1.1	-01:04:00	\N	0.8	-01:20:00	-01:17:00	Yaquina Bay entrance	OR
64341	Highway Bridge, Yaquina Bay, Oregon Current	NOS	PCT1081_1	44.62333	-124.057	:America/Los_Angeles	USA	knots	222	44	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:53:00	\N	1	-00:50:00	\N	0.6	-01:31:00	-01:40:00	Highway Bridge	OR
64342	Yaquina, Yaquina River, Yaquina Bay, Oregon Current	NOS	PCT1086_1	44.602	-124.01133	:America/Los_Angeles	USA	knots	2	184	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:33:00	\N	0.5	-00:50:00	\N	0.3	-01:09:00	-01:33:00	Yaquina, Yaquina River	OR
64343	Yaquina River, 1 mile below Toledo, Yaquina Bay, Oregon Current	NOS	PCT1091_1	44.6005	-123.94167	:America/Los_Angeles	USA	knots	132	332	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:02:00	\N	0.7	-00:13:00	\N	0.4	-00:27:00	-00:46:00	Yaquina River, 1 mile below Toledo	OR
64344	Tillamook Bay entrance, Tillamook Bay, Oregon Current	NOS	PCT1096_1	45.56217	-123.93833	:America/Los_Angeles	USA	knots	305	141	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	1.3	-00:47:00	\N	0.9	-00:20:00	-01:05:00	Tillamook Bay entrance	OR
64345	Sand Island Tower, 1nm SE of (midchannel) (Depth 15ft), Washington Current	NOS	PCT1106_1	46.25283	-123.99083	:America/Los_Angeles	USA	knots	275	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:07:00	\N	1.6	01:03:00	\N	1.6	01:12:00	00:38:00	Sand Island Tower, 1nm SE of (midchannel)	WA
64346	Sand Island Tower, 0.9nm SE of (north channel) (Depth 15ft), Washington Current	NOS	PCT1111_1	46.25783	-123.9945	:America/Los_Angeles	USA	knots	262	92	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:44:00	\N	0.7	00:33:00	\N	1.1	00:39:00	00:27:00	Sand Island Tower, 0.9nm SE of (north channel)	WA
64347	Baker Bay entrance, E of Sand Island Tower (Depth 23ft), Washington Current	NOS	PCT1116_1	46.262	-123.998	:America/Los_Angeles	USA	knots	202	8	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:14:00	\N	0.3	00:08:00	\N	0.6	00:28:00	00:20:00	Baker Bay entrance, E of Sand Island Tower	WA
64348	Clatsop Spit, NNE of (Depth 15ft), Washington Current	NOS	PCT1121_1	46.24617	-123.99417	:America/Los_Angeles	USA	knots	289	114	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:20:00	\N	1.1	00:56:00	\N	1.4	00:45:00	00:56:00	Clatsop Spit, NNE of	WA
64349	Sand Island, SSE of (Depth 12ft), Washington Current	NOS	PCT1126_1	46.2555	-123.968	:America/Los_Angeles	USA	knots	265	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:32:00	\N	0.4	-00:25:00	\N	0.3	00:18:00	-00:16:00	Sand Island, SSE of	WA
64350	Youngs Bay Bridge (Depth 9ft), Oregon Current	NOS	PCT1146_1	46.17783	-123.86833	:America/Los_Angeles	USA	knots	320	135	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:28:00	\N	0.3	-00:14:00	\N	0.4	00:10:00	00:50:00	Youngs Bay Bridge	OR
64351	Hammond, northeast of ship channel (Depth 15ft), Oregon Current	NOS	PCT1151_1	46.21117	-123.9345	:America/Los_Angeles	USA	knots	307	134	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:01:00	\N	0.6	00:24:00	\N	0.4	00:57:00	00:26:00	Hammond, northeast of ship channel	OR
64352	McGowan, SSW of (Depth 14ft), Washington Current	NOS	PCT1156_1	46.2395	-123.91533	:America/Los_Angeles	USA	knots	282	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:23:00	\N	1.6	01:14:00	\N	0.9	01:28:00	00:21:00	McGowan, SSW of	WA
64353	Point Ellice, east of (Depth 17ft), Washington Current	NOS	PCT1161_1	46.24167	-123.84833	:America/Los_Angeles	USA	knots	254	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:11:00	\N	0.9	00:25:00	\N	0.8	00:55:00	00:51:00	Point Ellice, east of	WA
64354	Point Adams, NNE OF (Depth 14ft), Oregon Current	NOS	PCT1166_1	46.22783	-123.9675	:America/Los_Angeles	USA	knots	297	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:11:00	\N	0.9	00:13:00	\N	0.8	01:16:00	00:26:00	Point Adams, NNE OF	OR
64355	Chinook Point, WSW of (Depth 14ft), Washington Current	NOS	PCT1171_1	46.24217	-123.96417	:America/Los_Angeles	USA	knots	287	117	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:21:00	\N	0.9	00:25:00	\N	1.2	00:29:00	00:45:00	Chinook Point, WSW of	WA
64356	Tongue Point, northwest of (Depth 15ft), Oregon Current	NOS	PCT1176_1	46.21917	-123.76667	:America/Los_Angeles	USA	knots	249	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:46:00	\N	0.9	01:09:00	\N	0.4	02:31:00	00:24:00	Tongue Point, northwest of	OR
64357	Woody Island Channel (Depth 15ft), Washington Current	NOS	PCT1186_1	46.2395	-123.67333	:America/Los_Angeles	USA	knots	298	118	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:15:00	\N	0.3	01:09:00	\N	0.5	01:12:00	01:36:00	Woody Island Channel	WA
64358	Woody Island Channel (off Seal Island) (Depth 12ft), Oregon Current	NOS	PCT1191_1	46.2175	-123.62917	:America/Los_Angeles	USA	knots	247	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	02:53:00	\N	0.4	01:53:00	\N	0.3	02:38:00	01:25:00	Woody Island Channel (off Seal Island)	OR
64359	Quinn Island, Prairie Channel (Depth 8ft), Washington Current	NOS	PCT1201_1	46.23717	-123.50333	:America/Los_Angeles	USA	knots	281	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:53:00	\N	0.5	01:52:00	\N	0.3	03:19:00	00:55:00	Quinn Island, Prairie Channel	WA
64360	Clifton Channel (Depth 10ft), Washington Current	NOS	PCT1206_1	46.21783	-123.46533	:America/Los_Angeles	USA	knots	301	118	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	02:17:00	\N	0.4	02:27:00	\N	0.3	03:41:00	01:21:00	Clifton Channel	WA
64361	Hunting Island, south of (Depth 20ft), Washington Current	NOS	PCT1216_1	46.20717	-123.40417	:America/Los_Angeles	USA	knots	295	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	03:20:00	\N	0.4	02:56:00	\N	0.2	04:20:00	01:38:00	Hunting Island, south of	WA
64362	Cathlamet Channel, SE of Nassa Point (Depth 19ft), Washington Current	NOS	PCT1231_1	46.15617	-123.315	:America/Los_Angeles	USA	knots	278	103	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	05:38:00	\N	0.6	03:23:00	\N	0.1	05:16:00	01:39:00	Cathlamet Channel, SE of Nassa Point	WA
64363	Walker Island, south of (Depth 12ft), Washington Current	NOS	PCT1251_1	46.14117	-123.04583	:America/Los_Angeles	USA	knots	330	148	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	05:09:00	\N	0.4	04:15:00	\N	0.2	05:46:00	02:41:00	Walker Island, south of	WA
64364	South Bend, Willapa River, Washington Current	NOS	PCT1271_1	46.66467	-123.80133	:America/Los_Angeles	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:06:00	\N	0.5	00:20:00	\N	0.6	00:19:00	00:24:00	South Bend, Willapa River	WA
64365	Entrance, 0.2 mile south of north jetty, Grays Harbor, Washington Current	NOS	PCT1276_1	46.92633	-124.16133	:America/Los_Angeles	USA	knots	243	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:47:00	\N	0.6	00:16:00	\N	1.3	-00:28:00	00:10:00	Entrance, 0.2 mile south of north jetty	WA
64366	Entrance, Point Chehalis Range, Grays Harbor, Washington Current	NOS	PCT1281_1	46.90833	-124.1555	:America/Los_Angeles	USA	knots	268	92	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:21:00	\N	1.1	-00:11:00	\N	0.9	00:08:00	-00:22:00	Entrance, Point Chehalis Range	WA
64367	Entrance, 0.6 mile WNW of Westport, Grays Harbor, Washington Current	NOS	PCT1286_1	46.91467	-124.125	:America/Los_Angeles	USA	knots	238	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:00:00	\N	0.7	00:00:00	\N	1.2	00:00:00	00:06:00	Entrance, 0.6 mile WNW of Westport	WA
64368	Entrance, 1.1 miles NW of Westport, Grays Harbor, Washington Current	NOS	PCT1296_1	46.91667	-124.13333	:America/Los_Angeles	USA	knots	233	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:23:00	\N	0.9	-00:06:00	\N	0.9	00:04:00	-00:05:00	Entrance, 1.1 miles NW of Westport	WA
64369	Channel, 1.5 miles north of Westport, Grays Harbor, Washington Current	NOS	PCT1301_1	46.93333	-124.1	:America/Los_Angeles	USA	knots	226	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:25:00	\N	0.6	-00:04:00	\N	0.7	-00:22:00	-00:04:00	Channel, 1.5 miles north of Westport	WA
64370	Channel, 2.1 miles NNE of Westport, Grays Harbor, Washington Current	NOS	PCT1306_1	46.93333	-124.08333	:America/Los_Angeles	USA	knots	249	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:02:00	\N	0.5	00:00:00	\N	0.6	-00:02:00	-00:02:00	Channel, 2.1 miles NNE of Westport	WA
64371	Westport, channel 0.4 mile NE of, Grays Harbor, Washington Current	NOS	PCT1316_1	46.91417	-124.10833	:America/Los_Angeles	USA	knots	310	113	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:36:00	\N	0.7	-00:04:00	\N	1	-00:41:00	-00:19:00	Westport, channel 0.4 mile NE of	WA
64375	Cape Muzon, 4 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2621_1	54.6	-132.68333	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	1.2	-00:47:00	\N	0.8	-00:39:00	-00:57:00	Cape Muzon, 4 miles south from	AK
64376	Point Marsh, 5 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2626_1	54.63333	-132.3	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	1.1	-00:47:00	\N	0.7	-00:39:00	-00:57:00	Point Marsh, 5 miles south from	AK
64377	West Devil Rock, 2 miles north of, Dixon Entrance, Alaska Current	NOS	PCT2636_1	54.7	-131.6	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1.2	-00:42:00	\N	0.8	-00:34:00	-00:52:00	West Devil Rock, 2 miles north of	AK
64378	Barren Island Light, 2 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2641_1	54.7	-131.35	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.1	-00:37:00	\N	0.7	-00:29:00	-00:47:00	Barren Island Light, 2 miles south from	AK
64379	East Devil Rock, 1 mile north of, Dixon Entrance, Alaska Current	NOS	PCT2646_1	54.7	-131.08333	:America/Juneau	USA	knots	265	85	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.1	00:23:00	\N	0.7	00:31:00	00:13:00	East Devil Rock, 1 mile north of	AK
64380	Between Dundas Island and Cape Fox, Dixon Entrance, Alaska Current	NOS	PCT2651_1	54.7	-130.83333	:America/Juneau	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	1.4	00:18:00	\N	0.6	00:14:00	00:20:00	Between Dundas Island and Cape Fox	AK
64381	Tongass Islands, east of, Nakat Bay, Dixon Entrance, Alaska Current	NOS	PCT2656_1	54.78233	-130.73717	:America/Juneau	USA	knots	157	326	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:31:00	\N	0.6	-02:40:00	\N	0.3	-01:31:00	-01:38:00	Tongass Islands, east of, Nakat Bay	AK
64382	Boston Islands, 1 mile south from, Dixon Entrance, Alaska Current	NOS	PCT2661_1	54.68333	-130.56667	:America/Juneau	USA	knots	265	85	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.1	-00:37:00	\N	0.7	-00:29:00	-00:47:00	Boston Islands, 1 mile south from	AK
64383	Portland Inlet, 2 miles S. of Wales Pt, Dixon Entrance, Alaska Current	NOS	PCT2666_1	54.66667	-130.48333	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.2	00:28:00	\N	0.8	00:36:00	00:18:00	Portland Inlet, 2 miles S. of Wales Pt	AK
64384	Haystack Island, Tongass Passage, Pearse Canal, Alaska Current	NOS	PCT2671_1	54.71667	-130.61667	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.2	00:23:00	\N	0.8	00:31:00	00:13:00	Haystack Island, Tongass Passage	AK
64385	Point Phipp, Pearse Canal, Alaska Current	NOS	PCT2676_1	54.78333	-130.63333	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.3	00:23:00	\N	0.9	00:31:00	00:13:00	Point Phipp	AK
64386	Narrows, Pearse Canal, Alaska Current	NOS	PCT2681_1	54.83467	-130.4855	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:47:00	\N	1.3	00:26:00	\N	0.9	00:34:00	00:31:00	Narrows	AK
64387	Blaine Point, Pearse Canal, Alaska Current	NOS	PCT2686_1	55.03333	-130.21667	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Blaine Point	AK
64388	Wales Point, 2 miles south from, Portland Canal, Alaska Current	NOS	PCT2691_1	54.66667	-130.48333	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.2	00:28:00	\N	0.8	00:36:00	00:18:00	Wales Point, 2 miles south from	AK
64389	Cliff Point, 1 mile east from, Portland Canal, Alaska Current	NOS	PCT2696_1	54.8	-130.31667	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.1	00:28:00	\N	0.7	00:36:00	00:18:00	Cliff Point, 1 mile east from	AK
64390	Flat Point , 1 mile east of, Portland Canal, Alaska Current	NOS	PCT2701_1	54.91667	-130.16667	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	1	00:33:00	\N	0.6	00:41:00	00:23:00	Flat Point , 1 mile east of	AK
64391	Tree Point, 1 mile east of, Portland Canal, Alaska Current	NOS	PCT2706_1	55.03333	-130.16667	:America/Juneau	USA	knots	165	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.9	00:33:00	\N	0.6	00:41:00	00:23:00	Tree Point, 1 mile east of	AK
64392	Dickens Point, Portland Canal, Alaska Current	NOS	PCT2711_1	55.15	-130.15	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.7	00:33:00	\N	0.5	00:41:00	00:23:00	Dickens Point	AK
64393	White Point, Portland Canal, Alaska Current	NOS	PCT2716_1	55.56667	-130.11667	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:59:00	\N	0.5	00:38:00	\N	0.3	00:46:00	00:28:00	White Point	AK
64394	Camp Point, Portland Canal, Alaska Current	NOS	PCT2721_1	55.28333	-129.98333	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.6	-00:22:00	\N	0.4	-00:14:00	-00:32:00	Camp Point	AK
64395	Miners Point, Portland Canal, Alaska Current	NOS	PCT2726_1	55.71667	-130.15	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.4	-00:17:00	\N	0.3	-00:09:00	-00:27:00	Miners Point	AK
64396	Lion Point, Portland Canal, Alaska Current	NOS	PCT2731_1	55.88333	-130.03333	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.2	-00:17:00	\N	0.2	-00:09:00	-00:27:00	Lion Point	AK
64397	Race Point, 0.7 mile ENE of, Revillagigedo Channel, Alaska Current	NOS	PCT2761_1	55.28583	-131.546	:America/Juneau	USA	knots	300	145	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:18:00	\N	0.2	00:22:00	\N	0.2	00:49:00	00:10:00	Race Point, 0.7 mile ENE of	AK
64398	Saxman Spire, 0.2 mile south of, Tongass Narrows, Alaska Current	NOS	PCT2781_1	55.3155	-131.60267	:America/Juneau	USA	knots	110	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:12:00	\N	0.3	-02:00:00	\N	0.2	-00:32:00	-02:02:00	Saxman Spire, 0.2 mile south of	AK
64400	Hotspur Island, 0.5 mile southeast of, Felice Strait, Alaska Current	NOS	PCT2806_1	54.96667	-131.48333	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:56:00	\N	0.4	-01:29:00	\N	0.3	-00:53:00	-01:06:00	Hotspur Island, 0.5 mile southeast of	AK
64401	Point Davidson, 1 mile south of, Felice Strait, Alaska Current	NOS	PCT2811_1	54.98333	-131.6	:America/Juneau	USA	knots	240	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1	-00:37:00	\N	0.6	-00:29:00	-00:47:00	Point Davidson, 1 mile south of	AK
64402	Harris Island, Felice Strait, Alaska Current	NOS	PCT2816_1	55	-131.53333	:America/Juneau	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.8	-00:37:00	\N	1.3	-00:29:00	-00:47:00	Harris Island	AK
64403	Ajax Reef, Felice Strait, Alaska Current	NOS	PCT2821_1	55	-131.46667	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.4	-00:32:00	\N	0.9	-00:24:00	-00:42:00	Ajax Reef	AK
64404	Snipe Island, Felice Strait, Alaska Current	NOS	PCT2831_1	55	-131.38333	:America/Juneau	USA	knots	250	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.8	-00:27:00	\N	1.3	-00:19:00	-00:37:00	Snipe Island	AK
64405	Grass Rock, Tamgas Harbor entrance, Felice Strait, Alaska Current	NOS	PCT2836_1	55.02167	-131.52233	:America/Juneau	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.2	-00:32:00	\N	0.8	-00:24:00	-00:42:00	Grass Rock, Tamgas Harbor entrance	AK
64406	Indian Reef, Felice Strait, Alaska Current	NOS	PCT2841_1	55.03333	-131.35	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.6	-00:27:00	\N	1.1	-00:19:00	-00:37:00	Indian Reef	AK
64407	Customhouse Cove, 1 mile west of, Felice Strait, Alaska Current	NOS	PCT2866_1	55.1	-131.26667	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Customhouse Cove, 1 mile west of	AK
64408	Hid Reef, 2.7 miles south of, Nichols Passage, Alaska Current	NOS	PCT2871_1	55.03333	-131.66667	:America/Juneau	USA	knots	190	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:12:00	\N	0.2	-00:54:00	\N	0.2	-00:18:00	-00:40:00	Hid Reef, 2.7 miles south of	AK
64563	Port Heiden, Alaska Current	NOS	PCT5771_1	56.98333	-158.88333	:America/Anchorage	USA	knots	233	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:15:00	\N	0.4	-01:05:00	\N	0.4	-02:23:00	-01:14:00	Port Heiden	AK
64409	Point McCartey Light, Nichols Passage, Alaska Current	NOS	PCT2876_1	55.11667	-131.7	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1	-00:32:00	\N	0.6	-00:24:00	-00:42:00	Point McCartey Light	AK
64410	Wharburton Island, Nichols Passage, Alaska Current	NOS	PCT2891_1	55.1335	-131.62867	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.1	-00:32:00	\N	0.7	-00:24:00	-00:42:00	Wharburton Island	AK
64411	Driest Point, Nichols Passage, Alaska Current	NOS	PCT2896_1	55.18333	-131.6	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.9	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Driest Point	AK
64412	Blank Point, Nichols Passage, Alaska Current	NOS	PCT2911_1	55.24867	-131.66933	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	1.1	-00:22:00	\N	0.7	-00:14:00	-00:32:00	Blank Point	AK
64413	Point Sykes, Behm Canal, Alaska Current	NOS	PCT2921_1	55.2	-131.11667	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Point Sykes	AK
64414	Behm Narrows, Behm Canal, Alaska Current	NOS	PCT2936_1	55.91367	-131.532	:America/Juneau	USA	knots	264	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-02:58:00	\N	0.6	-03:07:00	\N	0.1	-01:41:00	-03:41:00	Behm Narrows	AK
64415	Helm Point, Behm Canal, Alaska Current	NOS	PCT2941_1	55.6	-131.83333	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.6	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Helm Point	AK
64416	Guard Islands, 2 miles northwest of, Behm Canal, Alaska Current	NOS	PCT2946_1	55.46667	-131.9	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Guard Islands, 2 miles northwest of	AK
64417	Grass Rock, 1 mile south of, Clarence Strait, Alaska Current	NOS	PCT2961_1	55	-131.55	:America/Juneau	USA	knots	235	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:22:00	\N	0.6	-00:29:00	\N	0.2	-00:24:00	-00:02:00	Grass Rock, 1 mile south of	AK
64418	Moira Rock, 2 miles east of, Clarence Strait, Alaska Current	NOS	PCT2966_1	55.08333	-131.93333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.7	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Moira Rock, 2 miles east of	AK
64419	Skin Island, 3 miles east from, Clarence Strait, Alaska Current	NOS	PCT2991_1	55.3	-131.98333	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Skin Island, 3 miles east from	AK
64420	Guard Island Lighthouse, 5.1 miles SW of, Clarence Strait, Alaska Current	NOS	PCT3011_1	55.4	-132	:America/Juneau	USA	knots	164	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:20:00	\N	0.3	-00:03:00	\N	0.2	00:06:00	-00:12:00	Guard Island Lighthouse, 5.1 miles SW of	AK
64421	Guard Islands, 2 miles west of, Clarence Strait, Alaska Current	NOS	PCT3016_1	55.45	-131.95	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Guard Islands, 2 miles west of	AK
64422	Ship Island, Clarence Strait, Alaska Current	NOS	PCT3021_1	55.6	-132.25	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.7	-00:22:00	\N	0.5	-00:14:00	-00:32:00	Ship Island	AK
64423	Narrow Point, Clarence Strait, Alaska Current	NOS	PCT3026_1	55.78333	-132.41667	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.7	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Narrow Point	AK
64424	Mabel Island, 3 miles west from, Clarence Strait, Alaska Current	NOS	PCT3031_1	55.91667	-132.5	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	0.7	-00:07:00	\N	0.5	00:01:00	-00:17:00	Mabel Island, 3 miles west from	AK
64425	Lincoln Rock Light, 1 mile west from, Clarence Strait, Alaska Current	NOS	PCT3036_1	56.05	-132.71667	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Lincoln Rock Light, 1 mile west from	AK
64426	McHenry Ledge, 1 mile north of, Ernest Sound, Alaska Current	NOS	PCT3041_1	55.8	-132.3	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	1	-00:17:00	\N	0.6	-00:09:00	-00:27:00	McHenry Ledge, 1 mile north of	AK
64427	Vixen Point, 3 miles west of, Ernest Sound, Alaska Current	NOS	PCT3046_1	55.85	-132.18333	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.8	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Vixen Point, 3 miles west of	AK
64429	Niblack Islands, Ernest Sound, Alaska Current	NOS	PCT3056_1	56.03333	-132.08333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.7	00:06:00	-00:12:00	Niblack Islands	AK
64430	Blanche Rock, Ernest Sound, Alaska Current	NOS	PCT3061_1	56.08333	-132.08333	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Blanche Rock	AK
64431	Point Warde, Ernest Sound, Alaska Current	NOS	PCT3066_1	56.18333	-131.96667	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	1	00:08:00	\N	0.6	00:16:00	-00:02:00	Point Warde	AK
64432	Blake Island, Alaska Current	NOS	PCT3071_1	56.223	-131.90883	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	1.2	00:13:00	\N	0.8	00:21:00	00:03:00	Blake Island	AK
64433	Berg Bay, Alaska Current	NOS	PCT3076_1	56.34367	-132.00767	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	1.1	00:18:00	\N	0.7	00:26:00	00:08:00	Berg Bay	AK
64434	The Narrows, Alaska Current	NOS	PCT3081_1	56.36783	-132.10267	:America/Juneau	USA	knots	45	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.4	00:23:00	\N	0.9	00:31:00	00:13:00	The Narrows	AK
64435	Channel Island, north of, Alaska Current	NOS	PCT3086_1	56.37517	-132.16967	:America/Juneau	USA	knots	320	140	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1	00:23:00	\N	0.6	00:31:00	00:13:00	Channel Island, north of	AK
64436	Mill Creek, Alaska Current	NOS	PCT3091_1	56.45	-132.21667	:America/Juneau	USA	knots	330	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	0.9	00:23:00	\N	0.6	00:31:00	00:13:00	Mill Creek	AK
64437	Point Highfield, Alaska Current	NOS	PCT3096_1	56.5	-132.38333	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.7	-00:02:00	\N	0.5	00:06:00	-00:12:00	Point Highfield	AK
64438	Found Island, 1 mile northwest of, Zimovia Strait, Alaska Current	NOS	PCT3101_1	56.11667	-132.1	:America/Juneau	USA	knots	140	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.8	00:03:00	\N	0.5	00:11:00	-00:07:00	Found Island, 1 mile northwest of	AK
64439	No Name Island, near Thoms Place, Zimovia Strait, Alaska Current	NOS	PCT3106_1	56.15	-132.15	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.8	00:08:00	\N	0.5	00:16:00	-00:02:00	No Name Island, near Thoms Place	AK
64440	Village Islands, Zimovia Strait, Alaska Current	NOS	PCT3111_1	56.21667	-132.31667	:America/Juneau	USA	knots	135	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	Village Islands	AK
64441	Young Rock, 2 miles south of, Zimovia Strait, Alaska Current	NOS	PCT3116_1	56.33333	-132.38333	:America/Juneau	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.8	00:13:00	\N	0.5	00:21:00	00:03:00	Young Rock, 2 miles south of	AK
64442	East Point, east of, Zimovia Strait, Alaska Current	NOS	PCT3121_1	56.38333	-132.4	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.8	-00:02:00	\N	0.5	00:06:00	-00:12:00	East Point, east of	AK
64443	Wrangell Harbor, 1.6 miles west of, Zimovia Strait, Alaska Current	NOS	PCT3131_1	56.46667	-132.45	:America/Juneau	USA	knots	235	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:33:00	\N	0.4	03:36:00	\N	0.3	02:28:00	02:16:00	Wrangell Harbor, 1.6 miles west of	AK
64444	Cape Muzon, 5 miles east of, Cordova Bay, Alaska Current	NOS	PCT3196_1	54.66667	-132.53333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	0.6	-00:47:00	\N	0.4	-00:39:00	-00:57:00	Cape Muzon, 5 miles east of	AK
64445	Dewey Rocks, 2 miles west of, Cordova Bay, Alaska Current	NOS	PCT3201_1	54.75	-132.53333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	0.5	-00:42:00	\N	0.3	-00:34:00	-00:52:00	Dewey Rocks, 2 miles west of	AK
64446	Boat Rocks, 2 miles west of, Cordova Bay, Alaska Current	NOS	PCT3211_1	54.81667	-132.56667	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	0.5	-00:42:00	\N	0.3	-00:34:00	-00:52:00	Boat Rocks, 2 miles west of	AK
64447	Webster Point, 1 mile west of, Cordova Bay, Alaska Current	NOS	PCT3221_1	54.96667	-132.63333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.8	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Webster Point, 1 mile west of	AK
64448	Mellen Rock, 1 mile east of, Cordova Bay, Alaska Current	NOS	PCT3226_1	55.03333	-132.65	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1	-00:32:00	\N	0.6	-00:24:00	-00:42:00	Mellen Rock, 1 mile east of	AK
64449	Shoe Rock, 1 mile north of, Tlevak Strait, Alaska Current	NOS	PCT3231_1	54.96667	-132.73333	:America/Juneau	USA	knots	105	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.8	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Shoe Rock, 1 mile north of	AK
64450	Grand Island, 2 miles north of, Tlevak Strait, Alaska Current	NOS	PCT3236_1	55	-132.86667	:America/Juneau	USA	knots	115	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.7	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Grand Island, 2 miles north of	AK
64451	High Point, 1 mile east of, Tlevak Strait, Alaska Current	NOS	PCT3241_1	55.01667	-132.93333	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.9	-00:32:00	\N	0.6	-00:24:00	-00:42:00	High Point, 1 mile east of	AK
64452	McFarland Islands, Tlevak Strait, Alaska Current	NOS	PCT3246_1	55.06667	-132.95	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.8	-00:27:00	\N	0.5	-00:19:00	-00:37:00	McFarland Islands	AK
64453	Corlies Islands, Tlevak Strait, Alaska Current	NOS	PCT3251_1	55.13333	-132.96667	:America/Juneau	USA	knots	165	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Corlies Islands	AK
64454	Sukkwan Narrows, Tlevak Strait, Alaska Current	NOS	PCT3256_1	55.19833	-132.824	:America/Juneau	USA	knots	130	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:09:00	\N	0.6	-00:45:00	\N	0.4	-00:29:00	-00:20:00	Sukkwan Narrows	AK
64455	The Sentinels, 1 mile west of, Tlevak Strait, Alaska Current	NOS	PCT3261_1	55.18333	-133.01667	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.8	-00:27:00	\N	0.5	-00:19:00	-00:37:00	The Sentinels, 1 mile west of	AK
64456	Meares Island, south of, Meares Passage, Alaska Current	NOS	PCT3281_1	55.25783	-133.18283	:America/Juneau	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.7	-00:19:00	-00:37:00	Meares Island, south of	AK
64457	Millar Rocks, Meares Passage, Alaska Current	NOS	PCT3291_1	55.2	-133.25	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.6	-00:37:00	\N	0.4	-00:29:00	-00:47:00	Millar Rocks	AK
64458	Diver Islands, Meares Passage, Alaska Current	NOS	PCT3296_1	55.18333	-133.28333	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.5	-00:37:00	\N	0.3	-00:29:00	-00:47:00	Diver Islands	AK
64460	Waterfall Cannery, Ulloa Channel, Alaska Current	NOS	PCT3311_1	55.3	-133.25	:America/Juneau	USA	knots	335	155	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Waterfall Cannery	AK
64461	Cape Bartolome, 2 miles east of, Alaska Current	NOS	PCT3316_1	55.23333	-133.55	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.6	-00:37:00	\N	0.4	-00:29:00	-00:47:00	Cape Bartolome, 2 miles east of	AK
64462	Point Arboleda, 1 mile west of, Alaska Current	NOS	PCT3326_1	55.31667	-133.48333	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.7	-00:32:00	\N	0.4	-00:24:00	-00:42:00	Point Arboleda, 1 mile west of	AK
64463	Cabras Islands, 1 mile west of, Alaska Current	NOS	PCT3331_1	55.35	-133.41667	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.6	-00:32:00	\N	0.4	-00:24:00	-00:42:00	Cabras Islands, 1 mile west of	AK
64464	Cape Flores, 1 mile north of, Alaska Current	NOS	PCT3336_1	55.36667	-133.3	:America/Juneau	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Cape Flores, 1 mile north of	AK
64465	Toti Island, 1.1 miles west of, Alaska Current	NOS	PCT3346_1	55.41667	-133.15	:America/Juneau	USA	knots	250	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Toti Island, 1.1 miles west of	AK
64466	Coronados Islands, 2 miles west of, Alaska Current	NOS	PCT3351_1	55.43333	-133.16667	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Coronados Islands, 2 miles west of	AK
64467	Craig Cannery, Alaska Current	NOS	PCT3356_1	55.48333	-133.15	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Craig Cannery	AK
64468	Tuxekan Passage, 0.2 mile S of Tuxekan, Alaska Current	NOS	PCT3456_1	55.88267	-133.24233	:America/Juneau	USA	knots	137	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-03:05:00	\N	0.2	-03:32:00	\N	0.3	-03:34:00	-01:42:00	Tuxekan Passage, 0.2 mile S of Tuxekan	AK
64469	Skookumchuck Pass, El Capitan Passage, Alaska Current	NOS	PCT3476_1	55.91467	-133.31233	:America/Juneau	USA	knots	207	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:03:00	\N	1	-00:19:00	\N	0.7	-00:06:00	-00:11:00	Skookumchuck Pass	AK
64470	Brockman Island, east of, El Capitan Passage, Alaska Current	NOS	PCT3481_1	55.96683	-133.30483	:America/Juneau	USA	knots	182	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:31:00	\N	0.2	00:43:00	\N	0.1	00:28:00	-00:13:00	Brockman Island, east of	AK
64471	Tenass Island, 0.3 mile  SSW of, El Capitan Passage, Alaska Current	NOS	PCT3491_1	55.98667	-133.30483	:America/Juneau	USA	knots	220	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:05:00	\N	0.3	-00:48:00	\N	0.2	00:06:00	-01:18:00	Tenass Island, 0.3 mile  SSW of	AK
64472	The Narrows, west of, Aneskett Point, El Capitan Passage, Alaska Current	NOS	PCT3506_1	56.16017	-133.338	:America/Juneau	USA	knots	248	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	05:37:00	\N	0.1	05:37:00	\N	0.2	04:57:00	05:54:00	The Narrows, west of	AK
64473	Cora Point, 2 miles east of, Sumner Strait, Alaska Current	NOS	PCT3521_1	55.91667	-134.05	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1	-00:42:00	\N	0.1	-00:34:00	-00:52:00	Cora Point, 2 miles east of	AK
64474	Point St. Albans, 3 miles SSE of, Sumner Strait, Alaska Current	NOS	PCT3551_1	56.03333	-133.95	:America/Juneau	USA	knots	232	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:28:00	\N	0.4	-01:14:00	\N	0.2	-00:05:00	-01:05:00	Point St. Albans, 3 miles SSE of	AK
64475	Point St. Albans, 4 miles east of, Sumner Strait, Alaska Current	NOS	PCT3556_1	56.08333	-133.85	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1	-00:37:00	\N	0.1	-00:29:00	-00:46:00	Point St. Albans, 4 miles east of	AK
64476	Ruins Point, 2 miles west of, Sumner Strait, Alaska Current	NOS	PCT3561_1	56.06667	-133.75	:America/Juneau	USA	knots	175	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:49:00	\N	0.3	00:38:00	\N	0.2	00:15:00	-00:48:00	Ruins Point, 2 miles west of	AK
64477	Shakan Light, 2.8 miles WNW of, Sumner Strait, Alaska Current	NOS	PCT3576_1	56.16667	-133.7	:America/Juneau	USA	knots	182	19	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:36:00	\N	0.3	-01:48:00	\N	0.2	-01:21:00	-01:34:00	Shakan Light, 2.8 miles WNW of	AK
64478	Beauclerc Island Light, 1 mile east of, Sumner Strait, Alaska Current	NOS	PCT3616_1	56.25	-133.81667	:America/Juneau	USA	knots	205	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:28:00	\N	0.4	-00:41:00	\N	0.1	00:09:00	-01:30:00	Beauclerc Island Light, 1 mile east of	AK
64479	Sumner Island, 1.8 miles south of, Sumner Strait, Alaska Current	NOS	PCT3636_1	56.36667	-133.81667	:America/Juneau	USA	knots	240	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	0.3	-03:33:00	\N	0.3	-02:39:00	-00:54:00	Sumner Island, 1.8 miles south of	AK
64480	Blaquiere Point, 1 mile SSW of, Sumner Strait, Alaska Current	NOS	PCT3681_1	56.55	-132.56667	:America/Juneau	USA	knots	240	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:23:00	\N	0.5	00:23:00	\N	0.3	-00:08:00	-00:20:00	Blaquiere Point, 1 mile SSW of	AK
64481	Southern entrance to Keku Strait, Keku Strait, Alaska Current	NOS	PCT3701_1	56.56667	-133.71667	:America/Juneau	USA	knots	184	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:32:00	\N	0.6	00:13:00	\N	0.3	00:57:00	-00:25:00	Southern entrance to Keku Strait	AK
64482	Eagle Island, 0.5 mile southeast of, Keku Strait, Alaska Current	NOS	PCT3706_1	56.60733	-133.68217	:America/Juneau	USA	knots	130	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:43:00	\N	1	-00:24:00	\N	0.5	-00:04:00	-00:49:00	Eagle Island, 0.5 mile southeast of	AK
64483	Devils Elbow, Keku Strait, Alaska Current	NOS	PCT3711_1	56.63617	-133.6895	:America/Juneau	USA	knots	90	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:13:00	\N	0.8	-00:09:00	\N	0.8	-00:18:00	-00:41:00	Devils Elbow	AK
64484	Summit Island, west of, Keku Strait, Alaska Current	NOS	PCT3716_1	56.6765	-133.7325	:America/Juneau	USA	knots	10	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:46:00	\N	1.2	01:43:00	\N	0.7	01:48:00	02:10:00	Summit Island, west of	AK
64485	High Island, 1.1 miles south of, Keku Strait, Alaska Current	NOS	PCT3721_1	56.70233	-133.733	:America/Juneau	USA	knots	10	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:30:00	\N	0.5	00:40:00	\N	0.3	00:40:00	00:28:00	High Island, 1.1 miles south of	AK
64486	High Island, northwest of, Keku Strait, Alaska Current	NOS	PCT3726_1	56.75	-133.73333	:America/Juneau	USA	knots	325	210	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:18:00	\N	0.4	00:49:00	\N	0.3	00:07:00	00:34:00	High Island, northwest of	AK
64487	Cucumber Reef, 0.2 mile northwest of, Keku Strait, Alaska Current	NOS	PCT3731_1	56.79	-133.767	:America/Juneau	USA	knots	325	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:11:00	\N	0.8	00:16:00	\N	0.4	00:11:00	00:04:00	Cucumber Reef, 0.2 mile northwest of	AK
64488	Point Alexander, Wrangell Narrows, Alaska Current	NOS	PCT3741_1	56.51033	-132.95833	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.5	-00:02:00	\N	0.3	00:06:00	-00:12:00	Point Alexander	AK
64489	Point Deception, Wrangell Narrows, Alaska Current	NOS	PCT3746_1	56.53333	-132.96667	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.5	-00:02:00	\N	0.3	00:06:00	-00:12:00	Point Deception	AK
64490	Point Lockwood, Wrangell Narrows, Alaska Current	NOS	PCT3751_1	56.55583	-132.96183	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.4	-00:02:00	\N	0.9	00:06:00	-00:12:00	Point Lockwood	AK
64491	Spike Rock, Wrangell Narrows, Alaska Current	NOS	PCT3756_1	56.601	-132.976	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	2.1	-00:02:00	\N	1.5	00:06:00	-00:12:00	Spike Rock	AK
64492	Anchor Point, Wrangell Narrows, Alaska Current	NOS	PCT3766_1	56.6395	-132.93117	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.6	-00:02:00	\N	1.1	00:06:00	-00:12:00	Anchor Point	AK
64493	Vexation Point, Woody Island, Wrangell Narrows, Alaska Current	NOS	PCT3771_1	56.65783	-132.927	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.2	-00:02:00	\N	0.8	00:06:00	-00:12:00	Vexation Point, Woody Island	AK
64494	Green Point, Wrangell Narrows, Alaska Current	NOS	PCT3781_1	56.7	-132.95	:America/Juneau	USA	knots	5	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.5	00:03:00	\N	0.3	00:11:00	-00:07:00	Green Point	AK
64495	Mountain Point, Wrangell Narrows, Alaska Current	NOS	PCT3786_1	56.73333	-132.95	:America/Juneau	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	1	00:13:00	\N	0.6	00:21:00	00:03:00	Mountain Point	AK
64496	Blunt Point, Wrangell Narrows, Alaska Current	NOS	PCT3791_1	56.77833	-132.97933	:America/Juneau	USA	knots	340	160	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.6	00:23:00	\N	1.1	00:31:00	00:13:00	Blunt Point	AK
64497	Turn Point, Wrangell Narrows, Alaska Current	NOS	PCT3796_1	56.80783	-132.9835	:America/Juneau	USA	knots	40	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.8	00:23:00	\N	1.4	00:31:00	00:13:00	Turn Point	AK
64498	Prolewy Rocks, Wrangell Narrows, Alaska Current	NOS	PCT3806_1	56.82233	-132.94833	:America/Juneau	USA	knots	60	240	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.6	00:23:00	\N	1.1	00:31:00	00:13:00	Prolewy Rocks	AK
64499	Cosmos Point, 0.5 mile east of, Frederick Sound, Alaska Current	NOS	PCT3811_1	56.66667	-132.6	:America/Juneau	USA	knots	305	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:42:00	\N	0.2	01:15:00	\N	0.1	01:55:00	00:25:00	Cosmos Point, 0.5 mile east of	AK
64500	The Brothers, 2 miles east of, Stephens Passage, Alaska Current	NOS	PCT3826_1	57.3	-133.71667	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.5	00:03:00	\N	0.3	00:11:00	-00:07:00	The Brothers, 2 miles east of	AK
64501	Point Gambier, 2 miles east of, Stephens Passage, Alaska Current	NOS	PCT3841_1	57.43333	-133.76667	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.2	00:08:00	\N	0.2	00:16:00	-00:02:00	Point Gambier, 2 miles east of	AK
64502	Point Hugh, Stephens Passage, Alaska Current	NOS	PCT3846_1	57.61667	-133.76667	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.5	00:13:00	\N	0.3	00:21:00	00:03:00	Point Hugh	AK
64503	Midway Island, Stephens Passage, Alaska Current	NOS	PCT3866_1	57.83333	-133.83333	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.5	00:13:00	\N	0.3	00:21:00	00:03:00	Midway Island	AK
64504	Point Arden, Stephens Passage, Alaska Current	NOS	PCT3876_1	58.15	-134.13333	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	0.5	00:18:00	\N	0.3	00:26:00	00:08:00	Point Arden	AK
64505	0.2 mile off Flat Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3896_1	58.33333	-134.05	:America/Juneau	USA	knots	200	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:07:00	\N	0.5	00:11:00	\N	0.2	00:48:00	-00:12:00	0.2 mile off Flat Point	AK
64562	Johnston Channel, off Halftide Rock, Alaska Current	NOS	PCT5766_1	55.83333	-160.78333	:America/Anchorage	USA	knots	337	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:24:00	\N	0.5	-04:45:00	\N	0.5	-04:27:00	-05:15:00	Johnston Channel, off Halftide Rock	AK
64506	0.2 mile off Taku Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3901_1	58.4	-134.01667	:America/Juneau	USA	knots	203	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:08:00	\N	0.4	00:34:00	\N	0.4	00:53:00	00:10:00	0.2 mile off Taku Point	AK
64507	Douglas, north of (Depth 15ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_1	58.283	-134.39367	:America/Juneau	USA	knots	144	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:32:00	\N	0.2	00:44:00	\N	0.1	02:12:00	00:11:00	Douglas, north of	AK
64508	Douglas, north of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_2	58.283	-134.39367	:America/Juneau	USA	knots	136	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:08:00	\N	0.3	00:41:00	\N	0.1	01:33:00	00:27:00	Douglas, north of	AK
64509	Juneau Harbor, S of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3921_1	58.29117	-134.407	:America/Juneau	USA	knots	102	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:05:00	\N	0.3	02:03:00	\N	0.1	03:19:00	00:34:00	Juneau Harbor, S of	AK
64510	West Juneau, NE of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3936_1	58.29633	-134.4245	:America/Juneau	USA	knots	137	314	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:21:00	\N	0.2	00:49:00	\N	0.1	00:24:00	00:32:00	West Juneau, NE of	AK
64511	Aurora Basin, SW of (Depth 15ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3946_1	58.305	-134.44083	:America/Juneau	USA	knots	163	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:51:00	\N	0.4	00:34:00	\N	0.2	01:01:00	00:10:00	Aurora Basin, SW of	AK
64512	Hazy Islands, Chatham Strait, Alaska Current	NOS	PCT4056_1	55.88333	-134.6	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Hazy Islands	AK
64513	Cape Ommaney Light, 5 miles east of, Chatham Strait, Alaska Current	NOS	PCT4061_1	56.16667	-134.51667	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Cape Ommaney Light, 5 miles east of	AK
64514	Port Walter Light, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4066_1	56.38333	-134.53333	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.7	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Port Walter Light, 3 miles east of	AK
64515	Point Ellis, 4 miles west of, Chatham Strait, Alaska Current	NOS	PCT4071_1	56.56667	-134.45	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.7	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Point Ellis, 4 miles west of	AK
64516	Kingsmill Point Light, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4076_1	56.83333	-134.51667	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	1	-00:07:00	\N	0.6	00:01:00	-00:17:00	Kingsmill Point Light, 3 miles west of	AK
64517	Point Gardner Light, 2 miles west of, Chatham Strait, Alaska Current	NOS	PCT4081_1	57.01667	-134.66667	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Gardner Light, 2 miles west of	AK
64518	Point Caution, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4086_1	57.25	-134.73333	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Point Caution, 3 miles west of	AK
64519	Point Thatcher, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4091_1	57.41667	-134.73333	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Point Thatcher, 3 miles east of	AK
64520	Danger Point Light, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4101_1	57.51667	-134.7	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	Danger Point Light, 3 miles west of	AK
64521	Turn Point, Kootznahoo Inlet, Chatham Strait, Alaska Current	NOS	PCT4106_1	57.5	-134.58333	:America/Juneau	USA	knots	285	105	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:09:00	\N	2.9	00:48:00	\N	2.2	00:56:00	00:38:00	Turn Point, Kootznahoo Inlet	AK
64522	South Passage Point, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4111_1	57.76667	-134.83333	:America/Juneau	USA	knots	355	175	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	South Passage Point, 3 miles east of	AK
64523	Point Augusta, ESE of (Depth 70ft), Chatham Strait, Alaska Current	NOS	PCT4116_1	58.025	-134.87333	:America/Juneau	USA	knots	164	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.3	-00:04:00	\N	0.2	-00:02:00	00:01:00	Point Augusta, ESE of	AK
64524	Biorka Channel, Sitka Sound, Alaska Current	NOS	PCT4131_1	56.83333	-135.5	:America/Juneau	USA	knots	232	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:13:00	\N	0.2	00:20:00	\N	0.1	00:47:00	00:15:00	Biorka Channel	AK
64525	Sitka Harbor, channel off Harbor Island, Sitka Sound, Alaska Current	NOS	PCT4166_1	57.05	-135.33333	:America/Juneau	USA	knots	156	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	0.2	-01:17:00	\N	0.1	-00:58:00	-02:02:00	Sitka Harbor, channel off Harbor Island	AK
64526	West Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4171_1	57.15	-135.58333	:America/Juneau	USA	knots	64	242	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:30:00	\N	0.5	-00:51:00	\N	0.4	-00:43:00	-01:01:00	West Channel (narrows)	AK
64527	East Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4176_1	57.16667	-135.55	:America/Juneau	USA	knots	229	51	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:23:00	\N	0.7	-00:32:00	\N	0.4	-00:30:00	-00:48:00	East Channel (narrows)	AK
64528	Allan Pt., 1.5mile W of, Nakwasina Passage, Alaska Current	NOS	PCT4191_1	57.25	-135.43333	:America/Juneau	USA	knots	82	260	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:40:00	\N	0.8	-01:06:00	\N	0.6	-01:06:00	-00:59:00	Allan Pt., 1.5mile W of, Nakwasina Passage	AK
64529	Wyvill Reef, Neva Strait, Alaska Current	NOS	PCT4211_1	57.26667	-135.58333	:America/Juneau	USA	knots	323	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:13:00	\N	0.7	-00:30:00	\N	0.5	-00:27:00	-00:04:00	Wyvill Reef	AK
64530	Highwater Island, west of, Neva Strait, Alaska Current	NOS	PCT4216_1	57.28333	-135.6	:America/Juneau	USA	knots	330	144	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:34:00	\N	0.7	-00:29:00	\N	0.3	-00:15:00	-00:11:00	Highwater Island, west of	AK
64531	Sea Rock, 1 mile north of, Salisbury Sound, Alaska Current	NOS	PCT4236_1	57.35	-135.88333	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Sea Rock, 1 mile north of	AK
64532	Kalinin Point, 1 mile north of, Salisbury Sound, Alaska Current	NOS	PCT4241_1	57.35	-135.8	:America/Juneau	USA	knots	260	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Kalinin Point, 1 mile north of	AK
64533	Sinitsin Island, Salisbury Sound, Alaska Current	NOS	PCT4246_1	57.35	-135.76667	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Sinitsin Island	AK
64534	Otstoia Island Light, 1 mile north of, Peril Strait, Alaska Current	NOS	PCT4286_1	57.58333	-135.45	:America/Juneau	USA	knots	100	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Otstoia Island Light, 1 mile north of	AK
64535	Nismeni Point, 1 mile north of, Peril Strait, Alaska Current	NOS	PCT4291_1	57.58333	-135.41667	:America/Juneau	USA	knots	105	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Nismeni Point, 1 mile north of	AK
64536	Peschani Point, 1 mile east of, Peril Strait, Alaska Current	NOS	PCT4296_1	57.53333	-135.3	:America/Juneau	USA	knots	145	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Peschani Point, 1 mile east of	AK
64537	Point Elizabeth, 1 mile northeast of, Peril Strait, Alaska Current	NOS	PCT4301_1	57.51667	-135.26667	:America/Juneau	USA	knots	135	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Elizabeth, 1 mile northeast of	AK
64538	Point Benham, 1 mile east of, Peril Strait, Alaska Current	NOS	PCT4306_1	57.48333	-135.18333	:America/Juneau	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Benham, 1 mile east of	AK
64539	False Linderberg Head, 1 mile south of, Peril Strait, Alaska Current	NOS	PCT4311_1	57.45	-135.08333	:America/Juneau	USA	knots	125	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	False Linderberg Head, 1 mile south of	AK
64540	Lindenberg Head, Peril Strait, Alaska Current	NOS	PCT4316_1	57.45	-135.03333	:America/Juneau	USA	knots	100	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Lindenberg Head	AK
64541	Eva Islands, Peril Strait, Alaska Current	NOS	PCT4321_1	57.45	-134.93333	:America/Juneau	USA	knots	95	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.6	00:03:00	\N	0.4	00:11:00	-00:07:00	Eva Islands	AK
64542	Fairway Island, Peril Strait, Alaska Current	NOS	PCT4326_1	57.45	-134.88333	:America/Juneau	USA	knots	85	265	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Fairway Island	AK
64543	Morris Reef, south of, Peril Strait, Alaska Current	NOS	PCT4331_1	57.45	-134.81667	:America/Juneau	USA	knots	95	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Morris Reef, south of	AK
64544	Claybluff Point Light, 3.5 nmi. south of (Depth 75ft), Icy Bay, Alaska Current	NOS	PCT4406_1	59.91	-141.595	:America/Anchorage	USA	knots	209	104	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:20:00	\N	0.2	-02:09:00	\N	0.2	-03:02:00	-03:14:00	Claybluff Point Light, 3.5 nmi. south of	AK
64545	Claybluff Point Light, 2.3 nmi. SE of (Depth 206ft), Icy Bay, Alaska Current	NOS	PCT4411_1	59.94667	-141.52	:America/Anchorage	USA	knots	215	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:14:00	\N	0.1	-02:44:00	\N	0.1	-03:10:00	-03:17:00	Claybluff Point Light, 2.3 nmi. SE of	AK
64546	Carson Creek Entrance, 1.4 nmi. ESE of (Depth 15ft), Icy Bay, Alaska Current	NOS	PCT4416_1	59.98333	-141.47	:America/Anchorage	USA	knots	164	71	IGNORE VELOCITIES	Velocities for this station should be disregarded--use times only.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:09:00	\N	0.001	-00:36:00	\N	0.2	-04:48:00	-00:20:00	Carson Creek Entrance, 1.4 nmi. ESE of	AK
64547	Carson Creek Entrance, 3.3 nmi. SE of (Depth 78ft), Icy Bay, Alaska Current	NOS	PCT4421_1	59.97	-141.41333	:America/Anchorage	USA	knots	232	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:03:00	\N	0.2	-01:45:00	\N	0.3	-02:49:00	-01:03:00	Carson Creek Entrance, 3.3 nmi. SE of	AK
64548	Carson Creek Entrance, 2.4 nmi. ESE of (Depth 50ft), Icy Bay, Alaska Current	NOS	PCT4426_1	59.98667	-141.43667	:America/Anchorage	USA	knots	244	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:06:00	\N	0.3	-01:38:00	\N	0.2	-03:00:00	-02:24:00	Carson Creek Entrance, 2.4 nmi. ESE of	AK
64549	Wingham Island, off northeast corner, Controller Bay, Alaska Current	NOS	PCT4436_1	60.05	-144.38333	:America/Anchorage	USA	knots	288	68	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:06:00	\N	0.6	01:11:00	\N	0.5	00:42:00	00:46:00	Wingham Island, off northeast corner	AK
64550	Kanak Island, southeast of, Controller Bay, Alaska Current	NOS	PCT4441_1	60.08333	-144.3	:America/Anchorage	USA	knots	255	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:53:00	\N	1	00:37:00	\N	0.5	00:58:00	00:38:00	Kanak Island, southeast of	AK
64551	Popof Strait, Shumagin Islands, Alaska Current	NOS	PCT5406_1	55.33333	-160.51667	:America/Anchorage	USA	knots	199	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:11:00	\N	0.2	-02:05:00	\N	0.1	-02:32:00	-01:28:00	Popof Strait	AK
64552	Unga Strait (1.4 miles N of Unga Spit), Shumagin Islands, Alaska Current	NOS	PCT5411_1	55.43333	-160.73333	:America/Anchorage	USA	knots	114	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	05:06:00	\N	0.1	05:42:00	\N	0.5	05:24:00	05:24:00	Unga Strait (1.4 miles N of Unga Spit)	AK
64553	Amak Island, 5 miles north of, Alaska Current	NOS	PCT5426_1	55.5	-163.16667	:America/Nome	USA	knots^2	139	337	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	05:09:00	\N	0.2	05:31:00	\N	0.2	04:52:00	04:50:00	Amak Island, 5 miles north of	AK
64554	Amak Island, 5 miles southeast of, Alaska Current	NOS	PCT5431_1	55.35	-163.01667	:America/Nome	USA	knots^2	200	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	04:35:00	\N	0.2	04:45:00	\N	0.2	04:24:00	04:32:00	Amak Island, 5 miles southeast of	AK
64555	Otter Point, off of, north side, Unimak Island, Alaska Current	NOS	PCT5441_1	55.06667	-163.78333	:America/Nome	USA	knots^2	258	89	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	03:53:00	\N	0.3	03:36:00	\N	0.2	03:36:00	03:35:00	Otter Point, off of, north side	AK
64556	Bechevin Bay, off Rocky Point, Isanotski Strait, Alaska Current	NOS	PCT5451_1	54.98333	-163.43333	:America/Nome	USA	knots^2	139	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	00:02:00	\N	0.5	-00:26:00	\N	0.5	-00:55:00	00:14:00	Bechevin Bay, off Rocky Point	AK
64557	Cape Lieskof, 3 miles west of, Aleutian Islands, Alaska Current	NOS	PCT5741_1	55.75	-162.2	:America/Nome	USA	knots	248	56	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:53:00	\N	0.3	-04:39:00	\N	0.3	-05:39:00	-04:38:00	Cape Lieskof, 3 miles west of	AK
64558	Entrance Point, 3 miles west of, Port Moller, Alaska Current	NOS	PCT5746_1	56	-160.65	:America/Anchorage	USA	knots	2	174	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:34:00	\N	0.8	-04:28:00	\N	0.7	-05:04:00	-04:06:00	Entrance Point, 3 miles west of	AK
64559	Entrance Point, Port Moller, Alaska Current	NOS	PCT5751_1	55.98333	-160.58333	:America/Anchorage	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-05:27:00	\N	0.6	-04:53:00	\N	0.5	-04:57:00	-05:06:00	Entrance Point	AK
64560	Harbor Point, Port Moller, Alaska Current	NOS	PCT5756_1	55.91667	-160.6	:America/Anchorage	USA	knots	335	158	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:26:00	\N	0.8	-04:03:00	\N	0.4	-04:28:00	-04:59:00	Harbor Point	AK
64561	Hague Channel, east of Doe Point, Alaska Current	NOS	PCT5761_1	55.9	-160.76667	:America/Anchorage	USA	knots	33	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-05:21:00	\N	0.6	-04:39:00	\N	0.9	-05:59:00	-04:23:00	Hague Channel, east of Doe Point	AK
64564	Morakas Point, Naknek River, Kvichak Bay, Alaska Current	NOS	PCT5781_1	58.73333	-156.93333	:America/Anchorage	USA	knots	294	111	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	01:15:00	\N	0.9	01:05:00	\N	0.5	02:01:00	00:04:00	Morakas Point, Naknek River	AK
64565	Cape Constantine, 4 miles Southeast of, Alaska Current	NOS	PCT5791_1	58.33333	-158.76667	:America/Anchorage	USA	knots	238	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:52:00	\N	0.7	-01:38:00	\N	0.6	-02:08:00	-01:05:00	Cape Constantine, 4 miles Southeast of	AK
64566	Protection Point, 2.5 miles east of, Alaska Current	NOS	PCT5796_1	58.5	-158.61667	:America/Anchorage	USA	knots	180	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:04:00	\N	1	-01:25:00	\N	1	-00:44:00	-00:40:00	Protection Point, 2.5 miles east of	AK
64567	Nushagak Bay entrance, Alaska Current	NOS	PCT5801_1	58.56667	-158.41667	:America/Anchorage	USA	knots	180	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-00:23:00	\N	1	00:03:00	\N	1	-00:59:00	00:19:00	Nushagak Bay entrance	AK
64568	Etolin Point, 8.5 miles west of, Alaska Current	NOS	PCT5806_1	58.63333	-158.58333	:America/Anchorage	USA	knots	173	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	00:05:00	\N	1.2	00:13:00	\N	0.9	-00:19:00	00:08:00	Etolin Point, 8.5 miles west of	AK
64569	Clarks Point, 1 mile west of, Alaska Current	NOS	PCT5811_1	58.83333	-158.58333	:America/Anchorage	USA	knots	213	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-00:02:00	\N	1.4	00:34:00	\N	1.3	-00:07:00	00:41:00	Clarks Point, 1 mile west of	AK
64570	Goodnews Bay entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5821_1	59.06667	-161.78333	:America/Anchorage	USA	knots	213	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-06:02:00	\N	0.9	-06:05:00	\N	0.9	-06:23:00	-05:26:00	Goodnews Bay entrance	AK
64571	Carter Bay, west of, Kuskokwim Bay, Alaska Current	NOS	PCT5826_1	59.28333	-162.36667	:America/Nome	USA	knots	212	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:21:00	\N	0.6	-04:29:00	\N	0.6	-05:10:00	-03:44:00	Carter Bay, west of	AK
64572	Warehouse Bluff, southwest of, Kuskokwim Bay, Alaska Current	NOS	PCT5831_1	59.78333	-162.23333	:America/Nome	USA	knots	188	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:45:00	\N	0.8	-03:21:00	\N	0.6	-03:43:00	-03:21:00	Warehouse Bluff, southwest of	AK
64573	Apokak Creek entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5836_1	60.13333	-162.16667	:America/Nome	USA	knots	205	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:51:00	\N	1.1	-03:42:00	\N	1.1	-05:04:00	-02:04:00	Apokak Creek entrance	AK
64574	Walrus Island, 0.5 mile west of, Pribilof Islands, Alaska Current	NOS	PCT5841_1	57.18333	-169.95	:America/Nome	USA	knots	210	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-06:38:00	\N	0.5	-06:47:00	\N	0.4	-06:40:00	-06:40:00	Walrus Island, 0.5 mile west of	AK
64575	SW Point, St. Paul Island, 1 mile off, Pribilof Islands, Alaska Current	NOS	PCT5861_1	57.15	-170.45	:America/Nome	USA	knots	170	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-08:10:00	\N	0.3	-08:10:00	\N	0.8	-08:55:00	-08:55:00	SW Point, St. Paul Island, 1 mile off	AK
64576	Hooper Bay entrance, Alaska Current	NOS	PCT5866_1	61.5	-166.05	:America/Nome	USA	knots	223	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	11:03:00	\N	0.8	11:16:00	\N	0.7	10:08:00	11:14:00	Hooper Bay entrance	AK
64577	St. Mathew I., southwest coast, Alaska Current	NOS	PCT5871_1	60.35	-172.71667	:America/Nome	USA	knots	119	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	03:07:00	\N	0.4	03:20:00	\N	0.5	02:24:00	03:29:00	St. Mathew I., southwest coast	AK
64578	Apavawook Cape, 1 mile south of, St. Lawrence Island, Alaska Current	NOS	PCT5881_1	63.11667	-168.93333	:America/Adak	USA	knots	272	75	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:23:00	\N	0.4	-02:14:00	\N	0.2	-02:58:00	-02:39:00	Apavawook Cape, 1 mile south of	AK
64579	Off Northeast Cape, St. Lawrence Island, Alaska Current	NOS	PCT5886_1	63.33333	-168.83333	:America/Adak	USA	knots	258	95	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	00:10:00	\N	0.3	00:57:00	\N	0.3	-00:41:00	01:16:00	Off Northeast Cape	AK
64580	Agate Passage, south end (Depth 25.1ft), Washington Current	NOS	PUG1501_1	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	21	200	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64581	Agate Passage, south end (Depth 21.9ft), Washington Current	NOS	PUG1501_2	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64582	Agate Passage, south end (Depth 18.6ft), Washington Current	NOS	PUG1501_3	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64583	Agate Passage, south end (Depth 15.3ft), Washington Current	NOS	PUG1501_4	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64584	Agate Passage, south end (Depth 12ft), Washington Current	NOS	PUG1501_5	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64585	Agate Passage, south end (Depth 8.7ft), Washington Current	NOS	PUG1501_6	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	16	203	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64586	Agate Passage, south end (Depth 5.4ft), Washington Current	NOS	PUG1501_7	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64587	Agate Passage, south end (Depth 2.2ft), Washington Current	NOS	PUG1501_8	47.7110214233398	-122.567146301269	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
64588	Alki Point, 1 mile west of (Depth 640.5ft), Washington Current	NOS	PUG1502_1	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64589	Alki Point, 1 mile west of (Depth 627.4ft), Washington Current	NOS	PUG1502_2	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64590	Alki Point, 1 mile west of (Depth 614.2ft), Washington Current	NOS	PUG1502_3	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64591	Alki Point, 1 mile west of (Depth 601.1ft), Washington Current	NOS	PUG1502_4	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64592	Alki Point, 1 mile west of (Depth 588ft), Washington Current	NOS	PUG1502_5	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64593	Alki Point, 1 mile west of (Depth 574.9ft), Washington Current	NOS	PUG1502_6	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64594	Alki Point, 1 mile west of (Depth 561.7ft), Washington Current	NOS	PUG1502_7	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64595	Alki Point, 1 mile west of (Depth 548.6ft), Washington Current	NOS	PUG1502_8	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64596	Alki Point, 1 mile west of (Depth 535.5ft), Washington Current	NOS	PUG1502_9	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64597	Alki Point, 1 mile west of (Depth 522.4ft), Washington Current	NOS	PUG1502_10	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64598	Alki Point, 1 mile west of (Depth 509.3ft), Washington Current	NOS	PUG1502_11	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64599	Alki Point, 1 mile west of (Depth 496.1ft), Washington Current	NOS	PUG1502_12	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64600	Alki Point, 1 mile west of (Depth 483ft), Washington Current	NOS	PUG1502_13	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	8	189	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64601	Alki Point, 1 mile west of (Depth 469.9ft), Washington Current	NOS	PUG1502_14	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64602	Alki Point, 1 mile west of (Depth 456.8ft), Washington Current	NOS	PUG1502_15	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64603	Alki Point, 1 mile west of (Depth 443.6ft), Washington Current	NOS	PUG1502_16	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64604	Alki Point, 1 mile west of (Depth 430.5ft), Washington Current	NOS	PUG1502_17	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64605	Alki Point, 1 mile west of (Depth 417.4ft), Washington Current	NOS	PUG1502_18	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64606	Alki Point, 1 mile west of (Depth 404.3ft), Washington Current	NOS	PUG1502_19	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64607	Alki Point, 1 mile west of (Depth 391.1ft), Washington Current	NOS	PUG1502_20	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64608	Alki Point, 1 mile west of (Depth 378ft), Washington Current	NOS	PUG1502_21	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64609	Alki Point, 1 mile west of (Depth 364.9ft), Washington Current	NOS	PUG1502_22	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64610	Alki Point, 1 mile west of (Depth 351.8ft), Washington Current	NOS	PUG1502_23	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64611	Alki Point, 1 mile west of (Depth 338.6ft), Washington Current	NOS	PUG1502_24	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64612	Alki Point, 1 mile west of (Depth 325.5ft), Washington Current	NOS	PUG1502_25	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64613	Alki Point, 1 mile west of (Depth 312.4ft), Washington Current	NOS	PUG1502_26	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64614	Alki Point, 1 mile west of (Depth 299.3ft), Washington Current	NOS	PUG1502_27	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64615	Alki Point, 1 mile west of (Depth 286.2ft), Washington Current	NOS	PUG1502_28	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64616	Alki Point, 1 mile west of (Depth 273ft), Washington Current	NOS	PUG1502_29	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64617	Alki Point, 1 mile west of (Depth 259.9ft), Washington Current	NOS	PUG1502_30	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64618	Alki Point, 1 mile west of (Depth 246.8ft), Washington Current	NOS	PUG1502_31	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64619	Alki Point, 1 mile west of (Depth 233.7ft), Washington Current	NOS	PUG1502_32	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64620	Alki Point, 1 mile west of (Depth 220.5ft), Washington Current	NOS	PUG1502_33	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64621	Alki Point, 1 mile west of (Depth 207.4ft), Washington Current	NOS	PUG1502_34	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64622	Alki Point, 1 mile west of (Depth 194.3ft), Washington Current	NOS	PUG1502_35	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	359	187	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64623	Alki Point, 1 mile west of (Depth 181.2ft), Washington Current	NOS	PUG1502_36	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64624	Alki Point, 1 mile west of (Depth 168ft), Washington Current	NOS	PUG1502_37	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64625	Alki Point, 1 mile west of (Depth 154.9ft), Washington Current	NOS	PUG1502_38	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64626	Alki Point, 1 mile west of (Depth 141.8ft), Washington Current	NOS	PUG1502_39	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64627	Alki Point, 1 mile west of (Depth 128.7ft), Washington Current	NOS	PUG1502_40	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64628	Alki Point, 1 mile west of (Depth 115.6ft), Washington Current	NOS	PUG1502_41	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.247	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64629	Alki Point, 1 mile west of (Depth 102.4ft), Washington Current	NOS	PUG1502_42	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64630	Alki Point, 1 mile west of (Depth 89.3ft), Washington Current	NOS	PUG1502_43	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64631	Alki Point, 1 mile west of (Depth 76.2ft), Washington Current	NOS	PUG1502_44	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	31	201	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.325	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64632	Alki Point, 1 mile west of (Depth 63.1ft), Washington Current	NOS	PUG1502_45	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.337	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64633	Alki Point, 1 mile west of (Depth 49.9ft), Washington Current	NOS	PUG1502_46	47.5836791992187	-122.451751708984	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.335	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile west of	WA
64634	Edmonds, 2.5 miles west of (Depth 500.4ft), Washington Current	NOS	PUG1503_1	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64635	Edmonds, 2.5 miles west of (Depth 487.2ft), Washington Current	NOS	PUG1503_2	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64636	Edmonds, 2.5 miles west of (Depth 474.1ft), Washington Current	NOS	PUG1503_3	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64637	Edmonds, 2.5 miles west of (Depth 461ft), Washington Current	NOS	PUG1503_4	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64638	Edmonds, 2.5 miles west of (Depth 447.9ft), Washington Current	NOS	PUG1503_5	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64639	Edmonds, 2.5 miles west of (Depth 434.7ft), Washington Current	NOS	PUG1503_6	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64640	Edmonds, 2.5 miles west of (Depth 421.6ft), Washington Current	NOS	PUG1503_7	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64641	Edmonds, 2.5 miles west of (Depth 408.5ft), Washington Current	NOS	PUG1503_8	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64642	Edmonds, 2.5 miles west of (Depth 395.4ft), Washington Current	NOS	PUG1503_9	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64643	Edmonds, 2.5 miles west of (Depth 382.3ft), Washington Current	NOS	PUG1503_10	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64644	Edmonds, 2.5 miles west of (Depth 369.1ft), Washington Current	NOS	PUG1503_11	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64645	Edmonds, 2.5 miles west of (Depth 356ft), Washington Current	NOS	PUG1503_12	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64646	Edmonds, 2.5 miles west of (Depth 342.9ft), Washington Current	NOS	PUG1503_13	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64647	Edmonds, 2.5 miles west of (Depth 329.8ft), Washington Current	NOS	PUG1503_14	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64648	Edmonds, 2.5 miles west of (Depth 316.6ft), Washington Current	NOS	PUG1503_15	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	346	167	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64649	Edmonds, 2.5 miles west of (Depth 303.5ft), Washington Current	NOS	PUG1503_16	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64650	Edmonds, 2.5 miles west of (Depth 290.4ft), Washington Current	NOS	PUG1503_17	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64651	Edmonds, 2.5 miles west of (Depth 277.3ft), Washington Current	NOS	PUG1503_18	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64652	Edmonds, 2.5 miles west of (Depth 264.1ft), Washington Current	NOS	PUG1503_19	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64654	Edmonds, 2.5 miles west of (Depth 237.9ft), Washington Current	NOS	PUG1503_21	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64655	Edmonds, 2.5 miles west of (Depth 224.8ft), Washington Current	NOS	PUG1503_22	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64656	Edmonds, 2.5 miles west of (Depth 211.6ft), Washington Current	NOS	PUG1503_23	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64657	Edmonds, 2.5 miles west of (Depth 198.5ft), Washington Current	NOS	PUG1503_24	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64658	Edmonds, 2.5 miles west of (Depth 185.4ft), Washington Current	NOS	PUG1503_25	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64659	Edmonds, 2.5 miles west of (Depth 172.3ft), Washington Current	NOS	PUG1503_26	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64660	Edmonds, 2.5 miles west of (Depth 159.2ft), Washington Current	NOS	PUG1503_27	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64661	Edmonds, 2.5 miles west of (Depth 146ft), Washington Current	NOS	PUG1503_28	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64662	Edmonds, 2.5 miles west of (Depth 132.9ft), Washington Current	NOS	PUG1503_29	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	355	161	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64663	Edmonds, 2.5 miles west of (Depth 119.8ft), Washington Current	NOS	PUG1503_30	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64664	Edmonds, 2.5 miles west of (Depth 106.7ft), Washington Current	NOS	PUG1503_31	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64665	Edmonds, 2.5 miles west of (Depth 93.5ft), Washington Current	NOS	PUG1503_32	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64666	Edmonds, 2.5 miles west of (Depth 80.4ft), Washington Current	NOS	PUG1503_33	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64667	Edmonds, 2.5 miles west of (Depth 67.3ft), Washington Current	NOS	PUG1503_34	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	358	161	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64668	Edmonds, 2.5 miles west of (Depth 54.2ft), Washington Current	NOS	PUG1503_35	47.8071212768554	-122.444129943847	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.248	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles west of	WA
64669	Ballard Locks entrance (Depth 28.9ft), Washington Current	NOS	PUG1504_1	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64670	Ballard Locks entrance (Depth 25.7ft), Washington Current	NOS	PUG1504_2	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64671	Ballard Locks entrance (Depth 22.4ft), Washington Current	NOS	PUG1504_3	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64672	Ballard Locks entrance (Depth 19.1ft), Washington Current	NOS	PUG1504_4	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64673	Ballard Locks entrance (Depth 15.8ft), Washington Current	NOS	PUG1504_5	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64674	Ballard Locks entrance (Depth 12.5ft), Washington Current	NOS	PUG1504_6	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64675	Ballard Locks entrance (Depth 9.3ft), Washington Current	NOS	PUG1504_7	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	90	144	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64676	Ballard Locks entrance (Depth 6ft), Washington Current	NOS	PUG1504_8	47.6709785461425	-122.406997680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballard Locks entrance	WA
64677	Eagle Harbor entrance (Depth 31.6ft), Washington Current	NOS	PUG1505_1	47.619571685791	-122.495300292968	:America/Los_Angeles	USA	knots	0	0	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Harbor entrance	WA
64678	Eagle Harbor entrance (Depth 8.6ft), Washington Current	NOS	PUG1505_8	47.619571685791	-122.495300292968	:America/Los_Angeles	USA	knots	137	337	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Harbor entrance	WA
64679	Harbor Island East (Depth 42.3ft), Washington Current	NOS	PUG1506_1	47.588451385498	-122.343971252441	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island East	WA
64680	Harbor Island East (Depth 22.6ft), Washington Current	NOS	PUG1506_7	47.588451385498	-122.343971252441	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island East	WA
64681	Harbor Island East (Depth 6.2ft), Washington Current	NOS	PUG1506_12	47.588451385498	-122.343971252441	:America/Los_Angeles	USA	knots	356	0	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island East	WA
64682	Harbor Island West (Depth 47.7ft), Washington Current	NOS	PUG1507_1	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64683	Harbor Island West (Depth 44.5ft), Washington Current	NOS	PUG1507_2	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64684	Harbor Island West (Depth 41.2ft), Washington Current	NOS	PUG1507_3	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64685	Harbor Island West (Depth 37.9ft), Washington Current	NOS	PUG1507_4	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64686	Harbor Island West (Depth 34.6ft), Washington Current	NOS	PUG1507_5	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64687	Harbor Island West (Depth 31.3ft), Washington Current	NOS	PUG1507_6	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64688	Harbor Island West (Depth 28.1ft), Washington Current	NOS	PUG1507_7	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64689	Harbor Island West (Depth 24.8ft), Washington Current	NOS	PUG1507_8	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64690	Harbor Island West (Depth 21.5ft), Washington Current	NOS	PUG1507_9	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	356	177	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64691	Harbor Island West (Depth 18.2ft), Washington Current	NOS	PUG1507_10	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64692	Harbor Island West (Depth 14.9ft), Washington Current	NOS	PUG1507_11	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64693	Harbor Island West (Depth 11.6ft), Washington Current	NOS	PUG1507_12	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64694	Harbor Island West (Depth 8.4ft), Washington Current	NOS	PUG1507_13	47.5831298828125	-122.360221862792	:America/Los_Angeles	USA	knots	1	178	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
64695	Liberty Bay (entrance), Port Orchard (Depth 36.7ft), Washington Current	NOS	PUG1508_1	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	110	296	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64696	Liberty Bay (entrance), Port Orchard (Depth 33.4ft), Washington Current	NOS	PUG1508_2	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64697	Liberty Bay (entrance), Port Orchard (Depth 30.1ft), Washington Current	NOS	PUG1508_3	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64698	Liberty Bay (entrance), Port Orchard (Depth 26.8ft), Washington Current	NOS	PUG1508_4	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64699	Liberty Bay (entrance), Port Orchard (Depth 23.6ft), Washington Current	NOS	PUG1508_5	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	124	288	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64700	Liberty Bay (entrance), Port Orchard (Depth 20.3ft), Washington Current	NOS	PUG1508_6	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64701	Liberty Bay (entrance), Port Orchard (Depth 17ft), Washington Current	NOS	PUG1508_7	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64702	Liberty Bay (entrance), Port Orchard (Depth 13.7ft), Washington Current	NOS	PUG1508_8	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64703	Liberty Bay (entrance), Port Orchard (Depth 10.4ft), Washington Current	NOS	PUG1508_9	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64704	Liberty Bay (entrance), Port Orchard (Depth 7.2ft), Washington Current	NOS	PUG1508_10	47.7068214416503	-122.62825012207	:America/Los_Angeles	USA	knots	313	287	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
64705	Point Jefferson, east of (Depth 71ft), Washington Current	NOS	PUG1509_1	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	14	212	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64706	Point Jefferson, east of (Depth 64.5ft), Washington Current	NOS	PUG1509_2	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64707	Point Jefferson, east of (Depth 57.9ft), Washington Current	NOS	PUG1509_3	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64708	Point Jefferson, east of (Depth 51.3ft), Washington Current	NOS	PUG1509_4	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64709	Point Jefferson, east of (Depth 44.8ft), Washington Current	NOS	PUG1509_5	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	21	214	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64710	Point Jefferson, east of (Depth 38.2ft), Washington Current	NOS	PUG1509_6	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64711	Point Jefferson, east of (Depth 31.7ft), Washington Current	NOS	PUG1509_7	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64712	Point Jefferson, east of (Depth 25.1ft), Washington Current	NOS	PUG1509_8	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.176	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64713	Point Jefferson, east of (Depth 18.5ft), Washington Current	NOS	PUG1509_9	47.7444686889648	-122.468017578125	:America/Los_Angeles	USA	knots	31	217	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, east of	WA
64734	Rich Passage, west end (Depth 44.3ft), Washington Current	NOS	PUG1514_3	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64714	Port Washington Narrows, Warren Ave. Bridge (Depth 20.5ft), Washington Current	NOS	PUG1510_1	47.5795707702636	-122.630653381347	:America/Los_Angeles	USA	knots	102	279	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Washington Narrows, Warren Ave. Bridge	WA
64715	Port Washington Narrows, Warren Ave. Bridge (Depth 4.1ft), Washington Current	NOS	PUG1510_6	47.5795707702636	-122.630653381347	:America/Los_Angeles	USA	knots	99	286	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Washington Narrows, Warren Ave. Bridge	WA
64716	President Point, 1.5 miles east of (Depth 307.6ft), Washington Current	NOS	PUG1511_20	47.76712	-122.4319	:America/Los_Angeles	USA	knots	331	161	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
64717	President Point, 1.5 miles east of (Depth 176.4ft), Washington Current	NOS	PUG1511_30	47.76712	-122.4319	:America/Los_Angeles	USA	knots	341	158	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
64718	President Point, 1.5 miles east of (Depth 71.4ft), Washington Current	NOS	PUG1511_38	47.76712	-122.4319	:America/Los_Angeles	USA	knots	3	177	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
64719	Restoration Point (Depth 140ft), Washington Current	NOS	PUG1512_1	47.5788497924804	-122.468719482421	:America/Los_Angeles	USA	knots	45	151	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
64720	Restoration Point (Depth 81ft), Washington Current	NOS	PUG1512_10	47.5788497924804	-122.468719482421	:America/Los_Angeles	USA	knots	42	142	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
64721	Restoration Point (Depth 21.9ft), Washington Current	NOS	PUG1512_19	47.5788497924804	-122.468719482421	:America/Los_Angeles	USA	knots	52	0	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.429	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
64722	Rich Passage, east end (Depth 70.3ft), Washington Current	NOS	PUG1513_1	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	108	314	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64723	Rich Passage, east end (Depth 63.7ft), Washington Current	NOS	PUG1513_2	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64724	Rich Passage, east end (Depth 57.2ft), Washington Current	NOS	PUG1513_3	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64725	Rich Passage, east end (Depth 50.6ft), Washington Current	NOS	PUG1513_4	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64726	Rich Passage, east end (Depth 44ft), Washington Current	NOS	PUG1513_5	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64727	Rich Passage, east end (Depth 37.5ft), Washington Current	NOS	PUG1513_6	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	127	323	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64728	Rich Passage, east end (Depth 30.9ft), Washington Current	NOS	PUG1513_7	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64729	Rich Passage, east end (Depth 24.3ft), Washington Current	NOS	PUG1513_8	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64730	Rich Passage, east end (Depth 17.8ft), Washington Current	NOS	PUG1513_9	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64731	Rich Passage, east end (Depth 11.2ft), Washington Current	NOS	PUG1513_10	47.5700187683105	-122.529800415039	:America/Los_Angeles	USA	knots	139	326	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, east end	WA
64732	Rich Passage, west end (Depth 57.4ft), Washington Current	NOS	PUG1514_1	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	53	235	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64733	Rich Passage, west end (Depth 50.8ft), Washington Current	NOS	PUG1514_2	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64735	Rich Passage, west end (Depth 37.7ft), Washington Current	NOS	PUG1514_4	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64736	Rich Passage, west end (Depth 31.1ft), Washington Current	NOS	PUG1514_5	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	55	238	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64737	Rich Passage, west end (Depth 24.6ft), Washington Current	NOS	PUG1514_6	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64738	Rich Passage, west end (Depth 18ft), Washington Current	NOS	PUG1514_7	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64739	Rich Passage, west end (Depth 11.5ft), Washington Current	NOS	PUG1514_8	47.5899314880371	-122.56233215332	:America/Los_Angeles	USA	knots	55	239	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, west end	WA
64740	West Point, west of (Depth 107.6ft), Washington Current	NOS	PUG1515_1	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	21	228	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64741	West Point, west of (Depth 101ft), Washington Current	NOS	PUG1515_2	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64742	West Point, west of (Depth 94.5ft), Washington Current	NOS	PUG1515_3	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64743	West Point, west of (Depth 87.9ft), Washington Current	NOS	PUG1515_4	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64744	West Point, west of (Depth 81.4ft), Washington Current	NOS	PUG1515_5	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64745	West Point, west of (Depth 74.8ft), Washington Current	NOS	PUG1515_6	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.193	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64746	West Point, west of (Depth 68.2ft), Washington Current	NOS	PUG1515_7	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64747	West Point, west of (Depth 61.7ft), Washington Current	NOS	PUG1515_8	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.193	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64748	West Point, west of (Depth 55.1ft), Washington Current	NOS	PUG1515_9	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64749	West Point, west of (Depth 48.6ft), Washington Current	NOS	PUG1515_10	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	357	230	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64750	West Point, west of (Depth 42ft), Washington Current	NOS	PUG1515_11	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64751	West Point, west of (Depth 35.4ft), Washington Current	NOS	PUG1515_12	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64752	West Point, west of (Depth 28.9ft), Washington Current	NOS	PUG1515_13	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64753	West Point, west of (Depth 22.3ft), Washington Current	NOS	PUG1515_14	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64754	West Point, west of (Depth 15.7ft), Washington Current	NOS	PUG1515_15	47.6620712280273	-122.441680908203	:America/Los_Angeles	USA	knots	341	234	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, west of	WA
64755	Alki Point, west of (Depth 247.6ft), Washington Current	NOS	PUG1516_1	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64756	Alki Point, west of (Depth 234.5ft), Washington Current	NOS	PUG1516_2	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64757	Alki Point, west of (Depth 221.4ft), Washington Current	NOS	PUG1516_3	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64758	Alki Point, west of (Depth 208.2ft), Washington Current	NOS	PUG1516_4	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64759	Alki Point, west of (Depth 195.1ft), Washington Current	NOS	PUG1516_5	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	4	200	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64760	Alki Point, west of (Depth 182ft), Washington Current	NOS	PUG1516_6	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64761	Alki Point, west of (Depth 168.9ft), Washington Current	NOS	PUG1516_7	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64762	Alki Point, west of (Depth 155.7ft), Washington Current	NOS	PUG1516_8	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64763	Alki Point, west of (Depth 142.6ft), Washington Current	NOS	PUG1516_9	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64764	Alki Point, west of (Depth 129.5ft), Washington Current	NOS	PUG1516_10	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64765	Alki Point, west of (Depth 116.4ft), Washington Current	NOS	PUG1516_11	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64766	Alki Point, west of (Depth 103.2ft), Washington Current	NOS	PUG1516_12	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	6	213	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64767	Alki Point, west of (Depth 90.1ft), Washington Current	NOS	PUG1516_13	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64768	Alki Point, west of (Depth 77ft), Washington Current	NOS	PUG1516_14	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64769	Alki Point, west of (Depth 63.9ft), Washington Current	NOS	PUG1516_15	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64770	Alki Point, west of (Depth 50.8ft), Washington Current	NOS	PUG1516_16	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64771	Alki Point, west of (Depth 37.6ft), Washington Current	NOS	PUG1516_17	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	4	215	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64772	Alki Point, west of (Depth 24.5ft), Washington Current	NOS	PUG1516_18	47.5760688781738	-122.427833557128	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, west of	WA
64773	Blake Island, S of (Depth 240.6ft), Washington Current	NOS	PUG1517_1	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.372	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64774	Blake Island, S of (Depth 230.7ft), Washington Current	NOS	PUG1517_2	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.392	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64775	Blake Island, S of (Depth 220.9ft), Washington Current	NOS	PUG1517_3	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64776	Blake Island, S of (Depth 211ft), Washington Current	NOS	PUG1517_4	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64777	Blake Island, S of (Depth 201.2ft), Washington Current	NOS	PUG1517_5	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64778	Blake Island, S of (Depth 191.3ft), Washington Current	NOS	PUG1517_6	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.444	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64779	Blake Island, S of (Depth 181.5ft), Washington Current	NOS	PUG1517_7	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.454	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64780	Blake Island, S of (Depth 171.7ft), Washington Current	NOS	PUG1517_8	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	350	218	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.465	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64781	Blake Island, S of (Depth 161.8ft), Washington Current	NOS	PUG1517_9	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.476	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64782	Blake Island, S of (Depth 152ft), Washington Current	NOS	PUG1517_10	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.488	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64783	Blake Island, S of (Depth 142.1ft), Washington Current	NOS	PUG1517_11	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64784	Blake Island, S of (Depth 132.3ft), Washington Current	NOS	PUG1517_12	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.512	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64785	Blake Island, S of (Depth 122.4ft), Washington Current	NOS	PUG1517_13	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.524	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64786	Blake Island, S of (Depth 112.6ft), Washington Current	NOS	PUG1517_14	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.538	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64787	Blake Island, S of (Depth 102.8ft), Washington Current	NOS	PUG1517_15	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.551	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64788	Blake Island, S of (Depth 92.9ft), Washington Current	NOS	PUG1517_16	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	349	237	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.564	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64789	Blake Island, S of (Depth 83.1ft), Washington Current	NOS	PUG1517_17	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64790	Blake Island, S of (Depth 73.2ft), Washington Current	NOS	PUG1517_18	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.588	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64791	Blake Island, S of (Depth 63.4ft), Washington Current	NOS	PUG1517_19	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.599	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64792	Blake Island, S of (Depth 53.5ft), Washington Current	NOS	PUG1517_20	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.607	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64793	Blake Island, S of (Depth 43.7ft), Washington Current	NOS	PUG1517_21	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	350	244	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.612	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64794	Blake Island, S of (Depth 33.9ft), Washington Current	NOS	PUG1517_22	47.520278930664	-122.487922668457	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.562	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
64795	Anderson Point, east of, Colvos Passage (Depth 153.5ft), Washington Current	NOS	PUG1518_10	47.43943	-122.52578	:America/Los_Angeles	USA	knots	351	181	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.524	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, east of, Colvos Passage	WA
64796	Anderson Point, east of, Colvos Passage (Depth 61.7ft), Washington Current	NOS	PUG1518_17	47.43943	-122.52578	:America/Los_Angeles	USA	knots	353	185	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.548	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, east of, Colvos Passage	WA
64797	Anderson Point, east of, Colvos Passage (Depth 35.4ft), Washington Current	NOS	PUG1518_19	47.43943	-122.52578	:America/Los_Angeles	USA	knots	356	183	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.537	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, east of, Colvos Passage	WA
64798	Point Richmond, east of, Colvos Passage (Depth 267.4ft), Washington Current	NOS	PUG1519_1	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.469	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64799	Point Richmond, east of, Colvos Passage (Depth 254.3ft), Washington Current	NOS	PUG1519_2	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.485	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64800	Point Richmond, east of, Colvos Passage (Depth 241.1ft), Washington Current	NOS	PUG1519_3	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	4	157	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.498	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64801	Point Richmond, east of, Colvos Passage (Depth 228ft), Washington Current	NOS	PUG1519_4	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64802	Point Richmond, east of, Colvos Passage (Depth 214.9ft), Washington Current	NOS	PUG1519_5	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.522	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64803	Point Richmond, east of, Colvos Passage (Depth 201.8ft), Washington Current	NOS	PUG1519_6	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.534	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64804	Point Richmond, east of, Colvos Passage (Depth 188.6ft), Washington Current	NOS	PUG1519_7	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.545	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64805	Point Richmond, east of, Colvos Passage (Depth 175.5ft), Washington Current	NOS	PUG1519_8	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.555	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64806	Point Richmond, east of, Colvos Passage (Depth 162.4ft), Washington Current	NOS	PUG1519_9	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.565	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64807	Point Richmond, east of, Colvos Passage (Depth 149.3ft), Washington Current	NOS	PUG1519_10	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.573	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64808	Point Richmond, east of, Colvos Passage (Depth 136.2ft), Washington Current	NOS	PUG1519_11	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.581	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64809	Point Richmond, east of, Colvos Passage (Depth 123ft), Washington Current	NOS	PUG1519_12	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.586	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64810	Point Richmond, east of, Colvos Passage (Depth 109.9ft), Washington Current	NOS	PUG1519_13	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	359	162	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.589	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64811	Point Richmond, east of, Colvos Passage (Depth 96.8ft), Washington Current	NOS	PUG1519_14	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.591	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64812	Point Richmond, east of, Colvos Passage (Depth 83.7ft), Washington Current	NOS	PUG1519_15	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.591	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64813	Point Richmond, east of, Colvos Passage (Depth 70.5ft), Washington Current	NOS	PUG1519_16	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.589	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64814	Point Richmond, east of, Colvos Passage (Depth 57.4ft), Washington Current	NOS	PUG1519_17	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.584	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64815	Point Richmond, east of, Colvos Passage (Depth 44.3ft), Washington Current	NOS	PUG1519_18	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	356	143	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.571	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64816	Point Richmond, east of, Colvos Passage (Depth 31.2ft), Washington Current	NOS	PUG1519_19	47.3766212463378	-122.528671264648	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.548	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, east of, Colvos Passage	WA
64817	Dolphin Point, 1.3 miles east of (Depth 218.1ft), Washington Current	NOS	PUG1520_22	47.5015487670898	-122.42357635498	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles east of	WA
64818	Dolphin Point, 1.3 miles east of (Depth 139.3ft), Washington Current	NOS	PUG1520_28	47.5015487670898	-122.42357635498	:America/Los_Angeles	USA	knots	343	184	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles east of	WA
64819	Dolphin Point, 1.3 miles east of (Depth 47.5ft), Washington Current	NOS	PUG1520_35	47.5015487670898	-122.42357635498	:America/Los_Angeles	USA	knots	343	186	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles east of	WA
64820	Browns Point, 1.6 miles north of (Depth 460.9ft), Washington Current	NOS	PUG1521_1	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64821	Browns Point, 1.6 miles north of (Depth 447.8ft), Washington Current	NOS	PUG1521_2	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64822	Browns Point, 1.6 miles north of (Depth 434.7ft), Washington Current	NOS	PUG1521_3	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64823	Browns Point, 1.6 miles north of (Depth 421.6ft), Washington Current	NOS	PUG1521_4	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64824	Browns Point, 1.6 miles north of (Depth 408.4ft), Washington Current	NOS	PUG1521_5	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64825	Browns Point, 1.6 miles north of (Depth 395.3ft), Washington Current	NOS	PUG1521_6	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.214	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64826	Browns Point, 1.6 miles north of (Depth 382.2ft), Washington Current	NOS	PUG1521_7	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.218	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64827	Browns Point, 1.6 miles north of (Depth 369.1ft), Washington Current	NOS	PUG1521_8	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64828	Browns Point, 1.6 miles north of (Depth 355.9ft), Washington Current	NOS	PUG1521_9	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64829	Browns Point, 1.6 miles north of (Depth 342.8ft), Washington Current	NOS	PUG1521_10	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64830	Browns Point, 1.6 miles north of (Depth 329.7ft), Washington Current	NOS	PUG1521_11	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.218	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64831	Browns Point, 1.6 miles north of (Depth 316.6ft), Washington Current	NOS	PUG1521_12	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.212	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64832	Browns Point, 1.6 miles north of (Depth 303.4ft), Washington Current	NOS	PUG1521_13	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.204	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64833	Browns Point, 1.6 miles north of (Depth 290.3ft), Washington Current	NOS	PUG1521_14	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	47	228	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64834	Browns Point, 1.6 miles north of (Depth 277.2ft), Washington Current	NOS	PUG1521_15	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64835	Browns Point, 1.6 miles north of (Depth 264.1ft), Washington Current	NOS	PUG1521_16	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64836	Browns Point, 1.6 miles north of (Depth 251ft), Washington Current	NOS	PUG1521_17	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64837	Browns Point, 1.6 miles north of (Depth 237.8ft), Washington Current	NOS	PUG1521_18	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64838	Browns Point, 1.6 miles north of (Depth 224.7ft), Washington Current	NOS	PUG1521_19	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64839	Browns Point, 1.6 miles north of (Depth 211.6ft), Washington Current	NOS	PUG1521_20	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64840	Browns Point, 1.6 miles north of (Depth 198.5ft), Washington Current	NOS	PUG1521_21	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64841	Browns Point, 1.6 miles north of (Depth 185.3ft), Washington Current	NOS	PUG1521_22	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64842	Browns Point, 1.6 miles north of (Depth 172.2ft), Washington Current	NOS	PUG1521_23	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64843	Browns Point, 1.6 miles north of (Depth 159.1ft), Washington Current	NOS	PUG1521_24	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	49	232	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64844	Browns Point, 1.6 miles north of (Depth 146ft), Washington Current	NOS	PUG1521_25	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64845	Browns Point, 1.6 miles north of (Depth 132.8ft), Washington Current	NOS	PUG1521_26	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64846	Browns Point, 1.6 miles north of (Depth 119.7ft), Washington Current	NOS	PUG1521_27	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64847	Browns Point, 1.6 miles north of (Depth 106.6ft), Washington Current	NOS	PUG1521_28	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64848	Browns Point, 1.6 miles north of (Depth 93.5ft), Washington Current	NOS	PUG1521_29	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64849	Browns Point, 1.6 miles north of (Depth 80.3ft), Washington Current	NOS	PUG1521_30	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64850	Browns Point, 1.6 miles north of (Depth 67.2ft), Washington Current	NOS	PUG1521_31	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64851	Browns Point, 1.6 miles north of (Depth 54.1ft), Washington Current	NOS	PUG1521_32	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64852	Browns Point, 1.6 miles north of (Depth 41ft), Washington Current	NOS	PUG1521_33	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.209	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64853	Browns Point, 1.6 miles north of (Depth 27.9ft), Washington Current	NOS	PUG1521_34	47.3287010192871	-122.454048156738	:America/Los_Angeles	USA	knots	42	234	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles north of	WA
64854	Dalco Passage (Depth 200.3ft), Washington Current	NOS	PUG1522_1	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.247	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64855	Dalco Passage (Depth 193.7ft), Washington Current	NOS	PUG1522_2	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64856	Dalco Passage (Depth 187.2ft), Washington Current	NOS	PUG1522_3	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	124	288	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.278	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64857	Dalco Passage (Depth 180.6ft), Washington Current	NOS	PUG1522_4	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64858	Dalco Passage (Depth 174ft), Washington Current	NOS	PUG1522_5	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64859	Dalco Passage (Depth 167.5ft), Washington Current	NOS	PUG1522_6	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.324	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64860	Dalco Passage (Depth 160.9ft), Washington Current	NOS	PUG1522_7	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.339	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64861	Dalco Passage (Depth 154.4ft), Washington Current	NOS	PUG1522_8	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.354	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64862	Dalco Passage (Depth 147.8ft), Washington Current	NOS	PUG1522_9	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.369	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64863	Dalco Passage (Depth 141.2ft), Washington Current	NOS	PUG1522_10	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.383	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64864	Dalco Passage (Depth 134.7ft), Washington Current	NOS	PUG1522_11	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64865	Dalco Passage (Depth 128.1ft), Washington Current	NOS	PUG1522_12	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	130	293	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.408	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64866	Dalco Passage (Depth 121.6ft), Washington Current	NOS	PUG1522_13	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64867	Dalco Passage (Depth 115ft), Washington Current	NOS	PUG1522_14	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64868	Dalco Passage (Depth 108.4ft), Washington Current	NOS	PUG1522_15	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.444	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64869	Dalco Passage (Depth 101.9ft), Washington Current	NOS	PUG1522_16	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.454	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64870	Dalco Passage (Depth 95.3ft), Washington Current	NOS	PUG1522_17	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.463	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64871	Dalco Passage (Depth 88.7ft), Washington Current	NOS	PUG1522_18	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.472	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64872	Dalco Passage (Depth 82.2ft), Washington Current	NOS	PUG1522_19	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64873	Dalco Passage (Depth 75.6ft), Washington Current	NOS	PUG1522_20	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.486	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64874	Dalco Passage (Depth 69.1ft), Washington Current	NOS	PUG1522_21	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.492	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64875	Dalco Passage (Depth 62.5ft), Washington Current	NOS	PUG1522_22	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.496	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64876	Dalco Passage (Depth 55.9ft), Washington Current	NOS	PUG1522_23	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.498	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64877	Dalco Passage (Depth 49.4ft), Washington Current	NOS	PUG1522_24	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.499	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64878	Dalco Passage (Depth 42.8ft), Washington Current	NOS	PUG1522_25	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.499	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64879	Dalco Passage (Depth 36.3ft), Washington Current	NOS	PUG1522_26	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64880	Dalco Passage (Depth 29.7ft), Washington Current	NOS	PUG1522_27	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64881	Dalco Passage (Depth 23.1ft), Washington Current	NOS	PUG1522_28	47.3251190185546	-122.524681091308	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
64882	Gig Harbor entrance (Depth 53.5ft), Washington Current	NOS	PUG1523_1	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	3	192	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64883	Gig Harbor entrance (Depth 50.2ft), Washington Current	NOS	PUG1523_2	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64884	Gig Harbor entrance (Depth 46.9ft), Washington Current	NOS	PUG1523_3	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64885	Gig Harbor entrance (Depth 43.7ft), Washington Current	NOS	PUG1523_4	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64886	Gig Harbor entrance (Depth 40.4ft), Washington Current	NOS	PUG1523_5	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64887	Gig Harbor entrance (Depth 37.1ft), Washington Current	NOS	PUG1523_6	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64888	Gig Harbor entrance (Depth 33.8ft), Washington Current	NOS	PUG1523_7	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64889	Gig Harbor entrance (Depth 30.5ft), Washington Current	NOS	PUG1523_8	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	357	198	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64890	Gig Harbor entrance (Depth 27.3ft), Washington Current	NOS	PUG1523_9	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64891	Gig Harbor entrance (Depth 24ft), Washington Current	NOS	PUG1523_10	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64892	Gig Harbor entrance (Depth 20.7ft), Washington Current	NOS	PUG1523_11	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64893	Gig Harbor entrance (Depth 17.4ft), Washington Current	NOS	PUG1523_12	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64894	Gig Harbor entrance (Depth 14.1ft), Washington Current	NOS	PUG1523_13	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64895	Gig Harbor entrance (Depth 10.9ft), Washington Current	NOS	PUG1523_14	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	7	198	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64896	Gig Harbor entrance (Depth 7.6ft), Washington Current	NOS	PUG1523_15	47.3241500854492	-122.571868896484	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor entrance	WA
64897	The Narrows, north end (midstream) (Depth 139.2ft), Washington Current	NOS	PUG1524_1	47.3059997558593	-122.550033569335	:America/Los_Angeles	USA	knots	331	132	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (midstream)	WA
64898	The Narrows, north end (midstream) (Depth 86.7ft), Washington Current	NOS	PUG1524_9	47.3059997558593	-122.550033569335	:America/Los_Angeles	USA	knots	335	141	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (midstream)	WA
64899	The Narrows, north end (midstream) (Depth 40.7ft), Washington Current	NOS	PUG1524_16	47.3059997558593	-122.550033569335	:America/Los_Angeles	USA	knots	337	145	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (midstream)	WA
64900	The Narrows, north end (east side) (Depth 58.2ft), Washington Current	NOS	PUG1525_1	47.30778	-122.54213	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-1.484	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (east side)	WA
64901	The Narrows, north end (east side) (Depth 32ft), Washington Current	NOS	PUG1525_9	47.30778	-122.54213	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-1.693	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (east side)	WA
64902	The Narrows, north end (east side) (Depth 12.3ft), Washington Current	NOS	PUG1525_15	47.30778	-122.54213	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-1.755	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (east side)	WA
64903	The Narrows, north end (west side) (Depth 193.3ft), Washington Current	NOS	PUG1526_5	47.3040008544921	-122.556747436523	:America/Los_Angeles	USA	knots	324	144	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (west side)	WA
64904	The Narrows, north end (west side) (Depth 94.8ft), Washington Current	NOS	PUG1526_20	47.3040008544921	-122.556747436523	:America/Los_Angeles	USA	knots	326	148	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.933	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (west side)	WA
64905	The Narrows, north end (west side) (Depth 42.4ft), Washington Current	NOS	PUG1526_28	47.3040008544921	-122.556747436523	:America/Los_Angeles	USA	knots	329	152	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, north end (west side)	WA
64906	The Narrows, 0.3 miles north of bridge (Depth 140.9ft), Washington Current	NOS	PUG1527_1	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	42	213	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64907	The Narrows, 0.3 miles north of bridge (Depth 134.3ft), Washington Current	NOS	PUG1527_2	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64908	The Narrows, 0.3 miles north of bridge (Depth 127.8ft), Washington Current	NOS	PUG1527_3	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64909	The Narrows, 0.3 miles north of bridge (Depth 121.2ft), Washington Current	NOS	PUG1527_4	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64910	The Narrows, 0.3 miles north of bridge (Depth 114.6ft), Washington Current	NOS	PUG1527_5	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64911	The Narrows, 0.3 miles north of bridge (Depth 108.1ft), Washington Current	NOS	PUG1527_6	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64912	The Narrows, 0.3 miles north of bridge (Depth 101.5ft), Washington Current	NOS	PUG1527_7	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64913	The Narrows, 0.3 miles north of bridge (Depth 94.9ft), Washington Current	NOS	PUG1527_8	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64914	The Narrows, 0.3 miles north of bridge (Depth 88.4ft), Washington Current	NOS	PUG1527_9	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64915	The Narrows, 0.3 miles north of bridge (Depth 81.8ft), Washington Current	NOS	PUG1527_10	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64916	The Narrows, 0.3 miles north of bridge (Depth 75.3ft), Washington Current	NOS	PUG1527_11	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64917	The Narrows, 0.3 miles north of bridge (Depth 68.7ft), Washington Current	NOS	PUG1527_12	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	42	204	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64918	The Narrows, 0.3 miles north of bridge (Depth 62.1ft), Washington Current	NOS	PUG1527_13	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64919	The Narrows, 0.3 miles north of bridge (Depth 55.6ft), Washington Current	NOS	PUG1527_14	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64920	The Narrows, 0.3 miles north of bridge (Depth 49ft), Washington Current	NOS	PUG1527_15	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64921	The Narrows, 0.3 miles north of bridge (Depth 42.5ft), Washington Current	NOS	PUG1527_16	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64922	The Narrows, 0.3 miles north of bridge (Depth 35.9ft), Washington Current	NOS	PUG1527_17	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64923	The Narrows, 0.3 miles north of bridge (Depth 29.3ft), Washington Current	NOS	PUG1527_18	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64924	The Narrows, 0.3 miles north of bridge (Depth 22.8ft), Washington Current	NOS	PUG1527_19	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	40	198	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64925	The Narrows, 0.3 miles north of bridge (Depth 16.2ft), Washington Current	NOS	PUG1527_20	47.2743186950683	-122.545318603515	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles north of bridge	WA
64926	The Narrows, south end (midstream) (Depth 131.2ft), Washington Current	NOS	PUG1528_1	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	32	222	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64927	The Narrows, south end (midstream) (Depth 124.6ft), Washington Current	NOS	PUG1528_2	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64928	The Narrows, south end (midstream) (Depth 118ft), Washington Current	NOS	PUG1528_3	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64929	The Narrows, south end (midstream) (Depth 111.5ft), Washington Current	NOS	PUG1528_4	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64930	The Narrows, south end (midstream) (Depth 104.9ft), Washington Current	NOS	PUG1528_5	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64931	The Narrows, south end (midstream) (Depth 98.4ft), Washington Current	NOS	PUG1528_6	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64932	The Narrows, south end (midstream) (Depth 91.8ft), Washington Current	NOS	PUG1528_7	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64933	The Narrows, south end (midstream) (Depth 85.2ft), Washington Current	NOS	PUG1528_8	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64934	The Narrows, south end (midstream) (Depth 78.7ft), Washington Current	NOS	PUG1528_9	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64935	The Narrows, south end (midstream) (Depth 72.1ft), Washington Current	NOS	PUG1528_10	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64936	The Narrows, south end (midstream) (Depth 65.6ft), Washington Current	NOS	PUG1528_11	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64937	The Narrows, south end (midstream) (Depth 59ft), Washington Current	NOS	PUG1528_12	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64938	The Narrows, south end (midstream) (Depth 52.4ft), Washington Current	NOS	PUG1528_13	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	28	221	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64939	The Narrows, south end (midstream) (Depth 45.9ft), Washington Current	NOS	PUG1528_14	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64940	The Narrows, south end (midstream) (Depth 39.3ft), Washington Current	NOS	PUG1528_15	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64941	The Narrows, south end (midstream) (Depth 32.7ft), Washington Current	NOS	PUG1528_16	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64942	The Narrows, south end (midstream) (Depth 26.2ft), Washington Current	NOS	PUG1528_17	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	26	220	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64943	The Narrows, south end (midstream) (Depth 19.6ft), Washington Current	NOS	PUG1528_18	47.2612991333007	-122.558280944824	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, south end (midstream)	WA
64944	Hale Passage, east end (Depth 77ft), Washington Current	NOS	PUG1529_1	47.2478981018066	-122.595596313476	:America/Los_Angeles	USA	knots	151	334	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.241	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east end	WA
64945	Hale Passage, east end (Depth 44.2ft), Washington Current	NOS	PUG1529_6	47.2478981018066	-122.595596313476	:America/Los_Angeles	USA	knots	145	330	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east end	WA
64946	Hale Passage, east end (Depth 11.4ft), Washington Current	NOS	PUG1529_11	47.2478981018066	-122.595596313476	:America/Los_Angeles	USA	knots	145	325	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east end	WA
64947	Hale Passage, west end (Depth 69.7ft), Washington Current	NOS	PUG1530_1	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	113	282	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.349	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64948	Hale Passage, west end (Depth 66.4ft), Washington Current	NOS	PUG1530_2	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.384	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64949	Hale Passage, west end (Depth 63.1ft), Washington Current	NOS	PUG1530_3	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.404	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64950	Hale Passage, west end (Depth 59.8ft), Washington Current	NOS	PUG1530_4	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64951	Hale Passage, west end (Depth 56.5ft), Washington Current	NOS	PUG1530_5	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.427	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64952	Hale Passage, west end (Depth 53.2ft), Washington Current	NOS	PUG1530_6	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.436	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64953	Hale Passage, west end (Depth 50ft), Washington Current	NOS	PUG1530_7	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.444	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64954	Hale Passage, west end (Depth 46.7ft), Washington Current	NOS	PUG1530_8	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.451	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64955	Hale Passage, west end (Depth 43.4ft), Washington Current	NOS	PUG1530_9	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.456	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64956	Hale Passage, west end (Depth 40.1ft), Washington Current	NOS	PUG1530_10	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	99	283	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.461	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64957	Hale Passage, west end (Depth 36.8ft), Washington Current	NOS	PUG1530_11	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.464	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64958	Hale Passage, west end (Depth 33.6ft), Washington Current	NOS	PUG1530_12	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.466	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64959	Hale Passage, west end (Depth 30.3ft), Washington Current	NOS	PUG1530_13	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.467	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64960	Hale Passage, west end (Depth 27ft), Washington Current	NOS	PUG1530_14	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.467	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64961	Hale Passage, west end (Depth 23.7ft), Washington Current	NOS	PUG1530_15	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.468	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64962	Hale Passage, west end (Depth 20.4ft), Washington Current	NOS	PUG1530_16	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.468	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64963	Hale Passage, west end (Depth 17.2ft), Washington Current	NOS	PUG1530_17	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.469	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64964	Hale Passage, west end (Depth 13.9ft), Washington Current	NOS	PUG1530_18	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	105	283	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64965	Hale Passage, west end (Depth 10.6ft), Washington Current	NOS	PUG1530_19	47.281379699707	-122.663116455078	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.472	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, west end	WA
64966	Gibson Point, 0.8 miles east of (Depth 198.6ft), Washington Current	NOS	PUG1531_1	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64967	Gibson Point, 0.8 miles east of (Depth 188.7ft), Washington Current	NOS	PUG1531_2	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64968	Gibson Point, 0.8 miles east of (Depth 178.9ft), Washington Current	NOS	PUG1531_3	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64969	Gibson Point, 0.8 miles east of (Depth 169.1ft), Washington Current	NOS	PUG1531_4	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64970	Gibson Point, 0.8 miles east of (Depth 159.2ft), Washington Current	NOS	PUG1531_5	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.166	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64971	Gibson Point, 0.8 miles east of (Depth 149.4ft), Washington Current	NOS	PUG1531_6	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	29	205	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64972	Gibson Point, 0.8 miles east of (Depth 139.5ft), Washington Current	NOS	PUG1531_7	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64973	Gibson Point, 0.8 miles east of (Depth 129.7ft), Washington Current	NOS	PUG1531_8	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64974	Gibson Point, 0.8 miles east of (Depth 119.8ft), Washington Current	NOS	PUG1531_9	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64975	Gibson Point, 0.8 miles east of (Depth 110ft), Washington Current	NOS	PUG1531_10	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64976	Gibson Point, 0.8 miles east of (Depth 100.2ft), Washington Current	NOS	PUG1531_11	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64977	Gibson Point, 0.8 miles east of (Depth 90.3ft), Washington Current	NOS	PUG1531_12	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64978	Gibson Point, 0.8 miles east of (Depth 80.5ft), Washington Current	NOS	PUG1531_13	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	34	204	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64979	Gibson Point, 0.8 miles east of (Depth 70.6ft), Washington Current	NOS	PUG1531_14	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64980	Gibson Point, 0.8 miles east of (Depth 60.8ft), Washington Current	NOS	PUG1531_15	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64981	Gibson Point, 0.8 miles east of (Depth 51ft), Washington Current	NOS	PUG1531_16	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64982	Gibson Point, 0.8 miles east of (Depth 41.1ft), Washington Current	NOS	PUG1531_17	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64983	Gibson Point, 0.8 miles east of (Depth 31.3ft), Washington Current	NOS	PUG1531_18	47.2191314697265	-122.588668823242	:America/Los_Angeles	USA	knots	42	204	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles east of	WA
64984	Steilacoom, 0.8 miles north of (Depth 242.4ft), Washington Current	NOS	PUG1532_1	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64985	Steilacoom, 0.8 miles north of (Depth 229.3ft), Washington Current	NOS	PUG1532_2	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64986	Steilacoom, 0.8 miles north of (Depth 216.1ft), Washington Current	NOS	PUG1532_3	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64987	Steilacoom, 0.8 miles north of (Depth 203ft), Washington Current	NOS	PUG1532_4	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64988	Steilacoom, 0.8 miles north of (Depth 189.9ft), Washington Current	NOS	PUG1532_5	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64989	Steilacoom, 0.8 miles north of (Depth 176.8ft), Washington Current	NOS	PUG1532_6	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	37	205	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64990	Steilacoom, 0.8 miles north of (Depth 163.6ft), Washington Current	NOS	PUG1532_7	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64991	Steilacoom, 0.8 miles north of (Depth 150.5ft), Washington Current	NOS	PUG1532_8	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64992	Steilacoom, 0.8 miles north of (Depth 137.4ft), Washington Current	NOS	PUG1532_9	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64993	Steilacoom, 0.8 miles north of (Depth 124.3ft), Washington Current	NOS	PUG1532_10	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64994	Steilacoom, 0.8 miles north of (Depth 111.2ft), Washington Current	NOS	PUG1532_11	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64995	Steilacoom, 0.8 miles north of (Depth 98ft), Washington Current	NOS	PUG1532_12	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64996	Steilacoom, 0.8 miles north of (Depth 84.9ft), Washington Current	NOS	PUG1532_13	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	55	213	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64997	Steilacoom, 0.8 miles north of (Depth 71.8ft), Washington Current	NOS	PUG1532_14	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64998	Steilacoom, 0.8 miles north of (Depth 58.7ft), Washington Current	NOS	PUG1532_15	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
64999	Steilacoom, 0.8 miles north of (Depth 45.5ft), Washington Current	NOS	PUG1532_16	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	51	215	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
65000	Steilacoom, 0.8 miles north of (Depth 32.4ft), Washington Current	NOS	PUG1532_17	47.1823806762695	-122.605598449707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles north of	WA
65001	Ketron Island, west of (Depth 260.9ft), Washington Current	NOS	PUG1533_1	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65002	Ketron Island, west of (Depth 247.8ft), Washington Current	NOS	PUG1533_2	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65003	Ketron Island, west of (Depth 234.7ft), Washington Current	NOS	PUG1533_3	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.162	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65004	Ketron Island, west of (Depth 221.6ft), Washington Current	NOS	PUG1533_4	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65005	Ketron Island, west of (Depth 208.4ft), Washington Current	NOS	PUG1533_5	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65006	Ketron Island, west of (Depth 195.3ft), Washington Current	NOS	PUG1533_6	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65007	Ketron Island, west of (Depth 182.2ft), Washington Current	NOS	PUG1533_7	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65008	Ketron Island, west of (Depth 169.1ft), Washington Current	NOS	PUG1533_8	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65009	Ketron Island, west of (Depth 155.9ft), Washington Current	NOS	PUG1533_9	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65010	Ketron Island, west of (Depth 142.8ft), Washington Current	NOS	PUG1533_10	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	12	206	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65011	Ketron Island, west of (Depth 129.7ft), Washington Current	NOS	PUG1533_11	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65012	Ketron Island, west of (Depth 116.6ft), Washington Current	NOS	PUG1533_12	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65013	Ketron Island, west of (Depth 103.4ft), Washington Current	NOS	PUG1533_13	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65014	Ketron Island, west of (Depth 90.3ft), Washington Current	NOS	PUG1533_14	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	12	208	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65015	Ketron Island, west of (Depth 77.2ft), Washington Current	NOS	PUG1533_15	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65016	Ketron Island, west of (Depth 64.1ft), Washington Current	NOS	PUG1533_16	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65017	Ketron Island, west of (Depth 51ft), Washington Current	NOS	PUG1533_17	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65018	Ketron Island, west of (Depth 37.8ft), Washington Current	NOS	PUG1533_18	47.1486015319824	-122.659400939941	:America/Los_Angeles	USA	knots	10	193	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, west of	WA
65019	Balch Passage, NE of Eagle Island (Depth 59.8ft), Washington Current	NOS	PUG1535_1	47.1906204223632	-122.691551208496	:America/Los_Angeles	USA	knots	108	288	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
65020	Balch Passage, NE of Eagle Island (Depth 30.3ft), Washington Current	NOS	PUG1535_10	47.1906204223632	-122.691551208496	:America/Los_Angeles	USA	knots	108	288	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.315	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
65021	Balch Passage, NE of Eagle Island (Depth 10.6ft), Washington Current	NOS	PUG1535_16	47.1906204223632	-122.691551208496	:America/Los_Angeles	USA	knots	104	287	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
65022	Pitt Passage, NE of Pitt Island (Depth 23.1ft), Washington Current	NOS	PUG1536_1	47.2238311767578	-122.711372375488	:America/Los_Angeles	USA	knots	23	202	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.287	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pitt Passage, NE of Pitt Island	WA
65023	Pitt Passage, NE of Pitt Island (Depth 6.7ft), Washington Current	NOS	PUG1536_6	47.2238311767578	-122.711372375488	:America/Los_Angeles	USA	knots	29	196	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.318	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pitt Passage, NE of Pitt Island	WA
65024	Drayton Passage (Depth 117.5ft), Washington Current	NOS	PUG1537_5	47.1725807189941	-122.741477966308	:America/Los_Angeles	USA	knots	34	213	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
65025	Drayton Passage (Depth 51.8ft), Washington Current	NOS	PUG1537_15	47.1725807189941	-122.741477966308	:America/Los_Angeles	USA	knots	23	210	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
65026	Drayton Passage (Depth 19ft), Washington Current	NOS	PUG1537_20	47.1725807189941	-122.741477966308	:America/Los_Angeles	USA	knots	31	215	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
65027	Devils Head, west of (Depth 190.9ft), Washington Current	NOS	PUG1538_5	47.1606712341308	-122.789367675781	:America/Los_Angeles	USA	knots	159	324	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, west of	WA
65028	Devils Head, west of (Depth 82.6ft), Washington Current	NOS	PUG1538_16	47.1606712341308	-122.789367675781	:America/Los_Angeles	USA	knots	153	336	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, west of	WA
65029	Devils Head, west of (Depth 23.6ft), Washington Current	NOS	PUG1538_22	47.1606712341308	-122.789367675781	:America/Los_Angeles	USA	knots	156	334	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.227	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, west of	WA
65030	Dana Passage (Depth 88.4ft), Washington Current	NOS	PUG1539_1	47.163101196289	-122.868103027343	:America/Los_Angeles	USA	knots	43	232	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
65031	Dana Passage (Depth 42.5ft), Washington Current	NOS	PUG1539_8	47.163101196289	-122.868103027343	:America/Los_Angeles	USA	knots	48	239	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.167	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
65032	Dana Passage (Depth 16.2ft), Washington Current	NOS	PUG1539_12	47.163101196289	-122.868103027343	:America/Los_Angeles	USA	knots	49	242	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.176	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
65033	Budd Inlet entrance (Depth 71.2ft), Washington Current	NOS	PUG1540_1	47.1401596069335	-122.921447753906	:America/Los_Angeles	USA	knots	2	170	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet entrance	WA
65034	Budd Inlet entrance (Depth 31.9ft), Washington Current	NOS	PUG1540_7	47.1401596069335	-122.921447753906	:America/Los_Angeles	USA	knots	4	172	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet entrance	WA
65035	Budd Inlet entrance (Depth 12.2ft), Washington Current	NOS	PUG1540_10	47.1401596069335	-122.921447753906	:America/Los_Angeles	USA	knots	10	184	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet entrance	WA
65036	Peale Passage, south end (Depth 35.3ft), Washington Current	NOS	PUG1541_1	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	159	338	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65037	Peale Passage, south end (Depth 32.1ft), Washington Current	NOS	PUG1541_2	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65038	Peale Passage, south end (Depth 28.8ft), Washington Current	NOS	PUG1541_3	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65039	Peale Passage, south end (Depth 25.5ft), Washington Current	NOS	PUG1541_4	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65040	Peale Passage, south end (Depth 22.2ft), Washington Current	NOS	PUG1541_5	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	157	347	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65041	Peale Passage, south end (Depth 18.9ft), Washington Current	NOS	PUG1541_6	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65042	Peale Passage, south end (Depth 15.6ft), Washington Current	NOS	PUG1541_7	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65043	Peale Passage, south end (Depth 12.4ft), Washington Current	NOS	PUG1541_8	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65044	Peale Passage, south end (Depth 9.1ft), Washington Current	NOS	PUG1541_9	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	16	346	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65045	Peale Passage, south end (Depth 5.8ft), Washington Current	NOS	PUG1541_10	47.174949645996	-122.886970520019	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, south end	WA
65046	Peale Passage, north end (Depth 17.1ft), Washington Current	NOS	PUG1542_1	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	132	326	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65047	Peale Passage, north end (Depth 13.8ft), Washington Current	NOS	PUG1542_2	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65048	Peale Passage, north end (Depth 10.5ft), Washington Current	NOS	PUG1542_3	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65049	Peale Passage, north end (Depth 7.3ft), Washington Current	NOS	PUG1542_4	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65050	Peale Passage, north end (Depth 4ft), Washington Current	NOS	PUG1542_5	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	135	326	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65051	Peale Passage, north end (Depth 0.7ft), Washington Current	NOS	PUG1542_6	47.2175216674804	-122.914649963378	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, north end	WA
65052	Squaxin Passage, north of Hunter Point (Depth 31.5ft), Washington Current	NOS	PUG1543_1	47.17626953125	-122.918998718261	:America/Los_Angeles	USA	knots	107	291	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, north of Hunter Point	WA
65053	Squaxin Passage, north of Hunter Point (Depth 18.4ft), Washington Current	NOS	PUG1543_5	47.17626953125	-122.918998718261	:America/Los_Angeles	USA	knots	108	298	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, north of Hunter Point	WA
65054	Squaxin Passage, north of Hunter Point (Depth 5.3ft), Washington Current	NOS	PUG1543_9	47.17626953125	-122.918998718261	:America/Los_Angeles	USA	knots	110	305	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, north of Hunter Point	WA
65055	Totten Inlet entrance (Depth 66.9ft), Washington Current	NOS	PUG1544_3	47.1882514953613	-122.945373535156	:America/Los_Angeles	USA	knots	52	229	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet entrance	WA
65056	Totten Inlet entrance (Depth 40.7ft), Washington Current	NOS	PUG1544_7	47.1882514953613	-122.945373535156	:America/Los_Angeles	USA	knots	39	227	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet entrance	WA
65057	Totten Inlet entrance (Depth 14.4ft), Washington Current	NOS	PUG1544_11	47.1882514953613	-122.945373535156	:America/Los_Angeles	USA	knots	31	222	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet entrance	WA
65058	Libby Point, Hammersley Inlet (Depth 19.4ft), Washington Current	NOS	PUG1545_1	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	77	261	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65059	Libby Point, Hammersley Inlet (Depth 17.8ft), Washington Current	NOS	PUG1545_2	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.301	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65060	Libby Point, Hammersley Inlet (Depth 16.1ft), Washington Current	NOS	PUG1545_3	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65061	Libby Point, Hammersley Inlet (Depth 14.5ft), Washington Current	NOS	PUG1545_4	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.352	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65062	Libby Point, Hammersley Inlet (Depth 12.9ft), Washington Current	NOS	PUG1545_5	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65063	Libby Point, Hammersley Inlet (Depth 11.2ft), Washington Current	NOS	PUG1545_6	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.399	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65064	Libby Point, Hammersley Inlet (Depth 9.6ft), Washington Current	NOS	PUG1545_7	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65065	Libby Point, Hammersley Inlet (Depth 7.9ft), Washington Current	NOS	PUG1545_8	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.437	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65066	Libby Point, Hammersley Inlet (Depth 6.3ft), Washington Current	NOS	PUG1545_9	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.452	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65067	Libby Point, Hammersley Inlet (Depth 4.7ft), Washington Current	NOS	PUG1545_10	47.1989212036132	-122.988998413085	:America/Los_Angeles	USA	knots	84	254	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.448	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
65068	Pickering Passage, west of Squaxin Island (Depth 52.1ft), Washington Current	NOS	PUG1546_1	47.2192802429199	-122.934516906738	:America/Los_Angeles	USA	knots	13	191	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, west of Squaxin Island	WA
65069	Pickering Passage, west of Squaxin Island (Depth 29.1ft), Washington Current	NOS	PUG1546_8	47.2192802429199	-122.934516906738	:America/Los_Angeles	USA	knots	6	194	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, west of Squaxin Island	WA
65070	Pickering Passage, west of Squaxin Island (Depth 9.4ft), Washington Current	NOS	PUG1546_14	47.2192802429199	-122.934516906738	:America/Los_Angeles	USA	knots	3	194	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, west of Squaxin Island	WA
65071	Pickering Passage, off Graham Point (Depth 59ft), Washington Current	NOS	PUG1547_1	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	27	207	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65072	Pickering Passage, off Graham Point (Depth 55.7ft), Washington Current	NOS	PUG1547_2	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65073	Pickering Passage, off Graham Point (Depth 52.5ft), Washington Current	NOS	PUG1547_3	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65074	Pickering Passage, off Graham Point (Depth 49.2ft), Washington Current	NOS	PUG1547_4	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65075	Pickering Passage, off Graham Point (Depth 45.9ft), Washington Current	NOS	PUG1547_5	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65076	Pickering Passage, off Graham Point (Depth 42.6ft), Washington Current	NOS	PUG1547_6	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65077	Pickering Passage, off Graham Point (Depth 39.3ft), Washington Current	NOS	PUG1547_7	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65078	Pickering Passage, off Graham Point (Depth 36.1ft), Washington Current	NOS	PUG1547_8	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65079	Pickering Passage, off Graham Point (Depth 32.8ft), Washington Current	NOS	PUG1547_9	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65080	Pickering Passage, off Graham Point (Depth 29.5ft), Washington Current	NOS	PUG1547_10	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	22	198	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65081	Pickering Passage, off Graham Point (Depth 26.2ft), Washington Current	NOS	PUG1547_11	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65082	Pickering Passage, off Graham Point (Depth 22.9ft), Washington Current	NOS	PUG1547_12	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65083	Pickering Passage, off Graham Point (Depth 19.7ft), Washington Current	NOS	PUG1547_13	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65084	Pickering Passage, off Graham Point (Depth 16.4ft), Washington Current	NOS	PUG1547_14	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65085	Pickering Passage, off Graham Point (Depth 13.1ft), Washington Current	NOS	PUG1547_15	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65086	Pickering Passage, off Graham Point (Depth 9.8ft), Washington Current	NOS	PUG1547_16	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	19	198	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65087	Pickering Passage, off Graham Point (Depth 6.5ft), Washington Current	NOS	PUG1547_17	47.2472496032714	-122.925918579101	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
65088	Pickering Passage, north end (Depth 77.9ft), Washington Current	NOS	PUG1548_1	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	69	258	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65089	Pickering Passage, north end (Depth 71.3ft), Washington Current	NOS	PUG1548_2	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65090	Pickering Passage, north end (Depth 64.7ft), Washington Current	NOS	PUG1548_3	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65091	Pickering Passage, north end (Depth 58.2ft), Washington Current	NOS	PUG1548_4	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65092	Pickering Passage, north end (Depth 51.6ft), Washington Current	NOS	PUG1548_5	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65093	Pickering Passage, north end (Depth 45ft), Washington Current	NOS	PUG1548_6	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	64	260	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65094	Pickering Passage, north end (Depth 38.5ft), Washington Current	NOS	PUG1548_7	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65095	Pickering Passage, north end (Depth 31.9ft), Washington Current	NOS	PUG1548_8	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65096	Pickering Passage, north end (Depth 25.4ft), Washington Current	NOS	PUG1548_9	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65097	Pickering Passage, north end (Depth 18.8ft), Washington Current	NOS	PUG1548_10	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	52	258	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65098	Pickering Passage, north end (Depth 12.2ft), Washington Current	NOS	PUG1548_11	47.3057212829589	-122.850921630859	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, north end	WA
65099	Hazel Point (Depth 153.7ft), Washington Current	NOS	PUG1601_1	47.6912384033203	-122.762786865234	:America/Los_Angeles	USA	knots	20	193	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
65100	Hazel Point (Depth 88.1ft), Washington Current	NOS	PUG1601_11	47.6912384033203	-122.762786865234	:America/Los_Angeles	USA	knots	23	200	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
65101	Hazel Point (Depth 22.5ft), Washington Current	NOS	PUG1601_21	47.6912384033203	-122.762786865234	:America/Los_Angeles	USA	knots	13	181	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
65102	South Point (Depth 177.9ft), Washington Current	NOS	PUG1602_1	47.8216590881347	-122.676719665527	:America/Los_Angeles	USA	knots	41	234	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
65103	South Point (Depth 43.4ft), Washington Current	NOS	PUG1602_42	47.8216590881347	-122.676719665527	:America/Los_Angeles	USA	knots	42	231	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
65104	South Point (Depth 23.7ft), Washington Current	NOS	PUG1602_48	47.8216590881347	-122.676719665527	:America/Los_Angeles	USA	knots	41	230	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
65105	Hood Canal Bridge (Depth 208.9ft), Washington Current	NOS	PUG1603_1	47.8547401428222	-122.629417419433	:America/Los_Angeles	USA	knots	37	223	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
65106	Hood Canal Bridge (Depth 110.5ft), Washington Current	NOS	PUG1603_11	47.8547401428222	-122.629417419433	:America/Los_Angeles	USA	knots	45	223	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
65107	Hood Canal Bridge (Depth 21.9ft), Washington Current	NOS	PUG1603_20	47.8547401428222	-122.629417419433	:America/Los_Angeles	USA	knots	46	219	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
65108	Port Gamble Bay entrance (Depth 32.4ft), Washington Current	NOS	PUG1604_1	47.8547210693359	-122.578178405761	:America/Los_Angeles	USA	knots	20	204	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gamble Bay entrance	WA
65109	Port Gamble Bay entrance (Depth 9.5ft), Washington Current	NOS	PUG1604_8	47.8547210693359	-122.578178405761	:America/Los_Angeles	USA	knots	14	197	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gamble Bay entrance	WA
65110	Possession Sound entrance (Depth 321.5ft), Washington Current	NOS	PUG1605_20	47.8992805480957	-122.360076904296	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound entrance	WA
65111	Possession Sound entrance (Depth 190.2ft), Washington Current	NOS	PUG1605_30	47.8992805480957	-122.360076904296	:America/Los_Angeles	USA	knots	198	8	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound entrance	WA
65112	Possession Sound entrance (Depth 59ft), Washington Current	NOS	PUG1605_40	47.8992805480957	-122.360076904296	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound entrance	WA
65113	Point No Point, 1.2 mi. E of (Depth 567.3ft), Washington Current	NOS	PUG1606_1	47.9124908447265	-122.501968383789	:America/Los_Angeles	USA	knots	321	149	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
65114	Point No Point, 1.2 mi. E of (Depth 107.9ft), Washington Current	NOS	PUG1606_36	47.9124908447265	-122.501968383789	:America/Los_Angeles	USA	knots	338	164	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.285	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
65115	Point No Point, 1.2 mi. E of (Depth 68.6ft), Washington Current	NOS	PUG1606_39	47.9124908447265	-122.501968383789	:America/Los_Angeles	USA	knots	336	164	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.321	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
65116	Point No Point, 2.1 mi. E of (Depth 240.5ft), Washington Current	NOS	PUG1607_1	47.91888	-122.48413	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
65117	Point No Point, 2.1 mi. E of (Depth 56.8ft), Washington Current	NOS	PUG1607_29	47.91888	-122.48413	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
65118	Point No Point, 2.1 mi. E of (Depth 30.5ft), Washington Current	NOS	PUG1607_33	47.91888	-122.48413	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
65119	Hood Canal entrance (Depth 255ft), Washington Current	NOS	PUG1608_1	47.9283790588378	-122.638816833496	:America/Los_Angeles	USA	knots	0	173	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal entrance	WA
65120	Hood Canal entrance (Depth 77.8ft), Washington Current	NOS	PUG1608_28	47.9283790588378	-122.638816833496	:America/Los_Angeles	USA	knots	352	164	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal entrance	WA
65121	Hood Canal entrance (Depth 31.9ft), Washington Current	NOS	PUG1608_35	47.9283790588378	-122.638816833496	:America/Los_Angeles	USA	knots	340	153	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal entrance	WA
65122	West of Mukilteo (Depth 271.5ft), Washington Current	NOS	PUG1609_20	47.9489517211914	-122.328460693359	:America/Los_Angeles	USA	knots	205	17	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
65123	West of Mukilteo (Depth 140.2ft), Washington Current	NOS	PUG1609_30	47.9489517211914	-122.328460693359	:America/Los_Angeles	USA	knots	205	16	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
65124	West of Mukilteo (Depth 61.5ft), Washington Current	NOS	PUG1609_36	47.9489517211914	-122.328460693359	:America/Los_Angeles	USA	knots	198	13	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
65125	Foulweather Bluff, 1.9 mi. NE of (Depth 124.9ft), Washington Current	NOS	PUG1610_17	47.9542999267578	-122.57859802246	:America/Los_Angeles	USA	knots	305	141	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
65126	Foulweather Bluff, 1.9 mi. NE of (Depth 26.5ft), Washington Current	NOS	PUG1610_32	47.9542999267578	-122.57859802246	:America/Los_Angeles	USA	knots	304	125	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.297	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
65127	Foulweather Bluff, 1.9 mi. NE of (Depth 19.9ft), Washington Current	NOS	PUG1610_33	47.9542999267578	-122.57859802246	:America/Los_Angeles	USA	knots	302	125	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
65128	Olele Point, 1.8 mi. ENE of (Depth 148.3ft), Washington Current	NOS	PUG1611_10	47.9788093566894	-122.64549255371	:America/Los_Angeles	USA	knots	333	189	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
65129	Olele Point, 1.8 mi. ENE of (Depth 66.2ft), Washington Current	NOS	PUG1611_35	47.9788093566894	-122.64549255371	:America/Los_Angeles	USA	knots	340	169	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
65130	Olele Point, 1.8 mi. ENE of (Depth 23.6ft), Washington Current	NOS	PUG1611_48	47.9788093566894	-122.64549255371	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.166	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
65131	Olele Point, 1.8 mi. ENE of (Depth 20.3ft), Washington Current	NOS	PUG1611_49	47.9788093566894	-122.64549255371	:America/Los_Angeles	USA	knots	342	149	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
65132	Clinton Ferry Terminal (Depth 79.6ft), Washington Current	NOS	PUG1612_1	47.96899	-122.34507	:America/Los_Angeles	USA	knots	184	16	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
65227	Rosario Strait (Depth 184.6ft), Washington Current	NOS	PUG1702_2	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65133	Clinton Ferry Terminal (Depth 46.8ft), Washington Current	NOS	PUG1612_6	47.96899	-122.34507	:America/Los_Angeles	USA	knots	187	349	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
65134	Clinton Ferry Terminal (Depth 20.5ft), Washington Current	NOS	PUG1612_10	47.96899	-122.34507	:America/Los_Angeles	USA	knots	178	4	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
65135	Everett (Depth 24.6ft), Washington Current	NOS	PUG1613_29	47.9762382507324	-122.238220214843	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Everett	WA
65136	Port Townsend Canal (Depth 15ft), Washington Current	NOS	PUG1614_1	48.032470703125	-122.732612609863	:America/Los_Angeles	USA	knots	323	145	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend Canal	WA
65137	Port Townsend Canal (Depth 5.1ft), Washington Current	NOS	PUG1614_7	48.032470703125	-122.732612609863	:America/Los_Angeles	USA	knots	323	140	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.836	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend Canal	WA
65138	Nodule Point, 0.5 mi. SE of (Depth 64.8ft), Washington Current	NOS	PUG1615_1	48.028709411621	-122.660888671875	:America/Los_Angeles	USA	knots	347	162	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.214	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
65139	Nodule Point, 0.5 mi. SE of (Depth 25.4ft), Washington Current	NOS	PUG1615_13	48.028709411621	-122.660888671875	:America/Los_Angeles	USA	knots	353	162	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.573	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
65140	Nodule Point, 0.5 mi. SE of (Depth 9ft), Washington Current	NOS	PUG1615_18	48.028709411621	-122.660888671875	:America/Los_Angeles	USA	knots	357	162	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.589	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
65141	Admiralty Inlet (off Bush Point) (Depth 193.1ft), Washington Current	NOS	PUG1616_6	48.0334815979003	-122.637649536132	:America/Los_Angeles	USA	knots	0	176	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
65142	Admiralty Inlet (off Bush Point) (Depth 68.4ft), Washington Current	NOS	PUG1616_25	48.0334815979003	-122.637649536132	:America/Los_Angeles	USA	knots	349	181	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.312	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
65143	Admiralty Inlet (off Bush Point) (Depth 29ft), Washington Current	NOS	PUG1616_31	48.0334815979003	-122.637649536132	:America/Los_Angeles	USA	knots	347	180	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.529	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
65144	Bush Point Light, 0.5 mile NW of (Depth 208ft), Washington Current	NOS	PUG1617_14	48.0308418273925	-122.613342285156	:America/Los_Angeles	USA	knots	348	187	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
65145	Bush Point Light, 0.5 mile NW of (Depth 76.7ft), Washington Current	NOS	PUG1617_34	48.0308418273925	-122.613342285156	:America/Los_Angeles	USA	knots	338	189	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
65146	Bush Point Light, 0.5 mile NW of (Depth 43.9ft), Washington Current	NOS	PUG1617_39	48.0308418273925	-122.613342285156	:America/Los_Angeles	USA	knots	336	189	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
65147	Camano Head-Sandy Point, passage (Depth 209.1ft), Washington Current	NOS	PUG1618_15	48.04785	-122.38897	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
65148	Camano Head-Sandy Point, passage (Depth 77.8ft), Washington Current	NOS	PUG1618_35	48.04785	-122.38897	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
65149	Camano Head-Sandy Point, passage (Depth 31.9ft), Washington Current	NOS	PUG1618_42	48.04785	-122.38897	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
65150	Marrowstone Point, 0.8 mi. NE of (Depth 150.8ft), Washington Current	NOS	PUG1619_9	48.106330871582	-122.672470092773	:America/Los_Angeles	USA	knots	344	119	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.269	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
65151	Marrowstone Point, 0.8 mi. NE of (Depth 62.2ft), Washington Current	NOS	PUG1619_36	48.106330871582	-122.672470092773	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
65152	Marrowstone Point, 0.8 mi. NE of (Depth 29.4ft), Washington Current	NOS	PUG1619_46	48.106330871582	-122.672470092773	:America/Los_Angeles	USA	knots	349	129	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
65153	Marrowstone Point, 1.65 mi. NE of (Depth 144.2ft), Washington Current	NOS	PUG1620_10	48.1193008422851	-122.662269592285	:America/Los_Angeles	USA	knots	315	139	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.301	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
65154	Marrowstone Point, 1.65 mi. NE of (Depth 78.5ft), Washington Current	NOS	PUG1620_20	48.1193008422851	-122.662269592285	:America/Los_Angeles	USA	knots	326	142	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
65155	Marrowstone Point, 1.65 mi. NE of (Depth 26ft), Washington Current	NOS	PUG1620_28	48.1193008422851	-122.662269592285	:America/Los_Angeles	USA	knots	333	145	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
65156	West of Camano Island (Depth 180ft), Washington Current	NOS	PUG1622_3	48.1696815490722	-122.553199768066	:America/Los_Angeles	USA	knots	159	354	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
65157	West of Camano Island (Depth 68.5ft), Washington Current	NOS	PUG1622_20	48.1696815490722	-122.553199768066	:America/Los_Angeles	USA	knots	151	341	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
65158	West of Camano Island (Depth 22.5ft), Washington Current	NOS	PUG1622_27	48.1696815490722	-122.553199768066	:America/Los_Angeles	USA	knots	159	352	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
65159	Point Wilson, 0.6 mi. NE of (Depth 118.4ft), Washington Current	NOS	PUG1623_14	48.1501083374023	-122.745361328125	:America/Los_Angeles	USA	knots	325	132	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
65160	Point Wilson, 0.6 mi. NE of (Depth 56.1ft), Washington Current	NOS	PUG1623_33	48.1501083374023	-122.745361328125	:America/Los_Angeles	USA	knots	322	124	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
65161	Point Wilson, 0.6 mi. NE of (Depth 16.7ft), Washington Current	NOS	PUG1623_45	48.1501083374023	-122.745361328125	:America/Los_Angeles	USA	knots	321	120	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
65162	Point Wilson, 1.6 mi. NE of (Depth 148.8ft), Washington Current	NOS	PUG1624_8	48.1568717956543	-122.726028442382	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
65163	Point Wilson, 1.6 mi. NE of (Depth 86.5ft), Washington Current	NOS	PUG1624_27	48.1568717956543	-122.726028442382	:America/Los_Angeles	USA	knots	316	117	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
65164	Point Wilson, 1.6 mi. NE of (Depth 20.9ft), Washington Current	NOS	PUG1624_47	48.1568717956543	-122.726028442382	:America/Los_Angeles	USA	knots	319	126	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
65165	Point Wilson, 2.7 mi. NE of (Depth 118.2ft), Washington Current	NOS	PUG1625_15	48.1670684814453	-122.707389831542	:America/Los_Angeles	USA	knots	333	135	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
65166	Point Wilson, 2.7 mi. NE of (Depth 55.9ft), Washington Current	NOS	PUG1625_34	48.1670684814453	-122.707389831542	:America/Los_Angeles	USA	knots	333	137	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
65167	Point Wilson, 2.7 mi. NE of (Depth 19.8ft), Washington Current	NOS	PUG1625_45	48.1670684814453	-122.707389831542	:America/Los_Angeles	USA	knots	333	138	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
65168	Skagit Bay, 1 mi. north of Rocky Point (Depth 54.4ft), Washington Current	NOS	PUG1626_7	48.2671203613281	-122.529571533203	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
65169	Skagit Bay, 1 mi. north of Rocky Point (Depth 28.1ft), Washington Current	NOS	PUG1626_15	48.2671203613281	-122.529571533203	:America/Los_Angeles	USA	knots	246	51	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
65170	Skagit Bay, 1 mi. north of Rocky Point (Depth 11.7ft), Washington Current	NOS	PUG1626_20	48.2671203613281	-122.529571533203	:America/Los_Angeles	USA	knots	234	59	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
65171	Skagit Bay, 1 mi. south of Goat Island (Depth 51.6ft), Washington Current	NOS	PUG1627_5	48.3447799682617	-122.545051574707	:America/Los_Angeles	USA	knots	154	332	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
65172	Skagit Bay, 1 mi. south of Goat Island (Depth 32ft), Washington Current	NOS	PUG1627_11	48.3447799682617	-122.545051574707	:America/Los_Angeles	USA	knots	149	333	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
65173	Skagit Bay, 1 mi. south of Goat Island (Depth 12.3ft), Washington Current	NOS	PUG1627_17	48.3447799682617	-122.545051574707	:America/Los_Angeles	USA	knots	147	329	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
65174	Skagit Bay channel, SW of Hope Island (Depth 39ft), Washington Current	NOS	PUG1628_4	48.3978309631347	-122.579551696777	:America/Los_Angeles	USA	knots	174	345	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
65175	Skagit Bay channel, SW of Hope Island (Depth 25.9ft), Washington Current	NOS	PUG1628_8	48.3978309631347	-122.579551696777	:America/Los_Angeles	USA	knots	168	345	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
65176	Skagit Bay channel, SW of Hope Island (Depth 9.5ft), Washington Current	NOS	PUG1628_13	48.3978309631347	-122.579551696777	:America/Los_Angeles	USA	knots	170	345	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
65177	Yokeko Point, Deception Pass (Depth 26.7ft), Washington Current	NOS	PUG1629_3	48.4127197265625	-122.613166809082	:America/Los_Angeles	USA	knots	226	52	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
65178	Yokeko Point, Deception Pass (Depth 13.6ft), Washington Current	NOS	PUG1629_7	48.4127197265625	-122.613166809082	:America/Los_Angeles	USA	knots	228	54	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
65179	Yokeko Point, Deception Pass (Depth 7ft), Washington Current	NOS	PUG1629_9	48.4127197265625	-122.613166809082	:America/Los_Angeles	USA	knots	230	55	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
65180	Kanem Point, 1.5 mi. SW of Protection Island (Depth 97.3ft), Washington Current	NOS	PUG1630_30	48.1076507568359	-122.973648071289	:America/Los_Angeles	USA	knots	289	121	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
65181	Kanem Point, 1.5 mi. SW of Protection Island (Depth 54.7ft), Washington Current	NOS	PUG1630_43	48.1076507568359	-122.973648071289	:America/Los_Angeles	USA	knots	284	125	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
65182	Kanem Point, 1.5 mi. SW of Protection Island (Depth 21.9ft), Washington Current	NOS	PUG1630_53	48.1076507568359	-122.973648071289	:America/Los_Angeles	USA	knots	279	117	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
65183	Violet Point, 3.7 mi. NW of Protection Island (Depth 111.8ft), Washington Current	NOS	PUG1631_4	48.1613998413085	-122.968101501464	:America/Los_Angeles	USA	knots	304	107	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
65184	Violet Point, 3.7 mi. NW of Protection Island (Depth 39.7ft), Washington Current	NOS	PUG1631_26	48.1613998413085	-122.968101501464	:America/Los_Angeles	USA	knots	297	103	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
65185	Violet Point, 3.7 mi. NW of Protection Island (Depth 16.7ft), Washington Current	NOS	PUG1631_33	48.1613998413085	-122.968101501464	:America/Los_Angeles	USA	knots	290	102	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
65186	Smith Island, 5.5 mi. WNW of (Depth 220ft), Washington Current	NOS	PUG1632_14	48.3245506286621	-122.964752197265	:America/Los_Angeles	USA	knots	253	78	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
65187	Smith Island, 5.5 mi. WNW of (Depth 141.2ft), Washington Current	NOS	PUG1632_26	48.3245506286621	-122.964752197265	:America/Los_Angeles	USA	knots	253	60	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
65188	Smith Island, 5.5 mi. WNW of (Depth 42.8ft), Washington Current	NOS	PUG1632_41	48.3245506286621	-122.964752197265	:America/Los_Angeles	USA	knots	255	58	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
65189	Point Partridge, 2.4 mi. NW of (Depth 130ft), Washington Current	NOS	PUG1633_15	48.25562	-122.79303	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.353	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Partridge, 2.4 mi. NW of	WA
65190	Point Partridge, 2.4 mi. NW of (Depth 77.5ft), Washington Current	NOS	PUG1633_23	48.25562	-122.79303	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.463	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Partridge, 2.4 mi. NW of	WA
65191	Point Partridge, 2.4 mi. NW of (Depth 25ft), Washington Current	NOS	PUG1633_31	48.25562	-122.79303	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Partridge, 2.4 mi. NW of	WA
65192	Smith Island, 3.4 mi. ESE of (Depth 134.4ft), Washington Current	NOS	PUG1634_1	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	230	102	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65193	Smith Island, 3.4 mi. ESE of (Depth 88.5ft), Washington Current	NOS	PUG1634_15	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.465	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65194	Smith Island, 3.4 mi. ESE of (Depth 62.2ft), Washington Current	NOS	PUG1634_23	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.596	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65195	Smith Island, 3.4 mi. ESE of (Depth 55.6ft), Washington Current	NOS	PUG1634_25	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	218	109	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.617	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65196	Smith Island, 3.4 mi. ESE of (Depth 36ft), Washington Current	NOS	PUG1634_31	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.652	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65197	Smith Island, 3.4 mi. ESE of (Depth 19.6ft), Washington Current	NOS	PUG1634_36	48.2963790893554	-122.776321411132	:America/Los_Angeles	USA	knots	218	114	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.663	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
65198	New Dungeness Light, 2.8 mi. NNW of (Depth 360.1ft), Washington Current	NOS	PUG1635_11	48.2334785461425	-123.133430480957	:America/Los_Angeles	USA	knots	244	73	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
65199	New Dungeness Light, 2.8 mi. NNW of (Depth 71.4ft), Washington Current	NOS	PUG1635_55	48.2334785461425	-123.133430480957	:America/Los_Angeles	USA	knots	273	69	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.346	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
65200	New Dungeness Light, 2.8 mi. NNW of (Depth 51.7ft), Washington Current	NOS	PUG1635_58	48.2334785461425	-123.133430480957	:America/Los_Angeles	USA	knots	273	66	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.405	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
65201	Discovery Island, 7.6 mi. SSE of (Depth 244.3ft), Washington Current	NOS	PUG1636_1	48.3001518249511	-123.167160034179	:America/Los_Angeles	USA	knots	220	54	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
65202	Discovery Island, 7.6 mi. SSE of (Depth 119.6ft), Washington Current	NOS	PUG1636_20	48.3001518249511	-123.167160034179	:America/Los_Angeles	USA	knots	245	72	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
65203	Discovery Island, 7.6 mi. SSE of (Depth 27.7ft), Washington Current	NOS	PUG1636_34	48.3001518249511	-123.167160034179	:America/Los_Angeles	USA	knots	240	69	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.187	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
65204	Ediz Hook Light, 5.3 mi. ENE of (Depth 179.2ft), Washington Current	NOS	PUG1637_5	48.1822700500488	-123.281501770019	:America/Los_Angeles	USA	knots	260	78	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
65205	Ediz Hook Light, 5.3 mi. ENE of (Depth 28.3ft), Washington Current	NOS	PUG1637_28	48.1822700500488	-123.281501770019	:America/Los_Angeles	USA	knots	258	88	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
65206	Ediz Hook Light, 5.3 mi. ENE of (Depth 21.8ft), Washington Current	NOS	PUG1637_29	48.1822700500488	-123.281501770019	:America/Los_Angeles	USA	knots	257	88	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.517	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
65207	Ediz Hook Light, 1.2 miles N of (Depth 183.6ft), Washington Current	NOS	PUG1638_7	48.166690826416	-123.415817260742	:America/Los_Angeles	USA	knots	279	112	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
65208	Ediz Hook Light, 1.2 miles N of (Depth 85.1ft), Washington Current	NOS	PUG1638_17	48.166690826416	-123.415817260742	:America/Los_Angeles	USA	knots	282	90	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
65209	Ediz Hook Light, 1.2 miles N of (Depth 35.9ft), Washington Current	NOS	PUG1638_22	48.166690826416	-123.415817260742	:America/Los_Angeles	USA	knots	283	89	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.358	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
65210	Angeles Pt., 2 mi. NNE of (Depth 60.9ft), Washington Current	NOS	PUG1639_1	48.1769981384277	-123.526947021484	:America/Los_Angeles	USA	knots	304	69	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
65211	Angeles Pt., 2 mi. NNE of (Depth 24.8ft), Washington Current	NOS	PUG1639_12	48.1769981384277	-123.526947021484	:America/Los_Angeles	USA	knots	300	75	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.257	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
65212	Angeles Pt., 2 mi. NNE of (Depth 11.7ft), Washington Current	NOS	PUG1639_16	48.1769981384277	-123.526947021484	:America/Los_Angeles	USA	knots	300	75	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
65213	Race Rocks, 4.5 mi. S of (Depth 394.4ft), Washington Current	NOS	PUG1640_1	48.2232017517089	-123.532302856445	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
65214	Race Rocks, 4.5 mi. S of (Depth 236.9ft), Washington Current	NOS	PUG1640_9	48.2232017517089	-123.532302856445	:America/Los_Angeles	USA	knots	274	82	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
65215	Race Rocks, 4.5 mi. S of (Depth 59.7ft), Washington Current	NOS	PUG1640_18	48.2232017517089	-123.532302856445	:America/Los_Angeles	USA	knots	268	91	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.596	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
65216	Pillar Point, 6 mi. NNE of (Depth 296.6ft), Washington Current	NOS	PUG1641_36	48.2999992370605	-124.037399291992	:America/Los_Angeles	USA	knots	273	93	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
65217	Pillar Point, 6 mi. NNE of (Depth 73.5ft), Washington Current	NOS	PUG1641_70	48.2999992370605	-124.037399291992	:America/Los_Angeles	USA	knots	293	114	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
65218	Pillar Point, 6 mi. NNE of (Depth 40.7ft), Washington Current	NOS	PUG1641_75	48.2999992370605	-124.037399291992	:America/Los_Angeles	USA	knots	290	115	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.288	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
65219	Strait of Juan de Fuca entrance (Depth 705.4ft), Washington Current	NOS	PUG1642_3	48.4499816894531	-124.583801269531	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca entrance	WA
65220	Strait of Juan de Fuca entrance (Depth 456.1ft), Washington Current	NOS	PUG1642_22	48.4499816894531	-124.583801269531	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca entrance	WA
65221	Strait of Juan de Fuca entrance (Depth 101.8ft), Washington Current	NOS	PUG1642_49	48.4499816894531	-124.583801269531	:America/Los_Angeles	USA	knots	306	113	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.564	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca entrance	WA
65222	Strait of Juan de Fuca entrance (Depth 88.6ft), Washington Current	NOS	PUG1642_50	48.4499816894531	-124.583801269531	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca entrance	WA
65223	Deception Pass (Narrows) (Depth 66.8ft), Washington Current	NOS	PUG1701_18	48.4061889648437	-122.643119812011	:America/Los_Angeles	USA	knots	270	96	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
65224	Deception Pass (Narrows) (Depth 47.1ft), Washington Current	NOS	PUG1701_24	48.4061889648437	-122.643119812011	:America/Los_Angeles	USA	knots	270	98	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.647	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
65225	Deception Pass (Narrows) (Depth 17.6ft), Washington Current	NOS	PUG1701_33	48.4061889648437	-122.643119812011	:America/Los_Angeles	USA	knots	277	108	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.618	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
65226	Rosario Strait (Depth 194.5ft), Washington Current	NOS	PUG1702_1	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65228	Rosario Strait (Depth 174.8ft), Washington Current	NOS	PUG1702_3	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65229	Rosario Strait (Depth 164.9ft), Washington Current	NOS	PUG1702_4	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65230	Rosario Strait (Depth 155.1ft), Washington Current	NOS	PUG1702_5	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65231	Rosario Strait (Depth 145.2ft), Washington Current	NOS	PUG1702_6	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65232	Rosario Strait (Depth 135.4ft), Washington Current	NOS	PUG1702_7	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.276	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65233	Rosario Strait (Depth 125.6ft), Washington Current	NOS	PUG1702_8	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65234	Rosario Strait (Depth 115.7ft), Washington Current	NOS	PUG1702_9	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	183	0	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65235	Rosario Strait (Depth 105.9ft), Washington Current	NOS	PUG1702_10	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.376	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65236	Rosario Strait (Depth 96ft), Washington Current	NOS	PUG1702_11	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.406	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65237	Rosario Strait (Depth 86.2ft), Washington Current	NOS	PUG1702_12	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65238	Rosario Strait (Depth 76.3ft), Washington Current	NOS	PUG1702_13	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	187	0	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.458	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65239	Rosario Strait (Depth 66.5ft), Washington Current	NOS	PUG1702_14	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.478	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65240	Rosario Strait (Depth 56.7ft), Washington Current	NOS	PUG1702_15	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.493	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65241	Rosario Strait (Depth 46.8ft), Washington Current	NOS	PUG1702_16	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	190	357	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65242	Rosario Strait (Depth 37ft), Washington Current	NOS	PUG1702_17	48.4580917358398	-122.75006866455	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
65243	San Juan Channel, south entrance (Depth 141ft), Washington Current	NOS	PUG1703_13	48.461009979248	-122.952026367187	:America/Los_Angeles	USA	knots	169	311	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
65244	San Juan Channel, south entrance (Depth 91.8ft), Washington Current	NOS	PUG1703_16	48.461009979248	-122.952026367187	:America/Los_Angeles	USA	knots	169	346	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.507	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
65245	San Juan Channel, south entrance (Depth 75.4ft), Washington Current	NOS	PUG1703_17	48.461009979248	-122.952026367187	:America/Los_Angeles	USA	knots	168	347	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.494	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
65246	Peavine Pass, west entrance (Depth 48.1ft), Washington Current	NOS	PUG1704_1	48.5870780944824	-122.819259643554	:America/Los_Angeles	USA	knots	235	50	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.401	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
65247	Peavine Pass, west entrance (Depth 18.5ft), Washington Current	NOS	PUG1704_10	48.5870780944824	-122.819259643554	:America/Los_Angeles	USA	knots	232	56	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.613	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
65305	Parker Reef Light, north of (Depth 97ft), Washington Current	NOS	PUG1712_15	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65248	Peavine Pass, west entrance (Depth 8.7ft), Washington Current	NOS	PUG1704_13	48.5870780944824	-122.819259643554	:America/Los_Angeles	USA	knots	231	56	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.629	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
65249	Obstruction Pass, north of Obstruction Island (Depth 53.9ft), Washington Current	NOS	PUG1705_1	48.603271484375	-122.812728881835	:America/Los_Angeles	USA	knots	274	100	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
65250	Obstruction Pass, north of Obstruction Island (Depth 14.5ft), Washington Current	NOS	PUG1705_13	48.603271484375	-122.812728881835	:America/Los_Angeles	USA	knots	286	88	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
65251	Obstruction Pass, north of Obstruction Island (Depth 7.9ft), Washington Current	NOS	PUG1705_15	48.603271484375	-122.812728881835	:America/Los_Angeles	USA	knots	286	87	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
65252	Peapod Rocks Light, 1.2 nm south of (Depth 170ft), Washington Current	NOS	PUG1706_1	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	218	35	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65253	Peapod Rocks Light, 1.2 nm south of (Depth 156.9ft), Washington Current	NOS	PUG1706_2	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65254	Peapod Rocks Light, 1.2 nm south of (Depth 143.7ft), Washington Current	NOS	PUG1706_3	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65255	Peapod Rocks Light, 1.2 nm south of (Depth 130.6ft), Washington Current	NOS	PUG1706_4	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.225	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65256	Peapod Rocks Light, 1.2 nm south of (Depth 117.5ft), Washington Current	NOS	PUG1706_5	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65257	Peapod Rocks Light, 1.2 nm south of (Depth 104.4ft), Washington Current	NOS	PUG1706_6	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.264	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65258	Peapod Rocks Light, 1.2 nm south of (Depth 91.2ft), Washington Current	NOS	PUG1706_7	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65259	Peapod Rocks Light, 1.2 nm south of (Depth 78.1ft), Washington Current	NOS	PUG1706_8	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	218	26	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.296	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65260	Peapod Rocks Light, 1.2 nm south of (Depth 65ft), Washington Current	NOS	PUG1706_9	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65261	Peapod Rocks Light, 1.2 nm south of (Depth 51.9ft), Washington Current	NOS	PUG1706_10	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65262	Peapod Rocks Light, 1.2 nm south of (Depth 38.7ft), Washington Current	NOS	PUG1706_11	48.6223907470703	-122.747619628906	:America/Los_Angeles	USA	knots	220	22	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.358	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
65263	Sinclair Island, 1.0 nm NE of (Depth 170.7ft), Washington Current	NOS	PUG1707_6	48.6441993713378	-122.658721923828	:America/Los_Angeles	USA	knots	131	327	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
65264	Sinclair Island, 1.0 nm NE of (Depth 98.5ft), Washington Current	NOS	PUG1707_17	48.6441993713378	-122.658721923828	:America/Los_Angeles	USA	knots	131	327	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.292	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
65265	Sinclair Island, 1.0 nm NE of (Depth 26.3ft), Washington Current	NOS	PUG1707_28	48.6441993713378	-122.658721923828	:America/Los_Angeles	USA	knots	131	324	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
65266	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 233.5ft), Washington Current	NOS	PUG1708_1	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65267	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 220.4ft), Washington Current	NOS	PUG1708_2	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65268	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 207.3ft), Washington Current	NOS	PUG1708_3	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65269	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 194.2ft), Washington Current	NOS	PUG1708_4	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65270	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 181ft), Washington Current	NOS	PUG1708_5	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65271	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 167.9ft), Washington Current	NOS	PUG1708_6	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65272	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 154.8ft), Washington Current	NOS	PUG1708_7	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65273	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 141.7ft), Washington Current	NOS	PUG1708_8	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65274	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 128.5ft), Washington Current	NOS	PUG1708_9	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65275	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 115.4ft), Washington Current	NOS	PUG1708_10	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	152	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65276	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 102.3ft), Washington Current	NOS	PUG1708_11	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65277	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 89.2ft), Washington Current	NOS	PUG1708_12	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65278	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 76ft), Washington Current	NOS	PUG1708_13	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65279	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 62.9ft), Washington Current	NOS	PUG1708_14	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	152	349	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65280	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 49.8ft), Washington Current	NOS	PUG1708_15	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65281	Lawrence Point, Orcas Island, 1.3 nm NE of (Depth 36.7ft), Washington Current	NOS	PUG1708_16	48.6794090270996	-122.714668273925	:America/Los_Angeles	USA	knots	151	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
65282	Clark Island, 1.6 nm north of (Depth 179.6ft), Washington Current	NOS	PUG1709_10	48.7312583923339	-122.773376464843	:America/Los_Angeles	USA	knots	150	333	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
65283	Clark Island, 1.6 nm north of (Depth 48.4ft), Washington Current	NOS	PUG1709_30	48.7312583923339	-122.773376464843	:America/Los_Angeles	USA	knots	157	336	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
65284	Clark Island, 1.6 nm north of (Depth 28.7ft), Washington Current	NOS	PUG1709_33	48.7312583923339	-122.773376464843	:America/Los_Angeles	USA	knots	159	335	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
65344	Wasp Passage narrows (Depth 53.6ft), Washington Current	NOS	PUG1721_4	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65285	Hale Passage, east of Lummi Point (Depth 43.7ft), Washington Current	NOS	PUG1710_3	48.7348518371582	-122.680168151855	:America/Los_Angeles	USA	knots	158	350	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
65286	Hale Passage, east of Lummi Point (Depth 27.3ft), Washington Current	NOS	PUG1710_8	48.7348518371582	-122.680168151855	:America/Los_Angeles	USA	knots	167	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
65287	Hale Passage, east of Lummi Point (Depth 7.6ft), Washington Current	NOS	PUG1710_14	48.7348518371582	-122.680168151855	:America/Los_Angeles	USA	knots	177	349	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
65288	Matia Island, west of (Depth 335.9ft), Washington Current	NOS	PUG1711_4	48.7748794555664	-122.84097290039	:America/Los_Angeles	USA	knots	135	299	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
65289	Matia Island, west of (Depth 86.5ft), Washington Current	NOS	PUG1711_23	48.7748794555664	-122.84097290039	:America/Los_Angeles	USA	knots	149	325	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
65290	Matia Island, west of (Depth 47.1ft), Washington Current	NOS	PUG1711_26	48.7748794555664	-122.84097290039	:America/Los_Angeles	USA	knots	153	327	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
65291	Parker Reef Light, north of (Depth 188.8ft), Washington Current	NOS	PUG1712_1	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65292	Parker Reef Light, north of (Depth 182.3ft), Washington Current	NOS	PUG1712_2	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65293	Parker Reef Light, north of (Depth 175.7ft), Washington Current	NOS	PUG1712_3	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65294	Parker Reef Light, north of (Depth 169.2ft), Washington Current	NOS	PUG1712_4	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65295	Parker Reef Light, north of (Depth 162.6ft), Washington Current	NOS	PUG1712_5	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65296	Parker Reef Light, north of (Depth 156ft), Washington Current	NOS	PUG1712_6	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65297	Parker Reef Light, north of (Depth 149.5ft), Washington Current	NOS	PUG1712_7	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65298	Parker Reef Light, north of (Depth 142.9ft), Washington Current	NOS	PUG1712_8	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65299	Parker Reef Light, north of (Depth 136.4ft), Washington Current	NOS	PUG1712_9	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65300	Parker Reef Light, north of (Depth 129.8ft), Washington Current	NOS	PUG1712_10	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	280	91	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65301	Parker Reef Light, north of (Depth 123.2ft), Washington Current	NOS	PUG1712_11	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65302	Parker Reef Light, north of (Depth 116.7ft), Washington Current	NOS	PUG1712_12	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65303	Parker Reef Light, north of (Depth 110.1ft), Washington Current	NOS	PUG1712_13	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65304	Parker Reef Light, north of (Depth 103.5ft), Washington Current	NOS	PUG1712_14	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65306	Parker Reef Light, north of (Depth 90.4ft), Washington Current	NOS	PUG1712_16	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65307	Parker Reef Light, north of (Depth 83.9ft), Washington Current	NOS	PUG1712_17	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65308	Parker Reef Light, north of (Depth 77.3ft), Washington Current	NOS	PUG1712_18	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65309	Parker Reef Light, north of (Depth 70.7ft), Washington Current	NOS	PUG1712_19	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65310	Parker Reef Light, north of (Depth 64.2ft), Washington Current	NOS	PUG1712_20	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65311	Parker Reef Light, north of (Depth 57.6ft), Washington Current	NOS	PUG1712_21	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65312	Parker Reef Light, north of (Depth 51ft), Washington Current	NOS	PUG1712_22	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65313	Parker Reef Light, north of (Depth 44.5ft), Washington Current	NOS	PUG1712_23	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	257	81	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65314	Parker Reef Light, north of (Depth 37.9ft), Washington Current	NOS	PUG1712_24	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65315	Parker Reef Light, north of (Depth 31.4ft), Washington Current	NOS	PUG1712_25	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	254	79	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.268	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65316	Parker Reef Light, north of (Depth 24.8ft), Washington Current	NOS	PUG1712_26	48.7326393127441	-122.88638305664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
65317	Patos Island, south of Toe Point (Depth 62.7ft), Washington Current	NOS	PUG1713_10	48.7720603942871	-122.933700561523	:America/Los_Angeles	USA	knots	196	46	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.267	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
65318	Patos Island, south of Toe Point (Depth 29.9ft), Washington Current	NOS	PUG1713_20	48.7720603942871	-122.933700561523	:America/Los_Angeles	USA	knots	191	52	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.356	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
65319	Patos Island, south of Toe Point (Depth 13.5ft), Washington Current	NOS	PUG1713_25	48.7720603942871	-122.933700561523	:America/Los_Angeles	USA	knots	188	54	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
65320	Patos Island Light, 1.4 nm west of (Depth 190.7ft), Washington Current	NOS	PUG1714_16	48.7731285095214	-123.005790710449	:America/Los_Angeles	USA	knots	225	40	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
65321	Patos Island Light, 1.4 nm west of (Depth 98.9ft), Washington Current	NOS	PUG1714_23	48.7731285095214	-123.005790710449	:America/Los_Angeles	USA	knots	215	44	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.469	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
65322	Patos Island Light, 1.4 nm west of (Depth 46.4ft), Washington Current	NOS	PUG1714_27	48.7731285095214	-123.005790710449	:America/Los_Angeles	USA	knots	209	45	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.443	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
65323	President Channel, east of Point Disney (Depth 200.2ft), Washington Current	NOS	PUG1715_28	48.6733512878418	-123.005989074707	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, east of Point Disney	WA
65324	President Channel, east of Point Disney (Depth 108.3ft), Washington Current	NOS	PUG1715_35	48.6733512878418	-123.005989074707	:America/Los_Angeles	USA	knots	219	39	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.369	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, east of Point Disney	WA
65325	President Channel, east of Point Disney (Depth 69ft), Washington Current	NOS	PUG1715_38	48.6733512878418	-123.005989074707	:America/Los_Angeles	USA	knots	218	37	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.502	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, east of Point Disney	WA
65326	Waldron Island, 1.7 nm west of (Depth 158.5ft), Washington Current	NOS	PUG1716_3	48.7042198181152	-123.104766845703	:America/Los_Angeles	USA	knots	232	28	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.328	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island, 1.7 nm west of	WA
65327	Waldron Island, 1.7 nm west of (Depth 92.8ft), Washington Current	NOS	PUG1716_13	48.7042198181152	-123.104766845703	:America/Los_Angeles	USA	knots	227	31	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island, 1.7 nm west of	WA
65328	Waldron Island, 1.7 nm west of (Depth 27.2ft), Washington Current	NOS	PUG1716_23	48.7042198181152	-123.104766845703	:America/Los_Angeles	USA	knots	252	325	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.22	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island, 1.7 nm west of	WA
65329	Turn Point, Boundary Pass (Depth 207.5ft), Washington Current	NOS	PUG1717_28	48.6912117004394	-123.245010375976	:America/Los_Angeles	USA	knots	232	358	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
65330	Turn Point, Boundary Pass (Depth 168.1ft), Washington Current	NOS	PUG1717_31	48.6912117004394	-123.245010375976	:America/Los_Angeles	USA	knots	235	359	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.393	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
65331	Turn Point, Boundary Pass (Depth 115.6ft), Washington Current	NOS	PUG1717_35	48.6912117004394	-123.245010375976	:America/Los_Angeles	USA	knots	236	3	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.297	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
65332	Haro Strait, 1.2 nm west of Kellett Bluff (Depth 204.2ft), Washington Current	NOS	PUG1718_29	48.5887184143066	-123.225830078125	:America/Los_Angeles	USA	knots	178	340	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
65333	Haro Strait, 1.2 nm west of Kellett Bluff (Depth 105.8ft), Washington Current	NOS	PUG1718_34	48.5887184143066	-123.225830078125	:America/Los_Angeles	USA	knots	179	345	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
65334	Haro Strait, 1.2 nm west of Kellett Bluff (Depth 66.4ft), Washington Current	NOS	PUG1718_36	48.5887184143066	-123.225830078125	:America/Los_Angeles	USA	knots	179	346	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.384	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
65335	Spieden Channel, north of Limestone Point (Depth 204.8ft), Washington Current	NOS	PUG1719_7	48.627830505371	-123.11164855957	:America/Los_Angeles	USA	knots	282	82	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
65336	Spieden Channel, north of Limestone Point (Depth 60.4ft), Washington Current	NOS	PUG1719_18	48.627830505371	-123.11164855957	:America/Los_Angeles	USA	knots	282	85	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.634	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
65337	Spieden Channel, north of Limestone Point (Depth 47.3ft), Washington Current	NOS	PUG1719_19	48.627830505371	-123.11164855957	:America/Los_Angeles	USA	knots	281	85	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.665	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
65338	Spring Passage, south entrance (Depth 62.3ft), Washington Current	NOS	PUG1720_11	48.6115417480468	-123.034103393554	:America/Los_Angeles	USA	knots	151	359	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
65339	Spring Passage, south entrance (Depth 26.2ft), Washington Current	NOS	PUG1720_22	48.6115417480468	-123.034103393554	:America/Los_Angeles	USA	knots	149	2	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
65340	Spring Passage, south entrance (Depth 13.1ft), Washington Current	NOS	PUG1720_26	48.6115417480468	-123.034103393554	:America/Los_Angeles	USA	knots	148	5	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
65341	Wasp Passage narrows (Depth 63.5ft), Washington Current	NOS	PUG1721_1	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65342	Wasp Passage narrows (Depth 60.2ft), Washington Current	NOS	PUG1721_2	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	66	264	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65343	Wasp Passage narrows (Depth 56.9ft), Washington Current	NOS	PUG1721_3	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65345	Wasp Passage narrows (Depth 50.3ft), Washington Current	NOS	PUG1721_5	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65346	Wasp Passage narrows (Depth 47ft), Washington Current	NOS	PUG1721_6	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65347	Wasp Passage narrows (Depth 43.8ft), Washington Current	NOS	PUG1721_7	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65348	Wasp Passage narrows (Depth 40.5ft), Washington Current	NOS	PUG1721_8	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65349	Wasp Passage narrows (Depth 37.2ft), Washington Current	NOS	PUG1721_9	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65350	Wasp Passage narrows (Depth 33.9ft), Washington Current	NOS	PUG1721_10	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65351	Wasp Passage narrows (Depth 30.6ft), Washington Current	NOS	PUG1721_11	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	62	259	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65352	Wasp Passage narrows (Depth 27.4ft), Washington Current	NOS	PUG1721_12	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65353	Wasp Passage narrows (Depth 24.1ft), Washington Current	NOS	PUG1721_13	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65354	Wasp Passage narrows (Depth 20.8ft), Washington Current	NOS	PUG1721_14	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65355	Wasp Passage narrows (Depth 17.5ft), Washington Current	NOS	PUG1721_15	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65356	Wasp Passage narrows (Depth 14.2ft), Washington Current	NOS	PUG1721_16	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65357	Wasp Passage narrows (Depth 11ft), Washington Current	NOS	PUG1721_17	48.5924682617187	-122.989570617675	:America/Los_Angeles	USA	knots	60	256	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
65358	Harney Channel, north of Point Hudson (Depth 98.5ft), Washington Current	NOS	PUG1722_1	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65359	Harney Channel, north of Point Hudson (Depth 95.2ft), Washington Current	NOS	PUG1722_2	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65360	Harney Channel, north of Point Hudson (Depth 91.9ft), Washington Current	NOS	PUG1722_3	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65361	Harney Channel, north of Point Hudson (Depth 88.6ft), Washington Current	NOS	PUG1722_4	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65362	Harney Channel, north of Point Hudson (Depth 85.3ft), Washington Current	NOS	PUG1722_5	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65363	Harney Channel, north of Point Hudson (Depth 82.1ft), Washington Current	NOS	PUG1722_6	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	72	267	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65364	Harney Channel, north of Point Hudson (Depth 78.8ft), Washington Current	NOS	PUG1722_7	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65365	Harney Channel, north of Point Hudson (Depth 75.5ft), Washington Current	NOS	PUG1722_8	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65366	Harney Channel, north of Point Hudson (Depth 72.2ft), Washington Current	NOS	PUG1722_9	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65367	Harney Channel, north of Point Hudson (Depth 68.9ft), Washington Current	NOS	PUG1722_10	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65368	Harney Channel, north of Point Hudson (Depth 65.6ft), Washington Current	NOS	PUG1722_11	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65369	Harney Channel, north of Point Hudson (Depth 62.4ft), Washington Current	NOS	PUG1722_12	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65370	Harney Channel, north of Point Hudson (Depth 59.1ft), Washington Current	NOS	PUG1722_13	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65371	Harney Channel, north of Point Hudson (Depth 55.8ft), Washington Current	NOS	PUG1722_14	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65372	Harney Channel, north of Point Hudson (Depth 52.5ft), Washington Current	NOS	PUG1722_15	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65373	Harney Channel, north of Point Hudson (Depth 49.2ft), Washington Current	NOS	PUG1722_16	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65374	Harney Channel, north of Point Hudson (Depth 46ft), Washington Current	NOS	PUG1722_17	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65375	Harney Channel, north of Point Hudson (Depth 42.7ft), Washington Current	NOS	PUG1722_18	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65376	Harney Channel, north of Point Hudson (Depth 39.4ft), Washington Current	NOS	PUG1722_19	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65377	Harney Channel, north of Point Hudson (Depth 36.1ft), Washington Current	NOS	PUG1722_20	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	78	265	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65378	Harney Channel, north of Point Hudson (Depth 32.8ft), Washington Current	NOS	PUG1722_21	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65379	Harney Channel, north of Point Hudson (Depth 29.6ft), Washington Current	NOS	PUG1722_22	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65380	Harney Channel, north of Point Hudson (Depth 26.3ft), Washington Current	NOS	PUG1722_23	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65381	Harney Channel, north of Point Hudson (Depth 23ft), Washington Current	NOS	PUG1722_24	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65382	Harney Channel, north of Point Hudson (Depth 19.7ft), Washington Current	NOS	PUG1722_25	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65383	Harney Channel, north of Point Hudson (Depth 16.4ft), Washington Current	NOS	PUG1722_26	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65384	Harney Channel, north of Point Hudson (Depth 13.2ft), Washington Current	NOS	PUG1722_27	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	78	263	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65385	Harney Channel, north of Point Hudson (Depth 9.9ft), Washington Current	NOS	PUG1722_28	48.5897216796875	-122.921730041503	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
65386	Upright Channel narrows (Depth 136ft), Washington Current	NOS	PUG1723_1	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65387	Upright Channel narrows (Depth 129.4ft), Washington Current	NOS	PUG1723_2	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65388	Upright Channel narrows (Depth 122.8ft), Washington Current	NOS	PUG1723_3	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65389	Upright Channel narrows (Depth 116.3ft), Washington Current	NOS	PUG1723_4	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65390	Upright Channel narrows (Depth 109.7ft), Washington Current	NOS	PUG1723_5	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65391	Upright Channel narrows (Depth 103.1ft), Washington Current	NOS	PUG1723_6	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65392	Upright Channel narrows (Depth 96.6ft), Washington Current	NOS	PUG1723_7	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	232	43	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65393	Upright Channel narrows (Depth 90ft), Washington Current	NOS	PUG1723_8	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.366	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65394	Upright Channel narrows (Depth 83.5ft), Washington Current	NOS	PUG1723_9	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.363	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65395	Upright Channel narrows (Depth 76.9ft), Washington Current	NOS	PUG1723_10	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.359	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65396	Upright Channel narrows (Depth 70.3ft), Washington Current	NOS	PUG1723_11	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65397	Upright Channel narrows (Depth 63.8ft), Washington Current	NOS	PUG1723_12	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65398	Upright Channel narrows (Depth 57.2ft), Washington Current	NOS	PUG1723_13	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	231	41	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65399	Upright Channel narrows (Depth 50.7ft), Washington Current	NOS	PUG1723_14	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.339	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65400	Upright Channel narrows (Depth 44.1ft), Washington Current	NOS	PUG1723_15	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65401	Upright Channel narrows (Depth 37.5ft), Washington Current	NOS	PUG1723_16	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65402	Upright Channel narrows (Depth 31ft), Washington Current	NOS	PUG1723_17	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65403	Upright Channel narrows (Depth 24.4ft), Washington Current	NOS	PUG1723_18	48.553840637207	-122.922622680664	:America/Los_Angeles	USA	knots	230	40	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
65404	South Haro Strait, south of Lime Kiln Light (Depth 211.8ft), Washington Current	NOS	PUG1724_27	48.4979705810546	-123.159896850585	:America/Los_Angeles	USA	knots	145	319	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
65405	South Haro Strait, south of Lime Kiln Light (Depth 159.4ft), Washington Current	NOS	PUG1724_29	48.4979705810546	-123.159896850585	:America/Los_Angeles	USA	knots	144	315	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
65406	South Haro Strait, south of Lime Kiln Light (Depth 106.9ft), Washington Current	NOS	PUG1724_31	48.4979705810546	-123.159896850585	:America/Los_Angeles	USA	knots	147	310	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
65407	Cherry Point, 1.8 nm southeast of (Depth 40.8ft), Washington Current	NOS	PUG1725_10	48.8337898254394	-122.727928161621	:America/Los_Angeles	USA	knots	167	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
65408	Cherry Point, 1.8 nm southeast of (Depth 24.4ft), Washington Current	NOS	PUG1725_20	48.8337898254394	-122.727928161621	:America/Los_Angeles	USA	knots	161	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
65409	Cherry Point, 1.8 nm southeast of (Depth 8ft), Washington Current	NOS	PUG1725_30	48.8337898254394	-122.727928161621	:America/Los_Angeles	USA	knots	156	346	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
65410	Strait of Georgia, 4.5 nm SW of Point Roberts (Depth 188.5ft), Washington Current	NOS	PUG1726_11	48.9388885498046	-123.165130615234	:America/Los_Angeles	USA	knots	107	313	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
65411	Strait of Georgia, 4.5 nm SW of Point Roberts (Depth 70.4ft), Washington Current	NOS	PUG1726_29	48.9388885498046	-123.165130615234	:America/Los_Angeles	USA	knots	120	326	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
65412	Strait of Georgia, 4.5 nm SW of Point Roberts (Depth 31ft), Washington Current	NOS	PUG1726_35	48.9388885498046	-123.165130615234	:America/Los_Angeles	USA	knots	129	332	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
65413	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of) (Depth 165ft), Washington Current	NOS	PUG1727_10	48.4124908447265	-122.740257263183	:America/Los_Angeles	USA	knots	174	24	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of)	WA
65414	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of) (Depth 46.9ft), Washington Current	NOS	PUG1727_28	48.4124908447265	-122.740257263183	:America/Los_Angeles	USA	knots	186	20	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of)	WA
65415	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of) (Depth 33.7ft), Washington Current	NOS	PUG1727_30	48.4124908447265	-122.740257263183	:America/Los_Angeles	USA	knots	186	21	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm E of (Lawson Reef, 1 nm NW of)	WA
65416	Point Colville, 1.4 nm east of (Depth 134.3ft), Washington Current	NOS	PUG1728_10	48.418098449707	-122.781196594238	:America/Los_Angeles	USA	knots	205	38	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
65417	Point Colville, 1.4 nm east of (Depth 55.5ft), Washington Current	NOS	PUG1728_22	48.418098449707	-122.781196594238	:America/Los_Angeles	USA	knots	207	41	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
65418	Point Colville, 1.4 nm east of (Depth 29.3ft), Washington Current	NOS	PUG1728_26	48.418098449707	-122.781196594238	:America/Los_Angeles	USA	knots	207	39	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
65419	Belle Rock Light, east of (Depth 114.7ft), Washington Current	NOS	PUG1729_7	48.4967918395996	-122.730796813964	:America/Los_Angeles	USA	knots	202	7	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
65420	Belle Rock Light, east of (Depth 62.2ft), Washington Current	NOS	PUG1729_15	48.4967918395996	-122.730796813964	:America/Los_Angeles	USA	knots	211	15	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.331	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
65421	Belle Rock Light, east of (Depth 22.8ft), Washington Current	NOS	PUG1729_21	48.4967918395996	-122.730796813964	:America/Los_Angeles	USA	knots	219	16	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.431	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
65422	Lopez Pass (Depth 57.9ft), Washington Current	NOS	PUG1730_4	48.4797401428222	-122.818908691406	:America/Los_Angeles	USA	knots	92	265	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
65423	Lopez Pass (Depth 35ft), Washington Current	NOS	PUG1730_11	48.4797401428222	-122.818908691406	:America/Los_Angeles	USA	knots	91	276	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
65424	Lopez Pass (Depth 15.3ft), Washington Current	NOS	PUG1730_17	48.4797401428222	-122.818908691406	:America/Los_Angeles	USA	knots	90	286	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
65425	Fauntleroy Point Light, east of (Depth 92.9ft), Washington Current	NOS	PUG1731_7	48.52158	-122.77066	:America/Los_Angeles	USA	knots	146	331	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
65426	Fauntleroy Point Light, east of (Depth 53.6ft), Washington Current	NOS	PUG1731_13	48.52158	-122.77066	:America/Los_Angeles	USA	knots	153	334	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.357	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
65427	Fauntleroy Point Light, east of (Depth 20.8ft), Washington Current	NOS	PUG1731_18	48.52158	-122.77066	:America/Los_Angeles	USA	knots	157	334	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.394	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
65428	Strawberry Island, west of (Depth 164.3ft), Washington Current	NOS	PUG1732_5	48.5609588623046	-122.754302978515	:America/Los_Angeles	USA	knots	156	348	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
65429	Strawberry Island, west of (Depth 46.2ft), Washington Current	NOS	PUG1732_23	48.5609588623046	-122.754302978515	:America/Los_Angeles	USA	knots	172	357	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.464	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
65430	Strawberry Island, west of (Depth 33.1ft), Washington Current	NOS	PUG1732_25	48.5609588623046	-122.754302978515	:America/Los_Angeles	USA	knots	174	356	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.463	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
65431	Thatcher Pass (Depth 146.1ft), Washington Current	NOS	PUG1733_4	48.5274314880371	-122.803970336914	:America/Los_Angeles	USA	knots	84	256	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.238	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
65432	Thatcher Pass (Depth 60.8ft), Washington Current	NOS	PUG1733_17	48.5274314880371	-122.803970336914	:America/Los_Angeles	USA	knots	90	255	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.386	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
65433	Thatcher Pass (Depth 28ft), Washington Current	NOS	PUG1733_22	48.5274314880371	-122.803970336914	:America/Los_Angeles	USA	knots	93	256	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
65434	Guemes Channel, west entrance (Depth 53.4ft), Washington Current	NOS	PUG1734_1	48.521240234375	-122.652183532714	:America/Los_Angeles	USA	knots	253	85	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, west entrance	WA
65435	Guemes Channel, west entrance (Depth 23.9ft), Washington Current	NOS	PUG1734_10	48.521240234375	-122.652183532714	:America/Los_Angeles	USA	knots	253	83	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, west entrance	WA
65436	Guemes Channel, west entrance (Depth 10.8ft), Washington Current	NOS	PUG1734_14	48.521240234375	-122.652183532714	:America/Los_Angeles	USA	knots	252	83	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.739	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, west entrance	WA
65437	Guemes Channel, east entrance (Depth 51.6ft), Washington Current	NOS	PUG1735_1	48.5276908874511	-122.606010437011	:America/Los_Angeles	USA	knots	253	75	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, east entrance	WA
65438	Guemes Channel, east entrance (Depth 25.4ft), Washington Current	NOS	PUG1735_9	48.5276908874511	-122.606010437011	:America/Los_Angeles	USA	knots	263	74	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, east entrance	WA
65439	Guemes Channel, east entrance (Depth 9ft), Washington Current	NOS	PUG1735_14	48.5276908874511	-122.606010437011	:America/Los_Angeles	USA	knots	268	75	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, east entrance	WA
65440	Saddle Bag Island Passage (Depth 238ft), Washington Current	NOS	PUG1736_1	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65441	Saddle Bag Island Passage (Depth 231.5ft), Washington Current	NOS	PUG1736_2	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65442	Saddle Bag Island Passage (Depth 224.9ft), Washington Current	NOS	PUG1736_3	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65443	Saddle Bag Island Passage (Depth 218.3ft), Washington Current	NOS	PUG1736_4	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.296	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65444	Saddle Bag Island Passage (Depth 211.8ft), Washington Current	NOS	PUG1736_5	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.283	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65445	Saddle Bag Island Passage (Depth 205.2ft), Washington Current	NOS	PUG1736_6	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65446	Saddle Bag Island Passage (Depth 198.7ft), Washington Current	NOS	PUG1736_7	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65447	Saddle Bag Island Passage (Depth 192.1ft), Washington Current	NOS	PUG1736_8	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.252	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65448	Saddle Bag Island Passage (Depth 185.5ft), Washington Current	NOS	PUG1736_9	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65449	Saddle Bag Island Passage (Depth 179ft), Washington Current	NOS	PUG1736_10	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65450	Saddle Bag Island Passage (Depth 172.4ft), Washington Current	NOS	PUG1736_11	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65451	Saddle Bag Island Passage (Depth 165.8ft), Washington Current	NOS	PUG1736_12	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65452	Saddle Bag Island Passage (Depth 159.3ft), Washington Current	NOS	PUG1736_13	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65453	Saddle Bag Island Passage (Depth 152.7ft), Washington Current	NOS	PUG1736_14	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.216	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65454	Saddle Bag Island Passage (Depth 146.2ft), Washington Current	NOS	PUG1736_15	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65455	Saddle Bag Island Passage (Depth 139.6ft), Washington Current	NOS	PUG1736_16	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65456	Saddle Bag Island Passage (Depth 133ft), Washington Current	NOS	PUG1736_17	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65457	Saddle Bag Island Passage (Depth 126.5ft), Washington Current	NOS	PUG1736_18	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65458	Saddle Bag Island Passage (Depth 119.9ft), Washington Current	NOS	PUG1736_19	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65459	Saddle Bag Island Passage (Depth 113.4ft), Washington Current	NOS	PUG1736_20	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65460	Saddle Bag Island Passage (Depth 106.8ft), Washington Current	NOS	PUG1736_21	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65461	Saddle Bag Island Passage (Depth 100.2ft), Washington Current	NOS	PUG1736_22	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65462	Saddle Bag Island Passage (Depth 93.7ft), Washington Current	NOS	PUG1736_23	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.167	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65463	Saddle Bag Island Passage (Depth 87.1ft), Washington Current	NOS	PUG1736_24	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	179	351	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65464	Saddle Bag Island Passage (Depth 80.5ft), Washington Current	NOS	PUG1736_25	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65465	Saddle Bag Island Passage (Depth 74ft), Washington Current	NOS	PUG1736_26	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65466	Saddle Bag Island Passage (Depth 67.4ft), Washington Current	NOS	PUG1736_27	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65467	Saddle Bag Island Passage (Depth 60.9ft), Washington Current	NOS	PUG1736_28	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65468	Saddle Bag Island Passage (Depth 54.3ft), Washington Current	NOS	PUG1736_29	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65469	Saddle Bag Island Passage (Depth 47.7ft), Washington Current	NOS	PUG1736_30	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	173	344	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65470	Saddle Bag Island Passage (Depth 41.2ft), Washington Current	NOS	PUG1736_31	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65471	Saddle Bag Island Passage (Depth 34.6ft), Washington Current	NOS	PUG1736_32	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.115	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65472	Saddle Bag Island Passage (Depth 28.1ft), Washington Current	NOS	PUG1736_33	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65473	Saddle Bag Island Passage (Depth 21.5ft), Washington Current	NOS	PUG1736_34	48.5359191894531	-122.563911437988	:America/Los_Angeles	USA	knots	166	342	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
65474	Allan Pass (Depth 92.9ft), Washington Current	NOS	PUG1737_1	48.47159	-122.69982	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
65475	Allan Pass (Depth 20.8ft), Washington Current	NOS	PUG1737_23	48.47159	-122.69982	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.495	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
65476	Allan Pass (Depth 10.9ft), Washington Current	NOS	PUG1737_26	48.47159	-122.69982	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.475	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
65477	Burrows Pass (Depth 100.4ft), Washington Current	NOS	PUG1738_1	48.48952	-122.68672	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.465	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
65478	Burrows Pass (Depth 28.2ft), Washington Current	NOS	PUG1738_23	48.48952	-122.68672	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
65479	Burrows Pass (Depth 15.1ft), Washington Current	NOS	PUG1738_27	48.48952	-122.68672	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.423	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
65480	Bellingham Channel South (Depth 117.8ft), Washington Current	NOS	PUG1739_1	48.53963	-122.68343	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
65481	Bellingham Channel South (Depth 32.5ft), Washington Current	NOS	PUG1739_27	48.53963	-122.68343	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
65482	Bellingham Channel South (Depth 19.4ft), Washington Current	NOS	PUG1739_31	48.53963	-122.68343	:America/Los_Angeles	USA	knots	\N	\N	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.381	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
65483	Bellingham Channel, off Cypress Head Light (Depth 119.2ft), Washington Current	NOS	PUG1740_10	48.5585403442382	-122.661758422851	:America/Los_Angeles	USA	knots	194	17	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.302	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
65484	Bellingham Channel, off Cypress Head Light (Depth 50.3ft), Washington Current	NOS	PUG1740_17	48.5585403442382	-122.661758422851	:America/Los_Angeles	USA	knots	191	18	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.457	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
65485	Bellingham Channel, off Cypress Head Light (Depth 30.6ft), Washington Current	NOS	PUG1740_19	48.5585403442382	-122.661758422851	:America/Los_Angeles	USA	knots	190	20	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.484	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
65486	Bellingham Channel North (Depth 171.2ft), Washington Current	NOS	PUG1741_5	48.5928115844726	-122.657676696777	:America/Los_Angeles	USA	knots	212	10	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North	WA
65487	Bellingham Channel North (Depth 46.5ft), Washington Current	NOS	PUG1741_24	48.5928115844726	-122.657676696777	:America/Los_Angeles	USA	knots	228	9	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North	WA
65488	Bellingham Channel North (Depth 26.8ft), Washington Current	NOS	PUG1741_27	48.5928115844726	-122.657676696777	:America/Los_Angeles	USA	knots	230	8	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North	WA
65489	Cattle Point, 1.2 nm SE of (Depth 117.4ft), Washington Current	NOS	PUG1742_15	48.4343681335449	-122.94660949707	:America/Los_Angeles	USA	knots	186	346	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
65490	Cattle Point, 1.2 nm SE of (Depth 78ft), Washington Current	NOS	PUG1742_18	48.4343681335449	-122.94660949707	:America/Los_Angeles	USA	knots	183	353	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
65491	Cattle Point, 1.2 nm SE of (Depth 38.6ft), Washington Current	NOS	PUG1742_21	48.4343681335449	-122.94660949707	:America/Los_Angeles	USA	knots	183	2	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
65492	Cattle Point, 4.6 nm SW of (Depth 186.6ft), Washington Current	NOS	PUG1743_14	48.3840103149414	-123.015670776367	:America/Los_Angeles	USA	knots	179	47	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
65493	Cattle Point, 4.6 nm SW of (Depth 104.6ft), Washington Current	NOS	PUG1743_19	48.3840103149414	-123.015670776367	:America/Los_Angeles	USA	knots	227	63	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
65494	Cattle Point, 4.6 nm SW of (Depth 55.4ft), Washington Current	NOS	PUG1743_22	48.3840103149414	-123.015670776367	:America/Los_Angeles	USA	knots	228	54	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.143	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
65495	Discovery Island, 3.0 nm NE of (Depth 159.5ft), Washington Current	NOS	PUG1744_13	48.4520683288574	-123.155441284179	:America/Los_Angeles	USA	knots	153	16	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.322	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
65496	Discovery Island, 3.0 nm NE of (Depth 67.7ft), Washington Current	NOS	PUG1744_20	48.4520683288574	-123.155441284179	:America/Los_Angeles	USA	knots	157	19	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
65497	Discovery Island, 3.0 nm NE of (Depth 41.4ft), Washington Current	NOS	PUG1744_22	48.4520683288574	-123.155441284179	:America/Los_Angeles	USA	knots	160	17	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
65498	Point George, west of (Depth 282.6ft), Washington Current	NOS	PUG1745_10	48.5567092895507	-122.998481750488	:America/Los_Angeles	USA	knots	139	327	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
65499	Point George, west of (Depth 118.5ft), Washington Current	NOS	PUG1745_20	48.5567092895507	-122.998481750488	:America/Los_Angeles	USA	knots	155	318	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
65500	Point George, west of (Depth 52.9ft), Washington Current	NOS	PUG1745_24	48.5567092895507	-122.998481750488	:America/Los_Angeles	USA	knots	152	321	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
65501	Pear Point, east of (Depth 111.7ft), Washington Current	NOS	PUG1746_4	48.5113983154296	-122.952903747558	:America/Los_Angeles	USA	knots	203	30	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
65502	Pear Point, east of (Depth 59.2ft), Washington Current	NOS	PUG1746_8	48.5113983154296	-122.952903747558	:America/Los_Angeles	USA	knots	196	29	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.247	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
65503	Pear Point, east of (Depth 32.9ft), Washington Current	NOS	PUG1746_10	48.5113983154296	-122.952903747558	:America/Los_Angeles	USA	knots	192	22	\N	\N	\N	NOS PugetHarmonicConstituents.xlsx via Charles Douglass 2019-06-11	Public domain	2019-06-20	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	-08:00:00	\N	-0.291	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
\.



SELECT pg_catalog.setval('public.data_sets_index_seq', 69970, true);



ALTER TABLE ONLY public.aliases
    ADD CONSTRAINT aliases_pkey PRIMARY KEY (format, alias);



ALTER TABLE ONLY public.constants
    ADD CONSTRAINT constants_pkey PRIMARY KEY (index, name);



ALTER TABLE ONLY public.constituents
    ADD CONSTRAINT constituents_pkey PRIMARY KEY (name);



ALTER TABLE ONLY public.data_sets
    ADD CONSTRAINT data_sets_pkey PRIMARY KEY (index);



ALTER TABLE ONLY public.aliases
    ADD CONSTRAINT aliases_name_fkey FOREIGN KEY (name) REFERENCES public.constituents(name);



ALTER TABLE ONLY public.constants
    ADD CONSTRAINT constants_index_fkey FOREIGN KEY (index) REFERENCES public.data_sets(index) ON DELETE CASCADE;



ALTER TABLE ONLY public.constants
    ADD CONSTRAINT constants_name_fkey FOREIGN KEY (name) REFERENCES public.constituents(name);



ALTER TABLE ONLY public.data_sets
    ADD CONSTRAINT data_sets_ref_index_fkey FOREIGN KEY (ref_index) REFERENCES public.data_sets(index);



